#### SEC Financial Reporting Series

# **2024 SEC** **annual reports —** **Form 10-K**

The better the question. The better the answer.
The better the world works.


---

### **Contents**

**1** **Overview ................................................................................................................... 1**

1.1 Section highlights .................................................................................................................. 2
1.2 EY publications and checklists ................................................................................................ 2
1.3 Other considerations in preparing Form 10-K .......................................................................... 3

**2** **General rules ............................................................................................................. 5**

2.1 When the report is due ........................................................................................................... 6
2.1.1 Large accelerated filer determination ............................................................................. 6
2.1.2 Accelerated filer determination ...................................................................................... 7
2.1.3 Non-accelerated filer determination ............................................................................... 8
2.1.3A Filer status summary ..................................................................................................... 8
2.1.4 Exit provisions .............................................................................................................. 9
2.1.5 Transition between accelerated and SRC status and requirement for
auditor attestation of ICFR ........................................................................................... 10
2.1.6 Acceleration status after IPO ....................................................................................... 11
2.1.7 Financial schedules ..................................................................................................... 11
2.1.8 Part III information ...................................................................................................... 11
2.1.9 Financial statements of significant equity investees ...................................................... 11
2.1.10 Initial Form 10-K filing due date for registrants ............................................................. 12
2.1.11 Initial Form 10-K filing due date for Regulation A issuers ............................................... 12
2.2 Electronic filing using EDGAR ............................................................................................... 12
2.3 XBRL .................................................................................................................................. 13
2.3.1 Background ................................................................................................................ 13
2.3.2 SEC’s requirement for interactive data (XBRL) .............................................................. 13
2.3.2.1 Inline XBRL filing of tagged data ................................................................. 13
2.3.2.2 SEC observations ...................................................................................... 13
2.3.2.3 Disclosure controls and procedures considerations ...................................... 14
2.3.2.4 Internal control over financial reporting ...................................................... 14
2.3.2.5 Consequences of noncompliance ................................................................ 14
2.3.2.6 Liability considerations .............................................................................. 14
2.3.2.7 SEC form cover page requirements ............................................................ 15
2.3.2.8 AICPA attestation guidance ....................................................................... 15
2.3.3 Taxonomies ................................................................................................................ 15
2.4 Signatures and director involvement ..................................................................................... 15
2.5 Section 906 management certifications ................................................................................ 17
2.6 Transmittal letter ................................................................................................................. 17
2.7 Content of the report ........................................................................................................... 17
2.8 Wholly owned subsidiaries .................................................................................................... 19
2.9 Combined periodic reporting ................................................................................................ 20
2.9.1 Parent and subsidiary .................................................................................................. 20
2.9.2 Multiple series registrants ............................................................................................ 21


**2024 SEC annual reports — Form 10-K** | i


---

Contents


2.10 Incorporation by reference ................................................................................................... 21

2.10.1 Cross-referencing and location of financial statement disclosures .................................. 22
2.11 Integrated reports ............................................................................................................... 22
2.12 Summary annual reports ...................................................................................................... 23
2.13 Amendments and comprehensive annual reports .................................................................. 23

2.13.1 Amendments .............................................................................................................. 23
2.13.2 Comprehensive annual reports .................................................................................... 24
2.13.3 Clawbacks .................................................................................................................. 25
2.14 Forward-looking information ................................................................................................ 25
2.15 Non-GAAP financial measures .............................................................................................. 26

2.15.1 Definition .................................................................................................................... 26
2.15.2 Conditions for presentation ......................................................................................... 26
2.16 Transition report — change in fiscal year ................................................................................ 28

2.16.1 Transition reporting on Forms 10-K and 10-Q ............................................................... 28
2.16.2 Transition period of six months or more ....................................................................... 28
2.16.3 Transition period less than six months .......................................................................... 29
2.16.4 Reporting prior to the determination date .................................................................... 30
2.16.5 Quarterly reporting during transition ............................................................................ 30
2.16.6 Quarterly reporting after transition .............................................................................. 31
2.16.7 Reporting fiscal year changes on Form 8-K ................................................................... 31
2.16.8 Transition reporting for successor issuers .................................................................... 31
2.16.9 MD&A for transition periods ......................................................................................... 31
2.16.10 Examples of reporting requirements for changes in year-end ........................................ 32

**3** **Part I of Form 10-K .................................................................................................. 37**

3.1 Item 1. Business .................................................................................................................. 37
3.2 Other business-related disclosures ........................................................................................ 38
3.2.1 Effect of compliance with government regulations ........................................................ 38
3.2.2 Human capital resources ............................................................................................. 38
3.2.3 Website access disclosure ............................................................................................ 39
3.3 Item 1A. Risk factors ............................................................................................................ 39
3.4 Item 1B. Unresolved staff comments .................................................................................... 40
3.5 Item 1C. Cybersecurity ......................................................................................................... 41
3.5.1 Risk management and strategy .................................................................................... 41
3.5.2 Governance ................................................................................................................ 41
3.6 Item 2. Properties ................................................................................................................ 42
3.7 Item 3. Legal proceedings .................................................................................................... 42
3.7.1 Disclosure of certain tax penalties ................................................................................ 43
3.8 Item 4. Mine safety disclosures ............................................................................................. 43

**4** **Part II of Form 10-K ................................................................................................. 45**

4.1 Item 5. Market for registrant’s common equity, related stockholder matters and
issuer purchases of equity securities ..................................................................................... 45
4.2 Securities authorized for issuance under equity compensation plans ...................................... 46
4.2.1 Stock performance graph ............................................................................................ 46
4.2.2 Recent sales of unregistered securities; use of proceeds from registered securities ........ 47
4.2.3 Purchases of equity securities by the issuer and affiliated purchasers ............................ 48
4.3 Item 7A. Quantitative and qualitative disclosures about market risk ........................................ 48


**2024 SEC annual reports — Form 10-K** | ii


---

Contents


4.4 Item 8. Financial statements and supplementary data ............................................................ 50
4.4.1 Interim financial information ........................................................................................ 50
4.4.2 Information about oil and gas producing activities ......................................................... 52
4.5 Item 9. Changes in and disagreements with accountants on accounting and
financial disclosure .............................................................................................................. 52
4.6 Item 9A. Controls and procedures......................................................................................... 53
4.6.1 Item 307 Disclosure controls and procedures ............................................................... 53
4.6.2 Item 308 (a) & (b) Internal control over financial reporting ............................................ 55
4.6.3 Item 308(c) Changes in internal control over financial reporting .................................... 60
4.6.3.1 Exhibit 31 Management’s Section 302 certification ...................................... 61
4.7 Item 9B. Other information .................................................................................................. 61
4.7.1 Items required to be disclosed in Form 8-K ............................................................................ 61
4.7.2 Insider trading arrangements and policies ............................................................................. 62
4.8 Item 9C. Disclosure regarding foreign jurisdictions that prevent inspections ............................ 62

**5** **Item 7. Management’s discussion and analysis (MD&A) .............................................. 63**

5.1 Overview ............................................................................................................................. 63
5.2 Overall presentation of MD&A ............................................................................................... 64
5.2.1 Executive-level overview ............................................................................................. 64
5.2.2 Clarity, understandability and organization ................................................................... 64
5.2.3 Emphasis on material information ................................................................................ 65
5.2.4 Key performance indicators ......................................................................................... 65
5.2.5 Segment analysis ........................................................................................................ 66
5.2.6 Material changes ......................................................................................................... 68
5.3 Results of operations ........................................................................................................... 68
5.3.1 Effects of macroeconomic factors ................................................................................ 69
5.3.2 Climate change ........................................................................................................... 69
5.3.3 Cybersecurity ............................................................................................................. 71
5.3.4 Pro forma MD&A ......................................................................................................... 72
5.4 Liquidity and capital resources ............................................................................................. 72
5.5 Off-balance sheet arrangements ........................................................................................... 77
5.6 Known trends, events, demands, commitments and uncertainties .......................................... 78
5.6.1 Sovereign debt exposures ........................................................................................... 79
5.7 Critical accounting policies and estimates .............................................................................. 80
5.7.1 Impairment of goodwill ................................................................................................ 82
5.7.2 Income taxes .............................................................................................................. 83
5.7.3 Investments (including high-yield, highly leveraged transactions) ................................... 85
5.7.4 Emerging growth company disclosures ........................................................................ 85
5.8 Other disclosures ................................................................................................................. 85
5.8.1 Accounting estimate and policy changes (including pending adoption of
new accounting standards) .......................................................................................... 85
5.8.2 Discontinued operations .............................................................................................. 87
5.8.3 Foreign operations ...................................................................................................... 87
5.8.4 Loss contingencies (including environmental and product liabilities)............................... 88
5.8.5 Restructuring charges ................................................................................................. 89
5.8.6 Transactions with related and certain other parties ....................................................... 90
5.8.7 Miscellaneous ............................................................................................................. 90


**2024 SEC annual reports — Form 10-K** | iii


---

Contents


**6** **Financial statements and parent company information ............................................... 92**

6.1 General ............................................................................................................................... 92
6.2 Consolidated financial statements......................................................................................... 93
6.3 Restrictions on net assets ..................................................................................................... 93
6.3.1 Disclosure in the notes to the consolidated financial statements .................................... 93
6.3.2 Condensed parent company financial statements ......................................................... 94
6.3.3 Definition of restricted net assets ................................................................................. 94
6.3.4 Computing the restricted net assets of subsidiaries ....................................................... 96
6.3.5 Examples of computing restricted net assets ................................................................ 97
6.3.6 Disclosure in the notes to the financial statements ........................................................ 99
6.4 Equity method investees .................................................................................................... 100
6.4.1 Separate financial statements .................................................................................... 100
6.4.2 Summarized financial information .............................................................................. 101
6.4.3 Example of the summarized financial information ....................................................... 103
6.4.4 Significant subsidiary definition .................................................................................. 103
6.4.4.1 Rule 3-09 considerations ......................................................................... 106
6.4.5 Example ................................................................................................................... 108
6.5 Preparing separate financial information of subsidiaries ....................................................... 109
6.5.1 Pushdown accounting ............................................................................................... 109
6.5.2 Allocation of expenses ............................................................................................... 109
6.6 Subsidiary guarantors or subsidiary issuers of guaranteed securities .................................... 110
6.7 Affiliates whose securities collateralize the registrant’s securities ......................................... 111
6.8 Regulation S-X waiver requests .......................................................................................... 112

**7** **Financial schedules ................................................................................................ 113**

7.1 Filing requirements ............................................................................................................ 113
7.2 Schedule I — Condensed financial information of registrant................................................... 114
7.3 Schedule II — Valuation and qualifying accounts ................................................................... 118
7.4 Schedule III — Real estate and accumulated depreciation ...................................................... 120
7.5 Schedule IV — Mortgage loans on real estate ....................................................................... 122
7.6 Schedule V — Supplemental information concerning property-casualty
insurance operations.......................................................................................................... 124

**8** **Notification of late filing ......................................................................................... 127**

8.1 Importance of timely filing .................................................................................................. 127
8.2 Other possible consequences of late filing ........................................................................... 128
8.3 Rule 12b-25 and Form 12b-25 ........................................................................................... 128
8.4 Portions of Form 10-K due following the filing date .............................................................. 129
8.5 Involvement of independent auditors .................................................................................. 130
8.6 Complete and accurate statements ..................................................................................... 130

**9** **Smaller reporting companies (SRCs) ....................................................................... 131**

9.1 SRC rules .......................................................................................................................... 131
9.2 Definition of a ‘smaller reporting company’.......................................................................... 131
9.2.1 Annual redeterminations ........................................................................................... 131
9.2.2 Implications of changes in SRC status ......................................................................... 133
9.2.3 Interaction between SRC status and accelerated filer status ........................................ 133
9.3 Form 10-K filing by an SRC ................................................................................................. 134
9.3.1 Content .................................................................................................................... 134


**2024 SEC annual reports — Form 10-K** | iv


---

Contents


9.3.2 Item 101. Description of business .............................................................................. 135
9.3.3 Item 201. Common equity and related stockholder matters ........................................ 136
9.3.4 Item 303. MD&A ....................................................................................................... 136
9.3.5 Item 305. Market risk disclosures ............................................................................... 137
9.3.6 Financial information of SRCs .................................................................................... 137
9.3.6.1 Financial Information of the SRC registrant ............................................... 137
9.3.6.2 Financial statements of other entities ....................................................... 137

**10** **Annual shareholders’ report, Part III of Form 10-K and proxy statement ................... 139**

10.1 Annual shareholders’ report ............................................................................................... 139

10.1.1 Stock performance graph .......................................................................................... 140
10.2 Part III of Form 10-K .......................................................................................................... 142
10.3 Part IV of Form 10-K .......................................................................................................... 142

10.3.1 Confidential information in exhibits ............................................................................ 143
10.4 Incorporation by reference of proxy material ....................................................................... 143

10.4.1 Item 10. Executive officers ........................................................................................ 144
10.4.2 Item 10. Audit committee financial experts ................................................................ 144
10.4.3 Item 10. Code of ethics ............................................................................................. 144
10.4.4 Item 10. Shareholder nominating procedures ............................................................. 145
10.4.5 Item 12. Authorized equity compensation .................................................................. 145

**A** **Common questions domestic 10-K filers ask ............................................................. A-1**

**B** **Abbreviations ......................................................................................................... B-1**


**2024 SEC annual reports — Form 10-K** | v


---

### **1 Overview**

We are pleased to present our _SEC Annual Reports — Form 10-K_ reference guide to help you prepare your
financial and related information for annual reports on Form 10-K and annual shareholders’ reports.


The Securities Exchange Act of 1934 (Exchange Act or 1934 Act) requires most publicly held companies
to file an annual report with the Securities and Exchange Commission (SEC or Commission) on Form 10-K
and to distribute an annual shareholders’ report under the SEC’s proxy rules. Both Form 10-K and the
annual shareholders’ report include financial statements and other data that involve a company’s accounting
personnel and its independent auditors.


The SEC’s integrated disclosure system is designed so the instructions in the forms under the Securities
Act of 1933 (Securities Act or 1933 Act) and the 1934 Act refer to Regulation S-X for financial statement
disclosures and Regulation S-K for the required nonfinancial statement disclosures. By standardizing
disclosure items in SEC filings, companies can incorporate information from one document into subsequently
filed documents.


For example, disclosures in the Annual Report to Shareholders (ARS) or definitive proxy statement can be
incorporated into a Form 10-K, and the Form 10-K can be incorporated into 1933 Act filings such as
Forms S-1, S-3, S-4 or S-8, subject to the eligibility requirements of these forms. Also, for continuous or
delayed securities offerings, reporting documents filed under the 1934 Act after the initial effective date
of a Form S-3 or S-8 are automatically incorporated by reference into these registration statements until
the securities offering is terminated.


This publication describes the SEC’s requirements for the content of Form 10-K and annual shareholders’
reports as of 5 December 2024 and reflects the following SEC releases that were expected to become
effective in 2024, but did not:


            - **Releases 34-99778** and **IC-35157**, _Share Repurchase Disclosure Modernization_ : In May 2023, the SEC
amended rules regarding share repurchase disclosures. In December 2023, the US Court of Appeals for
the Fifth Circuit vacated these rules, which would have required registrants to disclose daily quantitative
share repurchase information on a quarterly basis, among other information. In April 2024, the SEC
adopted technical amendments to various rules and forms under the Exchange Act to reflect the court’s
vacatur of the amended share repurchase disclosure rules. As a result, registrants should continue to
follow the repurchase disclosure requirements in Item 703 of Regulation S-K described in section 4.2.3
of this publication.


            - **Releases 33-11275** and **34-99678**, _The Enhancement and Standardization of Climate-Related_
_Disclosures for Investors_ : In March 2024, the SEC adopted final rules requiring registrants to disclose
climate-related information in registration statements and annual reports. Following the adoption of
the rules, several lawsuits were filed challenging them, and the SEC issued an order on 4 April 2024 to
stay the rules pending the judicial review by the Eighth Circuit Court of Appeals of the consolidated
challenges. Absent the stay, the rules would have been effective 28 May 2024 and phased in starting
in 2025, depending on the registrant’s filer status and the type of disclosure. This publication does
not describe the requirements of these rules as, due to the stay, they did not become effective in 2024
and do not apply to 2024 annual reports on Form 10-K. Companies should continue to consider the


**2024 SEC annual reports — Form 10-K** | 1


---

1 Overview


Commission’s 2010 interpretive guidance [1] and the September 2021 **[sample comment letter](https://www.sec.gov/rules-regulations/staff-guidance/disclosure-guidance/sample-letter-companies-regarding-climate)**
regardless of the status of the new rules and whether they are adopted. For additional information
about the rules, as adopted, refer to our Technical Line publication, _**[A closer look at the SEC’s climate-](https://www.ey.com/en_us/technical/accountinglink/technical-line-a-closer-look-at-the-secs-climate-related-disclosure-requirements)**_
_**[related disclosure requirements](https://www.ey.com/en_us/technical/accountinglink/technical-line-a-closer-look-at-the-secs-climate-related-disclosure-requirements)**_ .


When preparing reports on Form 10-K and annual shareholders’ reports, readers of this publication should
consider applicable changes to SEC reporting requirements in final rules issued after 5 December 2024.

##### 1.1 Section highlights


The following is an overview of the sections in this publication:


            - Section 2 explains the general rules and requirements for preparing and filing Form 10-K.


            - Sections 3, 4 and 5 discuss the requirements for Part I and Part II of Form 10-K, other than financial
statements and schedules.


            - Sections 6 and 7 discuss the requirements for financial statements and schedules.


            - Section 8 covers late filings.


            - Section 9 discusses the requirements for “smaller reporting companies.”


            - Section 10 discusses the annual shareholders’ report, the proxy statement and Part III and Part IV of
Form 10-K.

##### 1.2 EY publications and checklists


EY publications provide interpretive guidance for preparing various SEC forms and schedules. These
publications are available free of charge from any EY representative or on the EY **[AccountingLink website](https://www.ey.com/en_us/technical/accountinglink)** .


            - _SEC Reporting Update — Highlights of trends in SEC comment letters_ discusses the SEC staff’s
comments on public company filings to provide insights on the SEC staff’s concerns and areas of focus.


            - _Proxy statements — An overview of the requirements and observations about current practice_
summarizes the requirements of Regulation 14A and Schedule 14A under the Exchange Act for
soliciting annual meeting and other proxies. This publication includes an overview of the disclosure
requirements regarding executive compensation, auditor fees and the audit, and compensation and
nominating committees.


            - _SEC quarterly reports — Form 10-Q_ summarizes the rules and practices that apply to quarterly
financial accounting and reporting on Form 10-Q. It provides guidance for preparing quarterly
reports to shareholders and Form 10-Q.


            - _Pro forma financial information — A guide for applying Article 11 of Regulation S-X_ summarizes the
requirements for pro forma financial information and illustrates how registrants may apply the
guidance to different transactions and pro forma adjustments.


            - _SEC in Focus_ is a quarterly newsletter summarizing current activities and regulatory developments at
the SEC. The newsletter provides an update on certain activities and events relating to SEC matters,
including Commission open meetings, final rules and rule proposals, SEC staff areas of focus,
SEC personnel changes and SEC enforcement actions.


1 FRR-82 (SEC Release No. 33-9106), _Commission Guidance Regarding Disclosure Related to Climate Change_ .


**2024 SEC annual reports — Form 10-K** | 2


---

1 Overview


            - _Financial reporting briefs_ provides a snapshot of the major accounting and regulatory developments
during the quarter. It includes a reference library that lists the EY publications issued during the
quarter, along with the links to them on our EY **[AccountingLink website](https://www.ey.com/en_us/technical/accountinglink)** .


The following is a list of EY checklists intended to assist registrants in preparing Form 10-K and annual
shareholders’ reports:


            - _GAAP disclosure checklist_            - assists in determining that the financial statement disclosure requirements
of generally accepted accounting principles and Regulation S-X have been satisfied (EY Form A13)


            - _GAAP disclosure checklist supplement for health care entities_            - contains the disclosures required by
Accounting Standards Codification (ASC) 954 (EY Form A68)


            - _Form 10-K and registration statement checklist_ _supplement to GAAP disclosure checklist —_ Parts I
and II of the checklist assist in determining that the Form 10-K requirements relating to financial
statements and financial schedules have been satisfied (EY Form A69)


            - _GAAP and Regulation S-X checklist supplement for insurance companies_            - includes the disclosures
required by ASC 944 and Article 7 of Regulation S-X (EY Form A69B)


            - _GAAP and Regulation S-X checklist supplement for banks, bank holding companies and savings_
_institutions_              - includes disclosures required by ASC 942, ASC 948 and Article 9 of Regulation S-X
and summarizes disclosures required by Regulation S-K Subpart 1400 (EY Form A69C)


            - _GAAP, Regulation S-X and Regulation S-K checklist supplement for oil and gas producing companies_            includes the disclosures required by ASC 932 and Regulation S-X and Regulation S-K Subpart 1200,
Disclosure by Registrants Engaged in Oil and Gas Producing Activities (EY Form A69E)


            - _SEC annual shareholders’ report checklist —_ assists in determining whether certain nonfinancial
statement disclosures required by Rule 14a-3 for the annual shareholders’ report (many of which are
identical to those of Form 10-K) have been satisfied. Parts I, II and III of the checklist address those
requirements, and Part IV assists in the preparation of non-GAAP disclosures in the annual
shareholders’ report (EY Form A150).

##### 1.3 Other considerations in preparing Form 10-K


This publication is not a substitute for reading the Form 10-K instructions and the referenced disclosure
requirements in Regulations S-K and S-X. In addition, the views of the SEC and its staff should be considered.
We note that SEC staff views are non-binding and, unlike SEC rules and regulations, do not have the force
and effect of law. However, registrants are generally expected to comply with the SEC staff’s views.


Registrants should consider the following Commission rules, interpretive guidance and SEC staff
interpretive guidance:


            - Regulation S-K contains the requirements for nonfinancial statement disclosures.


            - Regulation S-X provides the requirements for financial statements and schedules.


            - Staff Accounting Bulletins (SABs) are written accounting interpretations and practices followed by the
SEC’s Division of Corporation Finance (DCF) and the Office of the Chief Accountant (OCA).


            - Staff Legal Bulletins (SLBs) are written interpretations of the requirements of the federal securities
laws or related rules and regulations published by the SEC’s legal staff.


**2024 SEC annual reports — Form 10-K** | 3


---

1 Overview


- The DCF’s Financial Reporting Manual (FRM) [2] provides views on financial reporting matters from the
staff at the DCF’s Office of the Chief Accountant.


- The DCF’s Compliance and Disclosure Interpretations (C&DIs) are staff interpretations and positions by
the SEC’s DCF on various rules and regulations, including certain content required in the Form 10-K.
They are published primarily by the Division’s Office of Chief Counsel.


- CF Disclosure Guidance Topics and sample comment letters provide observations and views expressed
by the staff of the DCF about disclosures required by existing SEC rules and regulations.


- The highlights of meetings the Center for Audit Quality (CAQ) SEC Regulations Committee holds
periodically with the SEC staff describe the staff’s views on emerging financial reporting issues
relating to SEC rules and regulations and can be found on the CAQ website. [3]


- A Financial Reporting Release (FRR) sometimes addresses revisions to Regulations S-K and S-X. The
Codification of Financial Reporting Policies (FRC) contains the current interpretive guidance provided
by the SEC relating to financial reporting as published in an Accounting Series Release (ASR), and
more recently, in an FRR.


The rules and regulations for financial reporting are complex. Any materially inaccurate or incomplete
information in Form 10-K can expose a company and its directors, officers and independent auditors to liability
under the federal securities laws. Additionally, as discussed in section 2 of this publication, Section 906 of the
Sarbanes-Oxley Act of 2002 (the Sarbanes-Oxley Act) requires the chief executive officer (CEO) and chief
financial officer (CFO) to provide a certification accompanying each periodic report, stating, among other things,
that the report “fully complies” with the requirements of Section 13(a) or 15(d) of the Securities Exchange Act of
1934. Section 906 provides for criminal penalties for an officer who provides the certification “knowing” it to be
untrue, of up to a $1 million fine and imprisonment of 10 years (with harsher penalties for “willful” violations).


In certain situations, it may be appropriate to consult on complex accounting issues with the SEC staff.
The SEC staff has a formal process to discuss proposed accounting treatments with registrants and their
independent auditors for unusual, complex or innovative transactions for which no clear authoritative
guidance exists. The SEC website provides guidelines for consultations with the SEC staff of the OCA,
titled “Form of Delivery and Content of Correspondence for OCA Consultations.” [4] Separately, registrants
can discuss financial reporting and legal matters with DCF staff and can seek relief from SEC financial
reporting requirements under Rule 3-13 of Regulation S-X. [5]


2 The FRM can be found at the following link: **[http://www.sec.gov/divisions/corpfin/cffinancialreportingmanual.shtml](http://www.sec.gov/divisions/corpfin/cffinancialreportingmanual.shtml)** .

3 The CAQ SEC Regulations Committee highlights can be found on the CAQ website at **[https://www.thecaq.org/resource-](https://www.thecaq.org/resource-hub?s%5BrefinementList%5D%5Btaxonomies.committee%5D%5B0%5D=SEC%20Meeting%20Notes)**

**[hub?s%5BrefinementList%5D%5Btaxonomies.committee%5D%5B0%5D=SEC%20Meeting%20Notes](https://www.thecaq.org/resource-hub?s%5BrefinementList%5D%5Btaxonomies.committee%5D%5B0%5D=SEC%20Meeting%20Notes)** .

4 This guidance can be found at the following link: **[https://www.sec.gov/about/divisions-offices/office-chief-accountant/form-](https://www.sec.gov/about/divisions-offices/office-chief-accountant/form-delivery-content-correspondence-consultations)**

**[delivery-content-correspondence-consultations](https://www.sec.gov/about/divisions-offices/office-chief-accountant/form-delivery-content-correspondence-consultations)** .

5 Requests for interpretation or pre-clearance of complex or unusual financial reporting positions can be submitted to the staff of

the OCA at the DCF by completing the online form _Requests for No-Action, Interpretive, Exemptive, and Waiver Letters_ at
**[https://www.sec.gov/forms/corp_fin_noaction?#no-back](https://www.sec.gov/forms/corp_fin_noaction?#no-back)** .


**2024 SEC annual reports — Form 10-K** | 4


---

### **2 General rules**

Three types of companies are required to file annual reports with the SEC pursuant to Sections 13(a) or
15(d) of the Exchange Act:


            - A company having any class of securities listed on a national securities exchange must register these
securities on Form 8A or Form 10 pursuant to Section 12(b) of the Exchange Act and must file
annual reports on Form 10-K as long as such registration continues in effect.


            - An unlisted company with more than $10 million of assets and 2,000 [6] or more holders (or 500 holders
who are not accredited investors) of any class of equity securities [7] must register these securities on
Form 10 according to Section 12(g) of the Exchange Act and must file annual reports on Form 10-K.
For banks, bank holding companies and savings and loan holding companies, the 2,000 holder threshold
is without regard to whether the investors are accredited. These annual reporting requirements
continue until the SEC receives notification on Form 15 that (1) the number of holders of such
registered securities has been reduced to fewer than 300 (1,200 for banks, bank holding companies
and savings and loan holding companies) or (2) the number of security holders has been reduced to
fewer than 500 and the company had less than $10 million in assets on the last day of each of the
three most recent years.


            - A company registering either equity or debt securities under the Securities Act is required by
Section 15(d) [8] of the Exchange Act to file at least one annual report on Form 10-K. [9] Section 15(d)
provides an automatic suspension of the periodic reporting obligation if the issuer has fewer than
300 security holders of record at the beginning of the fiscal year. A Form 15 should be filed to notify the
SEC of such suspension, but the suspension is granted by statute and is not contingent on filing the
Form 15. However, Rule 12h-3 of the Exchange Act permits a company to suspend its reporting
obligations under Section 15(d) at any time during the year if the issuer has (1) fewer than 300
(1,200 for banks, bank holding companies and savings and loan holding companies) security holders or
(2) fewer than 500 security holders and less than $10 million in assets on the last day of each of the
three most recent fiscal years. Rule 12h-3 requires the filing of Form 15 as a condition of the suspension.


6 The Jumpstart Our Business Startups Act (JOBS Act), enacted 5 April 2012, amended the record holder definition in Section 12(g)(5)

of the Exchange Act to exclude (1) current or former employees who received securities through an employee stock compensation
plan that is exempt from registration and (2) holders of securities issued through permitted crowdfunding. The Fixing America’s
Surface Transportation Act (FAST Act), enacted 4 December 2015, amended the JOBS Act to apply the new record holder
thresholds for banks and bank holding companies to savings and loan holding companies.

7 A December 2007 SEC final rule, _Exemption of Compensatory Employee Stock Options From Registration Under Section 12(g) of the_

_Securities Exchange Act of 1934_ (SEC Release No. 34-56887), exempted non-reporting issuers from Exchange Act Section 12(g)
registration for compensatory employee stock options issued under written stock option plans if certain conditions regarding
permitted option holders, transferability restrictions and information requirements are met. The exemption does not cover the
common stock or other securities underlying the options; companies must continue to apply the Exchange Act Section 12
registration requirements separately to the underlying class to determine if registration is required. As a result, a private company
does not have to register using Form 10 just because it has more than 500 option holders, provided it meets certain conditions.

8 Section 15(d) of the Exchange Act also requires the filing of an annual report by registrants that are asset-backed security

issuers. General Instruction J to Form 10-K specifies the information asset-backed issuers must include in Form 10-K.

9 However, despite the automatic exemption based on a lower security holder count described later in this section, many indenture

agreements require that companies with public debt outstanding continue to file Exchange Act reports with the SEC regardless of the
number of debt holders.


**2024 SEC annual reports — Form 10-K** | 5


---

2 General rules


Form 10-K is the primary form for these annual reports and is designed to update much of the information
contained in the registrant’s original registration statement. Therefore, Form 10-K provides continuing
disclosure of material facts about the registrant. Because the securities regulations are complex, preparing
Form 10-K requires cooperation among corporate officers, independent auditors, attorneys and the audit
committee of the board of directors. Generally, the rules discussed in this section apply to a smaller
reporting company (SRC) and an emerging growth company (EGC). The rules and requirements that are
unique or inapplicable to SRCs are discussed in section 9 of this publication. Requirements that have
been modified for EGCs are discussed in the relevant sections of this publication.

##### 2.1 When the report is due


The SEC does not consider the Form 10-K filed until it receives the document or it is “accepted” per its
Electronic Data Gathering, Analysis and Retrieval (EDGAR) system. If the due date falls on a holiday or
weekend, registrants have until the next business day to file. The rules require registrants to promptly
notify the SEC if they cannot file all or any required portion of Form 10-K within the prescribed time period
(see section 8, Notification of late filing). The deadlines for filing the Form 10-K are determined by a company’s
filing status (i.e., non-accelerated, accelerated or large accelerated filer).


For purposes of determining filing status, a registrant must determine its public float, which is the aggregate
worldwide market value of its voting and non-voting common equity held by non-affiliates. For this purpose,
public float is calculated on the last business day of a company’s most recent second fiscal quarter, which
is intended to allow the company to determine well in advance when it must file its next Form 10-K.
A registrant must disclose on the cover page of Form 10-K the company’s public float as of the end of its
most recent second fiscal quarter. A registrant (including a foreign private issuer (FPI) that elects to file its
annual report on Form 10-K) also must indicate its filing status on the cover page of Form 10-K by selecting
from the following options: (1) large accelerated filer, (2) accelerated filer or (3) non-accelerated filer. In
addition, a registrant that is not a large accelerated filer may also be identified as an EGC, SRC or both.

##### 2.1.1 Large accelerated filer determination


Rule 12b-2 of the Exchange Act defines a “large accelerated filer” as an issuer that meets all of the
following conditions as of the end of its fiscal year:


            - Has a public float of $700 million or more (measured as of the last business day of its most recent
second fiscal quarter)


            - Has been a public company for at least 12 months [10] subject to the reporting requirements of
Section 13(a) or 15(d) of the Exchange Act


            - Has previously filed at least one annual report


When a company meets the definition of a large accelerated filer as of the end of its fiscal year, it must file
its Form 10-K for that fiscal year within 60 days after its fiscal year-end. In the subsequent fiscal year, the
company must file its quarterly reports on Form 10-Q within 40 days of each quarter-end. Once a company
is a large accelerated filer, it remains so unless it satisfies the exit provisions discussed separately below.


10 A calendar month for purposes of applying this requirement comprises an entire month. For example, if a registrant became

subject to the requirements of Section 13(a) of the Exchange Act on 15 January and remained subject to it through the end of
the year, it would have been subject to Section 13(a) for 11 months as of 31 December.


**2024 SEC annual reports — Form 10-K** | 6


---

2 General rules

##### 2.1.2 Accelerated filer determination


Rule 12b-2 of the Exchange Act defines an “accelerated filer” as an issuer that meets all of the following
conditions as of the end of its fiscal year:


            - Has a public float of $75 million or more but less than $700 million (measured as of the last business
day of its most recent second fiscal quarter)


            - Has been a public company for at least 12 months [11] subject to the reporting requirements of
Section 13(a) or 15(d) of the Exchange Act


            - Has previously filed at least one annual report


            - Is unable to qualify as an SRC because of its revenues (as discussed below)


The SEC amended its rules, effective 27 April 2020, to allow issuers with less than $100 million in annual
revenues [12] and less than $700 million in public float to qualify as non-accelerated filers and not be subject
to any accelerated filing requirements. Consequently, these issuers are not subject to the requirements
for auditor attestation for internal control over financial reporting (ICFR) in Section 404(b) of the
Sarbanes-Oxley Act of 2002 (SOX).


When a company meets the definition of an accelerated filer as of the end of its fiscal year, it must file its
Form 10-K for that fiscal year within 75 days after its fiscal year-end. In the subsequent fiscal year, the
company must file its quarterly reports on Form 10-Q within 40 days of each quarter-end. Once a company
is an accelerated filer, it remains so unless it satisfies the exit provisions discussed separately below.


**Subsidiaries of accelerated filers or large accelerated filers:** When a company that is or was a subsidiary
of a company required to file on an accelerated basis (i.e., a large accelerated filer or an accelerated filer)
must file separate periodic reports with the SEC (e.g., because it issues publicly traded equity or debt
securities, or it is spun off), it does not automatically succeed to the filing status of its parent or former
parent. Instead, the subsidiary or former subsidiary must make its own determination as to its filing
status under Rule 12b-2 based on its specific facts and circumstances.


There are situations, however, in which a newly formed public company may elect to adopt the filing status
of another company for purposes of filing a registration statement on Form S-3. For example, a spun-off
entity may attempt to use its parent’s reporting history or a newly formed holding company may seek to
use its predecessor’s reporting history. [13] The SEC staff has indicated that because of the interrelationship
between Form S-3 eligibility and accelerated filer status, if a newly formed public company seeks to use
and is deemed eligible to use Form S-3 on the basis of another entity’s reporting history, that company
also would be an accelerated filer. [14]


**Change in year-end:** When a company changes its year-end, the end of the transition period (regardless
of whether the transition report is filed on Form 10-K or Form 10-Q — see _Transition report — Change in_
_fiscal year_ later in this section for more discussion of transition reports) is the company’s new fiscal yearend. A company would determine its filing status as of its new fiscal year-end, including a lookback from
its new fiscal year-end to determine whether it met the public float test of Rule 12b-2 as of the end of its
second fiscal quarter of its new fiscal year.


11 A calendar month for purposes of applying this requirement comprises an entire month. For example, if a registrant became

subject to the requirements of Section 13(a) of the Exchange Act on 15 January and remained subject to it through the end of
the year, it would have been subject to Section 13(a) for 11 months as of 31 December.

12 The amended rules also allow business development companies to qualify as non-accelerated filers if they have investment

income of less than $100 million and a public float of $75 million to less than $700 million.

13 SEC Staff Legal Bulletin No. 4, Question 9 dated 16 September 1997.

14 Footnote 76 to SEC Release No. 33-8760 dated 15 December 2006.


**2024 SEC annual reports — Form 10-K** | 7


---

2 General rules


**Subsequent to filing Form 15:** If a company goes private and files a Form 15 with the SEC suspending its
reporting obligations under the Exchange Act, it does not automatically retain its prior status requiring
accelerated filing if it re-enters the Exchange Act reporting system. Such a company would evaluate its
status under Rule 12b-2 based on its specific facts and circumstances as of the end of its first fiscal year
on re-entering the Exchange Act reporting system.

##### 2.1.3 Non-accelerated filer determination


The term “non-accelerated filer” is not defined in Rule 12b-2, or elsewhere in the SEC’s rules. However,
the SEC said in SEC Release No. 34-88365 that “if an issuer does not meet the definition of accelerated
filer or large accelerated filer, it is considered a non-accelerated filer.” [ 15] The cover page of Form 10-K is
required to indicate whether the registrant is a non-accelerated filer, accelerated or large accelerated
(i.e., its acceleration status). An issuer must separately indicate on its Form 10-K cover page whether it
qualifies as an SRC. (The requirements for SRC status are discussed in section 9 of this publication.) An
issuer may be either (1) an accelerated filer and an SRC or (2) a non-accelerated filer and an SRC.


When a company is a non-accelerated filer as of the end of its fiscal year, it must file its Form 10-K for that fiscal
year within 90 days after its fiscal year-end. A non-accelerated filer must file its quarterly reports on Form 10-Q
within 45 days of each quarter-end. A non-accelerated filer must reassess its status each fiscal year.


It is important to note that the requirement to obtain an auditor’s attestation on the effectiveness of ICFR
under Section 404(b) applies to a filer that is required to transition to accelerated or large accelerated
filer status in its Form 10-K for the current fiscal year and an SRC that qualifies for accelerated filer
status (i.e., it has annual revenue of more than $100 million and a public float of $75 million to less than
$250 million), unless they are an EGC.

##### 2.1.3A Filer status summary


The following table summarizes the entry thresholds for the various acceleration status categories that
registrants have to monitor at their annual filer status redetermination date, along with the auditor
attestation requirements for ICFR:


|Status|Public float|Annual revenue|Required to<br>obtain auditor<br>attestation on<br>ICFR|Form 10-K<br>due date<br>(days from<br>year-end)|
|---|---|---|---|---|
|SRC and non-<br>accelerated filer|Less than<br>$75 million|No limit|No|90 days|
|SRC and non-<br>accelerated filer|$75 million to less<br>than $700 million|Less than<br>$100 million|No|90 days|
|SRC and<br>accelerated filer|$75 million to less<br>than $250 million|$100 million or<br>more|Yes|75 days|
|Accelerated filer<br>(not SRC)|$250 million to less<br>than $700 million|$100 million or<br>more|Yes|75 days|
|Large accelerated<br>filer|$700 million and<br>greater|Not applicable|Yes|60 days|


Companies that qualify as EGCs continue to be exempt from the requirements of Section 404(b) even if
they are accelerated filers.


15 Footnote 5 to SEC Release No. 34-88365 dated 12 March 2020.


**2024 SEC annual reports — Form 10-K** | 8


---

2 General rules


See our Technical Line publication, _**[Reminders on reporting and filer status considerations for SEC](https://www.ey.com/en_us/technical/accountinglink/technical-line-reminders-on-reporting-and-filer-status-considerations-for-sec-registrants)**_
_**[registrants](https://www.ey.com/en_us/technical/accountinglink/technical-line-reminders-on-reporting-and-filer-status-considerations-for-sec-registrants)**_, for further guidance on filer status considerations **.**

##### 2.1.4 Exit provisions


_**Exit threshold based only on public float (regardless of revenue)**_


The exit thresholds based solely on public float for large accelerated and accelerated filer status are set at
80% of the respective entry thresholds and have to be applied at every annual status redetermination date.
A domestic registrant has to measure its public float on the last business day of its second fiscal quarter for
purposes of its year-end filer status determination. Any change in acceleration status must first be reflected
in the annual report for the year for which the accelerated status assessment is made.


For example, a large accelerated filer whose public float, as of the last business day of its most recently
completed second fiscal quarter, is less than $560 million but more than $60 million would no longer be
considered a large accelerated filer for that fiscal year. Such an issuer would become an accelerated filer [16] with
its Form 10-K for that year that would be due 75 days after year-end. A large accelerated filer whose public float
drops below $60 million would become a non-accelerated filer with its Form 10-K due 90 days after year-end.


Similarly, an accelerated filer whose public float falls below $60 million as of the last business day of its
second fiscal quarter would no longer be considered an accelerated filer for that fiscal year and would
become a non-accelerated filer for its annual report that would be due 90 days after that year-end.


_**Exit thresholds based on public float in combination with revenue**_


An accelerated filer would also become a non-accelerated filer as of the end of its fiscal year, considering
both its revenue and public float, in each of the following situations:


            - An issuer that qualified as an accelerated filer and an SRC because its revenue was more than
$100 million and its public float was less than $250 million on its prior annual redetermination date
reports revenue below $100 million and estimates that its public float is still less than $250 million
for purposes of the current-year redetermination test.


            - An issuer that was an accelerated filer (but not an SRC) in the prior year because its revenue was more
than $100 million and its public float was greater than $250 million reports revenue below $80 million
and estimates public float below $560 million for purposes of its current annual redetermination test.


For example, if a calendar year-end issuer has public float of $230 million at 30 June 20Y2 and had annual
revenue of $101 million in 20Y1, it would be an SRC and an accelerated filer for the purposes of its 20Y2
annual report based on its public float because it exceeded the revenue threshold. If its public float remains
the same at 30 June 20Y3 and its annual revenue in 20Y2 falls to less than $100 million, it would be an
SRC and a non-accelerated filer for the purposes of its 20Y3 annual report.


In contrast, if a calendar year-end issuer has public float of $400 million at 30 June 20Y2 and had an
annual revenue of $101 million in 20Y1, it also would not be eligible to be an SRC because it exceeds the
revenue threshold, and it would be an accelerated filer for the purposes of its 20Y2 annual report based on
its public float. If its public float remains the same at 30 June 20Y3, its annual revenue in 20Y2 would need
to fall below $80 million for it to be eligible to be an SRC and a non-accelerated filer for the purposes of its
20Y3 annual report.


Registrants that have seen changes in their public float due to fluctuations in stock price as of their
accelerated filer redetermination date (i.e., 30 June 20Y2 for calendar-year companies) should consider
whether they entered accelerated or large accelerated filer status for year-end filings. Registrants that


16 This excludes certain SRCs with annual revenue of less than $100 million, which would qualify as non-accelerated filers (see

section 9 for further discussion on exit provisions for SRCs).


**2024 SEC annual reports — Form 10-K** | 9


---

2 General rules


determine that for the first time they have to follow the accelerated filing dates for their 20Y2 Form 10-K
filings should begin planning to comply with Section 404(b) of the Sarbanes-Oxley Act of 2002, which
requires them to obtain independent auditor attestation on the effectiveness of their ICFR. [ 17]


All issuers must include a checkbox on the cover page of Form 10-K to indicate whether an ICFR auditor
attestation is included in their annual report, regardless of their acceleration status and whether such
auditor attestation is required.

##### 2.1.5 Transition between accelerated and SRC status and requirement for auditor attestation of ICFR


The chart below provides guidance for companies transitioning between the ICFR auditor attestation
requirements based on a change in their filer status.


|Prior status|Initial public<br>float|Initial annual<br>revenue|Required to obtain<br>auditor attestation<br>on ICFR?|Enter/exit ICFR attestation requirement if:|
|---|---|---|---|---|
|**SRC and non-**<br>**accelerated**<br>**filer**|Less than<br>$75 million|Less than<br>$100 million|No|The issuer’s (1) public float increases to $700 million or<br>more (making it a large accelerated filer) or (2) public<br>float increases to $75 million but less than $700 million<br>and revenue increases to $100 million or more (making<br>it an accelerated filer)|
|**SRC and non-**<br>**accelerated**<br>**filer**|Less than<br>$75 million|$100 million or<br>more|No|The issuer’s (1) public float increases to $700 million or<br>more (making it a large accelerated filer) or (2) public<br>float increases to $75 million but less than $700 million<br>(making it an accelerated filer), unless revenue<br>decreases to less than $100 million (in which case it<br>remains an SRC and non-accelerated filer)|
|**SRC and non-**<br>**accelerated**<br>**filer**|$75 million<br>or more, but<br>less than<br>$700 million|Less than<br>$100 million|No|The issuer’s (1) public float increases to $700 million or<br>more (making it a large accelerated filer) or (2) revenue<br>increases to $100 million or more (making it an<br>accelerated filer), unless public float also decreases to<br>less than $75 million (in which case it remains an SRC<br>and non-accelerated filer)|
|**SRC and**<br>**accelerated**<br>**filer**|$75 million<br>to less than<br>$250 million|$100 million or<br>more|Yes|The issuer’s (1) public float decreases to less than<br>$60 million (making it a non-accelerated filer and an<br>SRC) or (2) revenue decreases to less than $100 million<br>(making it a non-accelerated filer and an SRC), unless<br>public float also increases to $700 million or more (in<br>which case it becomes a large accelerated filer)|
|**Accelerated**<br>**filer**|$250 million<br>to less than<br>$700 million|$100 million or<br>more|Yes|The issuer’s (1) public float decreases to less than<br>$60 million (making it an SRC and non-accelerated filer)<br>or (2) revenue decreases to less than $80 million<br>(making it an SRC and non-accelerated filer), unless<br>public float also increases to $700 million or more (in<br>which case it becomes a large accelerated filer)|
|**Large**<br>**accelerated**<br>**filer**|$700 million<br>and greater|Less than<br>$100 million|Yes|The issuer’s (1) public float decreases to less than<br>$60 million (making it an SRC and non-accelerated filer)<br>or (2) public float decreases to between $60 million and<br>less than $560 million and revenue remains below<br>$100 million (making it an SRC and non-accelerated filer)|
|**Large**<br>**accelerated**<br>**filer**|$700 million<br>and greater|$100 million or<br>more|Yes|The issuer’s (1) public float decreases to less than<br>$60 million (making it an SRC and non-accelerated filer)<br>or (2) public float decreases to between $60 million and<br>less than $560 million and revenue decreases to less than<br>$80 million (making it an SRC and non-accelerated filer)|


17 However, EGCs continue to be exempt from Section 404(b) even if they are accelerated filers.


**2024 SEC annual reports — Form 10-K** | 10


---

2 General rules

##### 2.1.6 Acceleration status after IPO


At the end of the fiscal year in which a company conducts its initial public offering (IPO), it could not
qualify to be an accelerated or large accelerated filer, because it would not have had periodic reporting
obligations for at least 12 months. It would be considered a non-accelerated filer for purposes of its first
annual report on Form 10-K following its IPO.


For example, a company with an IPO registration statement on Form S-1 that became effective on 3 December
20Y2 closed on its IPO offering on 4 December 20Y2 and raised approximately $800 million in public
float. It files its annual report for its fiscal year ended 31 December 20Y2 as a non-accelerated filer
within 90 days of its fiscal year-end. It remeasures its public float on the last business day of its second
fiscal quarter for 20Y3 at $900 million. At 31 December 20Y3, this new registrant would become a large
accelerated filer since its public float exceeded $700 million, it has previously filed at least one annual
report on Form 10-K and it has had Exchange Act periodic reporting obligations for at least 12 months.

##### 2.1.7 Financial schedules


Financial schedules (see section 7, _Financial schedules_ ) may be filed by amendment up to 30 days
following the due date of Form 10-K. Thus, the financial schedules for a non-accelerated filer must be
filed within 120 days of its fiscal year-end. For an accelerated filer, financial schedules must be filed
within 105 days of its fiscal year-end. For a large accelerated filer, financial schedules must be filed
within 90 days of its fiscal year-end.

##### 2.1.8 Part III information


The information required in Part III of Form 10-K (e.g., information regarding directors and executive
officers, executive compensation, security ownership) may be incorporated by reference from a proxy
statement, or provided in an amended Form 10-K, within 120 days of the issuer’s fiscal year-end. The
120-day period applies to all companies, despite their filer status.

##### 2.1.9 Financial statements of significant equity investees


Financial statements of significant equity investees (see section 6, _Financial statements and parent_
_company information_ ) may be filed in an amendment to the Form 10-K in certain circumstances. When
the investee is a non-accelerated filer or is not a registrant, issuers can file a US investee’s financial
statements within 90 days of the investee’s fiscal year-end in an amended Form 10-K or on the due date
of the registrant’s Form 10-K, whichever is later. Otherwise, when the investee is a large accelerated filer
or an accelerated filer, and its reporting deadline falls after the date the issuer files its Form 10-K, the
issuer must file the investee’s financial statements in an amended Form 10-K by the due date of the
investee’s Form 10-K.


If the investee is a foreign business, issuers can file the investee’s financial statements within six months
after the investee’s fiscal year-end in an amended Form 10-K or on the due date of the registrant’s
Form 10-K, whichever is later. [18]


18 The SEC’s _Foreign Issuer Reporting Enhancements_ (FIRE) rule (SEC Release Nos. 33-8959 and 34-58620 dated 23 September

2008) accelerated the reporting deadline for annual reports filed on Form 20-F by foreign private issuers from six months to
four months after their fiscal year-end, regardless of the size of issuer. However, the text of Rule 3-09 of Regulation S-X was not
amended by the FIRE rule. Rule 3-09 continues to allow the financial statements of foreign business investees to be filed up to
six months after the investee’s fiscal year-end or the due date of the registrant’s Form 10-K, whichever is later.


**2024 SEC annual reports — Form 10-K** | 11


---

2 General rules

##### 2.1.10 Initial Form 10-K filing due date for registrants


When the effective date of a registrant’s initial registration statement is within 45 days (90 days for an SRC)
of its fiscal year-end, but the registration statement does not include audited financial statements of the
recently completed fiscal year, the due date of the new registrant’s first Form 10-K depends on whether its
securities are registered under the Exchange Act or the Securities Act, as follows:


            - If securities are registered under Section 12(b) or 12(g) of the Exchange Act, the new registrant is
required to file its first Form 10-K within 90 days of its fiscal year-end. See additional guidance in
section 2.1.11 for the initial Form 10-K filing due date for Regulation A issuers.


            - If the securities are registered only under the Securities Act, the registrant is required to file a
Special Report [19] on Form 10-K within 90 days of the effective date of the initial registration
statement. A complete annual report on Form 10-K is not required until the following fiscal year.

##### 2.1.11 Initial Form 10-K filing due date for Regulation A issuers


Regulation A issuers are subject to periodic reporting obligations (e.g., Forms 10-K, 10-Q) under the Exchange
Act when they register their securities on Form 8-A under Section 12(b) of the Exchange Act to be able
to list their securities on a national securities exchange. In Question 182.22 of the C&DIs about Securities
Act rules, the SEC staff clarified that Regulation A issuers that register on Form 8-A can file their first
annual report on Form 10-K for the preceding year within 90 days of the effective date of their Form 8-A.

##### 2.2 Electronic filing using EDGAR


Virtually all submissions to the SEC, including Form 10-K, must be made electronically using the SEC’s
EDGAR system. The rules for electronic filings on the EDGAR system are included in Regulation S-T and
the EDGAR Filer Manual. The EDGAR Filer Manual is an essential “how to” manual prepared by the SEC
that describes the technical format and other requirements for an electronic submission. The EDGAR
Filer Manual, which is updated periodically, can be downloaded from the SEC website ( **[www.sec.gov](http://www.sec.gov/)** ).
While electronic filing has become routine, the SEC has established a “Filer Support” line that registrants
may call for assistance (+1 202 551 8900).


Regulation S-T requires that, with a few exceptions, all filings and related correspondence with the SEC be
submitted electronically. However, registrants may request a hardship exemption from electronic filing
because of technical difficulties or undue burdens and expenses. The temporary hardship exemption is
available automatically for unanticipated technical difficulties by filing Form TH, “Notification of Reliance
on Temporary Hardship Exemption,” within one business day of the required filing date. After filing on
Form TH, registrants have six days to submit the filing on EDGAR without losing their timely-filer status.
A continuing hardship exemption also may be granted by the SEC staff for a specific or indefinite period.


Exhibits filed before the registrant’s transition to EDGAR reporting are not required to be refiled in
electronic format. However, new exhibits must be filed electronically and amendments to previously filed
paper exhibits require the amended exhibit to be electronically refiled in its entirety.


While Regulation S-T specifies that information included in filings must be searchable, the staff will not
object to the use of images or graphics that are not text-searchable. Filers that use items that are not
text searchable must also present the information as searchable elsewhere in the filing. The EDGAR
system provides the ability to include graphic and image files in documents, the ability to use hyperlinks,
including links to previously filed documents on the SEC public website EDGAR database, and the ability


19 Special Report on Form 10-K is only required to include audited financial statements that comply with Regulation S-X. A Special

Report on Form 10-K does not require, but permits, the inclusion of management’s discussion and analysis and other narrative
disclosures otherwise required in a Form 10-K.


**2024 SEC annual reports — Form 10-K** | 12


---

2 General rules


to use the Internet to transmit filings to the EDGAR system. The SEC does not accept magnetic media
(e.g., diskettes, tapes, cartridges). Filings should be submitted to EDGAR via the Internet or direct
transmission. Filers may submit their filings in ASCII, HTML or iXBRL format.


Manual signatures are no longer required. Instead, signatures in the electronic filing document should be
typed. However, the registrant must maintain evidence of appropriate authorization (see Signatures and
director involvement later in this section for further discussion).

##### 2.3 XBRL 2.3.1 Background


The SEC continues to work on an interactive data initiative to significantly increase the speed and
accuracy of data retrieval and analysis. Extensible Business Reporting Language (XBRL), the financial
and operational business reporting offshoot of Extensible Markup Language (XML), is a freely licensable,
open technology standard. Instead of treating financial information as a block of text — as in a standard
internet page or a printed document — XBRL provides a computer readable identifying “tag” for each
individual item of data. For example, “net profit” has its own unique tag. As a result of attaching
identifying XBRL tags to individual pieces of data, a business-reporting document becomes “smart”
(i.e., a computer can read the data in context, search for information or perform calculations).

##### 2.3.2 SEC’s requirement for interactive data (XBRL)


The SEC’s rule on XBRL, _Interactive Data to Improve Financial Reporting_, issued in 2009 _,_ [20] requires the
use of XBRL for SEC financial reporting. Interactive data is required for the entirety of the financial
statements, including the footnotes and all required registrant schedules. The SEC does not currently
require tagging of MD&A and executive compensation (except pay versus performance disclosures as
required by Regulation S-K 402(v)) but has been adding tagging requirements to the majority of its
recent final rules.


**2.3.2.1** **Inline XBRL filing of tagged data**


The SEC requires operating companies to use Inline XBRL and embed tags in their financial statements,
rather than provide this data in separate XBRL exhibits. The SEC does not view XBRL exhibits or Inline XBRL
data to be part of the financial statements and in scope for the financial statement audit. Controls over
XBRL are within the scope of the registrant’s disclosure controls and procedures (DCP) but not its ICFR.


The Inline XBRL requirements apply to all filers, [21] regardless of whether they are EGCs, SRCs or FPIs that
prepare financial statements in accordance with IFRS as issued by the International Accounting
Standards Board (IASB).


**2.3.2.2** **SEC observations**


The SEC staff addresses XBRL filing issues by publishing _Staff Observations, Guidance, and Trends_ on the
SEC’s website at **[http://www.sec.gov/spotlight/xbrl/staff-review-observations.shtml.](http://www.sec.gov/spotlight/xbrl/staff-review-observations.shtml)** The SEC staff
monitors trends in custom tagging in XBRL exhibits and the use of unnecessary customized tags that
could potentially reduce comparability across companies. SEC rules permit custom tags to be used only
when a standard tag from the XBRL taxonomy doesn’t exist for a financial element. The SEC staff plans
to continue monitoring trends in custom tagging and may consider further guidance or other actions.


20 Release Nos. **[33-9002](https://www.sec.gov/rules/final/2009/33-9002.pdf)** and **[34-59324](https://www.sec.gov/rules/final/2009/33-9002.pdf)** .

21 Investment companies registered with the SEC under the 1940 Act and business development companies (BDCs) are not included in the

definition of operating companies, and accordingly are currently not in the scope of XBRL rules or Inline XBRL tagging requirements.


**2024 SEC annual reports — Form 10-K** | 13


---

2 General rules


The staff of the SEC Office of Interactive Disclosure periodically updates its interpretative responses to
frequently asked questions about XBRL: Staff Interpretations and FAQs Related to Interactive Data
Disclosure, which is available at **[http://www.sec.gov/spotlight/xbrl/staff-interps.shtml.](http://www.sec.gov/spotlight/xbrl/staff-interps.shtml)**


The SEC staff’s C&DIs about interactive data are also available at **[https://www.sec.gov/corpfin/interactive-](https://www.sec.gov/corpfin/interactive-data-cdi)**
**[data-cdi.](https://www.sec.gov/corpfin/interactive-data-cdi)** In August 2019, the SEC staff issued several C&DIs that address matters related to the
adoption of Inline XBRL.


In September 2023, the SEC staff posted a **[sample comment letter](https://www.sec.gov/corpfin/sample-letter-companies-regarding-their-xbrl-disclosures?utm_medium=email&utm_source=govdelivery)** to illustrate the types of comments it
may issue to registrants on XBRL and Inline XBRL disclosures. The SEC staff said it may also comment on
matters other than those in the sample comment letter, depending on the type of filing under review and
the facts and circumstances.


**2.3.2.3** **Disclosure controls and procedures considerations**


The SEC’s adopting release on XBRL from December 2008 makes clear that an issuer’s disclosure controls
and procedures must address the interactive data reporting requirements. Further, under Exchange Act
Rules 13a-15 and 15d-15 and Item 307 of Regulation S-K, management of the issuer must consider its
controls over interactive data in disclosing the conclusions of its principal executive and principal
financial officer regarding the effectiveness of its DCP.


Therefore, an issuer should document the processes it follows and identify the DCP that it relies on in
tagging its financial statements. An issuer also should consider establishing processes and documentation
to provide evidence that those controls and procedures are performed and reviewed. To evaluate the
effectiveness of DCP under Exchange Act Rules 13a-15 and 15d-15 and Item 307 of Regulation S-K,
companies should:


            - Identify the controls and procedures they rely on to comply with the SEC reporting requirements for
XBRL tagging


            - Assess whether the disclosure controls and procedures result in timely, accurate and complete
XBRL tagging


            - Assess whether the XBRL tagging presents the financial information accurately in all material respects


However, the XBRL final rule from December 2008 amended Exchange Act Rules 13a-14 and 15d-14 to
exclude interactive data from the scope of the officer certification requirements.


**2.3.2.4** **Internal control over financial reporting**


Although most issuers will not have XBRL controls that fall within the scope of ICFR, the SEC observed
that as technology associated with interactive data improves, the integration of such technology into the
overall financial reporting process could cause the related controls and procedures to fall within the
scope of internal control over financial reporting.


**2.3.2.5** **Consequences of noncompliance**


If a company is delinquent in providing its XBRL data to the SEC, the company will be deemed not to be
current in its Exchange Act reporting obligations. Consequently, the company could not use short-form
registration statements on Forms S-3, F-3 or S-8, and it would not be considered to have adequate current
public information for purposes of the resale exemption safe harbor under Rule 144 of the Securities Act.
However, such a company will be considered to be current in its reporting obligations when it provides the
XBRL data to the SEC.


**2.3.2.6** **Liability considerations**


Registrants are liable for inaccuracies in XBRL data under the Securities Act and the Exchange Act.


**2024 SEC annual reports — Form 10-K** | 14


---

2 General rules


**2.3.2.7** **SEC form cover page requirements**


The cover page of Form 10-K requires a company to indicate, by a Yes or No check mark, whether it has
submitted electronically every Interactive Data File required to be submitted pursuant to Rule 405 of
Regulation S-T during the preceding 12 months (or for such shorter period that the registrant was required
to submit such files). All the information presented on the cover page of Form 10-K must be tagged.


**2.3.2.8** **AICPA attestation guidance**


Management is responsible for the completeness, accuracy and consistency of its XBRL data. The standards
of the Public Company Accounting Oversight Board (PCAOB) and the rules and regulations of the SEC do
not require that an independent auditor perform procedures related to the XBRL data, as part of its audit
services. In addition, unlike other information in documents containing the audited financial statements
(e.g., MD&A), the independent auditor is not required to read the XBRL submission for material
inconsistencies with the information or manner of its presentation appearing in the financial statements
as part of its audit procedures.


American Institute of Certified Public Accountants (AICPA) Statement of Position 13-02, _Performing_
_Agreed-Upon Procedures Engagements That Address the Completeness, Mapping, Consistency, or_
_Structure of XBRL-Formatted Information (SOP 13-02)_ (AUD sec. 55) describes the components of an
XRBL agreed-upon procedures engagement and the principles a practitioner should follow in completing
such an engagement.

##### 2.3.3 Taxonomies


All XBRL tagging must apply the appropriate taxonomy (i.e., set of defined tags and definitions). The
approved taxonomies are available on the **[FASB website](https://www.fasb.org/xbrl)** and the **[SEC website](https://www.sec.gov/structureddata/announcement/osd-announcement-031218-xbrl-taxonomy-update-march-12-2018)** . The SEC staff encourages
companies to adopt the latest version of the US GAAP taxonomy the SEC has approved.

##### 2.4 Signatures and director involvement


The following persons, or persons performing similar functions, must sign the Form 10-K: the principal
executive officer or officers, the principal financial officer, the controller or principal accounting officer
and at least a majority of the board of directors or persons performing similar functions. [22] When an
officer also signs as a director, the Form 10-K must indicate both capacities below the signature.


When adopting the requirement for directors’ signatures, the SEC stated that its intention was to
encourage directors to devote attention to reviewing the Form 10-K and “to seek the involvement of
other professionals to the degree necessary to give themselves sufficient comfort.”


Documents filed electronically necessarily include typed, rather than manual, signatures. Registrants
must maintain a manually or electronically (as discussed below) signed signature page or other document
authenticating and acknowledging the signatures included in all electronic filings. This document must be
executed before or at the same time the filing is made and must be retained for five years. Accordingly,
the filing of typed signatures does not relieve the registrant of its obligation to obtain signatures from the
officers, directors and others (e.g., auditors) before the filing is submitted. On request, registrants must
provide the SEC with documentation supporting typed signatures.


22 For asset-backed security issuers, the Form 10-K must be signed either (1) on behalf of the depositor by the senior officer in

charge of securitization of the depositor or (2) on behalf of the issuing entity by the senior officer in charge of the servicing
function of the servicer.


**2024 SEC annual reports — Form 10-K** | 15


---

2 General rules


_Electronic Signatures Rule 302 of Regulation S-T_


Rule 302(b) of Regulation S-T [23] permits a signatory to an electronic filing on EDGAR who follows
certain procedures to sign an authentication document through an electronic signature that meets
certain requirements specified in the EDGAR Filer Manual. Signatories have the option of signing an
authentication document either manually or electronically; however, the signing process for an electronic
signature is required to meet certain conditions that are consistent with the evidentiary purposes of the
authentication document.


When a signatory signs an authentication document using an electronic signature, the signing process for
the electronic signature must, at a minimum:


- Require the signatory to present a physical, logical (e.g., use of password), or digital credential that
authenticates the signatory’s identity


- Reasonably provide for non-repudiation of the signature


- Provide that the signature be attached, affixed, or otherwise logically associated with the signature
page or document being signed


- Include a time stamp to record the date and time of the signature


Companies should consult with their securities counsel about when and whether it is appropriate to avail
themselves of the electronic signature authentication in their SEC filings on Form 10-K or in other filings.


_**Other considerations for officer and director signatures in SEC filings**_


The requirement for directors to sign the Form 10-K may affect the timing of the preparation of Form 10-K.
Management should develop procedures to obtain their signatures. This might be done by scheduling a
meeting of the board of directors or its audit committee shortly before the Form 10-K is due so that
directors may review the form, possibly with counsel and the independent auditors. Alternatively, the
directors may sign a signature page in advance, or execute a power of attorney, and approve the use of
their signatures after receiving a draft of the Form 10-K.


Regarding the signing of a report or other documentation through power of attorney, Item 601(b)(24) of
Regulation S-K requires the following:


- If the name of any officer or director is signed pursuant to a power of attorney, signed copies of such
power of attorney must be filed with the SEC.


- If the power of attorney is included elsewhere in the filing, a reference must be made in the index to
the part of the filing containing the power of attorney.


- If the name of any officer signing on behalf of the registrant is signed by a power of attorney, certified
copies of the board of directors’ resolution authorizing such signature must be filed with the SEC.


- A power of attorney should relate only to a specific SEC filing or amendment. A power of attorney
that confers general authority is not acceptable.


23 See SEC Release **[33-10889](https://www.sec.gov/rules/final/2020/33-10889.pdf)**, _Electronic Signatures in Regulation S-T Rule 302._


**2024 SEC annual reports — Form 10-K** | 16


---

2 General rules

##### 2.5 Section 906 management certifications


Section 906 of the Sarbanes-Oxley Act (Section 1350 of Chapter 63 of Title 18 of the United States
Code) requires a separate certification by the CEO and CFO (or their equivalent) [24] to “accompany” each
periodic report that includes financial statements. The contents of this certification are specified in
Section 906(a) of the Sarbanes-Oxley Act, _Certifications of Periodic Financial Reports,_ not in an SEC rule.
The certification must state that the periodic report “fully complies” with the requirements of Exchange
Act Section 13(a) and 15(d) and that “information contained in the periodic report fairly presents, in all
material respects, the financial condition and results of operations of the issuer.” The certification can
take the form of a single certification signed by both the company’s CEO and CFO. Section 906 provides
for criminal penalties for an officer who provides the certification “knowing” it to be untrue. They can be
fined up to $1 million and/or imprisoned for up to 10 years (with harsher penalties for “willful” violations).
The Section 906 certification requirement applies to all registrants, except asset-backed security issuers.


The Section 906 certification is required to be “furnished” (versus filed) as Exhibit 32 to annual and
quarterly SEC reports. As “furnished” information, the Section 906 certification is not subject to the civil
liability provisions of Section 18 of the Exchange Act and would not be incorporated by reference into
Securities Act registration statements unless the issuer expressly specifies otherwise.


For signed documents filed electronically, SEC rules require issuers to retain the manually or
electronically signed original of each Section 906 management certification for five years. In addition,
the SEC has stated that an individual required to sign the Section 906 certification “may not have the
certification signed on his or her behalf pursuant to a power of attorney or other form of confirming
authority.” Refer to the recent amendments to Rule 302(b) of Regulation S-T described in section 2.4
above permitting the option to authenticate signatures in SEC filings electronically.

##### 2.6 Transmittal letter


General instruction D(3) to Form 10-K requires registrants to discuss in a transmittal letter to the
Form 10-K any changes in accounting principles or practices, or in the method of applying those principles
or practices, from its last Form 10-K. This requirement is separate from the requirement to include, as an
exhibit, a “preferability letter” from the independent auditors regarding a change in accounting principle.

##### 2.7 Content of the report


Instructions to Form 10-K, Regulations 12B, 13A, 15D and AB under the Exchange Act, and Regulations S-K
and S-X include Form 10-K requirements. The form itself, which is divided into four parts, is merely a guide
and, except for the cover page, should not be used as a blank form to be filled in. The report should include
all required item numbers and captions (e.g., Item 1, _Business_ ). When required information is presented
elsewhere, generally it is not necessary to repeat the information, provided that it is adequately crossreferenced. All information should be given as of the latest practicable date, except where it must be given
for the fiscal year-end or as of a specified date.


Regulation S-K includes the nonfinancial statement disclosure requirements for Exchange Act periodic
reports and Securities Act registration statements. With the notable exception of financial statements
and schedules, which are governed by Regulation S-X, the instructions to Form 10-K generally refer to
the disclosure requirements of Regulation S-K.


24 The SEC certification rules refer to “each principal executive officer” and “each principal financial officer,” which will be referred to

as CEO and CFO for purposes of the discussion of certifications in this publication.


**2024 SEC annual reports — Form 10-K** | 17


---

2 General rules


The following table shows the item number, caption and location of the disclosure instructions, which is
noted parenthetically and refers to the items in Regulation S-K for the various items of Form 10-K.


**Form 10-K**
**Item No.** **Disclosure Required**


**Part I**
Item 1 Business (Item 101)
Item 1A Risk Factors (Item 105)
Item 1B Unresolved Staff Comments (The disclosure requirements are included in the Instructions to Form 10-K.)
Item 1C Cybersecurity (Item 106)
Item 2 Properties (Item 102)
Item 3 Legal Proceedings (Item 103)
Item 4 Mine Safety Disclosures (Item 104)

**Part II**
Item 5 Market for Registrant’s Common Equity, Related Stockholder Matters and Issuer Purchases of Equity
Securities (Items 201, 701 and 703)
Item 6 [Reserved]
Item 7 Management’s Discussion and Analysis of Financial Condition and Results of Operations (Item 303)
Item 7A Quantitative and Qualitative Disclosures About Market Risk (Item 305)
Item 8 Financial Statements and Supplementary Data (Item 302 — The financial statements are subject to the
disclosure requirements of Regulation S-X.)
Item 9 Changes in and Disagreements with Accountants on Accounting and Financial Disclosure (Item 304(b))
Item 9A Controls and Procedures (Items 307 and 308)
Item 9B Other Information (The disclosure requirements refer to Form 8-K and Item 408(a))
Item 9C Disclosure Regarding Foreign Jurisdictions that Prevent Inspections (The disclosure requirements are
included in the Instructions to Form 10-K.)

**Part III**
Item 10 Directors, Executive Officers and Corporate Governance (Items 401, 405, 406 and 407(c)(3),
(d)(4),(d)(5) and 408(b))
Item 11 Executive Compensation (Items 402 and 407(e)(4) and (e)(5))
Item 12 Security Ownership of Certain Beneficial Owners and Management and Related Stockholder Matters
(Items 201(d) and 403)
Item 13 Certain Relationships and Related Transactions, and Director Independence (Items 404 and 407(a))
Item 14 Principal Accountant Fees and Services (Item 9(e) of Schedule 14A)

**Part IV**
Item 15 Exhibits and Financial Statement Schedules (Item 601 — The financial statements and financial
schedules are subject to the provisions of Regulation S-X.)
Item 16 Form 10-K Summary (optional)


Rule 12b-20 of the Exchange Act requires the registrant to disclose any material information, even if not
specifically required, that may be necessary to keep the required information from being misleading.


Rule 12b-21 of the Exchange Act states that information required by any of the parts “need be given only
insofar as it is known or reasonably available to the registrant.” Therefore, if obtaining the information involves
unreasonable effort or expense, or it rests peculiarly within the knowledge of another person not affiliated
with the registrant, the information may be omitted. When information is omitted, the registrant must:


- Give the information on the subject that it does possess or can acquire without unreasonable effort
or expense, together with the sources thereof


- Include a statement either that an unreasonable effort or expense would be involved or indicating the
absence of any affiliation with the person within whose knowledge the information rests and stating
the result of a request made to such person for the information


**2024 SEC annual reports — Form 10-K** | 18


---

2 General rules


The application of Rule 12b-21 depends on the registrant’s facts and circumstances, and we have
observed that use of this accommodation has been rare.

##### 2.8 Wholly owned subsidiaries [25]


Wholly owned subsidiaries that are required to file an annual report on Form 10-K because they have
issued registered securities may avail themselves of the significant disclosure accommodations listed in
General Instruction I.(2) in their annual report on Form 10-K, if they meet _all_ of the following conditions [26]
as of the filing date:


            - All of the registrant’s equity securities must be owned, directly or indirectly, by a single parent that is
subject to the Exchange Act reporting requirements and has filed all applicable material pursuant to
Sections 13, 14 or 15(d) of the Exchange Act.


            - The registrant must name its parent in the description of its business.


            - During the preceding 36 months and any subsequent period, there must not have been a material
default in the payment of principal, interest, a sinking or purchase fund installment or any other
material default not cured within 30 days, for any indebtedness of the registrant or its subsidiaries or
a material default in the payments of rentals under a long-term lease.


            - The cover page of the Form 10-K must contain a statement that the registrant meets the conditions
for filing the reduced disclosures in General Instruction I.(1)(a) and (b) of Form 10-K.


Wholly owned subsidiaries that meet the conditions described above are required to include only the
following items of Form 10-K:


Item 1 Business

Item 1A Risk Factors

Item 1B Unresolved Staff Comments

Item 1C Cybersecurity (Item 106)

Item 2 Properties

Item 3 Legal Proceedings

Item 4 Mine Safety Disclosures

Item 5 Market for the Registrant’s Common Equity, Related Stockholder Matters and Issuer Purchases of Equity
Securities (This item is required although it generally is not applicable to wholly owned subsidiaries.)

Item 6 [Reserved]

Item 7 Management’s narrative analysis of the results of operations over the most recent fiscal year presented
and the fiscal year immediately preceding it (in lieu of full MD&A)

Item 7A Quantitative and Qualitative Disclosures About Market Risk

Item 8 Financial Statements and Supplementary Data

Item 9 Changes in and Disagreements with Accountants on Accounting and Financial Disclosure

Item 9A Controls and Procedures

Item 9B Other Information

Item 9C Disclosure Regarding Foreign Jurisdictions that Prevent Inspections

Item 14 Principal Accountant Fees and Services

Item 15 Exhibits and Financial Statement Schedules (except the exhibit of subsidiaries required by Item 601 of
Regulation S-K)


25 The terms “wholly owned subsidiary” and “totally owned subsidiaries” are defined in Exchange Act Rule 12b-2 and applied in

various other SEC rules.

26 The conditions are specified in General Instruction I.(1) of Form 10-K, and one of them is that the issuer is not an asset-backed

securities issuer.


**2024 SEC annual reports — Form 10-K** | 19


---

2 General rules


In lieu of Item 7, _Management’s Discussion and Analysis of Financial Condition and Results of Operations_,
the Form 10-K may include management’s narrative analysis of the results of operations that explains
the reasons for material changes in the amount of revenue and expense items between the most recent
fiscal year presented and the immediately preceding fiscal year.


The responses to Item 1, _Business_, and Item 2, _Properties_, may be limited to a brief description of
business done during the year and a brief description of material properties. The description of business
should indicate the general nature and scope of the registrant’s business, and material properties need to
be described only to the extent necessary to provide an understanding of the business. Exhibit 21 listing
subsidiaries, otherwise called for by Item 15(c), also may be omitted.


Wholly owned subsidiaries are _not_ exempt from the SEC requirements for the Section 302 and Section 906
management certifications, Item 307 disclosures about disclosure controls and procedures, and Item 308
reporting on internal control over financial reporting.


Debt or preferred stock registered under the Securities Act may be guaranteed by one or more affiliates
of the issuer. It’s common for a parent company to raise capital by offering its own securities that are
guaranteed by one or more subsidiaries or through one of its subsidiaries with guarantees from the parent
and/or one or more other subsidiaries. If certain conditions are met, Rule 3-10 of Regulation S-X allows
for alternative financial disclosure or, in certain instances, narrative disclosure in the parent company’s
annual report on Form 10-K and other filings in lieu of separate financial statements for each subsidiary
issuer and guarantor of registered debt. See the discussion about subsidiary guarantors or subsidiary
issuers of guaranteed securities in section 6, _Financial statements and parent company information_ .

##### 2.9 Combined periodic reporting


The SEC staff has indicated that it would not object to the filing of a combined periodic report (i.e., Form 10-K
or Form 10-Q) for parent and subsidiary registrants and multiple series registrants in certain situations.

##### 2.9.1 Parent and subsidiary


Parent and subsidiary registrants may file a combined periodic report if all of the following conditions are met:


            - The parent company owns substantially all of the subsidiary [27]


            - There are no more than nominal differences between the financial statements of the parent and the
subsidiary and the nonfinancial disclosures of the parent and subsidiary are substantially similar


            - All of the following items are included in the combined periodic report:


              - Separate audit reports for each entity


              - Separately reviewed interim financial statements for each entity


              - Separate reports on disclosure controls and procedures and internal control over financial
reporting for each entity


              - Separate complete sets of annual and interim financial statements (e.g., balance sheet,
statement of operations, statement of comprehensive income, statement of cash flows and
statement of changes in stockholders’ equity, as applicable)


              - Separate footnotes for areas that differ between the parent and the subsidiary


              - Separate CEO/CFO Certifications for each entity


27 “Substantially all” is not defined in terms of a minimum percentage ownership. Recently, based on the facts and circumstances,

the SEC Staff has shown flexibility in interpreting this criterion to provide combined periodic reports.


**2024 SEC annual reports — Form 10-K** | 20


---

2 General rules

##### 2.9.2 Multiple series registrants


A multiple series registrant is a trust or partnership that offers the sale of its investments in multiple series,
on a single registration statement. Because multiple series registrants are formed as trusts or partnerships
under state law, each series is established as both a legal entity and as an SEC issuer; however, the trust or
partnership is considered the only entity with SEC reporting requirements (i.e., the legal registrant).
Because an investor invests in an individual series of the trust or partnership, financial statements of each
individual series of the trust or partnership still must be provided. The SEC staff will not object to the filing
of a combined periodic report for the trust or partnership and each individual series as long as certain
separate reporting continues to be applied at both the legal registrant and the series level. Specifically, to
qualify to file a combined periodic report, there must be separate assessments of materiality for purposes
of Regulations S-K and S-X for the legal registrant and for each series and all of the following items must
be separately provided for the legal registrant and for each series in the combined periodic report:


            - Separate annual financial statements and audit reports or separately reviewed interim financial statements


            - Separate reports on disclosure controls and procedures and internal control over financial reporting


Multiple series registrants also should include in the “controls and procedures” disclosure of their
periodic reports a statement that the CEO/CFO certifications are applicable to each of the series as well
as to the trust (partnership).

##### 2.10 Incorporation by reference


Most of the information required in Form 10-K is required in other SEC filings or in the annual shareholders’
report prescribed by the SEC’s proxy requirements. Instead of reproducing information in the Form 10-K
that has already been included in a previous SEC filing or an annual shareholders’ report, a registrant
may incorporate by reference that information into the Form 10-K. For example, in lieu of reproducing
the same financial statements in response to Item 8 of Form 10-K, a registrant may incorporate by
reference into the Form 10-K the sections of the annual shareholders’ report containing the audited
financial statements. Rule 303 of Regulation S-T stipulates that registrants that incorporate by reference
all or portions of their annual reports to shareholders must file the incorporated portions in electronic
form as an exhibit (Exhibit 13) to the Form 10-K filing.


General Instruction G to Form 10-K provides that information called for by Parts I and II (Items 1 through 9A
or any portion thereof) _may_ be incorporated by reference from the registrant’s annual shareholders’ report.
As a condition to the incorporation of any information from the annual shareholders’ report, the entire
report must comply with the requirements of Rule 14a-3(b) or 14c-3(a) — the SEC requirements for annual
shareholders’ reports in conjunction with proxy statements or information statements. Thus, a registrant
filing Form 10-K pursuant to Section 15(d) [28] must conform its annual shareholders’ report to the SEC’s
proxy requirements, even though it is not otherwise required to do so, to incorporate any portion of the
report into Form 10-K.


General Instruction G also provides that information called for by Part III of Form 10-K (Items 10, 11, 12, 13
and 14) may be incorporated by reference from the registrant’s definitive proxy or information statement _if_
the proxy or information statement is filed with the SEC not later than 120 days after the fiscal year-end.
However, if the information called for by these items cannot be incorporated by reference, it must either be
included within Form 10-K when filed or included by amendment on Form 10-K/A no later than 120 days
after the fiscal year-end. In addition, as discussed in section 10 of this publication, the following four
disclosures required by Part III of Form 10-K are not required to be included in the annual proxy statement,
and may be included in the Form 10-K as filed, or by amendment: (1) executive officers, (2) audit committee
financial experts, (3) code of ethics and (4) changes in shareholder nominating procedures.


28 Unlike Sections 12(b) and 12(g) registrants, Section 15(d) reporting companies are not subject to the SEC’s proxy rules.


**2024 SEC annual reports — Form 10-K** | 21


---

2 General rules


In addition to the instructions to Form 10-K, several rules under Regulation 12B contain instructions for
incorporation by reference that are applicable to all Exchange Act filings, including Form 10-K.


Financial statements may be incorporated by reference when they meet the requirements of Form 10-K
(subject to General Instruction G of Form 10-K discussed above regarding incorporation by reference
from annual shareholders’ reports). Financial statements and data must be presented in comparative
format. Rule 12b-23 provides that a registrant cannot incorporate this material by reference unless it
includes the entire period for which the comparative data is required. Thus, it is not permissible to
separately incorporate by reference a previous year’s financial statements or data.


A Form 10-K may incorporate by reference financial statements filed under the Securities Act, such as
from a registration statement. When this is done, Rule 12b-36 requires that an auditor’s consent be filed
with the Form 10-K.


Rule 12b-23(d) also requires that when information on EDGAR is incorporated by reference, registrants
are required to include an active hyperlink.


Rule 12b-23 also requires that:


            - The matter incorporated by reference must be clearly identified in the reference by page, paragraph,
caption or otherwise.


            - If only certain portions of a document are incorporated by reference and filed with the report, the
document from which the material is taken must be clearly identified in the reference.


            - An express statement that the specified matter is incorporated by reference must be made at the
particular place in the report where the information is required.


            - Material must not be incorporated by reference in any case where such incorporation would render
the report incomplete, unclear or confusing.


            - If any modification has occurred in the text of any document incorporated by reference since its filing, a
registrant must file with the reference a statement containing the text of the modification and the date it
was made.


When financial statements or other information included in the published annual shareholders’ report are
incorporated by reference, registrants should specifically identify the information so incorporated. Failure
to do so could imply that the entire annual report (including the “president’s letter” and other subjective
information) is incorporated by reference; the entire annual report then could be deemed a “filed document”
under the Exchange Act. This could unnecessarily expose the registrant to additional liability.

##### 2.10.1 Cross-referencing and location of financial statement disclosures


To address concerns about financial statement users’ understanding of auditors’ responsibilities, registrants
are prohibited from having financial statements cross-reference disclosures in other parts of a filing or
incorporate information by reference from other filings, unless cross-referencing or incorporating information
by reference is specifically permitted by the Commission rules, US GAAP or IFRS as issued by the IASB.

##### 2.11 Integrated reports


The SEC permits the annual shareholders’ report and Form 10-K to be filed as a combined report. A registrant
must satisfy the following conditions when integrating the annual shareholders’ report with Form 10-K:


            - The report must contain all the information required by Form 10-K, including the cover page and
required signatures. A cross-reference sheet should indicate the location of information required by
the items of the form. When responses to certain items of the form are separated within the report,
an appropriate cross-reference should be made.


**2024 SEC annual reports — Form 10-K** | 22


---

2 General rules


            - If the information required by Part III of Form 10-K (see General Instruction G) is omitted, a definitive
proxy or information statement must be filed not later than 120 days after the end of the fiscal year
covered by the Form 10-K.


Information contained in integrated annual reports, other than that required by the Form 10-K instructions,
is not deemed “filed” for purposes of liability under Section 18 of the Exchange Act. Before electing to
prepare an integrated report, certain factors should be considered. Cost may not be a significant factor
because the savings of preparing only one document may be offset by its larger size and by additional
printing and mailing costs. [29] Another consideration is the additional disclosures required by the SEC rules.
All information required by the Form 10-K instructions must be included. Some commercial companies will
have to include audited financial statements of unconsolidated subsidiaries, investees and affiliates, as
well as financial schedules.


Some registrants have followed a practice similar to integration — including the Form 10-K as a separate
section in the annual shareholders’ report. If the registrant wants to include the Form 10-K information in the
annual shareholders’ report, this approach may be more desirable and/or cost-efficient than fully integrating
the two reports. Registrants could continue to eliminate duplication through incorporation by reference.

##### 2.12 Summary annual reports


Some registrants have prepared “summary annual reports” in lieu of the traditional annual report most public
companies provide to their shareholders. The summary annual report does not include all of the financial
disclosures required by the SEC’s proxy rules, which require that audited consolidated financial statements,
MD&A and certain other information be included in an annual report to all shareholders when soliciting proxies
for the annual meeting. Because the summary annual report is not used for compliance purposes, there are
no specific rules about its content. The only restrictions on the information in the summary annual report are
(1) the general requirement that corporate communications by public companies must not include false or
misleading information or fail to disclose material information that would make the communications not
misleading (i.e., Rule 10b-5 of the Exchange Act) and (2) the provisions of Regulation G for any non-GAAP
financial measures presented. Registrants that use a summary annual report must continue to provide
shareholders with the complete information required under the proxy rules, which may be included in an
addendum to the annual meeting proxy statement. Because the use of a summary annual report does not
reduce the amount of information that must be provided to shareholders, its use has been limited.

##### 2.13  Amendments and comprehensive annual reports


Occasionally, a registrant may need to amend a filing or management may believe it is more efficient to
include multiple delinquent or corrected filings in one document. The SEC has rules for filing amended or
delinquent filings.

##### 2.13.1 Amendments


A Form 10-K may be deficient because a registrant has omitted material information, or because the
registrant has not prepared the financial statements in accordance with generally accepted accounting
principles or Regulation S-X. In other cases, the registrant may choose to file the financial schedules (see
section 7, _Financial schedules_ ) as an amendment to the Form 10-K no later than 30 days after the
applicable due date of the Form 10-K. Alternatively, under particular circumstances, the registrant may
have to file Part III information (regarding directors and executive officers and executive compensation
and transactions) after the initial filing of Form 10-K but within 120 days of the fiscal year-end. Under
these circumstances, an amendment to Form 10-K is required. Amendments should be filed only after
review by legal counsel and the independent auditors.


29 Section 2 of our publication, _[Proxy statements — An overview of the requirements and observations about current practice](https://www.ey.com/en_us/technical/accountinglink/2025-proxy-statements-an-overview-of-the-requirements)_, discusses

proxy delivery requirements, including the internet availability of proxy materials that also may reduce printing and mailing costs.


**2024 SEC annual reports — Form 10-K** | 23


---

2 General rules


All amendments to Exchange Act reports should be filed under cover of the form amended, marked with
the letter “A” to designate the document as an amendment (e.g., Form 10-K/A). The amended report
should indicate the reasons for the revisions included therein in an explanatory note. The amendment
must include the entire item as amended, rather than just the amended or additional text (e.g., if the
liquidity discussion within MD&A is amended, the entire Item 7, _Management’s Discussion and Analysis of_
_Financial Condition and Results of Operations_, should be refiled). However, based on informal discussions
with the SEC staff, a registrant is not required to refile the entire Item 8, _Financial Statements and_
_Supplementary Data_, when filing the financial schedules as an amendment to a previously filed Form 10-K.


Amendments must be signed on behalf of the registrant by a duly authorized representative of the registrant
(see Signatures and director involvement above for further discussion). In addition, each CEO and CFO must
provide a new management certification. The CEO and CFO must furnish, as Exhibit 32, the complete
Section 906 certification. However, in lieu of the complete Section 302 certification, the CEO and CFO
may file, as Exhibit 31, a modified Section 302 certification to comply with Section 13(a) or 15(d) of the
Exchange Act. The SEC staff’s C&DI of Section 13(a) and 15(d) of the Exchange Act provides guidance on the
modifications to Section 302 certifications when a periodic report is amended. Paragraph 3 of the
certification may be omitted if there are no financial statements or other financial information in the
amendment. If the amendment does not contain or amend disclosures required by Item 307 or 308 of
Regulation S-K and such disclosures are not required given the nature of the amendment, the registrant may
omit paragraphs 4 and 5. See section 4, _Part II_, for further information about the Section 302 certification.


##### 2.13.2 Comprehensive annual reports

A registrant that has missed filing one or more required reports with the SEC may decide to file the delinquent
financial information in one comprehensive annual report sometimes referred to as a “Super 10-K.”


The comprehensive annual report would need to include all material information that would otherwise
have been available had the registrant filed individual reports. It must also include the necessary
unaudited quarterly financial statements along with a sufficiently detailed discussion of operating results,
trends and liquidity for each interim and annual period presented.


**2024 SEC annual reports — Form 10-K** | 24


---

2 General rules


Filing a comprehensive annual report does not absolve a registrant from any liability under the Exchange
Act for failing to file all required reports and would not remove the possibility of enforcement action for
the registrant’s filing delinquencies. In addition, filing a comprehensive annual report does not result in
the registrant being considered “current” for purposes of Regulation S, Rule 144 or Form S-8 registration
statements. Finally, the registrant would not be eligible to use Form S-3 until it establishes a sufficient
history of making timely filings.

##### 2.13.3 Clawbacks


In October 2022, the SEC adopted final rules that directed national securities exchanges to establish
listing standards requiring listed companies to claw back incentive-based compensation received by
current and former executive officers during the three years preceding an accounting restatement (the
“relevant recovery period”). The rules require companies to disclose their clawback policies as exhibits to
annual reports required by Item 601 of Regulation S-K. They also require companies to make certain
additional disclosures in proxy and information statements if, during the last completed fiscal year, they
were required to recover excess compensation or had an outstanding balance of excess compensation
related to a prior restatement. The SEC approved listing standards proposed by the NYSE and Nasdaq in
July 2023 and the standards were effective on 2 October 2023. Registrants listed on those exchanges
were required to adopt compliant clawback policies starting on 1 December 2023.


Companies are required to check boxes on the cover page of their Form 10-K to indicate whether (1) the
financial statements included in the filing reflect the correction of an error to previously issued financial
statements and (2) any of those restatements required a recovery analysis of incentive-based
compensation received by any of the registrant’s executive officers during the relevant recovery period.


Registrants must check box No. 1 if the financial statements for the prior years included in the Form 10-K
reflect a Big “R” or Little “r” restatement. In addition, the SEC staff has expressed its belief that this box
must also be checked if a registrant voluntarily corrects an immaterial error in the financial statements
for prior periods, which could include corrections in classification or revisions to footnote disclosures
(although they would not have to check the second box in this scenario). Registrants do not need to
check this box for the adoption of a new accounting standard with retrospective application, voluntary
reclassifications of prior year amounts that are not errors to conform to the current year presentation
and out-of-period adjustments.


See our _**[Proxy statements — An overview of the requirements and observations about current practice](https://www.ey.com/en_us/technical/accountinglink/2025-proxy-statements-an-overview-of-the-requirements)**_
publication for details on the disclosures required when a recovery analysis was required. Additionally,
see section 6, _Correction of an error in previously issued financial statements_, of our Financial reporting
developments (FRD) publication, _**[Accounting changes and error corrections](https://www.ey.com/en_us/technical/accountinglink/financial-reporting-developments---accounting-changes-and-error-)**_, for further discussion on the
types of error corrections referred to above.

##### 2.14 Forward-looking information


The federal securities laws include “safe harbor” provisions, which can protect public companies from
liability in private litigation for forward-looking statements (e.g., estimates, projections) made by them
and by others on their behalf. This protection is available when a company includes appropriate
cautionary language when making a forward-looking statement. Generally, these provisions are intended
to promote disclosures about a company’s future prospects by reducing the threat of liability if those
predictions fail to materialize. These provisions are found in Section 27A of the Securities Act and
Section 21E of the Exchange Act, in Rule 175 of the Securities Act and Rule 3b-6 of the Exchange Act.


In evaluating whether a forward-looking statement is protected under a safe harbor provision, courts
consider factors such as whether the statement was made in good faith and with a reasonable basis.


Registrants should consult legal counsel in drafting forward-looking statements. Registrants also should
consult with counsel whether they have forward-looking information that is required to be disclosed, for
example, because there are “known trends and uncertainties” to include in MD&A.


**2024 SEC annual reports — Form 10-K** | 25


---

2 General rules

##### 2.15 Non-GAAP financial measures 2.15.1 Definition


Item 10(e)(2) of Regulation S-K defines a “non-GAAP financial measure” as a numerical measure of a
company’s historical or future financial performance, financial position or cash flows that excludes
(includes) amounts, or is subject to adjustments that have the effect of excluding (including) amounts,
that are included (excluded) in the most directly comparable measure calculated in accordance with
GAAP. Thus, non-GAAP financial measures may be forward-looking.


Non-GAAP financial measures provide an alternative source of information, and management may
disclose them to help investors understand a company’s operating performance, cash flows or financial
position. Common non-GAAP measures include earnings before interest, taxes, depreciation and
amortization (EBITDA) and, for real estate investment trusts, funds from operations (FFO).


The definition of non-GAAP financial measures specifically excludes measures that are required to be
disclosed by GAAP, SEC rules or an applicable system of regulation imposed by a government, governmental
authority or self-regulatory organization (e.g., capital or reserves calculated for regulatory purposes).
In addition, non-GAAP financial measures do not include certain statistical and operating measures.
For example, non-GAAP financial measures do not include unit sales, number of website visitors, gross
billings/bookings, number of employees, number of subscribers, number of advertisers or any ratios or
measures that are calculated using financial amounts calculated in accordance with GAAP.


A ratio that includes a non-GAAP financial measure also is considered a non-GAAP financial measure. For
example, if operating margin is calculated using a non-GAAP measure of operating income (e.g., operating
income, adding back stock compensation expense) and sales revenue determined under GAAP, the statistic
would be considered a non-GAAP financial measure. Moreover, forward-looking information is not considered
a non-GAAP financial measure as long as the information is determined using GAAP-based measurement
principles. In addition, the definition of non-GAAP financial measures excludes the measure of segment profit
or loss used by the chief operating decision maker to allocate resources and assess performance because
ASC 280 [30,31] requires companies to disclose it in the notes to the financial statements.

##### 2.15.2 Conditions for presentation


Under Item 10(e) of Regulation S-K, when a company presents a non-GAAP financial measure in an
SEC filing, including an earnings release furnished in Form 8-K, it must (1) present, with equal or greater
prominence, the most directly comparable financial measure calculated and presented in accordance
with GAAP and (2) numerically reconcile the non-GAAP financial measure, by schedule or other clearly
understandable format, to the most directly comparable GAAP measure. If a company presents a
forward-looking non-GAAP measure, similar disclosures are required. However, a reconciliation of the
forward-looking non-GAAP financial measure to the corresponding forward-looking GAAP measure is not
required if it would involve an “unreasonable effort.” The SEC staff’s C&DI indicates that a company
should provide any reconciling information that is available without an unreasonable effort and disclose
the nature and significance of any reconciling information that is unavailable.


30 ASC 280 requires that companies report certain measures for each reportable segment on a basis consistent with that used for

internal management reporting purposes. ASC 280 requires segment revenues, assets, a measure of operating profit or loss, and
any other significant segment measures to be reconciled to the corresponding GAAP measures, with significant reconciling items
separately identified and described.

31 Refer to the discussion in section 5.2.5 of this publication related to the FASB’s issuance of ASU 2023-07, _Improvements to_

_reportable segment disclosures._


**2024 SEC annual reports — Form 10-K** | 26


---

2 General rules


Item 100(b) of Regulation G also states that a non-GAAP financial measure, taken together with
accompanying information, may not misstate a material fact or omit a material fact necessary to make
the presentation not misleading, in light of the circumstances in which the presentation is made.


The SEC staff’s C&DIs provide guidance on non-GAAP measures that may be misleading. Items may be
misleading if they apply “individually tailored” accounting principles, adjust performance measures to
remove normal cash operating expenses or exclude nonrecurring charges but not nonrecurring gains,
among others. The C&DIs also warn that the presentation of a non-GAAP financial measure might not
satisfy the SEC rules if the measure is not presented consistently with prior presentations. Accordingly,
issuers should include appropriate disclosures that describe changes in the methodology used to calculate
a non-GAAP financial measure and should consider recasting prior-period measures using the new
calculation methodology.


In addition, to present the corresponding GAAP measure with equal or greater prominence, the SEC staff
believes that it must be presented first. This includes in the required reconciliation (i.e., reconciling from
the GAAP measure to the non-GAAP measure).


The C&DIs also note that disclosures of non-GAAP financial measures also should be balanced with
disclosures regarding the corresponding GAAP measure. For instance, the SEC staff expects non-GAAP
cash flow and liquidity measures to be balanced with a discussion of cash flows from operating, investing
and financing activities reported in the statement of cash flows. Similarly, the SEC staff expects non-GAAP
performance measures to be balanced with a discussion of net income or income from continuing operations
reported in the statement of operations.


The following additional disclosure requirements apply to any disclosure of a non-GAAP financial measure
in material provided to the SEC, such as a Form 10-K filing or an earnings release furnished in Form 8-K:


- The issuer must disclose the reasons why management believes the non-GAAP financial measure provides
useful information to investors about the company’s financial condition and results of operations. [32]


- The issuer must disclose, to the extent material, any additional purposes for which management uses
the non-GAAP financial measure.


The following restrictions apply to any disclosure of a non-GAAP financial measure in any SEC filing, such
as Form 10-K:


- A non-GAAP liquidity measure other than EBIT (earnings before interest and taxes) or EBITDA
(earnings before interest, taxes, depreciation and amortization) may not exclude charges or liabilities
that required cash settlement, will require cash settlement or would have required cash settlement
absent an ability to settle in another manner.


- A non-GAAP performance measure may not be adjusted to eliminate or smooth items identified as
“nonrecurring, infrequent or unusual,” when (1) the nature of the charge or gain is such that it is reasonably
likely [33] to recur within two years or (2) there was a similar charge or gain within the prior two years.


32 FRR-65, _Conditions for Use of Non-GAAP Financial Measures_, states that the required disclosures should not be boilerplate. The

disclosures should be specific to the non-GAAP financial measure, the manner in which management uses the measure given the
registrant’s business and industry, and the manner in which investors might use the measure.

33 As the SEC stated in FRR-61, “reasonably likely” is a lower disclosure threshold than “more likely than not.”


**2024 SEC annual reports — Form 10-K** | 27


---

2 General rules


            - Non-GAAP financial measures may not be presented on the face of the company’s GAAP financial
statements or in the accompanying notes (unless the measure is required or permitted to be
presented in the financial statements by the standard setter responsible for establishing the
accounting principles used in preparing that issuer’s financial statements). [34]


            - Non-GAAP financial measures may not be presented on the face of any pro forma financial
information required to be disclosed by Article 11 of Regulation S-X.


            - An issuer may not use titles or descriptions of non-GAAP financial measures that are the same as, or
confusingly similar to, titles or descriptions used for GAAP financial measures.


See our Technical Line publication, _**[Navigating the requirements for non-GAAP financial measures](https://www.ey.com/en_us/technical/accountinglink/technical-line-navigating-the-requirements-for-non-gaap-financial-measures)**_, for
more details on non-GAAP rules and regulations. See our **SEC Reporting Update:** _**[Highlights of trends in](https://www.ey.com/en_us/technical/accountinglink/sec-reporting-update-highlights-of-trends-in-2024-sec-staff-comment-letters1)**_
_**[2024 SEC Staff comment letters](https://www.ey.com/en_us/technical/accountinglink/sec-reporting-update-highlights-of-trends-in-2024-sec-staff-comment-letters1)**_ publication for recent developments.

##### 2.16 Transition report — change in fiscal year


Rules 13a-10 and 15d-10 of the Exchange Act provide the SEC’s reporting and filing requirements when a
registrant changes its fiscal year-end or a successor issuer has a different fiscal year-end than its predecessor.
These rules designate as the “transition period” the short period between the end of the registrant’s most
recent fiscal year and the opening date of its newly selected fiscal year (e.g., a change in fiscal year from
31 December to 30 September would result in a nine-month transition period). Similarly, the reports
required by Rules 13a-10 and 15d-10 are designated “transition reports.” Under the accelerated reporting
rules, the deadline for a transition report filed by a large accelerated filer or an accelerated filer mirrors the
deadline for the respective Exchange Act form. Other rules, which are not addressed in this publication,
provide the reporting and filing requirements for a change in fiscal year-end by foreign private issuers
(Rules 13a-10(g) and 15d-10(g) of the Exchange Act) and registered investment companies (Rule 30b1-3
of the Investment Company Act of 1940).

##### 2.16.1 Transition reporting on Forms 10-K and 10-Q


Transition reports are required for all transition periods in excess of one month. A transition report on
Form 10-K, including audited financial statements, is required for transition periods of six or more months.
For transition periods less than six months, a registrant has the option of filing its transition report on either
Form 10-Q, including unaudited financial statements, or Form 10-K, including audited financial statements.


Transition periods of one month or less may be reported in conjunction with the first report on Form 10-Q or
Form 10-K of the fiscal year following transition. A change from a fiscal year ending as of the last day of the
month to a 52 to 53-week fiscal year-end of the same month, or vice versa, does not create a transition period.

##### 2.16.2 Transition period of six months or more


The due date for a transition report on Form 10-K is computed based on the close of the transition period
or the date of the determination to change the fiscal year, whichever is later. A transition report on
Form 10-K must include audited financial statements for the transition period and specified financial
information for the prior-year period comparable to the transition period. The comparable information
may be unaudited and can be presented within the financial statements or in the notes thereto.


34 Refer to the discussion in section 5.2.5 of this publication related to the FASB’s issuance of ASU 2023-07, _Improvements to_

_reportable segment disclosures._


**2024 SEC annual reports — Form 10-K** | 28


---

2 General rules


The comparable information must include revenue, gross profits, income taxes, income or loss from
continuing operations, net income or loss and related per share amounts. In addition, the effects of
discontinued operations, if applicable, should be included. If it is not practicable or cannot be cost-justified
to develop the information for comparable periods, the SEC staff might accept financial information for
the prior-year period most nearly comparable to the transition period. In that case, the SEC staff would
expect disclosures similar to those required in a Form 10-Q where comparable periods are not presented
(see discussion below).


In addition to the transition period, a transition report on Form 10-K must include audited financial
statements for fiscal years preceding transition as otherwise required by Form 10-K (i.e., three years).
The SEC will accept, but does not require, restatement of prior-period financial statements on the basis
of the newly adopted fiscal year. Pursuant to Rule 3-06 of Regulation S-X, a transition period of nine or
more months will be considered a full year.


For example, if there is a nine-month transition period, the requirements of Form 10-K would be satisfied by
providing audited balance sheets as of the close of the transition period and the preceding fiscal year-end, and
audited statements of income and cash flows for the nine-month transition period and two preceding fiscal
years. Conversely, if there is a six-month transition period, the transition report on Form 10-K would include
audited balance sheets as of the close of the transition period and the two preceding fiscal years, and audited
statements of income and cash flows for the six-month transition period and the three preceding fiscal years.


When the transition period is required to be included in subsequent reports, it is shown on the face of the
statements. Financial information for the comparable period would be included either within comparative
financial statements or in the notes thereto. The Form 10-K for the fiscal year following transition would include
audited balance sheets as of the close of that fiscal year and the transition period. The periods for which audited
statements of income and cash flows are required would be determined considering Rule 3-06 of Regulation S-X
(i.e., at least 33 consecutive months of audited statements of income and cash flows must be presented).

##### 2.16.3 Transition period less than six months


The due date for a transition report on Form 10-Q is computed based on the close of the transition period
or the date of the determination to change the fiscal year, whichever is later. A transition report on
Form 10-Q must include condensed unaudited financial statements for the transition period and financial
information about the comparable period of the prior year. When a registrant files a transition report on
Form 10-Q, separate audited statements of income and cash flows are required to be filed for the
transition period in the Form 10-K for the full year following transition. Therefore, a registrant with a
transition period of less than six months may elect to file a transition report on Form 10-K and include
audited financial statements for the transition period. Registrants might want to choose this option to
allow more time to prepare financial statements covering the transition period and to avoid the possibility
of later having to revise previously published unaudited financial statements for the transition period.


When a registrant files a transition report on Form 10-Q, the Form 10-K for the full year following
transition may include the audited balance sheet as of the end of the fiscal year preceding transition in
lieu of an audited balance sheet as of the close of the transition period. This option is in consideration of
the fact that the transition period balance sheet filed on Form 10-Q was not required to be audited.
Further, notes to the financial statements for the transition period included in the annual report may be
integrated with the notes for the full fiscal year. While financial schedules are not required in a transition
report on Form 10-Q, audited financial schedules (see section 7, _Financial schedules_ ) including the
transition period are required to be filed in subsequent annual reports on Form 10-K.


**2024 SEC annual reports — Form 10-K** | 29


---

2 General rules


For a transition period of one month or less, in lieu of a transition report on Form 10-K or Form 10-Q, a
registrant may separately include the unaudited financial statements for the transition period in the
Form 10-Q for the first quarter of the newly adopted fiscal year that ends after the determination date
for the change in fiscal year. However, separate audited statements of income and cash flows still are
required to be filed for the transition period in the Form 10-K of the full year following transition. If the
registrant’s first report is the Form 10-K for the full year following transition, the transition period of one
month or less would be separately covered in that Form 10-K.


Where comparative information is required in a transition report on Form 10-Q or in a quarterly report
based on the quarters of the newly adopted fiscal year, a registrant is not required to recast data for the
comparable period, where recasting either is not practicable or cannot be cost-justified, if the registrant
provides all of the following:


            - Financial statements for the quarters reported on the old fiscal year basis most nearly comparable to
the transition period or the interim period reported on the new fiscal year basis


            - An adequate discussion of seasonal and other factors that could affect the comparability of
information or trends reflected


            - An assessment of the comparability of the data


            - An explanation of why the statements have not been recast

##### 2.16.4 Reporting prior to the determination date


An issuer is required to file an annual report on Form 10-K for any fiscal year that ended before the date
on which the determination was made to change its fiscal year. Similarly, an issuer is required to file a
quarterly report for any quarter of the old fiscal year that ended before the date of the issuer’s
determination to change its year-end.

##### 2.16.5 Quarterly reporting during transition


During the transition period, registrants have the option of filing quarterly reports based on the quarters
of either the old or newly adopted fiscal year, provided that once the quarterly reporting basis is changed
to the new fiscal year, that basis must be followed consistently.


For example, an issuer with a 31 December year-end that decides on 15 April 20Y2 to change its yearend to 30 November 20Y2 would have an option to file its next Form 10-Q based on the quarter ended
30 June 20Y2 (old fiscal year basis) or 31 August 20Y2 (new fiscal year basis).


If the length of the transition period is other than three, six or nine months, the quarter ends of the new
fiscal year will not correspond to those of the old fiscal year. Accordingly, the change in quarterly reporting
from the old to the new fiscal year might result in a period that would not be covered in a separate report
on Form 10-Q. Such a period would be covered by the next report on either Form 10-Q or Form 10-K, or
in the transition report, depending on when the change occurred. Such a period would be reported
separately in a quarterly report on Form 10-Q, or on a cumulative basis in the transition report or the
Form 10-K for the fiscal year following the transition.


In the above example, if the issuer filed its Form 10-Q for the quarter ended 31 August 20Y2, separate
financial statements for the two-month period ended 31 May 20Y2 would be included in that Form 10-Q.
On the other hand, if the issuer continued to file Forms 10-Q on the old fiscal-year basis, the two-month
period ended 30 November 20Y2 would be included in the 11-month period ended 30 November 20Y2 in
the transition report on Form 10-K.


**2024 SEC annual reports — Form 10-K** | 30


---

2 General rules


Although the financial statements of the period created by the change in the basis of quarterly reporting
(as well as a one-month transition period) must be provided separately from those of the current
quarter when included in a quarterly Form 10-Q, the transition rules provide that other information
required by Form 10-Q, such as MD&A, may be combined for those periods and the current quarter.

##### 2.16.6 Quarterly reporting after transition


The requirement to file quarterly reports on the new basis begins with the first quarter in the fiscal year
following transition. However, the rules do not require an issuer to file new Forms 10-Q for any quarters
of the fiscal year following transition that have already been reported on the old fiscal-year basis. For
example, an issuer with a 31 December year-end might decide on 15 December 20Y2 to change its yearend to 30 April 20Y2. This registrant would have filed Forms 10-Q for the three quarters of its old fiscal
year and would not be required to file Forms 10-Q for the quarters of its 20Y3 fiscal year that ended before
its determination to change (i.e., the quarters ending 31 July 20Y2 and 31 October 20Y2). Such an
issuer would file its next quarterly report for the quarter ending 31 January 20Y3, which would include
separate financial statements for the one-month period ended 31 October 20Y2.

##### 2.16.7 Reporting fiscal year changes on Form 8-K


A registrant is required to report, on Form 8-K, its decision to adopt a new fiscal year. This filing is due four
business days after the date on which the registrant determines to change its fiscal year-end. Item 5.03
of Form 8-K requires a registrant to report both the date on which it decides to change its fiscal year and
the date of its new fiscal year. In addition, the Form 8-K must state whether a Form 10-K or Form 10-Q
will be filed to report financial information for the transition period.

##### 2.16.8 Transition reporting for successor issuers


In the situation where a successor issuer has a different fiscal year than its predecessor, the periods to
be covered are different from those described above. The period to be included in the transition report
by the successor issuer ends on the date of the succession, rather than on the day before the beginning
of the newly adopted year. This ensures a transition period that reflects the predecessor’s operations
separately from those of the successor. In addition, the due date for the transition report always is
measured from the date of succession (i.e., the end of the transition period). Examples of succession
include the leveraged buy-out of a public company and the reverse acquisition of a public company by a
nonpublic company (a backdoor registration). [35]

##### 2.16.9 MD&A for transition periods


The length of the transition period will determine the extent of disclosures required under Item 303 of
Regulation S-K, _Management’s Discussion and Analysis of Financial Condition and Results of Operations_ .
For transition periods of nine or more months, information is required under Item 303(b) as if the
transition period were a full fiscal year. For shorter transition periods, the information for interim
periods under Item 303(c) is required.


35 If a backdoor registration is accomplished by taking a private company public by merger with a “shell company,” as defined by

Regulation C, additional reporting considerations might be applicable. For further information, see the July 2005 SEC Final Rule,
_Use of Form S-8, Form 8-K, and Form 20-F by Shell Companies_ (Release Nos. 33-8587 and 34-52038).


**2024 SEC annual reports — Form 10-K** | 31


---

2 General rules

##### 2.16.10 Examples of reporting requirements for changes in year-end


Although not intended to cover all circumstances, the examples on the following pages illustrate reporting
requirements and alternatives, following a change in fiscal year-end. The actual reporting requirements and
options will vary based on the length of the transition period and the date on which the determination was
made to change the fiscal year-end. A registrant considering a change in fiscal year-end should consult with
its independent auditors and legal counsel regarding its reporting obligations. Because the financial
statements in annual shareholders’ reports and Form 10-K should be identical under the uniform financial
statement instructions, these illustrations apply to both unless otherwise discussed with the SEC staff.


**Examples of reporting requirements for changes in year-end**


**(Transition periods less than six months)**

**Reports filed prior**
**to transition report (1)** **Transition report**


**Reports filed for periods**
**subsequent to transition**

**report (4) (6)**


**Example 1: Change from 31 Dec 20Y1 to 28 Feb 20Y2**

**(Decision made 1 Mar 20Y2)**


Form 8-K filed within 4 business days
after 1 Mar 20Y2

Form 10-K filed 90 days after
31 Dec 20Y1:

Audited financial statements for the
three years ended 31 Dec 20Y1


Form 10-Q filed 45 days after
1 Mar 20Y2:

Unaudited financial statements

from 1 Jan 20Y2 to 28 Feb
20Y2 (2)

from 1 Jan 20Y1 to 28
Feb 20Y1 (5)

or

Form 10-K filed 90 days after
1 Mar 20Y2:

Audited statements of income and
cash flows

from 1 Jan 20Y2 to 28 Feb 20Y2
and three years ended
31 Dec 20Y1 (6)

Unaudited statements of income
and cash flows

from 1 Jan 20Y1 to 28 Feb
20Y1 (3)

Audited balance sheets as of

28 Feb 20Y2; 31 Dec 20Y1 and
20Y0


Form 10-K: Audited statements of
income and cash flows

from 1 Mar 20Y2 to 28 Feb 20Y3

from 1 Jan 20Y2 to 28 Feb 20Y2

from 1 Jan 20Y1 to 31 Dec 20Y1

from 1 Jan 20Y0 to 31 Dec 20Y0

Unaudited statements of income and
cash flows

from 1 Jan 20Y1 to 28 Feb
20Y1(3)

Audited balance sheets as of

28 Feb 20Y3 and either 28 Feb
20Y2 or 31 Dec 20Y1

Form 10-Q: Unaudited financial
statements (5)

from 1 Mar 20Y2 to 31 May 20Y2

from 1 Jun 20Y2 to 31 Aug 20Y2
and six months ended 31 Aug 20Y2

from 1 Sep 20Y2 to 30 Nov 20Y2
and nine months ended
30 Nov 20Y2


_**Note: The above tables reflect reporting deadlines for issuers that are “non-accelerated filers.” For large**_
_**accelerated filers and accelerated filers, the reporting deadline would correspond to the deadline**_
_**applicable to the respective Form.**_


See subsequent pages for footnote references.


**2024 SEC annual reports — Form 10-K** | 32


---

2 General rules


**Examples of reporting requirements for changes in year-end**


**(Transition periods less than six months)**

**Reports filed prior**
**to transition report (1)** **Transition report**


**Reports filed for periods**
**subsequent to transition**

**report (4) (6)**


**Example 2: Change from 31 Dec 20Y1 to 28 Feb 20Y2**

**(Decision made 1 Nov 20Y2)**


Form 8-K filed within 4 days business
after 1 Nov 20Y2

Form 10-K filed 90 days after 31 Dec
20Y1:

Audited financial statements for the
three years ended 31 Dec 20Y1

Form 10-Q filed 45 days after
31 Mar 20Y2, 30 Jun 20Y2 and
30 Sep 20Y2:

Unaudited financial statements

from 1 Jan 20Y2 to 31 Mar
20Y2, with comparable prior-year
period

from 1 Apr 20Y2 to 30 Jun 20Y2
and six months ended 30 Jun
20Y2, with comparable prior-year
periods

from 1 Jul 20Y2 to 30 Sep 20Y2
and nine months ended 30 Sep
20Y2, with comparable prior-year
periods


Form 10-Q filed 45 days after
1 Nov 20Y2:

Unaudited financial statements

from 1 Jan 20Y2 to 28 Feb
20Y2 (2)

from 1 Jan 20Y1 to 28 Feb
20Y1 (5)

or

Form 10-K filed 90 days after 1 Nov
20Y2:

Audited statements of income and
cash flows

from 1 Jan 20Y2 to 28 Feb
20Y2, and three years ended
31 Dec 20Y1 (6)

Unaudited statements of income
and cash flows

from 1 Jan 20Y1 to 28 Feb
20Y1 (3)

Audited balance sheets as of

28 Feb 20Y2; 31 Dec 20Y1 and
20Y0


Form 10-Q: Unaudited financial
statements (5)

from 1 Sep 20Y2 to 30 Nov
20Y2 (9)

Form 10-K: Audited statements of
income and cash flows

from 1 Mar 20Y2 to 28 Feb 20Y3

from 1 Jan 20Y2 to 28 Feb 20Y2

from 1 Jan 20Y1 to 31 Dec 20Y1

from 1 Jan 20Y0 to 31 Dec 20Y0

Unaudited statements of income and
cash flows

from 1 Jan 20Y1 to 28 Feb
20Y1 (3)

Audited balance sheets as of

28 Feb 20Y3 and either 28 Feb
20Y2 or 31 Dec 20Y1


_**Note: The above tables reflect reporting deadlines for issuers that are “non-accelerated filers.” For large**_
_**accelerated filers and accelerated filers, the reporting deadline would correspond to the deadline**_
_**applicable to the respective Form.**_


See subsequent pages for footnote references.


**2024 SEC annual reports — Form 10-K** | 33


---

2 General rules


**Examples of reporting requirements for changes in year-end**


**(Transition periods more than six months)**

**Reports filed prior**
**to transition report (1)** **Transition report**


**Reports filed for periods**
**subsequent to transition**

**report (4) (6)**


**Example 3: Change from 31 Dec 20Y1 to 31 Oct 20Y2**

**(Decision made 1 Feb 20Y2)**


Form 8-K filed within 4 business days
after 1 Feb 20Y2

Form 10-K filed 90 days after
31 Dec 20Y1:

Audited financial statements for the
three years ended 31 Dec 20Y1

Form 10-Q filed 45 days after
31 Mar 20Y2 and 30 Jun 20Y2 (8):

Unaudited financial statements

from 1 Jan 20Y2 to 31 Mar 20Y2
and comparable prior-year period

from 1 Apr 20Y2 to 30 Jun 20Y2
and six months ended 30 June
20Y2, with comparable prior-year
periods

or

Form 10-Q filed 45 days after 30 Apr
20Y2 and 31 Jul 20Y2 (8):

Unaudited financial statements

from 1 Jan 20Y2 to 31 Jan 20Y2
and from 1 Feb 20Y2 to 30 Apr
20Y2, with comparable prior-year
periods (5)

from 1 May 20Y2 to 31 Jul 20Y2
and six months ended 31 Jul
20Y2, with comparable prior-year
periods (5)


Form 10-K filed 90 days after
31 Oct 20Y2:

Audited statements of income and
cash flows

from 1 Jan 20Y2 to 31 Oct
20Y2 (7) and two years ended
31 Dec 20Y1 (6)

Unaudited statements of income
and cash flows

from 1 Jan 20Y1 to 31 Oct
20Y1 (3)

Audited balance sheets as of

31 Oct 20Y2 and 31 Dec 20Y1


Form 10-Q: Unaudited financial
statements (5)

from 1 Nov 20Y2 to 31 Jan 20Y3

from 1 Feb 20Y3 to 30 Apr 20Y3
and six months ended 30 Apr 20Y3

from 1 May 20Y3 to 31 Jul 20Y3
and nine months ended 31 Jul 20Y3

Form 10-K: Audited financial
statements

from 1 Nov 20Y2 to 31 Oct 20Y3

from 1 Jan 20Y2 to 31 Oct
20Y2 (7)

from 1 Jan 20Y1 to 31 Dec 20Y1

Unaudited statements of income and
cash flows

from 1 Jan 20Y1 to 31 Oct
20Y1 (3)


_**Note: The above tables reflect reporting deadlines for issuers that are “non-accelerated filers.” For large**_
_**accelerated filers and accelerated filers, the reporting deadline would correspond to the deadline**_
_**applicable to the respective Form.**_


See subsequent pages for footnote references.


**2024 SEC annual reports — Form 10-K** | 34


---

2 General rules


**Examples of reporting requirements for changes in year-end**


**(Transition periods more than six months)**

**Reports filed prior**
**to transition report (1)** **Transition report**


**Reports filed for periods**
**subsequent to transition**

**report (4) (6) (10)**


**Example 4: Change from 31 Dec 20Y1 to 31 Oct 20Y2**

**(Decision made 15 Nov 20Y2)**


Form 8-K filed within 4 business days
after 15 Nov 20Y2

Form 10-K filed 90 days after
31 Dec 20Y1:

Audited financial statements for the
three years ended 31 Dec 20Y1

Form 10-Q filed 45 days after
31 Mar 20Y2, 30 Jun 20Y2 and
30 Sep 20Y2:

Unaudited financial statements

from 1 Jan 20Y2 to 31 Mar 20Y2,
with comparable prior-year period

from 1 Apr 20Y2 to 30 Jun 20Y2
and six months ended 30 Jun
20Y2, with comparable prior-year
periods

from 1 Jul 20Y2 to 30 Sep 20Y2
and nine months ended 30 Sep
20Y2, with comparable prior-year
periods


Form 10-K filed 90 days after
15 Nov 20Y2:

Audited statements of income and
cash flows

from 1 Jan 20Y2 to 31 Oct
20Y2 (7) and two years ended
31 Dec 20Y1 (6)

Unaudited statements of income
and cash flows

from 1 Jan 20Y1 to 31 Oct
20Y1 (3)

Audited Balance Sheets as of

31 Oct 20Y2 and 31 Dec 20Y1


Form 10-Q: Unaudited financial
statements (5)

from 1 Nov 20Y2 to 31 Jan 20Y3

from 1 Feb 20Y3 to 30 Apr 20Y3
and six months ended 30 Apr 20Y3

from 1 May 20Y3 to 31 Jul 20Y3
and nine months ended 31 Jul 20Y3

Form 10-K: Audited financial
statements

from 1 Nov 20Y2 to 31 Oct 20Y3

from 1 Jan 20Y2 to 31 Oct
20Y2 (7)

from 1 Jan 20Y1 to 31 Dec 20Y1

Unaudited statements of income and
cash flows

from 1 Jan 20Y1 to 31 Oct 20Y1 (3)


_**Note: The above tables reflect reporting deadlines for issuers that are “non-accelerated filers.” For large**_
_**accelerated filers and accelerated filers, the reporting deadline would correspond to the deadline**_
_**applicable to the respective Form.**_


See subsequent pages for footnote references.


**2024 SEC annual reports — Form 10-K** | 35


---

2 General rules


The following note references correspond to the examples presented on the previous pages:


(1) This column lists reporting requirements subsequent to the latest fiscal year-end to the date of the

transition report.


(2) Form 10-K covering the full year from 1 March 20Y2 to 28 February 20Y3 must include separate

audited statements of income, comprehensive income and cash flows covering the transition period
from 1 January 20Y2 to 28 February 20Y2.


(3) This information may be in a note to the financial statements and must include revenue, gross

profits, income taxes, income or loss from continuing operations, net income or loss, and related
per share amounts, as well as the effects of discontinued operations, if applicable.


(4) These reports would be based on the new fiscal year and filed subsequent to the transition period

within the prescribed time period for the appropriate form.


(5) Although the rules encourage registrants to recast prior-year financial information on a comparable

basis with the transition period and new fiscal-year quarters, this is not required if it is not practicable
or cannot be cost-justified, provided certain disclosures are made.


(6) The rules also allow registrants to recast all prior years to correspond to the newly adopted fiscal year.


(7) The 10-month period from 1 January 20Y2 to 31 October 20Y2 would be considered equivalent to

a year for purposes of meeting the requirement to provide financial statements for three fiscal
years. However, unaudited financial information for the comparable period of the preceding year
must be provided.


(8) As an alternative to transition period quarterly reporting consistent with the basis of either the old

or the new fiscal year, a registrant may switch the basis of quarterly reporting during the transition
period. In this example, the registrant may file the first Form 10-Q on the old fiscal-year basis (for
the old quarter ended 31 March 20Y2 with unaudited financial statements from 1 January 20Y2 to
31 March 20Y2 and comparable prior-year period) and the second Form 10-Q on the new fiscal-year
basis (for the new quarter ended 31 July 20Y2 with unaudited financial statements from 1 April 20Y2
to 30 April 20Y2 and from 1 May 20Y2 to 31 July 20Y2 and comparable prior-year periods).


(9) A Form 10-Q must be filed for any quarter of the fiscal year following transition that ends after the

issuer determined to change its year-end. When the determination to change the year-end is made
after the close of the transition period, compliance with this requirement may result in an overlap
in quarterly reporting. In this example, the month of September 20Y2 is reported in both the
30 September 20Y2 Form 10-Q (old fiscal-year basis) and the 30 November 20Y2 Form 10-Q
(new fiscal-year basis).


(10) The audited financial statements filed on Form 10-K must include at least 33 months of audited

financial information, including the transition period. In this example, a total of 34 months are
provided (two 12-month fiscal years plus the 10-month transition period). Had the transition period
in this example been at least six months but less than nine months, an additional year of audited
financial statements would have been required to present the minimum of 33 months of audited
financial information.


**2024 SEC annual reports — Form 10-K** | 36


---

### **3 Part I of Form 10-K**

Regulation S-K contains most of the rules for disclosure of information required in Part I of Form 10-K,
including:


Item 101 Description of Business

Item 102 Description of Property

Item 103 Legal Proceedings


Item 104
Item 105


Mine Safety Disclosure
Risk Factors


Item 106 Cybersecurity


This section is designed to assist management in preparing information required by the above items in
Items 1 through 4 of Form 10-K.

##### 3.1 Item 1. Business


Item 1 of Form 10-K, _Business_, calls for information specified in Item 101 of Regulation S-K, _Description_
_of Business_, about: (1) the development of the registrant’s business (which may provide only material
updates along with a hyperlink to the most recently filed full discussion of developments that, together
with the update, would present a complete discussion) and (2) a description of the business done and
intended to be done by the registrant and its subsidiaries, focusing on each reportable segment about
which financial information is presented in the financial statements.


Item 101(c), _Description of business_, of Regulation S-K allows the registrant to focus its business discussion
on its dominant segment or each reportable segment about which financial information is presented the
registrant’s financial statements. It contains a non-exclusive list of topics that ordinarily require
disclosures only if they are material to an understanding of the registrant’s business taken as a whole:


            - Revenue-generating activities, products and/or services, and any dependence on revenue-generating
activities, key products, services, product families or customers, including governmental customers


            - Status of development efforts for new or enhanced products, trends in market demand and
competitive conditions


            - Sources and availability of raw materials


            - The duration and effect of all patents, trademarks, licenses, franchises and concessions held


            - Description of any material portion of the business that may be subject to renegotiation of profits or
termination of contracts or subcontracts by the government


            - Extent to which the business is or may be seasonal


            - Effects of compliance with government regulations


            - Description of human capital resources, including number of employees, and any human capital
measures or objectives on which management focuses


The list is nonexclusive, which the SEC said is intended to make the requirements more clearly principlesbased and less likely to elicit disclosure that is not material.


**2024 SEC annual reports — Form 10-K** | 37


---

3 Part I of Form 10-K


There may be situations where information should be disclosed about a particular segment even though the
information is not material in quantitative terms and may not otherwise appear significant to the registrant’s
business taken as a whole. Furthermore, copies of contracts or other agreements are required to be filed
as exhibits to Form 10-K if they are specifically referred to in the registrant’s discussion of segments.


These SEC guidelines are subjective and require careful consideration by management.


Certain information about the nature of organization required by ASC 275, _Risks and Uncertainties_, should
be included in the notes to the financial statements of domestic registrants preparing annual reports on
Form 10-K. Among other things, ASC 275 requires disclosures about the risks and uncertainties existing
as of the balance sheet date in the following areas: (1) nature of operations, (2) use of estimates in the
preparation of the financial statements, (3) certain significant estimates and (4) current vulnerability because
of certain concentrations. [36]


The disclosure requirements of ASC 280, _Segments_, are described in detail in our GAAP disclosure checklist
(EY Form A13) and in our FRD publication, _**[Segment reporting](https://www.ey.com/en_us/technical/accountinglink/financial-reporting-developments-segment-reporting-)**_ _,_ and our Technical Line publication, _**[A closer](https://www.ey.com/en_us/technical/accountinglink/technical-line-a-closer-look-at-the-fasbs-new-segment-disclosure-requirements#:~:text=How%20a%20flexible%20supply%20chain%20raised%20the%20bar)**_
_**[look at the FASB’s new segment disclosure requirements](https://www.ey.com/en_us/technical/accountinglink/technical-line-a-closer-look-at-the-fasbs-new-segment-disclosure-requirements#:~:text=How%20a%20flexible%20supply%20chain%20raised%20the%20bar)**_ . [37]

##### 3.2 Other business-related disclosures 3.2.1 Effect of compliance with government regulations


Item 101(c)(2)(i) requires registrants to disclose the material effects that compliance with government
regulations, including environmental regulations, may have on the capital expenditures, earnings and
competitive position of the registrant and its subsidiaries. Registrants must disclose any material estimated
capital expenditures for environmental control facilities for the rest of its fiscal year and any succeeding
periods. The information specified in Item 101(c)(2)(i) should be discussed with respect to, and to the
extent material to an understanding of, the business taken as a whole, except that if the information is
material to a particular segment, the registrant should identify that segment.


These disclosures should be coordinated with related environmental disclosures under Item 103 of
Regulation S-K, _Legal Proceedings_ (see below), and Item 303 of Regulation S-K, _Management’s Discussion_
_and Analysis of Financial Condition and Results of Operations_ (see section 5, _Item 7. MD&A_ ).

##### 3.2.2 Human capital resources


Human capital resources disclosures required by Item 101(c)(2)(ii) of Regulation S-K include a description
of human capital resources and any measures or objectives on which management focuses, if they are
material to an understanding of the business. Examples of human capital measures and objectives that
may be material are measures on personnel attraction, development and/or retention. In its 2020
adopting release, **33-10825,** _**[Modernization of Regulation S-K Items 101, 103, and 105](https://www.sec.gov/rules/final/2020/33-10825.pdf)**_, the SEC
emphasized that these measures are examples of potentially relevant subjects, not mandates, and
provided registrants with significant disclosure flexibility related to human capital disclosures.


The SEC also said in its 2020 adopting release that its principles-based requirement will allow the human
capital disclosures to evolve over time in response to factors such as the industry, the various regions or
jurisdictions in which the registrant operates, strategy (e.g., vertically integrated), and macroeconomic
and other conditions that affect human capital resources, such as national or global health matters.


36 See section 5 of this publication with respect to the ASC 275 financial statement requirements about significant estimates and

vulnerabilities from concentrations, which also meet the MD&A disclosure requirements.

37 The SEC staff continues to emphasize segment disclosures and the application of ASC 280 in its comment letters. The SEC staff

comments generally focus on (1) the identification of operating segments, (2) the aggregation of operating segments, and (3) the
disclosure of the measure of profit or loss for reportable segments, the appropriate entity-wide disclosures for products and services,
revenues attributable to individual foreign countries and revenues from major customers, and reconciliations required by ASC 280.
See our **SEC Reporting Update:** _**[Highlights of trends in 2024 SEC Staff comment letters](https://www.ey.com/en_us/technical/accountinglink/sec-reporting-update-highlights-of-trends-in-2024-sec-staff-comment-letters1)**_, publication for additional details.


**2024 SEC annual reports — Form 10-K** | 38


---

3 Part I of Form 10-K


There is only one human capital metric for which quantitative disclosure is required: the number of
persons employed by the registrant. Registrants can determine whether to quantify their other human
capital disclosures based on the focus of the registrant’s management. Our _**[How to approach the SEC’s](https://www.ey.com/en_us/technical/accountinglink/how-to-approach-the-sec-s-new-human-capital-disclosures)**_
_**[new human capital disclosures](https://www.ey.com/en_us/technical/accountinglink/how-to-approach-the-sec-s-new-human-capital-disclosures)**_ publication provides guidance for registrants to consider as they prepare
their disclosures.

##### 3.2.3 Website access disclosure


Item 101(e)(3) of Regulation S-K requires a company to disclose in its Form 10-K its company website
address, if it has one. Item 101(e) also requires accelerated and large accelerated filers to disclose the
following additional information:


            - Whether the issuer provides access to its SEC reports (i.e., Form 10-K, Form 10-Q and Form 8-K) and
related amendments free of charge on or through the company’s website as soon as reasonably
practicable after the report is electronically filed with, or furnished to, the SEC (i.e., typically the
same day)


            - If the issuer does not provide such website access, why it does not and whether the issuer will
voluntarily provide electronic or paper copies of its SEC filings free of charge on request


Disclosure of a company’s website address in its Form 10-K will not, by itself, cause information on the
website to be included or incorporated by reference into the SEC report, unless the company explicitly
incorporates any such information by reference. [38]


##### 3.3 Item 1A. Risk factors

In their annual reports, issuers [39] must disclose risk factors, as specified in Item 105 of Regulation S-K,
that apply to an investment in the issuer rather than participation in a particular securities offering.
The Form 10-K instructions require registrants to discuss risk factors concisely and in “plain English.”
Item 105 requires the discussion of material risk factors to be organized under relevant subheadings in
addition to each risk factor appearing in a separate subcaption that adequately describes the risk. Risks
that could apply generically to any registrant are discouraged, and if provided, they have to be placed at
the end of the risk factors disclosure in a subheading titled “General risk factors.” If a filing’s risk factors
section exceeds 15 pages, the registrant must include a summary of the principal risk factors that is no
more than two pages in the forepart of the annual report where risk factors are discussed.


38 The SEC’s interpretive release, _Commission Guidance on the Use of Company Websites_ (SEC Release No. 34-58288), provides

guidance regarding the use of company websites under the Exchange Act and the antifraud provisions of the federal securities
laws. The guidance focuses on: (1) when information posted on a company website is “public” for purposes of the applicability of
Regulation FD; (2) company liability for information on company websites — including previously posted information, hyperlinks to
third-party information, summary information and the content of interactive websites; (3) the types of controls and procedures
advisable with respect to such information; and (4) the format of information presented on a company website, with the focus on
readability, not printability.

39 Issuers of asset-backed securities and SRCs are not required to disclose risk factors in their annual reports.


**2024 SEC annual reports — Form 10-K** | 39


---

3 Part I of Form 10-K


The SEC’s 2010 interpretive guidance [40 ] on climate-related disclosures addresses several potential risks that
a registrant may have to consider for risk factor disclosure. See our Technical Line publication, _**[Revisiting](https://www.ey.com/en_us/technical/accountinglink/technical-line---revisiting-the-sec-s-guidance-on-climate-change)**_
_**[the SEC's guidance on climate change disclosures in today's environment](https://www.ey.com/en_us/technical/accountinglink/technical-line---revisiting-the-sec-s-guidance-on-climate-change)**_, for additional information.


Additionally, please refer to the SEC staff’s **[sample comment letter](https://www.sec.gov/corpfin/sample-letter-climate-change-disclosures?utm_medium=email&utm_source=govdelivery)** posted on the SEC website in
September 2021 that illustrates the types of comments issued to companies about risk factor
disclosures. As previously discussed in the Overview section of this publication, the SEC voluntarily
stayed its climate-related disclosure rules on 4 April 2024 pending judicial review by the US Court of
Appeals for the Eight Circuit of the consolidated challenges to the rules. Companies should continue to
consider the Commission’s 2010 guidance and the September 2021 sample comment.


See our **SEC Reporting Update:** _**[Highlights of trends in 2024 SEC staff comment letters](https://www.ey.com/en_us/technical/accountinglink/sec-reporting-update-highlights-of-trends-in-2024-sec-staff-comment-letters1)**_ publication for
[additional information on risk factor disclosures.](https://www.ey.com/en_us/technical/accountinglink/sec-reporting-update-highlights-of-trends-in-2024-sec-staff-comment-letters1)

##### 3.4 Item 1B. Unresolved staff comments


Issuers that meet the definition of a large accelerated filer or an accelerated filer (see discussion on when
the report is due in section 2), as well as that of a “well-known seasoned issuer,” [41] must disclose in their
Form 10-K the substance of any unresolved written comments received from the SEC staff. Disclosure is
required only if the comments were received from the SEC staff more than 180 days before the issuer’s
fiscal year-end covered by the annual report, the issuer believes the comments are material and the
comments remain unresolved at the time of the Form 10-K filing. SEC staff comments that have been
resolved, including those the issuer and the SEC staff have agreed will be addressed in future Exchange
Act reports, are not required to be disclosed. In disclosing unresolved SEC staff comments, the issuer is
allowed to provide other information, including its position, for any such comment.


40 FRR-82 (SEC Release No. 33-9106), _Commission Guidance Regarding Disclosure Related to Climate Change_ .

41 Securities Act Rule 405 defines a “well-known seasoned issuer” (or WKSI) as an issuer, that as of the most recent determination

date, was eligible to use Form S-3 or Form F-3, with either of the following attributes:

  - Worldwide market value of $700 million or more of outstanding voting and non-voting common equity held by non-affiliates of
the registrant (i.e., “public float”)

  - Issued at least $1 billion aggregate principal amount of non-convertible securities, other than common equity, in registered
primary offerings for cash, not exchange, in the last three years
The WKSI definition specifically excludes asset-backed issuers, registered investment companies, business development
companies and ineligible issuers.


**2024 SEC annual reports — Form 10-K** | 40


---

3 Part I of Form 10-K

##### 3.5  Item 1C. Cybersecurity


Item 106 of Regulation S-K requires registrants to disclose their cybersecurity risk management,
strategy and governance in their annual reports on Form 10-K.

##### 3.5.1  Risk management and strategy


Item 106(b) requires registrants to disclose their processes, if any, to assess, identify and manage
material risks from cybersecurity threats in sufficient detail for a reasonable investor to understand
those processes. The rule provides the following list of potential disclosure items:


            - Whether and how any such processes have been integrated into a registrant’s overall risk
management system or processes


            - Whether the registrant uses assessors, consultants, auditors or other third parties in connection with
any such processes


            - Whether the registrant has processes to oversee and identify material risks from cybersecurity
threats related to its use of third-party service providers


A registrant must disclose whether any risks from cybersecurity threats, including as a result of any
previous cybersecurity incidents, have materially affected or are reasonably likely to materially affect its
business strategy, results of operations or financial condition and, if so, how.


A registrant is not required to disclose the name of any third-party service provider used or a description
of its services because this information could expose cybersecurity vulnerabilities, but the registrant may
elect to do so.


Although the SEC used the term “processes” instead of “policies and procedures” in the rules to avoid
providing detailed operating disclosures to bad actors, registrants should disclose additional information
as necessary based on their facts and circumstances such that a reasonable investor can understand
their cybersecurity processes and practices. This may include whether the registrant has a risk
assessment program in place and sufficient detail for investors to understand the registrant’s
cybersecurity risk profile. Registrants are only required to describe these processes if they relate to
material cybersecurity risks.


Examples of cybersecurity risks that may be material to registrants include intellectual property theft,
fraud, extortion, harm to employees or customers, violation of privacy laws, and other legal risk and
reputational risk.

##### 3.5.2  Governance


Item 106(c)(1) of Regulation S-K requires disclosure of the board’s role in overseeing risks from
cybersecurity threats. A registrant must identify any board committee or subcommittee that oversees
cybersecurity risks, if applicable, and describe the processes by which the committee is informed about
such risks. Although the rules do not require registrants to disclose the frequency of the board’s or
committee’s discussions on cybersecurity, registrants could include this information when describing the
processes by which their board or relevant committee is informed about cybersecurity risks.


Registrants may find that Item 407(h) of Regulation S-K, which requires the description of the board’s
leadership structure and administration of risk oversight, overlaps with the disclosure requirements
under Item 106(c)(1) related to the board’s oversight of specific cybersecurity risk. If the disclosures are
duplicative, a registrant may incorporate this information by reference.


**2024 SEC annual reports — Form 10-K** | 41


---

3 Part I of Form 10-K


Item 106(c)(2) requires disclosures about management’s role in assessing and managing material risks
from cybersecurity threats. At a minimum, companies should consider disclosing:


            - Whether and which management positions or committees are responsible for assessing and
managing cybersecurity risk and their relevant expertise in enough detail to fully describe the nature
of the expertise


            - The processes by which management is informed about and monitors the prevention, detection,
mitigation and remediation of cybersecurity incidents


            - Whether management reports information about such risks to the board of directors or a board
committee or subcommittee


See our Technical Line publication, _**[A closer look at the SEC’s new rules on cybersecurity disclosures](https://www.ey.com/en_us/technical/accountinglink/technical-line-a-closer-look-at-the-secs-new-rules-on-cybersecurity-disclosures)**_, for
additional information about the SEC’s cybersecurity rules.

##### 3.6 Item 2. Properties


Item 102 of Regulation S-K requires registrants to describe the location and general character of their
“principal physical properties” that are material and identify the business segment(s) that use these
properties. Item 102 also requires disclosure of how the property is held (if not in fee) and of any
material encumbrance.


The disclosure under Item 2 of Form 10-K should be sufficient to reasonably inform investors as to the
“suitability, adequacy, productive capacity and extent of utilization of the facilities by the registrant.” If
appropriate, the disclosure about properties may be provided on a collective basis.

##### 3.7 Item 3. Legal proceedings


Item 103 of Regulation S-K requires a brief description of:


            - Any material pending legal proceedings involving the registrant or its subsidiaries, or of which any
of their property is the subject, other than “ordinary routine litigation incidental to the business”
(e.g., actions for negligence or other claims of a kind normal to the issuer’s business)


            - Any similar proceedings known to be contemplated by governmental authorities


            - Any proceedings in which the adversary is any director, officer or affiliate of the registrant, any
beneficial owner of more than 5% of any class of voting securities of the registrant or any associate
of any of the foregoing persons, or in which any such persons have a material interest adverse to the
registrant or any of its subsidiaries


However, no disclosure is required for any of these types of proceedings (or group of similar proceedings)
involving primarily a claim for damages if the amount involved, exclusive of interest and costs, does not
exceed 10% of consolidated current assets.


Item 103 of Regulation S-K also requires a brief description of any material bankruptcy, receivership or
similar proceeding involving the registrant or any of its significant subsidiaries.


Separately, Item 103 of Regulation S-K requires a brief description of any administrative or judicial
proceeding (or group of similar proceedings) under any Federal, State or local environmental protection
provisions that: (1) is material to the business or financial condition of the registrant; (2) involves claims
for damages (or potential monetary sanctions, capital expenditures, current or deferred charges to
income) greater than 10% of consolidated current assets, exclusive of interest and costs; or (3) involves
a governmental authority as a party and potential monetary sanctions (unless the registrant reasonably


**2024 SEC annual reports — Form 10-K** | 42


---

3 Part I of Form 10-K


believes that aggregate monetary sanctions, exclusive of interest and costs, will not exceed $300,000).
A registrant may choose a higher threshold than $300,000 under the third criterion above, if the threshold
is reasonably designed to result in disclosure of any material federal, state or local environmental
protection proceeding and does not exceed the lesser of $1 million or 1% of the registrant’s current assets.


For any of the proceedings subject to disclosure under Item 103 of Regulation S-K, the description
should include the name of the court or agency in which the proceedings are pending, the date instituted,
the principal parties involved, the allegations and the relief sought. The information required in Item 103 may
be provided by hyperlink or cross-reference to legal proceedings disclosure elsewhere in the same filing
(e.g., financial statement footnotes).


Although this is not specifically required to be included in Item 3 of Form 10-K, the Iran Threat Reduction and
Syria Human Rights Act of 2012, amended Section 13 of the Exchange Act to require public companies
to disclose in their annual reports on Form 10-K whether they or their affiliates knowingly engaged in
specified activities involving Iran. The required disclosures include:


            - The nature and extent of the activity


            - Gross revenues and net profits attributable to the activity


            - Whether the registrant or any of its affiliates intend to continue engaging in such activities [42]


In addition, if these disclosures are required, companies must separately file a notice with the SEC stating
that such disclosures are included in the Form 10-K.

##### 3.7.1 Disclosure of certain tax penalties


The American Jobs Creation Act of 2004 (AJCA) added Section 6707A, _Penalty for Failure to Include_
_Reportable Transaction Information with Return_, to the Internal Revenue Code (Code). This section
requires a person or company that files periodic reports with the SEC (or who is consolidated with
another company for purposes of those reports) to disclose in those reports if they are required to pay
certain penalties relating to certain reportable transactions. The disclosure requirement is one of several
provisions in the AJCA designed to crack down on tax avoidance transactions.


To provide further guidance on the application of the law, the IRS issued Revenue Procedure (Rev. Proc.)
2005-51 in August 2005. In March 2007, the IRS issued Rev. Proc. 2007-25 to reinforce that the
disclosure requirement extends to other periodic reports in addition to Form 10-K, and that the application
guidance in Rev. Proc. 2005-51 is also relevant for the other forms.


Registrants should consult with legal counsel in drafting the disclosures required by the AJCA and related
IRS Revenue Procedures.

##### 3.8 Item 4. Mine safety disclosures


Item 4 of Form 10-K requires registrants to include a brief statement that the information concerning mine
safety violations or other regulatory matters required by Section 1503(a) of the Dodd-Frank Wall Street
Reform and Consumer Protection Act is included in Exhibit 95, _Mine Safety Disclosure Exhibit_, to the
Form 10-K. Exhibit 95 must be filed to provide the information required by Item 104 of Regulation S-K.


42 The SEC staff issued guidance on complying with the Iran Threat Reduction and Syria Human Rights Act of 2012. The staff clarified

that the term “affiliate” refers to any person who directly or indirectly controls, is controlled by or is under common control with
the issuer. If neither the issuer nor its affiliates have engaged in any of the specified activities, no disclosure is required. The SEC
staff C&DIs can be found at **[http://www.sec.gov./divisions/corpfin/guidance/exchangeactsections-interps.htm#147.01](http://www.sec.gov./divisions/corpfin/guidance/exchangeactsections-interps.htm#147.01)** .


**2024 SEC annual reports — Form 10-K** | 43


---

3 Part I of Form 10-K


Item 104 of Regulation S-K requires a registrant that is the operator, or that has a subsidiary that is an
operator, of a coal or other mine in the US to provide the information specified below for the time period
covered by the report (i.e., for the fiscal year):


- For each coal or other mine of which the registrant or a subsidiary of the registrant is an operator,
identify the mine and disclose:


   - The total number of violations of mandatory health or safety standards that could significantly
and substantially contribute to the cause and effect of a coal or other mine safety or health
hazard under Section 104 of the Federal Mine Safety and Health Act of 1977 (Act) for which the
operator received a citation from the Mine Safety and Health Administration (MSHA).


   - The total number of orders issued under Section 104(b) of such Act.


   - The total number of citations and orders for unwarrantable failure of the mine operator to
comply with mandatory health or safety standards under Section 104(d) of such Act.


   - The total number of flagrant violations under Section 110(b)(2) of such Act.


   - The total number of imminent danger orders issued under Section 107(a) of such Act.


   - The total dollar value of proposed assessments from MSHA under such Act. Registrants must
provide the total dollar value of assessments proposed by MSHA relating to any type of violation
during the period covered by the report, regardless of whether the registrant has challenged or
appealed the assessment.


   - The total number of mining-related fatalities at mines subject to such Act. Registrants must
report all fatalities occurring at a coal or other mine during the period covered by the report
unless the fatality has been determined by MSHA to be unrelated to mining activity.


- A list of coal or other mines, of which the registrant or a subsidiary of the registrant is an operator,
that receive written notice from MSHA of:


   - A pattern of violations of mandatory health or safety standards that are of such nature as could
have significantly and substantially contributed to the cause and effect of coal or other mine
health or safety hazards under Section 104(e) of such Act; or


   - The potential to have such a pattern.


- Any pending legal action before the Federal Mine Safety and Health Review Commission (FMSHRC)
involving such coal or other mine. In doing so, the registrant must report the total number of legal
actions that were pending before FMSHRC by mine as of the last day of the time period covered by
the report categorized according to the type of proceeding, as well as the aggregate number of legal
actions instituted and the aggregate number of legal actions resolved during the reporting period.


**2024 SEC annual reports — Form 10-K** | 44


---

4 Part II of Form 10-K

### **4 Part II of Form 10-K**


Regulation S-K contains the rules for disclosure of information required in Part II of Form 10-K, including:


Item 201 Market Price of and Dividends on the Registrant’s Common Equity and Related Stockholder Matters

Item 302 Supplementary Financial Information

Item 303 Management’s Discussion and Analysis of Financial Condition and Results of Operations

Item 304 Changes in and Disagreements with Accountants on Accounting and Financial Disclosure

Item 305 Quantitative and Qualitative Disclosures About Market Risk

Item 307 Disclosure Controls and Procedures

Item 308 Internal Control Over Financial Reporting

Item 408 Insider trading arrangements and policies

Item 701 Recent Sales of Unregistered Securities; Use of Proceeds from Registered Securities

Item 703 Purchases of Equity Securities by the Issuer and Affiliated Purchasers


Regulation S-X provides the financial statement requirements of the registrant and its subsidiaries for
Item 8 of Part II of Form 10-K. Section 6, _Financial statements and parent company information_,
discusses the Form 10-K financial statement requirements of Regulation S-X in detail. This section is
designed to help management prepare information required by the above Regulation S-K items, except for
Regulation S-K Item 303, _Management’s Discussion and Analysis of Financial Condition and Results of_
_Operations_, which is discussed in section 5 of this publication.

##### 4.1 Item 5. Market for registrant’s common equity, related stockholder matters and issuer purchases of equity securities


Items 201(a) and (b) of Regulation S-K require disclosure of certain information about each class of the
registrant’s common stock. Briefly, a registrant is required to disclose the following information:


            - Principal US markets on which the registrant’s common stock is traded and all US securities
exchanges on which the common stock is listed (when there is no established trading market, a
statement to that effect should be made) [43]


            - If the principal market is an exchange, the trading symbol(s) for each class of the registrant’s
common equity


            - If there is no established public trading market for a class of common equity, a statement to that effect
and, if applicable, the range of high and low bid information for each full quarterly period within the two
most recent fiscal years, indicating the source of such quotations. Also, the disclosure should indicate,
if applicable, that any over-the-counter market quotations reflect inter-dealer prices, without retail
markup, markdown or commission and may not necessarily represent actual transactions.


            - Approximate number of shareholders as of the latest practicable date (identifying the method of
computation — e.g., number of record holders)


43 Likewise, a foreign registrant should identify the principal foreign trading market(s) and the corresponding trading symbol(s) for

each class of its common equity.


**2024 SEC annual reports — Form 10-K** | 45


---

4 Part II of Form 10-K


Registrants must adjust the market price data to give retroactive effect to material changes resulting
from stock dividends, stock splits and reverse stock splits.


##### 4.2 Securities authorized for issuance under equity compensation plans

Item 201(d) of Regulation S-K requires registrants to provide in their Form 10-K, tabular information for
all equity compensation plans and individual compensation arrangements in effect as of the end of the
latest fiscal year. The disclosures summarize the potential dilution that could occur from past and future
equity grants for all plans and arrangements, whether or not approved by security holders.


Even though the Form 10-K instructions indicate that the disclosures required under Item 201(d) of
Regulation S-K must be provided in response to both Item 5 and Item 12 of Form 10-K, the SEC staff has
indicated that those disclosures should be included only in response to Item 12 of Part III of Form 10-K.
That is, Item 5 of Part II of Form 10-K should include the disclosures required under Items 201(a) and (b)
of Regulation S-K, which are discussed above.


If the registrant is submitting a compensation plan for shareholder action, the registrant must provide the
information required under Item 201(d) in response to Item 10 of Schedule 14A (the proxy statement).
Even if the registrant does not submit a compensation plan for shareholder action, the registrant may
provide the information required under Item 201(d) in its proxy statement. In either case, the registrant
may incorporate the proxy statement disclosure by reference into Item 12 of Form 10-K if the proxy
statement is filed no later than 120 days after the company’s fiscal year-end. See our _**[Proxy statements —](https://www.ey.com/en_us/technical/accountinglink/2025-proxy-statements-an-overview-of-the-requirements)**_
_**An overview of the requirements**_ _**[and observations about current practice](https://www.ey.com/en_us/technical/accountinglink/2025-proxy-statements-an-overview-of-the-requirements)**_ publication for a further
discussion of the requirements of Item 201(d) of Regulation S-K.

##### 4.2.1 Stock performance graph


Item 201(e) of Regulation S-K requires registrants to provide a performance graph that compares the
registrant’s cumulative total shareholder return during the previous five years with a performance
indicator of the overall stock market (i.e., a broad-based index), and the registrant’s peer group.
Instruction 7 to Item 201(e) states the disclosure is required only in a registrant’s annual shareholders’
report that precedes or accompanies a proxy or information statement relating to an annual meeting of
security holders for the election of directors. Accordingly, the performance graph is not required in Item 5
of Part II of Form 10-K and is discussed further in section 10 of this publication.


**2024 SEC annual reports — Form 10-K** | 46


---

4 Part II of Form 10-K

##### 4.2.2 Recent sales of unregistered securities; use of proceeds from registered securities


Item 701 of Regulation S-K requires disclosure of information about all securities of the registrant sold
by the registrant within the past three years that were not registered under the Securities Act (including
sales of reacquired securities, new issues, securities issued in exchange for property, services or other
securities and new securities resulting from the modification of outstanding securities). Item 5(a) of Part II
of Form 10-K indicates that Item 701 of Regulation S-K information need not be disclosed in the Form 10-K
if such information previously has been included in a Quarterly Report on Form 10-Q, or in a Current
Report on Form 8-K. [44] Therefore, Form 10-K disclosure would be limited to any sales of unregistered
securities during the fourth fiscal quarter that were not previously reported in an Item 3.02 Form 8-K.


Item 701 requires disclosure of the following information:


            - Date of sale, the amount and the title of securities sold


            - Names of the principal underwriters, if any, and for any securities not publicly offered, the name of
the person or class of persons to whom the securities were sold


            - For securities sold for cash, the aggregate offering price and aggregate underwriting discounts or
commissions


            - For any securities sold other than for cash, the nature of the transaction and the nature and
aggregate amount of consideration received by the registrant


            - The section of the Securities Act or SEC rule under which exemption from registration was claimed
and a brief description of the facts relied on to claim such exemption


            - If the securities sold by the registrant are convertible or exchangeable into equity securities, or
are warrants or options representing equity securities, the terms of conversion or exercise for
the securities


Following the effective date of the registrant’s first registration statement filed under the Securities Act,
Item 701(f) of Regulation S-K requires disclosure in periodic reports (Form 10-K or Form 10-Q) of certain
information about the use of proceeds. Such disclosures are required until the later of disclosure of the
application of all of the offering proceeds or disclosure of the termination of the offering.


44 Item 3.02 of Form 8-K requires reporting when the aggregate amount of previously undisclosed unregistered sales of equity

securities exceeds 1% of the number of shares outstanding of the respective class. Form 10-Q and Form 10-K continue to require the
registrant to report unregistered sales of equity securities during the most recent fiscal quarter that did not meet the disclosure
threshold and were not reported in any Item 3.02 Form 8-K.


**2024 SEC annual reports — Form 10-K** | 47


---

4 Part II of Form 10-K

##### 4.2.3 Purchases of equity securities by the issuer and affiliated purchasers


Disclosure of the following information must be provided, aggregated on a monthly basis and in a tabular
format, about all issuer repurchases for its last fiscal quarter (i.e., the fourth quarter for purposes of
disclosure in Form 10-K):


            - The total number of shares (or units) purchased (with disclosure, in a brief footnote to the table, of
the nature of transactions other than through a publicly announced repurchase plan or program)


            - The average price paid per share (or unit)


            - The total number of shares (or units) purchased as part of publicly announced repurchase plans or
programs (with disclosure in a footnote to the table of the principal terms of each such plan or program)


            - The maximum number (or approximate dollar value) of shares (or units) that may yet be purchased
under the plans or programs


##### 4.3 Item 7A. Quantitative and qualitative disclosures about market risk

Item 305 of Regulation S-K, which does not apply to SRCs, [45] requires quantitative and qualitative market
risk disclosures about all financial instruments to be presented outside the financial statements in both
annual reports on Form 10-K and in registration statements. Market risk is a broad term referring to
economic losses because of adverse changes in the fair value of a financial instrument. Item 305 affects
most registrants as nearly all have financial instruments that expose them to market risk.


45 SRCs are not required to provide the disclosures specified in Item 305 of Regulation S-K. However, if an SRC chooses to voluntarily

provide this information, it must comply with all of the disclosure requirements of Item 305.


**2024 SEC annual reports — Form 10-K** | 48


---

4 Part II of Form 10-K


The quantitative disclosures are intended to provide an investor with a greater ability to assess the
registrant’s exposure to market risk (e.g., interest rate risk, foreign currency exchange rate risk, commodity
price risk, equity price risk) and must be disclosed in one of three ways: (1) a comprehensive table
(i.e., tabular presentation) that schedules cash flow amounts by maturity dates for all instruments that
are sensitive to future changes in interest rates, currency exchange rates, commodity prices, or other
market factors, (2) a sensitivity or “shock” analysis that quantifies the effect of at least one hypothetical
move in market conditions relating to each market risk factor or (3) specified “value at risk” disclosures
(the most complex of the three options) that measure the potential exposure to adverse market movements
over a specified time period with a selected likelihood of occurrence.


Registrants are required to disclose various elements of the modeling techniques used to derive the
quantitative disclosures as well as relevant assumptions or limitations of the amounts. In addition,
Item 305 requires disclosure of the reasons for material changes in the amount of reported market risk
compared with the information reported in the prior year.


The qualitative disclosures include discussion of a company’s primary risk exposures, its objectives for
managing those exposures and actual or expected material changes in the primary market risk exposures.
The qualitative disclosures should provide a context for the required quantitative disclosures.


The disclosures are required only when the exposure to market risk is material. Under the SEC’s rules,
a materiality assessment must be made for each market risk exposure category (e.g., interest rate risk,
foreign currency exchange rate risk) in the trading and other-than-trading portfolios. Materiality assessments
are based on the fair value of market risk sensitive instruments as of the end of the reporting period, as
well as the materiality of the potential loss in future earnings, fair values or cash flows from reasonably
possible near-term market movements. The SEC’s rules provide the following guidelines for evaluating
whether a potential loss is material: the magnitude of past market movements, expectations about the
magnitude of reasonably possible future market movements and potential losses that could arise from
leverage, option or multiplier features.


The SEC staff has stated that it usually is most appropriate to present the market risk information in a
single location outside the financial statements. A separate section in Form 10-K for the market risk
disclosures is common, but not necessary. The SEC staff has indicated that management instead may
elect to integrate the market risk disclosures with MD&A and the description of business sections.


Item 303 of Regulation S-K requires discussion in MD&A of known events, trends or uncertainties that
are reasonably likely to materially affect the registrant. If a known market risk materially affected
reported trends or financial condition in the period presented, or is reasonably likely to materially affect
future reported results or liquidity, discussion of the market risk and its effects is necessary in MD&A.
The quantitative and qualitative market risk disclosure rules require more information than Item 303
because Item 305 requires specific descriptive and quantitative disclosures about losses from market risk
sensitive instruments that could result from reasonably possible market changes. For example, a
sensitivity analysis responsive to Item 305 presents quantitative information about possible future losses
from reasonably possible near-term changes in market rates and prices. This information need not be
repeated in MD&A, but cross-references may be necessary to make a particular disclosure complete.


See our _SEC annual shareholders’ report checklist_ (EY Form A150) for additional information about the
SEC’s market risk disclosures.


**2024 SEC annual reports — Form 10-K** | 49


---

4 Part II of Form 10-K

##### 4.4 Item 8. Financial statements and supplementary data


See section 6, _Financial statements and parent company information_, for financial statement requirements.


Item 302 of Regulation S-K requires disclosure of certain interim financial information and additional
disclosures about oil and gas producing activities. The required information may be disclosed outside the
financial statements as supplementary financial information.

##### 4.4.1 Interim financial information


When there are one or more retrospective changes to the statements of comprehensive income for any
of the quarters within the most recent two fiscal years that individually or in the aggregate are material,
Item 302(a) of Regulation S-K [46] requires registrants to provide an explanation of the reasons for the
changes and disclose, for each affected quarterly period and the fourth quarter in the affected year,
summarized financial information related to the statements of comprehensive income (as specified in
Rule 1-02(bb)(ii) of Regulation S-X) and earnings per share reflecting the changes. Rule 1-02(bb)
provides flexibility for registrants to use the same line item captions that appear in their financial
statements, if necessary, in lieu of the line item captions prescribed in Rule 1-02(bb). If required, the
disclosure of quarterly financial data must be reviewed by the independent auditor.


When such disclosures are required, the independent public accountant must perform a PCAOB Auditing
Standard (AS) 4105 review of the registrant’s fourth-quarter interim financial information even though
a separate fourth-quarter report on Form 10-Q is not required to be filed with the SEC. A PCAOB AS 4105
review is not required if selected quarterly financial data is voluntarily provided. However, that
information would be subject to the requirements of PCAOB AS 2710, _Other information in documents_
_containing audited financial statements._ The auditor is required to read and consider such information for
material inconsistencies with the audited financial statements.


When a company provides summarized financial data for earlier quarters in an annual report to shareholders
but does not include summarized financial data for the fourth quarter in a separate fourth-quarter report or
in the annual report, ASC 270, _Interim Reporting_, requires the registrant to disclose the following information
in an unaudited note to the annual financial statements (collectively Fourth Quarter Disclosures):


            - Accounting changes, including restatement, if appropriate, of financial information for the prechange interim periods of the fiscal year in which the change is made (see discussion in section 4
of our publication, _[SEC quarterly reports - Form 10-Q](https://www.ey.com/en_us/technical/accountinglink/2025-sec-quarterly-reports-form-10-q)_ )


            - Disposals of components of an entity


            - Unusual or infrequently occurring items recognized in the fourth quarter


            - Aggregate effect of year-end adjustments material to the results of the fourth quarter [47]


46 Item 302(a) of Regulation S-K applies to all companies that have securities registered under Sections 12(b) (except mutual life

insurance companies) or 12(g) of the Exchange Act, except SRCs and foreign private issuers.

47 SAB Topic 6.G indicates that the disclosures provided for a year-end adjustment that is material to the fourth quarter would be

similar to the disclosures provided for a change in accounting estimate.


**2024 SEC annual reports — Form 10-K** | 50


---

4 Part II of Form 10-K


When there has been a material retrospective change affecting comprehensive income, Item 302(a) of
Regulation S-K requires the disclosure of quarterly financial data for the most recent two fiscal years,
which includes some, but not all, of the Fourth Quarter Disclosures required by ASC 270. Selected
quarterly financial data may be included outside the financial statements as supplementary information
in annual shareholders’ reports and in SEC filings, or in an unaudited note to the annual financial
statements. If a registrant elects to include the selected quarterly financial data in an unaudited note to
the financial statements, the registrant may combine the disclosure requirements of ASC 270 and
Item 302(a) in a single footnote.


The SEC does not require selected quarterly financial data in an IPO registration statement or Exchange
Act registration statement (i.e., Form 10). Item 302(a) applies beginning with the first filing on Form 10-K
after the registrant’s initial registration of securities under sections 12(b) or 12(g) of the Exchange Act.


Some examples of a retrospective change that may trigger Item 302(a) disclosure include:


- A correction of an error


- A disposition of a business that is accounted for as discontinued operations


- A reorganization of entities under common control


- A change in an accounting principle


These examples are not intended to be an exhaustive list, and the amounts may not always be material
such that disclosure would be required under Item 302(a). Further, not all changes in accounting
principles would result in a retrospective change.


**Data to be disclosed** : Summarized financial information should generally include the following disclosures:


- Net sales or gross revenue


- Gross profit (or, alternatively, costs and expenses applicable to net sales or gross revenues)


- Income (loss) from continuing operations


- Net income (loss)


- Net income (loss) attributable to the registrant


- Earnings per share data (basic and, when applicable, diluted)


Registrants in specialized industries (e.g., banks, insurance companies) may substitute other information
for sales and related costs and expenses if doing so is necessary for a more meaningful presentation.


**Quarterly data of subsidiaries and investees:** Quarterly financial data are not required to be included in
supplemental financial statements for unconsolidated subsidiaries and equity investees unless the
financial statements are for a company that is itself a registrant required to provide disclosures under
Item 302 of Regulation S-K.


**2024 SEC annual reports — Form 10-K** | 51


---

4 Part II of Form 10-K

##### 4.4.2 Information about oil and gas producing activities


Item 302(b) [ 48] of Regulation S-K requires registrants engaged in “significant” oil and gas producing activities
to present, as supplementary information, disclosures pursuant to ASC 932 (specifically ASC 932-235-50) _._ [49]
The oil and gas activities are significant if one or more of the tests in the definition of significant oil and gas
activities in ASC 932-235-20 are met. Disclosures that relate to annual periods and disclosures required
as of the beginning of an annual period are presented for each year for which an income statement is
required. Disclosures as of the end of an annual period are presented as of the date of each required
audited balance sheet. These disclosures are summarized in our _GAAP, Regulation S-X and Regulation S-K_
_checklist supplement for oil and gas producing companies_ (EY Form A69E).


Securities Act Rule 175 and Exchange Act Rule 3b-6 provide a safe harbor from the liability provisions of
the securities laws for disclosures about the value of proved oil and gas reserves (such as a standardized
measure of discounted future net cash flows relating to proved oil and gas reserves, as set forth in
ASC 932-235-50-29 through 50-33).

##### 4.5 Item 9. Changes in and disagreements with accountants on accounting and financial disclosure


If during the registrant’s two most recent fiscal years, or any subsequent interim period, the registrant’s
principal auditor, or an independent auditor on whom the principal auditor expressed reliance in its report,
resigned, declined to stand for re-election or was dismissed, the registrant is subject to additional disclosure
requirements pursuant to Item 304 of Regulation S-K.


When a change in auditors occurs, the registrant is required to report the event within four business days
in a Form 8-K under Item 4.01, and provide the disclosures required by Item 304(a) of Regulation S-K. [50]
These disclosures include:


            - Whether the auditor resigned, declined to stand for re-election or was dismissed and the date the
change occurred.


            - Whether the principal auditor’s report on the financial statements for either of the past two years
contained an adverse opinion or disclaimer of opinion, or was qualified as to uncertainty (e.g., a
going concern uncertainty), audit scope or accounting principles and the nature of any opinion
modification or qualification.


            - Whether the decision to change auditors was recommended or approved by the audit or similar
committee of the board of directors.


            - Whether there were any disagreements with the auditor during the two most recent fiscal years and
any interim period preceding a resignation, declination or dismissal. If this is the case, certain
additional disclosures are required.


48 The SEC had proposed eliminating Item 302(b), disclosure of oil and gas producing activities, on the condition that the FASB

finalize amendments to US GAAP that would require disclosures now required by Item 302(b). The FASB had not (as of the
adopting release date of the 19 November 2020 amendments to Regulation S-K) finalized the amendments, so the Commission
retained Item 302(b) and may reconsider the proposal in the future.

49 A registrant engaged in oil and gas producing activities also is subject to the financial reporting and disclosure requirements

included in Item 102 of Regulation S-K and Rule 4-10 of Regulation S-X.

50 A merger of accounting firms always results in a change in accountants if there is a change in legal entity of the firm that performs

the audit. An Item 4.01 Form 8-K must be filed no later than four business days after the merger. In addition, a change to an
accountant that is related in some manner to the former accountant (e.g., the firms are affiliates or are members of the same
network) would require an Item 4.01 Form 8-K to be filed no later than four business days after the change in accountant if the new
and former accountants are separate legal entities and are separately registered with the PCAOB.


**2024 SEC annual reports — Form 10-K** | 52


---

4 Part II of Form 10-K


            - Whether during the two most recent fiscal years and any subsequent interim period [51] before such
resignation, declination or dismissal there were any reportable events (e.g., auditor communication
about a lack of sufficient internal controls, including an adverse opinion on the effectiveness of ICFR,
inability of the auditor to rely on management’s representations, need for the auditor to expand
significantly the scope of the audit), in which case, certain additional disclosures are required.


Once these disclosures have been filed in a Form 8-K, a later Form 10-K is not required to repeat them.
However, proxy statements relating to the annual election of directors or the election, approval or
ratification of the principal auditor are required to contain all disclosures required by Item 304(a) of
Regulation S-K, despite any previous disclosure. These disclosures may be made in the annual shareholders’
report or in the proxy statement itself.


Following a change in auditors, Form 10-K and the annual report to shareholders are required to include
the disclosures specified in Item 304(b) of Regulation S-K if they apply. Disclosure is required if there
were disagreements (or reportable events) involving the former auditor _and_ the financial statements
include transactions or events that are accounted for, or disclosed, in a manner with which the former
auditor would have taken exception. The required disclosures include the existence and nature of the
disagreement or reportable event, and the effect on the financial statements of applying the accounting
method that would have been required by the former auditors. These disclosures are not required if the
method asserted by the former auditors has been superseded by subsequently issued accounting
standards updates and is no longer generally accepted.

##### 4.6 Item 9A. Controls and procedures 4.6.1 Item 307 Disclosure controls and procedures


**Definition:** Exchange Act Rules 13a-15(a) and 15d-15(a) require registrants to maintain “disclosure
controls and procedures.” Exchange Act Rules 13a-15(e) and 15d-15(e) define the term “disclosure
controls and procedures” as:


“Controls and other procedures of an issuer that are designed to ensure that information required to
be disclosed by the issuer in the reports that it files or submits under the [Exchange] Act is recorded,
processed, summarized and reported, within the time periods specified in the Commission’s rules and
forms. Disclosure controls and procedures include, without limitation, controls and procedures
designed to ensure that information required to be disclosed by an issuer in the reports that it files or
submits under the [Exchange] Act is accumulated and communicated to the issuer’s management,
including its principal executive and principal financial officers, or persons performing similar functions,
as appropriate to allow timely decisions regarding required disclosure.”


**Evaluation and disclosure:** Exchange Act Rules 13a-15(b) and 15d-15(b) require each issuer’s
management to evaluate, with the participation of the issuer’s principal executive and principal financial
officers, or persons performing similar functions, the effectiveness of the issuer’s disclosure controls and
procedures as of the end of each fiscal quarter. Based on that evaluation, Item 307 of Regulation S-K
requires each Form 10-Q and, for the fourth quarter, the Form 10-K, to disclose the conclusions of the
registrant’s principal executive and principal financial officers, or persons performing similar functions,
regarding the effectiveness of the registrant’s disclosure controls and procedures as of the end of the
period covered by the report.


51 This SEC staff interprets this to mean through the dismissal or termination date.


**2024 SEC annual reports — Form 10-K** | 53


---

4 Part II of Form 10-K


In providing the disclosures under Item 307 of Regulation S-K, some companies have indicated that
disclosure controls and procedures are designed only to provide “reasonable assurance” that they will
meet their objectives. While not objecting to such language, the SEC staff has required these companies
to disclose management’s conclusion about whether the company’s disclosure controls and procedures
are effective at the “reasonable assurance” level. In providing the disclosures under Item 307 of
Regulation S-K, other companies have disclosed that there is “no assurance” that disclosure controls and
procedures will operate effectively under all circumstances. In these cases, the SEC staff has requested
that the companies clarify that their disclosure controls and procedures are designed to provide
“reasonable assurance,” subject to the conditions discussed above.


The SEC staff reminds registrants that management’s conclusions about the effectiveness of the registrant’s
disclosure controls and procedures in interim and annual reports under Item 307 of Regulation S-K must
include an explicit statement about whether disclosure controls and procedures are either “effective” or
“ineffective.” In addition, management’s conclusion must consider disclosure controls and procedures
“in their totality.” The SEC staff will require a registrant to amend its filing if it discloses inappropriate
expressions of management’s conclusions, such as conclusions that disclosure controls and procedures
are “adequate,” “effective, except for,” or “effective except as disclosed below.”


**Relationship between “disclosure controls and procedures” and “internal control over financial reporting”:**
In its commentary, [52] the SEC expresses its view that there is “substantial overlap” between a company’s
disclosure controls and procedures and its internal control over financial reporting (discussed below).
However, there are some elements of disclosure controls and procedures that are beyond the scope of
internal control over financial reporting, and there are some (albeit very few) elements of internal control
over financial reporting that may fall outside the scope of a registrant’s disclosure controls and procedures.
In the SEC’s view, the elements of internal control over financial reporting that provide reasonable
assurances that transactions are recorded as necessary to permit preparation of financial statements
in accordance with generally accepted accounting principles would always be included in a company’s
disclosure controls and procedures. Aside from those elements, the SEC indicated that companies can
be expected to make judgments about the processes and controls on which management relies to meet
applicable Exchange Act disclosure requirements.


The SEC staff has indicated [53] that a registrant may exclude a business it acquired during the year from
its assessment of internal control over financial reporting. In light of the overlap between a company's
disclosure controls and procedures and its internal control over financial reporting, the registrant also
may exclude these controls from its evaluation of disclosure controls and procedures. In these situations,
the registrant should indicate the significance of the acquired business to the registrant's consolidated
financial statements.


An entity that identifies a material error should assess whether and how it affects the entity’s conclusions
about the effectiveness of the related internal controls, and hence the effectiveness of disclosure controls
and procedures. When amending a prior filing to correct a material error, registrants should consider
whether the disclosures previously provided to comply with Item 307 of Regulation S-K need to be modified,
supplemented or corrected to explain whether management’s previous conclusions regarding the
effectiveness of disclosure and control procedures continue to be appropriate in light of the assessment to
restate financial statements or non-reliance on a previously issued audit report or interim review.


52 SEC Release No. 33-8238, _Management’s Reports on Internal Control Over Financial Reporting and Certification of Disclosure in_

_Exchange Act Periodic Reports_, issued 5 June 2003.

53 Regulation S-K C&DI 214.01, _Item 307 — Disclosure Controls and Procedures_ . The SEC staff Regulation S-K C&DIs can be found at

**[https://www.sec.gov/divisions/corpfin/guidance/regs-kinterp.htm](https://www.sec.gov/divisions/corpfin/guidance/regs-kinterp.htm)** .


**2024 SEC annual reports — Form 10-K** | 54


---

4 Part II of Form 10-K

##### 4.6.2 Item 308 (a) & (b) Internal control over financial reporting


With the exception of newly public companies, all issuers are required to provide a report by management
assessing the effectiveness of the company’s internal control over financial reporting, as required by
Section 404(a) of the Sarbanes-Oxley Act. [54]


However, non-accelerated filers and EGCs are exempted from the auditor attestation requirement of
Section 404(b) of the Sarbanes-Oxley Act. Refer to sections 2.1.1, 2.1.2 and 2.1.3 in this publication for
further information on the determination of filer status.


**Transition from non-accelerated to accelerated or large accelerated filer:** When a non-accelerated filer
meets all of the criteria in Rule 12b-2 of the Exchange Act to be an accelerated filer or a large accelerated
filer as of the end of its fiscal year, its Form 10-K for that fiscal year will be due on an accelerated basis
and it must comply with Section 404(b).


Assume, for example, that a calendar-year registrant filed its 20Y2 Form 10-K as a non-accelerated filer
and reported revenues higher than $100 million for 20Y2 and did not have its auditor attest to the
effectiveness of ICFR. Also assume that on 30 June 20Y3, the registrant’s public float had increased to
$80 million, and as of 31 December 20Y3, it met the criteria of an accelerated filer. [55] The registrant’s
20Y3 Form 10-K will be due 16 March 20Y4 (75 days after year-end) and must include its auditor’s
report on the effectiveness of ICFR as of 31 December 20Y3.


Refer to section 2.1.5 above for further information regarding transition between acceleration status
categories and requirement for auditor attestation of ICFR.


**Transition when exiting EGC status:** When an issuer loses its EGC status, it must comply with the
requirements of Section 404(b), unless it is a non-accelerated filer (as described above). A registrant
with EGC status loses its eligibility as an EGC five years after its common equity IPO. An issuer also loses
its EGC status if it meets any of the following criteria:


            - Has annual revenues exceeding $1.235 billion [56]


            - Issues more than $1 billion in nonconvertible debt securities over a rolling 36-month period,
including securities issued in registered or unregistered offerings


            - Becomes a large accelerated filer (i.e., a seasoned issuer with public float of $700 million or more)


A registrant that loses its EGC status would be required to file its annual report for that year as a non-EGC.
For example, if a calendar-year EGC exceeds $1.235 billion in annual revenue in 20Y3, the EGC relief
provisions would not apply to its 20Y3 Form 10-K. This means the registrant would have to comply with
Section 404(b) in its 20Y3 Form 10-K, unless it is a non-accelerated filer.


54 Section 404 reporting commences with the second annual report of any newly public company. The surviving issuer in a reverse

acquisition is not considered a newly public company. The SEC staff has published Regulation S-K C&DI 215.02 for companies to
consider in such reverse acquisition situations ( **[http://www.sec.gov/divisions/corpfin/guidance/regs-kinterp.htm](http://www.sec.gov/divisions/corpfin/guidance/regs-kinterp.htm)** ).

55 This example assumes the issuer is not an SRC with annual revenue of less than $100 million, which would qualify the issuer as a

non-accelerated filer when applying the revenue and public float thresholds discussed in Section 2.1.1.

56 The cap on annual gross revenues reflects inflation adjustments required by the JOBS Act. The final rules the SEC adopted to

implement the latest adjustment were effective 20 September 2022.


**2024 SEC annual reports — Form 10-K** | 55


---

4 Part II of Form 10-K


**Transition when there is a change in fiscal year-end:** A registrant that changes its fiscal year is required
to provide a management report on internal control over financial reporting, and the related auditor
attestation report, when filing a transition report on Form 10-K. [57] This is because transition reports filed
on Form 10-K must contain audited financial statements and, accordingly, also must include management’s
report on internal control, subject to the transition provisions described above.


If the transition report is filed on Form 10-Q, a registrant would be required to provide only a management
assessment as of its new fiscal year-end in connection with the registrant’s first Form 10-K filed following
a change in fiscal year.


For example, assume on 1 April 20Y2 an accelerated filer changes its fiscal year from 31 December to
31 March and elects to file its transition report on Form 10-Q for the transition period 1 January 20Y2 to
31 March 20Y2. Such accelerated filer’s transition report on Form 10-Q for the period ended 31 March
20Y2 is not required to include internal control reports. The registrant would include only a management
report on internal control over financial reporting, and related auditor attestation report, in the registrant’s
next annual report on Form 10-K for the fiscal year ending 31 March 20Y3. Therefore, the registrant
would not be required to perform an assessment of, and file a report on, its internal control over financial
reporting as of the end of the 31 March 20Y2 transition period, unless it elected to file its transition report
on Form 10-K rather than Form 10-Q.


**Definition:** Exchange Act Rules 13a-15(a) and 15d-15(a) require registrants to maintain “internal control
over financial reporting.” Exchange Act Rules 13a-15(f) and 15d-15(f) define the term “internal control
over financial reporting” as:


“A process designed by, or under the supervision of, the issuer’s principal executive and principal
financial officers, or persons performing similar functions, and effected by the issuer’s board of
directors, management and other personnel, to provide reasonable assurance regarding the reliability
of financial reporting and the preparation of financial statements for external purposes in accordance
with generally accepted accounting principles and includes those policies and procedures that:


(1) Pertain to the maintenance of records that in reasonable detail accurately and fairly reflect the

transactions and dispositions of the assets of the issuer;


(2) Provide reasonable assurance that transactions are recorded as necessary to permit preparation

of financial statements in accordance with generally accepted accounting principles, [58 ] and that
receipts and expenditures of the issuer are being made only in accordance with authorizations of
management and directors of the issuer; and


(3) Provide reasonable assurance regarding prevention or timely detection of unauthorized acquisition,

use or disposition of the issuer’s assets that could have a material effect on the financial statements.”


57 Question 6 of the SEC staff’s document, _Management’s Report on Internal Control Over Financial Reporting and Certification of_

_Disclosure in Exchange Act Periodic Reports: Frequently Asked Questions (revised 24 September 2007)_ (Section 404 FAQ).

58 As discussed in the section Relationship between “disclosure controls and procedures” and “internal control over financial

reporting” above, the elements of internal control over financial reporting that address this objective also would represent an
element of the company’s disclosure controls and procedures.


**2024 SEC annual reports — Form 10-K** | 56


---

4 Part II of Form 10-K


This definition is consistent with the definition of internal accounting controls in Section 13 of the
Exchange Act, which was added by the Foreign Corrupt Practices Act of 1977. This definition also
encompasses the subset of internal controls addressed in the Committee of Sponsoring Organizations of
the Treadway Commission’s (COSO) _Internal Control — Integrated Framework_ (COSO Report) pertaining
to financial reporting objectives. Thus, “internal control over financial reporting” does not extend to the
other elements of internal control identified in the COSO Report relating to the effectiveness and
efficiency of a company’s operations and a company’s compliance with applicable laws and regulations
(with the exception of compliance with the applicable laws and regulations directly related to the
preparation of financial statements, such as compliance with SEC regulations).


**Management report:** Exchange Act Rules 13a-15(c) and 15d-15(c) require each issuer’s management to
evaluate, with the participation of the issuer’s principal executive and principal financial officers, or
persons performing similar functions, the effectiveness, as of the end of each fiscal year, of the issuer’s
internal control over financial reporting. [59] Item 308(a) of Regulation S-K requires each Form 10-K to
include a report of management on the company’s internal control over financial reporting, [60] which
must, at a minimum, include the following:


- A statement of management’s responsibility for establishing and maintaining adequate internal
control over financial reporting for the registrant


- A statement identifying the framework used by management to evaluate the effectiveness of the
registrant’s internal control over financial reporting


- Management’s assessment of the effectiveness of the registrant’s internal control over financial
reporting as of the end of the registrant’s most recent fiscal year, including a statement about
whether internal control over financial reporting is effective [61]


- A statement that the registered public accounting firm that audited the financial statements included
in the annual report has issued an attestation report on the registrant’s internal control over financial
reporting (accelerated filers and large accelerated filers only)


While Item 308(a) of Regulation S-K clarifies the information required in management’s report on internal
control over financial reporting, it does not specify the exact format or content of the management
report. If management’s report indicates that internal control over financial reporting is designed to
provide only “reasonable assurance” that it will meet its objectives, the SEC has stated that “the discussion
must be presented in a manner that neither makes the disclosure in the report confusing nor renders
management’s assessment concerning the effectiveness of the company’s internal control over financial
reporting unclear.”


59 If a subsidiary issuer or subsidiary guarantor is exempt from Exchange Act reporting under Rule 12h-5, the SEC staff has

indicated that Form 10-K is required to include only a Section 404 report for the consolidated parent company. Also, in this
situation, the information required to be furnished by Item 9A of Form 10-K applies only to the consolidated parent company and,
accordingly, a separate Section 404 report is not required for such subsidiary issuer or subsidiary guarantor.

60 While the SEC’s final Section 404 rule does not mandate the location of management’s annual report on internal control over

financial reporting, the Commission has indicated that it is important for the report to be in close proximity to the corresponding
audit report on internal control over financial reporting issued by the company’s independent registered public accounting firm.
Further, the SEC staff stated its expectation that companies will choose to place the internal control reports together near their
MD&A disclosure or in a portion of the document immediately preceding the financial statements. We believe that including both
management’s Section 404(a) report and the auditor’s Section 404(b) report in Item 9A on Form 10-K satisfies those expectations.
Because Exchange Act Rule 14a-3 was not amended to require the information specified in Items 307 and 308 of Regulation S-K,
internal control reports are not required in “glossy” annual reports.

61 Negative assurance (i.e., a statement that nothing has come to management’s attention to suggest that the company’s internal

control over financial reporting is not effective) will not satisfy this requirement.


**2024 SEC annual reports — Form 10-K** | 57


---

4 Part II of Form 10-K


Exchange Act Rules 13a-15(c) and 15d-15(c) provide that management must base its evaluation of
the effectiveness of its internal control over financial reporting on a “suitable, recognized control
framework that is established by a body or group that has followed due-process procedures, including the
broad distribution of the framework for public comment.” The SEC further indicated that, in its view, a suitable
framework must be free from bias; permit reasonably consistent qualitative and quantitative measurements
of a company’s internal control; be sufficiently complete so that relevant factors that would alter a conclusion
about the effectiveness of a company’s internal control are not omitted; and be relevant to an evaluation of
internal control over financial reporting. The SEC cited the COSO Report as a suitable, recognized internal
control framework meeting the requirements of Exchange Act Rules 13a-15(c) and 15d-15(c). [62]


COSO updated its internal control framework in 2013 to address changes in the business, operating and
regulatory environment since it issued its original framework in 1992.


**Scope of management’s assessment:** Because the process of evaluating internal control over financial
reporting will vary from company to company, SEC rules do not specify the methods or procedures to be
performed in an evaluation. [63] The SEC’s interpretive guidance, _Commission Guidance Regarding_
_Management’s Report on Internal Control over Financial Reporting Under Section 13(a) or 15(d) of the_
_Securities Exchange Act of 1934_, states that the methods and procedures for identifying financial reporting
risks will vary based on characteristics of the company such as its size, complexity, organizational structure
and its processes and financial reporting environment, as well as the control framework used by
management. However, an instruction to Item 308 of Regulation S-K states, “the registrant must maintain
evidential matter, including documentation, to provide reasonable support for management’s assessment
of the effectiveness of the registrant’s internal control over financial reporting.”


In adopting its Section 404 reporting rules in 2003, the SEC stated:


“The assessment of a company’s internal control over financial reporting must be based on
procedures sufficient both to evaluate its design and to test its operating effectiveness. Controls
subject to such assessment include, but are not limited to: controls over initiating, recording,
processing and reconciling account balances, classes of transactions and disclosure and related
assertions included in the financial statements; controls related to the initiation and processing of
non-routine and non-systematic transactions; controls related to the selection and application of
appropriate accounting policies; and controls related to the prevention, identification, and detection
of fraud. The nature of a company’s testing activities will largely depend on the circumstances of the
company and the significance of the control. However, inquiry alone generally will not provide an
adequate basis for management’s assessment.


An assessment of the effectiveness of internal control over financial reporting must be supported by
evidential matter, including documentation, regarding both the design of internal controls and the
testing processes. This evidential matter should provide reasonable support: for the evaluation of
whether the control is designed to prevent or detect material misstatements or omissions; for the
conclusion that the tests were appropriately planned and performed; and that the results of the tests
were appropriately considered.”


62 The _Guidance on Assessing Control_, published by the Canadian Institute of Chartered Accountants, and the _Turnbull Report_,

published by the Institute of Chartered Accountants in England & Wales, also are identified by the SEC as suitable frameworks.

63 In June 2007, the SEC published interpretive guidance, _Commission Guidance Regarding Management’s Report on Internal_

_Control over Financial Reporting Under Section 13(a) or 15(d) of the Securities Exchange Act of 1934_ (SEC Release Nos. 33-8810
and 34-55929, FRR-77), for management of all public companies subject to Section 404 regarding their evaluations of internal
control over financial reporting. The SEC also amended Exchange Act Rules 13a-15(c) and 15d-15(c) to provide for a nonexclusive safe-harbor such that a company that performs an evaluation of internal control in accordance with the interpretive
guidance satisfies the annual evaluation required by those Exchange Act Rules.


**2024 SEC annual reports — Form 10-K** | 58


---

4 Part II of Form 10-K


The SEC staff also stated in the Section 404 FAQs its views on the scope of management’s assessment as
it relates to a consolidated entity (i.e., variable interest entity (VIE) or an acquired business). The SEC
staff indicated that management’s report on internal control over financial reporting typically should
include controls at all consolidated entities, regardless of the basis for consolidation. For instance, the
SEC staff indicated that the internal controls of an entity consolidated by virtue of variable interest entity
accounting should be covered in management’s report on internal control over financial reporting.


The SEC staff acknowledged that it might not always be possible to assess an acquired business’s internal
control over financial reporting in the period between the consummation date and the date of management’s
assessment. [ 64] In such instances, the SEC staff would not object to management referring in its internal
control report to a discussion in the registrant’s Form 10-K regarding the scope of management’s
assessment and to such disclosure noting that management excluded the acquired business [65] from
management’s report on internal control over financial reporting. If such a reference is made, however,
management must identify the excluded acquired business and indicate the significance of the business
to the registrant’s consolidated financial statements.


Despite management’s exclusion of an acquired business’s internal controls from its annual assessment,
a registrant must disclose any material change to its internal control over financial reporting because of
the acquisition pursuant to Exchange Act Rule 13a-15(d) or 15d-15(d). However, if the registrant excludes
a recently acquired business from its internal control assessment, the disclosures related to all material
changes resulting from the business combination since the date of the acquisition may be included in the
first annual report in which the acquired business is included in the scope of its ICFR assessment. In addition,
the period during which management may omit an assessment of an acquired business’s internal control
over financial reporting from its assessment of the registrant’s internal control may not extend beyond
one year from the date of acquisition, nor may this assessment be omitted from more than one annual
management report on internal control over financial reporting.


As for the timing of the evaluation and testing, the SEC’s adopting release states: “management of each
company should perform evaluations of the design and operation of the company’s entire system of
internal control over financial reporting over a period of time that is adequate for it to determine whether,
as of the end of the company’s fiscal year, the design and operation of the company’s internal control
over financial reporting are effective.”


This approach makes practical sense recognizing that some controls operate continuously while others
operate only at certain times, such as the end of the fiscal year. The SEC recognizes that, while the
evaluation date is as of the end of the fiscal year, for practical purposes, the testing of many internal
controls must be performed at interim dates with appropriate roll-forward procedures.


The adopting release also acknowledges that, while “management” is ultimately responsible for the
assessment of internal control over financial reporting, the necessary activities to evaluate the design
and operating effectiveness of the company’s internal control over financial reporting may be conducted
by non-management personnel acting under the supervision of management.


64 The term “business” includes those acquisitions that would constitute a business based on the facts and circumstances as

outlined in Article 11-01(d) of Regulation S-X. While in some instances an acquisition may not meet the definition of a business in
ASC 805 and would not be accounted for as a business combination, it nevertheless may be a business under the definition in
Article 11 used for SEC reporting purposes. This guidance applies irrespective of whether the acquisition is significant under
Rule 1-02(w) of Regulation S-X.

65 Question 3 of the SEC staff’s Section 404 FAQs addresses whether management may exclude a business acquired through a

“material purchase business combination” from management’s report on ICFR. However, at the 25 September 2013 CAQ SEC
Regulations Committee meeting, the SEC staff said that a business acquired through a merger of entities under common control
also would be eligible for the temporary ICFR scope exemption.


**2024 SEC annual reports — Form 10-K** | 59


---

4 Part II of Form 10-K


**Effects of material weaknesses and significant deficiencies:** If a “material weakness” exists at the end
of the fiscal year, it must be disclosed in management’s internal control report, and the presence of a
material weakness would preclude management from concluding that internal control over financial
reporting is effective. [66]


Management’s certification called for by Section 302 of the Sarbanes-Oxley Act requires the certifying
officers to disclose to the registrant’s auditors and the audit committee all significant deficiencies and
material weaknesses in the design or operation of internal control over financial reporting. [67] In PCAOB
AS 2201, _An Audit of Internal Control Over Financial Reporting That Is Integrated with an Audit of Financial_
_Statements_, a “significant deficiency” is defined as “a deficiency, or a combination of deficiencies, in
internal control over financial reporting that is less severe than a material weakness, yet important enough
to merit attention by those responsible for oversight of the company’s financial reporting.” AS 2201 and
the SEC define the term “material weakness” as “a deficiency, or a combination of deficiencies, in internal
control over financial reporting, such that there is a reasonable possibility that a material misstatement of
the company’s annual or interim financial statements will not be prevented or detected on a timely basis.”
AS 2201 indicates that the “reasonable possibility” of an event, included in the definition of a material
weakness, has the same meaning as the terms “reasonably possible” or “probable” as defined in the
FASB’s Codification. An aggregation of significant deficiencies in internal control over financial reporting
could constitute a material weakness and also preclude management from determining that a company’s
internal control over financial reporting is effective.


While this is not addressed in the SEC rules, we believe that a material weakness in internal control that
was identified and corrected during the fiscal year would not preclude management from concluding that
internal control over financial reporting was effective as of the end of the fiscal year. In those circumstances,
management’s internal control report would not be required to disclose the existence and correction of a
material weakness earlier in the company’s fiscal year. However, under Item 308(c) of Regulation S-K
(discussed below), a change during a fiscal year necessary to correct a material weakness in internal control
would need to be disclosed in the periodic SEC report covering the respective fiscal quarter.


**Auditor attestation:** Rules 1-02 and 2-02 of Regulation S-X require the issuer’s registered public accounting
firm to attest to, and report on whether the registrant maintained, in all material respects, effective internal
control over financial reporting as of the assessment date. Item 308(b) of Regulation S-K requires each
Form 10-K of an accelerated or a large accelerated filer (other than an EGC) to include the attestation
report from the issuer’s registered public accounting firm on the registrant’s internal control over financial
reporting, issued pursuant to auditing standards adopted by the PCAOB.

##### 4.6.3 Item 308(c) Changes in internal control over financial reporting


The SEC staff clarified that it would not object if a registrant does not disclose changes or improvements to
controls made in preparation of the registrant’s first Section 404 report (e.g., between its IPO and second
Form 10-K report date). However, if the registrant were to identify a material weakness in advance of its
Section 404 compliance date, the SEC staff stated that the registrant “should carefully consider whether
that fact should be disclosed, as well as changes made in response to the material weakness.” [ 68]


66 When management concludes that the company’s internal control over financial reporting is ineffective, the SEC staff indicated

that the company should consider including in their disclosures: (1) the nature of any material weakness; (2) its effect on financial
reporting and the control environment and (3) management’s current plans, if any, for remediating the weakness.

67 The SEC expects that the certifying officers also would make the auditors and audit committee aware of any significant

deficiencies, material weaknesses or fraud requiring disclosure of which they become aware outside, or subsequent to, the
formal evaluation process.

68 Question 7 of the SEC staff’s Section 404 FAQ.


**2024 SEC annual reports — Form 10-K** | 60


---

4 Part II of Form 10-K


After the registrant’s first Section 404 report, Item 9A of Form 10-K requires the issuer to disclose any
change in internal control over financial reporting that occurred during the fourth quarter of the fiscal
year that has “materially affected, or is reasonably likely to materially affect, the registrant’s internal
control over financial reporting.” The SEC staff clarified that this would encompass disclosing a change
(including an improvement) to internal control over financial reporting that was not necessarily in
response to an identified material weakness (i.e., the implementation of a new information system) if it
materially affected the registrant’s internal control over financial reporting.


Read literally, Item 308(c) of Regulation S-K and the form of management’s Section 302 (of the
Sarbanes-Oxley Act) certification require only disclosure of material changes in internal control over
financial reporting that occurred during a fiscal quarter, not the underlying reasons for such changes
(e.g., material weakness, business acquisition, change in the design of internal controls to increase their
effectiveness and efficiency). However, the SEC has stated, “a company will have to determine, on a
facts and circumstances basis, whether the reasons for the change, or other information about the
circumstances surrounding the change, constitute material information necessary to make the disclosure
about the change not misleading.”


The SEC staff has discussed the importance of considering whether changes to internal controls in
conjunction with the adoption of a new accounting standard require disclosure as a material change in
ICFR in the relevant quarter under Item 308(c) of Regulation S-K. When these disclosures are required,
registrants should include these disclosures no later than the period of the change, which would be the
first quarter the new standard is adopted in most cases.


**4.6.3.1** **Exhibit 31 Management’s Section 302 certification**


The management certification called for by Section 302 of the Sarbanes-Oxley Act must be filed as
Exhibit 31 to the Form 10-K. As “filed” information, Section 302 certifications remain subject to the
civil liability provisions of Section 18 of the Exchange Act, and may be incorporated by reference into
registration statements filed under the Securities Act where they would become subject to the liability
provisions of Section 11 of the Securities Act.


The specified form of the Section 302 certification is included in Item 601, _Exhibits_, of Regulation S-K.
The certifications must be filed in the exact form specified by the SEC rules. [69] Separate certifications are
required to be filed by the CEO and CFO. [70]

##### 4.7 Item 9B. Other information 4.7.1 Items required to be disclosed in Form 8-K


Item 9B of Form 10-K requires disclosure of any reportable events not reported on Form 8-K as required
during the fourth quarter of the year covered by the Form 10-K, whether or not otherwise required to be
disclosed in the Form 10-K. If disclosure of the required delinquent information is made in Item 9B, such
disclosure is not required to be repeated in a report on Form 8-K.


69 In SEC Release No. 33-8238, _Asset-Backed Securities_, the Commission amended Item 601 of Regulation S-K to add the specific

form and content of the required Section 302 certification to the exhibit filing requirements for asset-backed securities issuers.
The requirements relating to the asset-backed issuer Section 302 certification are specified in paragraph (d) of Exchange Act
Rules 13a-14 and 15d-14.

70 The introductory language in paragraph 4 and the language in paragraph 4(b) of the certification contain references to the

certifying officers' responsibility for designing, establishing and maintaining internal control over financial reporting. The CEO and
the CFO of a registrant may omit the language making such references until the registrant becomes subject to the internal control
over financial reporting requirements (e.g., between its IPO and second Form 10-K report date).


**2024 SEC annual reports — Form 10-K** | 61


---

4 Part II of Form 10-K


Certain Form 8-K items qualify for a limited safe harbor from public and private claims under Exchange
Act Section 10(b) and Rule 10b-5 for failure to file a timely Form 8-K regarding certain items. Under the
limited safe harbor, a failure to file a report on Form 8-K for the specified events will not be deemed to be
a violation of Section 10(b) and Rule 10b-5 under the Exchange Act. This safe harbor applies only to a
failure to file; material misstatements or omissions in a Form 8-K continue to be subject to Section 10(b)
and Rule 10b-5 liability. In addition, the safe harbor does not provide protection from Section 10(b) or
Rule 10b-5 liability that might arise from the registrant’s failure to satisfy any other separate duties to
disclose the information (e.g., in a registration statement under the Securities Act). The limited safe
harbor extends only until the due date of the registrant’s next periodic report for the period during which
the Form 8-K was not timely filed.

##### 4.7.2 Insider trading arrangements and policies


Item 9B of Form 10-K requires the disclosure of information required by Items 408(a) of Regulation S-K
during the registrant’s last fiscal quarter (i.e., the fourth quarter for purposes of disclosure in Form 10-K)
about whether any officer or director adopted, modified or terminated a trading plan. [71]


A registrant must identify whether the trading plan is intended to satisfy the affirmative defense
conditions of Exchange Act Rule 10b5-1 and provide a description of the material terms, including:


            - Name and title of the director or officer


            - Date on which the director or officer adopted, modified or terminated [72] the trading plan


            - Duration of the trading plan


            - Aggregate number of securities to be purchased or sold pursuant to the plan


For more details about the proxy statement disclosure requirements for insider trading arrangements and
policies, refer to our publication _**[Proxy statements — An overview of the requirements and observations](https://www.ey.com/en_us/technical/accountinglink/2025-proxy-statements-an-overview-of-the-requirements)**_
_**[about current practice](https://www.ey.com/en_us/technical/accountinglink/2025-proxy-statements-an-overview-of-the-requirements)**_ .

##### 4.8 Item 9C. Disclosure regarding foreign jurisdictions that prevent inspections


The SEC requires disclosure by companies that the SEC identifies as having filed annual reports whose
financial statements are audited by registered public accounting firms in foreign jurisdictions that don’t
allow inspections by the PCAOB (i.e., Commission-Identified Issuers), as mandated by the Holding Foreign
Companies Accountable Act (the HFCA Act). For most registrants, the response to this item will likely be
“Not applicable.” All registrants must present the PCAOB ID number of the audit firm(s) providing the
opinion(s) related to the financial statements in their annual reports. The SEC did not provide guidance
on the location of the PCAOB ID number. While it is ultimately the registrants’ decision where the
PCAOB ID is presented, they may consider including it in the index to Item 8 of the Form 10-K (covered in
section 6 of this publication), following the reference to the financial statement opinion (e.g., Report of
Independent Registered Public Accounting Firm (PCAOB ID: XXXX)). If the registrant’s financial statements
are audited by predecessor and successor auditors, the registrant must present PCAOB ID numbers for
both audit firms.


71 Item 408(a) applies to any Rule 10b5-1 trading arrangement or non-Rule 10b5-1 trading arrangement covering securities in

which an officer or director has a direct or indirect pecuniary interest that is reportable under Section 16 that the officer or
director has made the decision to adopt or terminate.

72 Disclosure regarding termination of a plan is not required for a plan that ends due to its expiration or completion.


**2024 SEC annual reports — Form 10-K** | 62


---

### **5 Item 7. Management’s discussion and** **analysis (MD&A)**

Financial statement users and regulators continue to seek more transparency in companies’ disclosures about
results of operations, liquidity and capital resources, critical accounting estimates and key financial and
operating metrics — all components of MD&A that are discussed in this section. [73]


This section is designed to help management prepare the information required by Item 303 of Regulation S-K,
Management’s Discussion and Analysis of Financial Condition and Results of Operations. Our _SEC annual_
_shareholders’ report checklist_ (EY Form A150) provides a helpful reference for preparing MD&A.


MD&A is required in annual shareholders’ reports, as well as in Form 10-K. Because the requirements are
the same for both documents, the text of MD&A in the annual shareholders’ report should be consistent
with that in Form 10-K if the registrant elects not to incorporate it by reference. Management may use its
discretion on the form and location of the discussion in the annual shareholders’ report.

##### 5.1 Overview


Management must discuss the registrant’s financial condition, changes in financial condition, results of
operations and cash flows in MD&A. Registrants should satisfy the following overarching principles to provide
an effective MD&A discussion and allow investors to view the registrant from management’s perspective:


            - Provide material information relevant to an assessment of the financial condition and results of
operations of the registrant, including an evaluation of the amount and certainty of cash flows from
operations and from outside sources


            - Focus the discussion on material events and uncertainties known to management that are reasonably
likely to cause reported financial information not to be indicative of future operating results or of the
registrant’s future financial condition, including descriptions and amounts of matters that are
reasonably likely, based on management’s assessment, to have a material impact on future operations


            - Discuss the financial statements and other statistical data the registrant believes will enhance the
reader’s understanding of the registrant’s financial condition, changes in financial condition, cash
flows and results of operations


The discussion generally should cover the most recent three fiscal years (i.e., the same period covered by the
financial statements). However, registrants that provide three years of financial statements in a filing can
omit a discussion of the earliest year from MD&A if a discussion of that year was included in any previous
filing, does not warrant material retrospective revision and the registrant does not believe repeating such
information is necessary to an understanding of its financial condition, changes in financial condition and
results of operations. [74] Registrants that elect to omit this discussion must disclose where the omitted
information can be found in the prior filing. [75] Registrants may use any presentation that enhances a reader’s
understanding of their financial condition, changes in their financial condition and results of their operations.


73 The SEC staff frequently comments about MD&A. See our **SEC Reporting Update:** _**[Highlights of trends in 2024 SEC Staff comment](https://www.ey.com/en_us/technical/accountinglink/sec-reporting-update-highlights-of-trends-in-2024-sec-staff-comment-letters1)**_

_**[letters](https://www.ey.com/en_us/technical/accountinglink/sec-reporting-update-highlights-of-trends-in-2024-sec-staff-comment-letters1)**_ publication for common areas of focus by the SEC staff.

74 The SEC staff addressed this matter in **[CD&I Regulation S-K, Question 110.03](https://www.sec.gov/divisions/corpfin/guidance/regs-kinterp.htm)** . A registrant must assess its information about the

earliest of three years and, if it believes it to be necessary to an understanding of its financial condition, changes in financial condition
and results of operations, include it in the current disclosure or expressly incorporate by reference its discussion from a previous filing.

75 The SEC staff issued **[CD&I Regulation S-K, Question 110.02](https://www.sec.gov/divisions/corpfin/guidance/regs-kinterp.htm)**, which indicates that a statement merely identifying the location in a

prior filing where the omitted discussion can be found does not incorporate such disclosure into the filing unless the registrant
expressly states that the information is incorporated by reference.


**2024 SEC annual reports — Form 10-K** | 63


---

5 Item 7. Management’s discussion and analysis (MD&A)

##### 5.2 Overall presentation of MD&A


As to the overall presentation of MD&A, companies should:


            - Focus on material information, eliminate immaterial information and avoid unnecessary duplicative
disclosure


            - Present their disclosure so that the most important material information is most prominent
(e.g., using a “layered” approach)


            - Consider starting MD&A with an executive-level overview that provides context for the remainder of
the discussion


            - Provide a balanced view of the underlying dynamics of the business, including not only a description
of a company’s successes but also of instances when it failed to realize goals, if material.

##### 5.2.1 Executive-level overview


Under the MD&A rules, a company has the flexibility to present MD&A in a manner that it believes is most
meaningful for investors. An executive-level overview can provide helpful context for the MD&A presentation.
It should include the most important matters on which the company’s executives focus in evaluating its
financial condition and operating performance. However, the SEC believes that an executive-level overview
should not merely repeat the more detailed discussion and analysis that follows.


The SEC expects a good executive-level overview to:


            - Include economic or industry-wide factors relevant to the company


            - Inform the reader about how the company earns revenue and generates cash


            - If necessary or useful, discuss the company’s lines of business, location(s) of operations and principal
products and services (but not merely duplicate the disclosure in the Description of Business section
of the filing)


            - Provide insight into material opportunities, challenges and risks (e.g., those presented by known
material trends and uncertainties), on which the company’s executives are most focused for both
the short- and long-term, as well as the actions they are taking to address these opportunities,
challenges and risks


As with the balance of MD&A, the SEC expects the executive-level overview to be dynamic and evolve
over time. In addition, the SEC recommends that companies avoid including boilerplate disclosure that
would detract from the executive-level overview.

##### 5.2.2 Clarity, understandability and organization


The SEC recommends that companies present MD&A in clear and understandable language. In addition,
companies should structure their MD&A to prominently present the most important information.
Accordingly, the SEC encourages companies to consider the following when preparing MD&A:


            - Using tabular presentations of relevant financial or other information (e.g., a tabular comparison of
dollar changes, percentage changes or other pertinent information followed by a discussion and
analysis of the more significant relevant changes)


            - Using headings to help readers follow the flow of MD&A and to promote a better understanding of MD&A


            - Using a “layered” approach to emphasize the most important information and analysis (e.g., beginning
a section with a statement of the principal factors, trends or other matters that are the main subjects
of the section, before providing more detailed analysis of period-to-period information)


**2024 SEC annual reports — Form 10-K** | 64


---

5 Item 7. Management’s discussion and analysis (MD&A)

##### 5.2.3 Emphasis on material information


Companies should focus on and emphasize the most important information in MD&A. In addition to
providing material information in response to specific MD&A rules, companies must provide other
material information that is necessary to make the required statements, in light of the circumstances in
which they are made, not misleading. For example, the SEC cautions companies that, if material information
(historical or forward-looking) is disclosed publicly other than in an SEC filing (e.g., earnings release,
conference call with analysts, website posting), the company should evaluate the information to
determine whether it is required to be included in MD&A. The SEC stated, “We are not seeking to sweep
into MD&A all the information that a company communicates.” Instead, the SEC expects each company to
consider whether elements of such communications are required to be included in MD&A, or consider
whether their inclusion would enhance the presentation of MD&A.

##### 5.2.4 Key performance indicators


Companies should identify key performance indicators, whether financial or nonfinancial, that management
uses to manage the business and that would be material to investors. Such key indicators could relate to
external or macroeconomic matters (e.g., interest rates, economic growth rates, their anticipated trends).
Other key indicators might be specific to a company. Examples include: manufacturing plant capacity and
utilization, backlog, trends in bookings, website visitors, employee turnover rates, information based on
units or volume, customer satisfaction, time-to-market, interest rates, product development, service
offerings, throughput capacity, affiliations/joint undertakings, market demand, customer/vendor relations,
employee retention, business strategy, changes in managerial approach or structure and regulatory
actions or regulatory environment. Since these measures are nonfinancial, the SEC believes that the
disclosure of such information would fall outside the scope of the requirements of Item 10 of Regulation S-K
regarding non-GAAP financial measures.


The Commission has issued guidance, [76 ] advising registrants to provide additional disclosures about key
performance indicators (KPIs) and other metrics included in MD&A. The SEC noted that registrants often
disclose financial and nonfinancial metrics in MD&A that can vary significantly among companies and
industries based on the facts and circumstances.


When disclosing key performance indicators and other metrics in MD&A, a registrant should consider
whether (1) they are US GAAP measures and whether the US GAAP disclosure framework applies to
them, or (2) they are non-GAAP measures and Regulation G and Item 10(e) of Regulation S-K applies to
them. If the metrics are not subject to either of those existing disclosure frameworks, the registrant
should then consider what additional information is needed to provide adequate context to help an
investor understand them. The SEC generally expects, based on the facts and circumstances, the
following disclosures about each KPI:


            - A clear definition of the metric and a description of how it is calculated


            - A statement indicating the reasons why the metric provides useful information to investors


            - A statement indicating how management uses the metric in managing or monitoring the
performance of the business


If there are estimates or assumptions underlying the metric or its calculation, a company should evaluate
whether disclosure of such items is necessary for the disclosure of the metric not to be misleading.


76 Refer to Release 33-10751, _**[Commission Guidance on Management’s Discussion and Analysis of Financial Condition and Results of](https://www.sec.gov/rules/interp/2020/33-10751.pdf)**_

_**[Operations](https://www.sec.gov/rules/interp/2020/33-10751.pdf)**_, for further information.


**2024 SEC annual reports — Form 10-K** | 65


---

5 Item 7. Management’s discussion and analysis (MD&A)


If a company changes the method it uses to calculate or present the metric from one period to another, it
should consider the need to disclose, if material:


            - The differences in how the metric is calculated or presented compared with prior periods


            - The reasons for such changes


            - The effects of any such changes on the amounts or other information being disclosed and on
amounts or other information previously reported


            - Other differences in methodology and results that would reasonably be expected to be relevant to
understanding the company’s performance or prospects


Depending on the significance of the changes in the methodology and results, a company should consider
whether it is necessary to recast previously reported metrics to conform to the current presentation and
place the current disclosure in an appropriate context. Also refer to our To the Point publication, _**SEC**_
_**[issues guidance on disclosures about key performance indicators and other metrics in MD&A](https://www.ey.com/en_us/technical/accountinglink/to-the-point---sec-issues-guidance-on-disclosures-about-key-performance)**_, for
additional information.

##### 5.2.5 Segment analysis


**Requirements:** The SEC’s requirements for management’s discussion of business segments are designed
to be flexible so that registrants may discuss their business in the manner most appropriate to individual
circumstances. The MD&A rules require registrants to discuss each relevant reportable segment and/or
other subdivision of the business (e.g., geographic area, product line) to provide an understanding of the
business. The discussion must focus on each relevant reportable segment and/or other subdivision of the
business and the business as a whole.


There may be other situations where information should be disclosed about a particular segment,
even though the information is not material in quantitative terms and may not otherwise appear
significant to the registrant’s business taken as a whole. These SEC guidelines are subjective and require
careful consideration by management.


**ASC 280 measures:** If a registrant determines segment profitability on a basis that differs from GAAP on
a consolidated basis (as allowed by ASC 280), and discloses any such ASC 280 measure of a segment’s
operating performance in MD&A, MD&A should include a discussion of the reconciling items (as disclosed
in the aggregate under ASC 280, between GAAP income and the sum of all reportable segments’
operating profit or loss) that are applicable to that segment. However, in these circumstances, the SEC
does not expect a numerical reconciliation of the ASC 280 segment measure to the corresponding GAAP


**2024 SEC annual reports — Form 10-K** | 66


---

5 Item 7. Management’s discussion and analysis (MD&A)


measure. Instead, the disclosure may be limited to a narrative discussion in MD&A of items that affect the
GAAP operating results of a segment, but that are not included in segment operating profit defined by
management. Nevertheless, companies may want to consider providing a numerical reconciliation, which
might be useful in facilitating the discussion of the reconciling items.


For example, the SEC would expect discussion in MD&A if a registrant’s measure of segment operating
profit or loss excludes the effects of revenues or expenses attributable to a segment. If a reconciling item
(e.g., a material restructuring or impairment charge) relates to a specific segment, but is not included
in the ASC 280 measure of the segment’s operating profit or loss disclosed in MD&A, the registrant is
expected to disclose the nature of the excluded item, the “applicable portion” of the charge attributable
to the reportable segment, and the circumstances that lead to incurring the charge.


In all cases, disclosures about segment profitability determined under ASC 280 should be explained in a
balanced and informative manner to include how the segment’s performance affects the GAAP
consolidated financial statements.


**Non-GAAP financial measures:** The SEC’s definition of non-GAAP financial measures specifically excludes
measures of profit or loss and total assets for each segment that are required to be disclosed under ASC 280.
The SEC staff’s Non-GAAP C&DIs state, “Because [ASC 280] requires or expressly permits the footnotes to
the company’s consolidated financial statements to include specific additional financial information for each
segment, that information also would be excluded from the definition of non-GAAP financial measures.”


However, the SEC staff has said that additional segment profitability measures a public entity chooses to
disclose that are not determined in accordance with US GAAP would be considered non-GAAP financial
measures because ASC 280 does not (1) _require_ disclosure of additional measures of segment profit or loss
or (2) _expressly permit_ their disclosure by prescribing or otherwise specifying the additional measures that
may be disclosed. [77]


Based on discussions with the SEC staff in August 2024, we understand that, although Item 10(e) of
Regulation S-K prohibits the inclusion of non-GAAP measures on the face of the financial statements and
accompanying footnotes, the staff will not object to the disclosure of additional segment profitability
measures that are not determined in accordance with US GAAP in the footnotes to the financial statements,
provided that these measures otherwise comply with the SEC’s rules and regulations [78] and the related SEC
staff’s C&DIs, on the use of non-GAAP measures. The SEC rules and SEC staff’s C&DIs describe the
requirements for disclosing non-GAAP measures in SEC filings and other communications, including
the following:


- Non-GAAP measures cannot be presented in any way that may be misleading.


- Non-GAAP measures must be reconciled to the most directly comparable GAAP measure.


- Non-GAAP measures cannot be presented with greater prominence than that of the most directly
comparable GAAP measure.


- Non-GAAP measures must be accompanied by disclosures about why they are useful to investors
and, if applicable, how management uses them.


77 Remarks from Lindsay McCord, Chief Accountant in the SEC’s Division of Corporation Finance, at the 2023 AICPA & CIMA

Conference on Current SEC and PCAOB Developments.

78 Regulation S-K Item 10(e) and Regulation G.


**2024 SEC annual reports — Form 10-K** | 67


---

5 Item 7. Management’s discussion and analysis (MD&A)


Entities that choose to disclose additional non-GAAP segment measures in their financial statement
footnotes will need to apply judgment to make sure the measures are not misleading. The SEC staff’s
C&DIs on non-GAAP financial measures note that whether an adjustment results in a misleading non-GAAP
measure depends on the registrant’s facts and circumstances and include several examples of actions
that could cause an adjustment to be misleading or presentation and disclosure to be inappropriate. [79]
See our Technical Line publication, _**[Navigating the requirements for non-GAAP financial measures](https://www.ey.com/en_us/technical/accountinglink/technical-line-navigating-the-requirements-for-non-gaap-financial-measures)**_, for
more information on non-GAAP rules and regulations. Entities should carefully consider this staff
guidance and engage with their legal counsel and independent auditors, when considering whether to
disclose additional non-GAAP segment measures of profit or loss in the financial statements.


Refer to our Technical Line publication, _**[A closer look at the FASB’s new segment disclosure requirements](https://www.ey.com/content/dam/ey-unified-site/ey-com/en-us/technical/accountinglink/documents/ey-tl23954-241us-07-18-2024.pdf)**_,
and our FRD publication, _**[Segment reporting](https://www.ey.com/en_us/technical/accountinglink/financial-reporting-developments-segment-reporting-)**_ .

##### 5.2.6 Material changes


The reasons underlying material changes in financial statement line items must be described to the extent
necessary for users to understand the business as a whole, including when a material change is a result
of multiple factors. In that case, each factor necessary to an understanding of a material change must be
described and quantified. This applies to all financial statements — not just the income statement — and
material changes in a line item must be described even when the changes offset each other. [80] In recent
comment letters, the SEC staff has asked registrants to provide more details about the specific factors
and underlying reasons that contributed to material period-to-period changes. Refer to our **[SEC Reporting](https://www.ey.com/en_us/technical/accountinglink/sec-reporting-update-highlights-of-trends-in-2024-sec-staff-comment-letters1)**
**Update:** _**[Highlights of trends in 2024 SEC staff comment letters](https://www.ey.com/en_us/technical/accountinglink/sec-reporting-update-highlights-of-trends-in-2024-sec-staff-comment-letters1)**_ publication. Determining which changes
are material is left to the registrant.


If the reasons underlying a material change in one line item in the financial statements also relate to
other line items, a registrant is not required to repeat the reasons in the discussion. In addition, a line-byline analysis of the financial statements as a whole is neither required nor generally appropriate, and a
registrant need not recite the amounts of changes from period to period if they are readily computable
from the financial statements or presented in accompanying tables.


As noted above, the SEC encourages companies to present a tabular comparison of the results in
different periods, with percentage changes, followed by a narrative discussion and analysis of the
reasons for material changes and their implications. The SEC intends the discussion to provide
meaningful discussion of the underlying reasons for the change and to avoid simply reciting amounts that
changed in the financial statements.

##### 5.3 Results of operations


In discussing the results of operations, management should:


            - Describe any unusual or infrequent events or transactions or any significant economic changes that
materially affect income from continuing operations and the extent to which income was affected


            - Describe any other significant components of revenue or expense necessary to understand the
results of operations


79 See Questions 100.01 through 100.06 in the C&DIs on Non-GAAP Financial Measures at

**[https://www.sec.gov/divisions/corpfin/guidance/nongaapinterp.htm](https://www.sec.gov/divisions/corpfin/guidance/nongaapinterp.htm)** .

80 The 1989 MD&A Interpretive Release provided the following effective disclosure example: “Revenue from sales of single-family

homes for 1987 increased 6 percent from 1986. The increase resulted from a 14 percent increase in average sales price per
home, partially offset by a 6 percent decrease in the number of homes delivered.”


**2024 SEC annual reports — Form 10-K** | 68


---

5 Item 7. Management’s discussion and analysis (MD&A)


            - Describe any known trends, events or uncertainties that have had, or are reasonably likely to have, a
material effect on sales, revenue or income from continuing operations


            - Disclose any future changes in the relationship between costs and revenue if events are known that
are reasonably likely to cause a material change, such as known future increases in labor or materials
costs or prices


            - Discuss the extent to which material changes in net sales or revenue are the result of changes in
sales volume, introduction of new products or services or sales prices


            - Discuss current-year changes in idle facilities when such changes materially affect the results
of operations


Discussion of commitments or obligations, including contingent obligations, arising from arrangements
with unconsolidated entities or persons that have or are reasonably likely to have a material current or
future effect on a registrant’s revenues or expenses or results of operations must be provided even when
the arrangement results in no obligations being reported in the registrant’s consolidated balance sheets.
See section 5.5 for further discussion of these commitments and obligations. The SEC has stated that
“appropriate disclosure in MD&A should be considered and may be required” in the following circumstances:


            - When material unusual or nonrecurring items, aberrations or other significant fluctuations are
reflected in a company’s financial statements, disclosure may be needed to ascertain the likelihood
that past performance will be indicative of future performance, after considering the extent of
variability in earnings and cash flows.


            - If the economic characteristics of any business arrangements, or the methods used to account for
them, materially affect results of operations or liquidity “in a structured or unusual fashion,”
disclosure may be needed to understand those effects.

##### 5.3.1 Effects of macroeconomic factors


If a macroeconomic factor, such as inflation, interest rates or supply chain issues, has a material impact on
a registrant’s business, the registrant should discuss it as part of its explanation of results of operations by
factor in qualitative and quantitative terms, as required by Item 303(b). In recent comment letters, the
SEC staff has requested that registrants disclose the material impacts of these macroeconomic factors
and what they are doing to mitigate those effects. See our **SEC Reporting Update:** _**[Highlights of trends in](https://www.ey.com/en_us/technical/accountinglink/sec-reporting-update-highlights-of-trends-in-2024-sec-staff-comment-letters1)**_
_**[2024 SEC staff comment letters](https://www.ey.com/en_us/technical/accountinglink/sec-reporting-update-highlights-of-trends-in-2024-sec-staff-comment-letters1)**_ publication for additional details.

##### 5.3.2 Climate change


The SEC staff has issued comment letters to registrants about their compliance with the SEC’s 2010
interpretive guidance on climate-related disclosures, which align with the **[sample comment letter](https://www.sec.gov/rules-regulations/staff-guidance/disclosure-guidance/sample-letter-companies-regarding-climate)** the staff
posted on the SEC website in September 2021 to illustrate the types of comments it had begun issuing to
companies about their compliance with the 2010 guidance. [81] Companies should continue to consider the
Commission’s 2010 interpretive guidance and the September 2021 sample comment letter regardless of
the status of the new rules and whether they are adopted. See our Technical Line publication, _**[Revisiting](https://www.ey.com/en_us/technical/accountinglink/technical-line---revisiting-the-sec-s-guidance-on-climate-change)**_
_**[the SEC’s guidance on climate change disclosures in today’s environment](https://www.ey.com/en_us/technical/accountinglink/technical-line---revisiting-the-sec-s-guidance-on-climate-change)**_, and our **[SEC Reporting Update:](https://www.ey.com/en_us/technical/accountinglink/sec-reporting-update-highlights-of-trends-in-2024-sec-staff-comment-letters1)**
_**[Highlights of trends in 2024 SEC staff comment letters](https://www.ey.com/en_us/technical/accountinglink/sec-reporting-update-highlights-of-trends-in-2024-sec-staff-comment-letters1)**_ publication.


81 FRR-82 (SEC Release No. 33-9106), _Commission Guidance Regarding Disclosure Related to Climate Change_ .


**2024 SEC annual reports — Form 10-K** | 69


---

5 Item 7. Management’s discussion and analysis (MD&A)


The 2010 guidance identifies factors companies should consider when assessing whether to include
climate-related disclosures in MD&A, including:


- Legislation and regulation


- International accords


- Indirect consequences of regulation or business trends


- Physical effects of climate change


**Legislation and regulation:** Significant developments in federal and state legislation and regulation regarding
climate change could trigger disclosure obligations under Item 303 of Regulation S-K. Item 303 requires
a company to assess whether any enacted climate change legislation or regulation is reasonably likely to
have a material effect on its financial condition or results of operations. In the case of a known uncertainty,
such as proposed legislation or regulation, the guidance indicates that assessing potential MD&A disclosure
requirements consists of two steps. First, management must evaluate whether the proposed legislation or
regulation is reasonably likely to be enacted. Unless management determines that it is not reasonably likely
to be enacted, management must proceed on the assumption that the legislation or regulation will be
enacted. Second, management must determine whether the legislation or regulation, if enacted, is
reasonably likely to have a material effect on the company’s business. Unless management determines
that a material effect is not reasonably likely, disclosure is required in MD&A regarding the legislation.


In addition to disclosing the potential effect of proposed legislation or regulation, the company also would
have to consider disclosure, if material, of the difficulties involved in assessing the timing and effect of
the proposed legislation or regulation.


The guidance states that a company should not limit its disclosure of the reasonably likely effects of a
proposed law to potential negative consequences. The guidance observes that changes in laws or in
business practices of some companies in response to those changes may provide new opportunities.


The guidance identifies several examples of possible consequences of proposed legislation and regulation
related to climate change, including:


- Costs to purchase, or profits from sales of, allowances or credits under a “cap and trade” system


- Costs required to improve facilities and equipment to reduce emissions to comply with regulatory
limits or to mitigate the financial consequences of a “cap and trade” regime


- Changes to operating profitability arising from increased or decreased demand for goods and
services produced by the company arising directly from legislation or regulation, and indirectly from
changes in costs of goods sold


**International accords:** The guidance indicates that, if material, companies should disclose the effect on
their business of treaties or international accords relating to climate change. Companies operating in
countries that signed the Paris Agreement, which set a long-term temperature goal, may consider
disclosing the effects of any national policies, laws or regulations aimed at reducing emissions to meet
that commitment. [82] The guidance suggests that companies reasonably likely to be affected by such
agreements should monitor the progress of any potential agreements and consider the potential effects.


82 The Paris Agreement, United Nations Climate Change: **[https://unfccc.int/process-and-meetings/the-paris-agreement/the-paris-](https://unfccc.int/process-and-meetings/the-paris-agreement/the-paris-agreement)**

**[agreement](https://unfccc.int/process-and-meetings/the-paris-agreement/the-paris-agreement)** .


**2024 SEC annual reports — Form 10-K** | 70


---

5 Item 7. Management’s discussion and analysis (MD&A)


**Indirect consequences:** Legal, technological, political and scientific developments regarding climate
change may create new opportunities or risks for companies. The guidance identifies the following
potential indirect consequences or opportunities:


            - Decreased demand for goods that produce significant greenhouse gas emissions


            - Increased demand for goods with lower emissions than competing products


            - Increased competition to develop innovative products


            - Increased demand for generation and transmission of energy from alternative sources


            - Decreased demand for services related to carbon-based energy sources, such as drilling services or
equipment maintenance services


These business trends or risks may require disclosure in MD&A.


**Physical effects:** The guidance indicates that significant physical effects of climate change, such as the
severity of weather (e.g., floods, hurricanes), sea levels, the arability of farmland and water availability
and quality have the potential to affect a company’s operations and results. For example, severe weather
can cause damage to physical plants and facilities and can disrupt manufacturing and distribution processes.

##### 5.3.3 Cybersecurity


The SEC expects registrants to consider the direct and indirect effects of cyber incidents such as costs
for remediation, protection and litigation, as well as implications of possible theft of intellectual property,
customer information or other sensitive data, and the related reputational damage with customers and
investors. Registrants also should consider the potential for lost revenues.


Registrants should address cybersecurity risks and cyber incidents in their MD&A if the costs or other
consequences associated with one or more known incidents or the risks of potential incidents represent a
material event, trend or uncertainty that is reasonably likely to have a material effect on the registrant’s
results of operations, liquidity or financial condition or would cause reported financial information not to
necessarily be indicative of future operating results or financial condition as described in Item 303 of
Regulation S-K.


For example, if material intellectual property is stolen in a cyber attack, and the effects of the theft are
reasonably likely to be material, the registrant should describe the property that was stolen and the effect
of the attack on its results of operations, liquidity and financial condition and whether the attack would
cause reported financial information not to be indicative of future operating results or financial condition.
If it is reasonably likely that the attack will lead to reduced revenues, an increase in cybersecurity
protection costs, including litigation, the registrant should discuss these possible outcomes, including the
amount and duration of the expected costs, if material. Alternatively, if the attack did not result in the loss
of intellectual property, but it prompted the registrant to materially increase its cybersecurity protection
expenditures, the registrant should note those increased expenditures.


In addition to MD&A, registrants should also consider the need to address cybersecurity risks and cyber
incidents in their risk factor disclosures (Item 105 of Regulation S-K as discussed in section 3 of this
publication), description of a business (Item 101 of Regulation S-K as discussed in section 3 of this
publication), legal proceedings disclosures (Item 103 of Regulation S-K as discussed in section 3 of this
publication), financial statement disclosures and management’s assessment of the effectiveness of disclosure
controls and procedures (Item 307 of Regulation S-K as discussed in section 4 of this publication). Refer to
section 3.5 of this publication for further guidance on disclosures related to cybersecurity risk
management, strategy and governance.


**2024 SEC annual reports — Form 10-K** | 71


---

5 Item 7. Management’s discussion and analysis (MD&A)

##### 5.3.4 Pro forma MD&A


When a registrant has a material acquisition or applies pushdown accounting (as discussed further in
section 6 of this publication), it should consider whether to include a supplemental discussion in MD&A
based on pro forma financial information. When determining whether a supplemental discussion based
on pro forma information is necessary, the registrant should consider all the facts and circumstances
surrounding the transaction, the nature of the pro forma adjustments to be made and the overall
meaningfulness of the supplemental discussion.


For example, if the application of pushdown accounting in historical financial statements results in
separate predecessor and successor periods, the historical financial statements may not be comparable.
As a result, the registrant may determine that a discussion based on pro forma financial information
would be meaningful to investors.


If a pro forma MD&A discussion is deemed appropriate, the registrant should clearly disclose why
management believes the presentation is meaningful, how the presentation was derived and whether
there are any risks or limitations associated with the presentation (e.g., the results might not necessarily
be indicative of future results). In addition, the registrant should not present the pro forma results more
prominently than the discussion about the historical results required by Item 303 of Regulation S-K.


The SEC staff believes that the pro forma presentation should be presented in a format consistent
with Article 11 of Regulation S-X. [83] The SEC staff said that it would not be appropriate to merely combine
the pre- and post-transaction results without reflecting all relevant pro forma adjustments required by
Article 11. Refer to our _**[Pro forma financial information: A guide for applying Article 11 of Regulation S-X](https://www.ey.com/en_us/technical/accountinglink/2023-pro-forma-financial-information)**_
**publication** for additional information.


When a registrant concludes that its adoption of a new accounting standard using a retrospective
approach has significantly affected the comparability of financial statements for the periods presented, it
may present supplemental pro forma MD&A to help explain changes in its financial statement line items.
These disclosures, if presented, should focus on (1) the effect on each financial statement line item
affected by such retrospective treatment (i.e., revenue and expense line items) and (2) the assumptions
that the registrant used in estimating the effect on the prior-year information presented (e.g., any
practical expedients applied, date of adoption).

##### 5.4 Liquidity and capital resources


Registrants must analyze their ability to generate and obtain cash and to meet their requirements and plans
for cash in the short term (i.e., 12 months from the most recent fiscal period end presented) and separately in
the long term. The discussion should analyze material cash requirements from known contractual obligations
(e.g., lease obligations, purchase obligations, other liabilities reflected on the registrant’s balance sheet)
and other obligations and specify the type of obligation and the relevant time period for the related cash
requirements. Cash requirements include capital expenditures and other material items, such as research and
development, human capital, and intellectual property.


Some companies may choose to present a contractual obligations table. The table was previously required
by Regulation S-K, but that requirement was rescinded by Release 33-10890, _Management’s Discussion_
_and Analysis, Selected Financial Data, and Supplementary Financial Information_ dated 19 November 2020.


83 The SEC staff said that other formats (e.g., pro forma information specified by ASC 805) also may be appropriate depending on

the specific facts and circumstances.


**2024 SEC annual reports — Form 10-K** | 72


---

5 Item 7. Management’s discussion and analysis (MD&A)


A discussion of commitments or obligations, including contingent obligations, arising from arrangements
with unconsolidated entities or persons that have or are reasonably likely to have a material current or
future effect on a registrant’s liquidity, cash requirements or capital resources must be provided, even
when the arrangement results in no obligations being reported in the registrant’s consolidated balance
sheet. See section 5.5 for further discussion of these commitments and obligations.


Based on these objectives, registrants must provide the following disclosures:


- Liquidity — A registrant must identify any known trends or any known demands, commitments,
events or uncertainties that will result in or that are reasonably likely to result in the registrant’s
liquidity increasing or decreasing in any material way. If a material deficiency is identified, indicate
the course of action that the registrant has taken or proposes to take to remedy the deficiency. A
registrant must also identify and separately describe internal and external sources of liquidity and
briefly discuss any material unused sources of liquid assets. Except where it is otherwise clear from
the discussion, the registrant must discuss balance sheet conditions or income or cash flow items
that the registrant believes may be indicators of its liquidity condition.


Where financial statements presented are required by Rule 4-08(e)(3) of Regulation S-X to include
disclosure of restrictions on the ability of both consolidated and unconsolidated subsidiaries to
transfer funds to the registrant in the form of cash dividends, loans or advances, the discussion of
liquidity must include a discussion of the nature and extent of such restrictions and the impact such
restrictions have had or are reasonably likely to have on the ability of the parent company to meet its
cash obligations.


- Capital resources — A registrant must describe its material cash requirements, including
commitments for capital expenditures, as of the end of the latest fiscal period, the anticipated source
of funds needed to satisfy such cash requirements and the general purpose of such requirements.


A registrant must also describe any known material trends, favorable or unfavorable, in the
registrant’s capital resources and indicate any reasonably likely material changes in the mix and
relative cost of such resources. The discussion must consider changes among equity, debt and any
off-balance sheet financing arrangements.


Although this is not required by the SEC’s rules or interpretive releases, registrants should consider available
internal cash flow projections in analyzing liquidity and capital resources. Such projections likely would be
helpful in identifying any expected material changes in liquidity. Further, as discussed in a 1994 enforcement
release, identification of a future material liquidity deficiency based on internal cash flow projections
likely would be considered by the SEC to be a “known trend” that would require discussion in MD&A.


Registrants commonly organize their discussion of liquidity and capital resources around the categories
presented in their statements of cash flows (i.e., operating, investing and financing). That’s because the
SEC expects a company’s discussion and analysis of liquidity to focus, in part, on material changes in the
operating, investing and financing cash flows depicted in its statements of cash flows and to present a
balanced discussion dealing with cash flows from investing and financing activities, as well as from
operations. However, that discussion should not be merely a recitation of the items in the statements of
cash flows. It should focus on the underlying drivers of change.


**2024 SEC annual reports — Form 10-K** | 73


---

5 Item 7. Management’s discussion and analysis (MD&A)


The following bullets include additional guidance on liquidity and capital resources disclosure: [84]


- Discuss material changes in the underlying drivers when discussing changes in operating, investing
and financing activity cash flows — The SEC warns that a registrant’s MD&A discussion of cash flows
from operating activities should not be limited to discussing changes in the line items that reconcile
net income to operating cash flows. Instead, the SEC expects all companies to address material
changes in the underlying drivers of operating cash flows (e.g., cash receipts from the sale of goods
and services and cash payments to acquire materials for manufacture or goods for resale). [85]


- Discuss changes in cash received from customers and other sources and cash paid to suppliers,
employees and others _—_ The operating activities discussion should provide information on changes in
cash received from customers and other sources and cash paid to suppliers, employees and others.
Instead of providing a summary of the statement of cash flows prepared using the indirect method, a
company might consider discussing increases in supplier costs and the extent to which it passed
those costs along to customers.


- Discuss any known trends and uncertainties that are reasonably expected to have material effects on
the separate sources and uses of cash — The operating activities discussion also should discuss any
known trends and uncertainties that are reasonably expected to have material effects on the
separate sources and uses of cash. Examples mentioned by the SEC staff included new product
releases, pricing changes, maturing product lines, rising costs and changes in credit terms.


- Evaluate capital expenditures on a discretionary and non-discretionary basis (e.g., new capacity
expansion versus maintenance of existing capacity) and discuss anticipated funding sources
(e.g., the extent that cash received from customers will be available) — The SEC staff observed that
companies typically disclose the quantity of historical and anticipated capital expenditures in the
investing activities discussion. Companies should consider separately disclosing capital expenditures
that are discretionary and those that are nondiscretionary and discuss any anticipated funding sources.
In addition, if a company believes it is reasonably likely that it will be required to reduce or delay capital
expenditures, it could describe the effect of these reductions and delays to cash flows from customers.


- Discuss the availability of funds from investments — For example, companies may need to disclose in
the investing activities discussion that material funds invested in investments designated as held to
maturity are not available for immediate use.


- Discuss the availability of credit — The financing activities discussion should include the potential
effect on liquidity of (1) financing arrangements that are reasonably likely to be available to the
company, (2) financing arrangements that the company would like to use but are no longer available or
are reasonably likely to become unavailable, (3) difficulties accessing the debt markets, (4) reliance
on commercial paper or other short-term financing arrangements, (5) maturity mismatches between
borrowing sources and the assets funded by those sources and (6) changes in borrowing terms
requested by counterparties and changes in the valuation of collateral and counterparty risk.


84 This guidance was developed under the legacy rules prior to their amendment on 19 November 2020 **(Release 33-10890**,

_Management’s Discussion and Analysis, Selected Financial Data, and Supplementary Financial Information_ ) and is based on
interpretations provided by the SEC or its staff that we believe remain relevant under the amended rules.

85 For example, if a decrease in operating cash flows was caused by a revised credit policy resulting in extended payment terms, the

SEC would expect the company to disclose this in MD&A, to the extent material, as well as the amount of the associated decrease
in operating cash flow if not otherwise apparent. In addition, the SEC would expect the company to disclose the expected future
implications of a new credit policy to liquidity.


**2024 SEC annual reports — Form 10-K** | 74


---

5 Item 7. Management’s discussion and analysis (MD&A)


Narrative disclosure should be considered, and may be required, if the company’s financial statements
do not adequately convey the registrant’s financing arrangements during the period, or the effect of
those arrangements on liquidity. For example, if borrowings during the period are materially different
from the period-end amounts recorded in the financial statements, FRR-83, _Commission Guidance on_
_Presentation of Liquidity and Capital Resources Disclosures in Management’s Discussion and Analysis,_
states that MD&A must disclose the intra-period variations to facilitate investors’ understanding of
the company’s liquidity position.


For companies with repurchase agreements, the MD&A discussion of liquidity should consider
whether obligations to repurchase assets are reasonably likely to result in the use of a material
amount of cash or other liquid assets. Even if the repurchase obligation involves a transaction
accounted for as a sale under applicable accounting standards, FRR-83 states that disclosures about
the repurchase obligation may be required in the MD&A discussion of liquidity.


- Discuss the factors that might materially influence credit ratings, the potential implications of known
or reasonably likely changes in credit ratings or credit rating outlook and management’s expectations
about credit rating prospects — The simple disclosure of a company’s credit ratings from each of the
major credit rating agencies provides limited value to investors. If a company does not expect a
ratings downgrade, a company could disclose its basis for that conclusion. If a company anticipates
that a ratings downgrade might occur in the foreseeable future, the company could consider disclosing
in the financing activities discussion the reasonably likely expected changes in borrowing costs, costs
of capital and the future operating prospects of the company. [86]


- Discuss any uncertainty or trends surrounding future compliance with financial covenants and the
material implications of a breach. When the filing provides actual ratios or amounts under the
agreement, also consider providing the company-specific calculations [87]   - The SEC staff recommended
that a company explain the basis for conclusions about compliance with debt covenants, including
those affecting debt obligations the company guarantees. For example, the financing activities discussion
also might include disclosures about a company’s expectation of meeting debt covenant requirements in
the short-term and long-term. In addition, a company should consider disclosing any reasonably likely
ratings downgrades and the effect on financial covenants. If a breach of financial covenants is
reasonably likely, FRR-72, _Commission Guidance Regarding Management’s Discussion and Analysis of_
_Financial Condition and Results of Operations,_ suggests that the company disclose that fact and analyze
the effect, including the following, if material [88] :


   - The steps that the company is taking to avoid the breach


   - The steps that the company intends to take to cure, obtain a waiver of or otherwise address
the breach


   - The impact or reasonably likely impact of the breach (including the effects of any cross-default or
cross-acceleration or similar provisions) on financial condition or operating performance


   - Alternate sources of funding to pay off resulting obligations or replace funding


86 In its 7 October 2009 proposal, _Credit Ratings Disclosure,_ the SEC reiterated the need for MD&A disclosure of the material effects

of any change in a credit rating.

87 In these circumstances, registrants should disclose the required ratios or amounts, as well as the actual ratios or amounts as of

each reporting date, to allow investors to understand the amount of “cushion” available. The SEC staff also has asked registrants
to consider showing the specific computations used to arrive at the actual ratios or amounts (with corresponding reconciliations
to US GAAP amounts, if necessary).

88 FRR-72 indicates that similar disclosure expectations would apply to mandatory prepayment provisions, “put” rights and other

similar provisions.


**2024 SEC annual reports — Form 10-K** | 75


---

5 Item 7. Management’s discussion and analysis (MD&A)


- Discuss whether covenants affect the company’s ability to incur additional debt or equity financing to
a material extent [89] _—_ If there are limitations to incur additional debt or equity financing, FRR-72
suggests that the company disclose that fact as well as:


- The consequences of those limitations on the company’s financial condition and operating performance


- Alternate sources of funding and, to the extent material, the consequences (e.g., costs) of accessing
those alternatives


- Discuss any uncertainties and reasonably likely implications related to loan facilities from banks and
other lending institutions, the commercial paper market, cash and securities held at banks and other
financial institutions, illiquid investments, future pension funding, share repurchase programs and
dividend payments — Current market conditions call for complete disclosures about a company’s
liquidity and capital resources. Companies could provide insight into the possible material
implications of any inability to access sources of funding that have been available in the past. The
SEC staff believes that a company should discuss uncertainties about the future amounts of pension
funding, as well as its ability to pay those amounts. Similarly, a company should discuss any
uncertainties regarding its intentions to continue share repurchase and dividend payment programs.


- Discuss any material amount of debt incurred — Companies should explain the reason for incurring the
debt, the use of the proceeds and how incurring the debt achieves the company’s business objectives. [90]
On the other hand, if debt was incurred for general working capital purposes, companies should
disclose the anticipated amount and timing of material working capital needs. [91] These disclosures
can be provided in the financing activities discussion.


- Discuss any other relevant relationships with counterparties or guarantors — For example, companies
should discuss receivable positions with derivative counterparties and any financial guarantors
(e.g., monoline insurers), if material, in the financing activities discussion.


- Provide the additional disclosures required when an opinion on a company’s financial statements
contains an explanatory paragraph about a going concern uncertainty — FRR Section 607.02
requires companies not only to provide disclosure in the notes to the financial statements of their
financial difficulties and plans to overcome them, but also to present a detailed management
discussion of material cash flows covering the 12-month period following the date of the financial
statements. Such a discussion would be updated quarterly, as appropriate.


89 FRR-72 indicates that examples of these covenants include, but are not limited to, debt incurrence restrictions, limitations on

interest payments, restrictions on dividend payments and various debt-ratio limits.

90 For example, if debt were issued to fund the construction of a new plant that will allow the company to expand its operations into

a new geographic area, the SEC would expect the company to disclose the reason for incurring the debt, as well as the expected
commencement date of the plant operations.

91 FRR-72 also reminds companies of the requirement in Item 5 of Form 10-K and Item 701(f) of Regulation S-K to disclose the use

of proceeds from offerings of registered securities.


**2024 SEC annual reports — Form 10-K** | 76


---

5 Item 7. Management’s discussion and analysis (MD&A)

##### 5.5 Off-balance sheet arrangements


Instruction 8 to Item 303(b) states that a discussion of commitments or obligations, including contingent
obligations, arising from arrangements with unconsolidated entities or persons that have or are reasonably
likely to have a material current or future effect on a registrant’s financial condition, changes in financial
condition, revenues or expenses, results of operations, liquidity, cash requirements or capital resources
must be provided in MD&A even when the arrangement results in no obligations being reported in the
registrant’s consolidated balance sheets. These arrangements may include [92] :


            - Guarantee contracts described in ASC 460-10-15-4


            - Retained or contingent interests in assets transferred to an unconsolidated entity


            - Contractual arrangements that support the credit, liquidity or market risk for transferred assets


            - Obligations that arise or could arise from variable interests held in an unconsolidated entity


            - Obligations related to derivative instruments that are both indexed to and classified in a registrant’s
own equity under US GAAP


To avoid repetition, a company’s MD&A discussion of off-balance sheet arrangements is allowed to crossreference information disclosed in the notes to its financial statements if specific, relevant information in
those notes is clearly identified. If a company chooses to cross-reference its financial statement
disclosures, its MD&A discussion still must integrate the substance of those disclosures and inform
investors of the significant information included in the notes to the financial statements.


ASC 460, _Guarantees_, also includes two groups of specific exceptions to its scope. The first group is
exempt from ASC 460 in its entirety, while the second group is subject to only the disclosure
requirements of ASC 460. Registrants should consider whether disclosure of guarantees subject to these
exceptions (see ASC 460-10-15-7 and 460-10-25-1) would be appropriate under this principles-based
disclosure requirement. **[93]**


**Disclosure threshold:** MD&A disclosure is required for off-balance sheet arrangements (as defined) that
have or are reasonably likely to have a material current or future effect on a registrant’s financial condition,
changes in financial condition, revenues or expenses, results of operations, liquidity, cash requirements,
or capital resources.


To determine whether MD&A disclosure is required for a particular off-balance sheet arrangement within
the definition discussed above, management should assess the likelihood of the occurrence of any known
trend, demand, commitment, event or uncertainty that could either require performance of a guarantee
or other obligation, or require the company to recognize an impairment or other loss. If management
objectively and reasonably concludes that the likelihood of occurrence is not reasonably likely, then no
disclosure is required, even if the consequences of an occurrence could be material. If management
cannot objectively and reasonably determine that such an occurrence is not reasonably likely, management
then must evaluate the consequences assuming occurrence. Disclosure is required unless management
determines that it is not reasonably likely that the effects would be material.


92 Registrants should note that the categories of off-balance sheet arrangements contained in the disclosure requirements in

Form 8-K, which are triggered when a registrant becomes subject to the obligation or commitment arising from an off-balance
sheet arrangement, differ from the categories contained in the MD&A disclosure requirements.

93 Prior to Release 33-10890, _Management’s Discussion and Analysis, Selected Financial Data, and Supplementary Financial_

_Information,_ dated 19 November 2020, both groups of exceptions were excluded from the definition of off-balance sheet
arrangements.


**2024 SEC annual reports — Form 10-K** | 77


---

5 Item 7. Management’s discussion and analysis (MD&A)


Disclosure of an off-balance sheet arrangement is not required until an unconditionally binding definitive
agreement exists or such an agreement is subject to only customary closing conditions. In the absence of
such agreement, disclosure is not required until settlement of the transaction occurs. Thus, companies
are not required to disclose off-balance sheet arrangements that are still being negotiated. However, if
settlement of an arrangement occurs after the balance sheet date but before the date of the SEC filing,
the company would have to consider whether disclosures are required in MD&A, in addition to any
separate Form 8-K report related to the contract or transaction.


**Disclosures:** The instruction does not include itemized disclosure requirements for off-balance sheet
arrangements within its scope. However, the legacy rules (prior to Release 33-10890, _Management’s_
_Discussion and Analysis, Selected Financial Data, and Supplementary Financial Information_, dated
19 November 2020) did include such requirements that we believe can be helpful. A registrant should
consider these legacy requirements when preparing its current disclosure and include it within the MD&A
section or sections that correspond to its impact. The requirements in the legacy instruction included the
following and generally covered material changes from the previous fiscal year:


            - The nature and business purpose of the arrangement


            - The importance of the arrangement to liquidity, capital resources, market risk support, credit risk
support or other benefits


            - The amounts of revenues, expenses and cash flows arising from the arrangement


            - The nature and amount of any interests retained, securities issued and other indebtedness incurred
by the company in connection with the arrangement


            - The nature and amounts of any other obligations or liabilities (including contingent obligations or
liabilities) of the company arising from the arrangement that are, or are reasonably likely to become,
material and the triggering events or circumstances that could cause them to arise


            - Any known event, demand, commitment, trend or uncertainty that will, or is reasonably likely to,
result in the termination or material reduction in availability of an arrangement that provides
material benefits, and the course of action that the company has taken, or proposes to take, in
response to any such circumstances


Contingencies could also result in the termination or limitation of an off-balance sheet arrangement, such
as adverse changes in the company’s credit rating, financial performance or ratios, stock price and the
value of underlying or indexed assets.

##### 5.6 Known trends, events, demands, commitments and uncertainties


One of the most difficult judgments management makes in MD&A relates to known “trends, events and
uncertainties” that might affect future earnings or other measures of performance.


Item 303 of Regulation S-K indicates that registrants should describe any known trends or uncertainties
that have had, or that are reasonably likely to have, a material favorable or unfavorable effect on
financial results.


The discussion should highlight known material trends, events and uncertainties that are reasonably
likely to cause the reported financial information not to be necessarily indicative of future operating
results or financial condition. This includes discussion of both (1) matters that would have an effect in the
future and have not had an effect in the past and (2) matters that have had an effect in the past and are
not expected to have an effect in the future.


**2024 SEC annual reports — Form 10-K** | 78


---

5 Item 7. Management’s discussion and analysis (MD&A)


A discussion of known trends, events and uncertainties is required unless management determines that
(1) the known trend, event or uncertainty “is not reasonably likely to occur” or (2) assuming that the
known trend, event or uncertainty comes to fruition, that its consequences would not be reasonably likely
to have a material effect on financial condition or results of operations. The SEC believes that
“reasonably likely” is a lower disclosure threshold than “more likely than not.”


Any forward-looking information supplied in MD&A might be covered by either (1) the SEC’s safe harbor
rules (Securities Act Rule 175 and Exchange Act Rule 3b-6), as long as the necessary conditions are met
(i.e., the forward-looking information was prepared on a reasonable basis and disclosed in good faith)
or (2) the statutory safe harbor for forward-looking information (see Forward-looking information in
section 2 of this publication). The SEC also provides its views on important factors to be considered in
formulating and disclosing projections in Item 10(b) of Regulation S-K, such as the appropriate basis and
format for projections, and how to facilitate investor understanding of projections, and in particular, their
limitations. As part of their disclosure controls and procedures (Exchange Act Rules 13a-15 and 15d-15),
registrants should consider all known trends, events and uncertainties as part of the MD&A preparation
process and consider documenting the reasons for disclosure or nondisclosure.


To identify known trends and uncertainties, the SEC suggests that a company consider financial,
operational and other information (including nonfinancial information) known to the company. The SEC
also suggests that companies consider whether or not the available information itself is material and
should be disclosed. FRR-72 states, “This information, over time, may reveal a trend or general pattern
in activity, a departure or isolated variance from an established trend, an uncertainty, or a reasonable
likelihood of the occurrence of such an event that should be disclosed.” FRR-72 adds that quantification
of the material effects of known material trends and uncertainties “should be considered and may be
required to the extent material if quantitative information is reasonably available.”


In addition, ASC 275-10-50-16 requires disclosures in the notes to the financial statements about
vulnerability from concentrations when all three of the following conditions are met:


            - The concentration of risk exists at the date of the financial statements


            - The concentration makes the enterprise vulnerable to the risk of a near-term “severe impact” [94]


            - It is at least reasonably possible that the events that could cause the severe impact will occur in the
near-term


Companies should consider whether they have concentrations in volume of business transacted with a
particular customer, supplier or lender; revenue from particular products or services; available sources
of supply materials, labor or services; or market or geographical area in which they operate that might
meet the three criteria above.

##### 5.6.1 Sovereign debt exposures


In January 2012, the SEC staff issued CF Disclosure Guidance: Topic No. 4, _European Sovereign Debt_
_Exposures_, to help registrants determine what they should disclose in MD&A about their exposures to
countries experiencing significant economic, fiscal or political challenges, when default is more likely to
occur than if such factors did not exist.


94 The Accounting Standards Codification defines “severe impact” as “a significant financially disruptive effect on the normal functioning of

the entity. Severe impact is a higher threshold than material. Matters that are important enough to influence a user’s decisions are
deemed to be material, yet they may not be so significant as to disrupt the normal functioning of the entity. Some events are material to
an investor because they might affect the price of an entity’s capital stock or its debt securities, but they would not necessarily have a
severe impact on (disrupt) the enterprise itself. The concept of severe impact, however, includes matters that are less than catastrophic.
Matters that are catastrophic include, for example, those that would result in bankruptcy.”


**2024 SEC annual reports — Form 10-K** | 79


---

5 Item 7. Management’s discussion and analysis (MD&A)


The SEC staff’s guidance does not list the specific countries subject to enhanced disclosure. Instead, the
SEC staff expects registrants to use their own judgment in determining for which countries to provide
disclosures. The SEC staff noted that the countries for which these disclosures are made will change as
risks change over time. Registrants should disclose in MD&A their basis for identifying countries included
in their enhanced disclosure.


This interpretive guidance indicates that the following should be included in MD&A on a country-bycountry and financial statement category basis for those countries identified as representing heightened
exposure of the registrant:


            - Gross funded exposures


            - Gross unfunded commitments


            - Net funded exposures

##### 5.7 Critical accounting policies and estimates


Item 303(b)(3) defines critical accounting estimates as estimates made in accordance with generally
accepted accounting principles that involve a significant level of estimation uncertainty and have had,
or are reasonably likely to have, a material impact on the registrant’s financial condition or results of
operations. If an estimate does not meet these criteria, identification as a critical estimate is not
required. Registrants should evaluate critical estimates using these criteria on an ongoing basis and add
or subtract as appropriate. For each critical accounting estimate, registrants are required to disclose:


            - Why the estimate is subject to uncertainty


            - How much the estimate and/or assumption has changed over a relevant period [95]


            - The sensitivity of the reported amounts to the methods, assumptions and estimates underlying the
estimate’s calculation


In addition, the discussion should provide quantitative as well as qualitative information when this
information is material and reasonably available. That is, for both qualitative and quantitative
information, the disclosure requirement is triggered if the information is necessary to understand the
estimation uncertainty and the impact the critical accounting estimate has had, or is reasonably likely to
have, on the registrant’s financial condition or results of operations. Furthermore, the critical accounting
estimates disclosure must supplement, but not duplicate, the description of accounting policies or other
disclosures in the notes to the financial statements.


Because critical accounting estimates and assumptions are based on matters that are highly uncertain,
the SEC believes that companies should analyze their specific sensitivity to change based on other
outcomes that are reasonably likely to occur and would have a material effect. The SEC believes that
companies should provide a quantitative, as well as qualitative disclosure, when quantitative information
is reasonably available and would provide material information. [96]


95 Item 303(b)(3) does not specify the period over which a registrant should discuss the changes in the estimate or assumption.

However, pursuant to SEC Release No. 33-10890 dated 19 November 2020, this approach is intended to give registrants the
flexibility to determine the relevant period necessary to describe material changes in estimates or assumptions that would
facilitate an understanding of estimation uncertainty, consistent with the principles-based nature of MD&A.

96 For example, if reasonably likely changes in the long-term rate of return used in accounting for a company’s pension plan would

have a material effect on the company’s financial condition or results of operations, the SEC believes that the company should
disclose and quantify the effect that could result given the range of reasonably likely outcomes.


**2024 SEC annual reports — Form 10-K** | 80


---

5 Item 7. Management’s discussion and analysis (MD&A)


In particular, the SEC staff has noted that registrants’ disclosures about critical accounting policies and
estimates often are too general and should be expanded to include a description of the significant
estimates and assumptions made by management. Some of the areas that the SEC staff has commented
on include allowance for loan losses, contingencies, derivatives, goodwill and other asset impairments,
inventory, pensions and other postretirement benefit costs and obligations, recognition of intangible
assets as part of a business combination, revenue recognition and share-based payments.


**2024 SEC annual reports — Form 10-K** | 81


---

5 Item 7. Management’s discussion and analysis (MD&A)


In addition, ASC 275-10-50-8 requires disclosures in the notes to the financial statements about certain
significant estimates when information that is known to management prior to the issuance of financial
statements meets both of the following criteria: (1) it is at least reasonably possible (as defined in the
Accounting Standards Codification) that management’s estimate of the effect on the financial statements of a
condition, situation or set of circumstances existing at the date of the financial statements will change in the
near-term as a result of one or more future confirming events and (2) the effect of the change would be
material to the financial statements. The disclosure should indicate the nature of the uncertainty and an
indication that it is at least reasonably possible that a change in the estimate will occur in the near-term.
Disclosure of the factors that cause the estimate to be sensitive to change also is encouraged but not required.

##### 5.7.1 Impairment of goodwill


The SEC staff may ask registrants to provide more robust disclosures about their accounting estimates
related to goodwill impairment testing, if those estimates are considered critical, as well as the details of
any recognized goodwill impairments. The SEC staff has asked in its comments for more discussion in
MD&A of the following:


            - The accounting policies related to the goodwill impairment tests, including when the two-step
impairment test is performed, whether the optional qualitative assessment was performed for any
reporting units, how reporting units are identified and aggregated, how goodwill is assigned to
reporting units, and how the implied fair value of goodwill is derived in the second step


            - The facts and circumstances leading to an impairment


            - How the fair value of each reporting unit was estimated, including the significant assumptions and
estimates used


            - Any reporting unit with a material amount of goodwill whose estimated fair value does not
substantially exceed its carrying amount (i.e., the reporting unit is “at risk” of failing a future
quantitative impairment test)


When the SEC staff believes that the factors resulting in a material goodwill impairment have not been
satisfactorily disclosed, they frequently request additional information as to the factors and
circumstances leading to the impairment.


Although detailed information such as the fair value or the carrying amount of reporting units is not
required by GAAP, the SEC believes that meaningful information about the potential for a future goodwill
impairment should be included in MD&A. The SEC staff frequently asks that registrants provide in MD&A
information that allows for an assessment of the probability of a future material impairment charge for any
reporting unit that may have a material amount of goodwill “at risk.” Specifically, the SEC staff expects a
registrant’s MD&A to disclose the following for reporting units that are “at risk” of impairment: [97]


            - The percentage by which the fair value exceeds the carrying value as of the most recent impairment test
(often referred to as “headroom”)


            - The amount of goodwill assigned to the reporting unit


            - A qualitative discussion of key assumptions that drive the fair value of the reporting unit (i.e., the
SEC staff encourages, but does not require, disclosure of the key numerical assumptions or a
quantitative sensitivity analysis) and how the assumptions were determined


97 If the registrant identifies goodwill impairment as a critical accounting estimate but does not have any reporting units that are at

risk of failing the goodwill impairment test, the SEC staff expects the registrant to disclose that fact in MD&A.


**2024 SEC annual reports — Form 10-K** | 82


---

5 Item 7. Management’s discussion and analysis (MD&A)


            - A discussion of the degree of uncertainty associated with the key assumptions, including specifics to
the extent possible (e.g., the valuation model assumes recovery from a business downturn within a
defined period of time)


            - A discussion of any potential events and/or circumstances that could reasonably be expected to
negatively affect the key assumptions


While no bright lines exist to determine whether a reporting unit’s goodwill is “at risk,” the SEC staff has
stated that it expects a registrant to apply judgment when making those disclosures. If an analysis of the
facts and circumstances and the headroom attributable to a particular reporting unit suggests that an
impairment does not constitute a known uncertainty that is reasonably likely to have a material impact
on financial condition or results of operations, a registrant need not provide these disclosures.


The SEC staff also may question whether adequate disclosure was made in previous filings when a
goodwill impairment charge is recorded for a reporting unit that was not previously disclosed as being
at risk. Further, the SEC staff may challenge the timing of a goodwill impairment charge, particularly
when the reasons for the charge existed in prior periods.

##### 5.7.2 Income taxes


The SEC expects registrants to provide in MD&A certain disclosures relating to income taxes. These disclosures
are discussed in greater detail in our _SEC annual shareholders’ report checklist_ (EY Form A150).


Additionally, as a result of the Pillar Two Global Anti-Base Erosion (GloBE) taxes stemming from the
Organisation for Economic Co-operation and Development (OECD), registrants should consider whether
disclosure of the known or expected impact of the GloBE rules on their results of operations or financial
condition is necessary in the MD&A disclosure. See our FRD publication, _**[Income taxes](https://www.ey.com/en_us/technical/accountinglink/financial-reporting-developments---income-taxes-)**_, _and our_ Technical
Line publication, _**[Accounting considerations for the global minimum tax under the Pillar Two GloBE](https://www.ey.com/en_us/technical/accountinglink/technical-line-accounting-considerations-for-the-global-minimum-tax-under-the-pillar-two-globe-model-rules)**_
_**[model rules](https://www.ey.com/en_us/technical/accountinglink/technical-line-accounting-considerations-for-the-global-minimum-tax-under-the-pillar-two-globe-model-rules)**_ .


The SEC staff has expressed concerns that registrants’ income tax disclosures in MD&A often don’t tell a
complete story about the company’s tax positions and related trends and uncertainties. Discussed below
are some types of disclosures registrants should consider:


_Realizability of deferred tax assets_            - The SEC staff routinely requests disclosures to be included in MD&A
regarding uncertainties that might exist about the realization of deferred tax assets that are not offset by
deferred tax liabilities. The SEC staff has requested that registrants include the following in their MD&A:


            - Disclosure of the basis for management’s determination that it is more likely than not that the net
deferred tax asset will be realized.


            - Disclosure of the types of uncertainties that may affect the ultimate realization of deferred tax assets
(e.g., those related to estimates of future taxable income)


            - Disclosure of the registrant’s intention to evaluate the realizability of the deferred tax asset quarterly
by assessing the need for a valuation allowance


Examples of uncertainties related to future taxable income may include:


            - Possible declines in sales, margins and revenues stemming from a variety of sources, such as loss of
market share, technological obsolescence or increased competition


            - The amount of expected future taxable income that would have to be generated to realize the
deferred tax assets, and whether the existing levels of pretax earnings for financial reporting
purposes are sufficient to generate that minimum amount of future taxable income


**2024 SEC annual reports — Form 10-K** | 83


---

5 Item 7. Management’s discussion and analysis (MD&A)


- The period that future taxable income would have to be earned to realize the deferred tax asset


- Whether the source of the expected future taxable income will stem from ordinary and recurring
operations or whether sales of operating assets will be necessary to achieve the required levels of income


   - If the source of the expected future taxable income is from other than ordinary and recurring
operations, the amount of taxable income that could be generated from those transactions
should be disclosed along with a discussion of how management plans to consummate those
transactions and any material uncertainties that could affect those transactions.


See our FRD publication, _**[Income taxes](https://www.ey.com/en_us/technical/accountinglink/financial-reporting-developments---income-taxes-)**_, for further discussion about the disclosure of the realizability of
deferred tax assets in MD&A.


_Income tax rate reconciliations_ - The income tax rate reconciliation in the notes to the financial statements
identifies and quantifies differences between the amount of reported total income tax expense or benefit
from continuing operations and the amount computed by multiplying the pretax income or loss from
continuing operations by the domestic federal statutory income tax rate, showing the nature and amount
(using percentages or dollar amounts) of each significant reconciling item. The SEC staff believes this
tabular disclosure provides a great source of information for MD&A. In addition, the staff believes that
registrants would benefit from using the income tax rate reconciliation as a starting point for the
narrative income tax disclosures in MD&A and tying MD&A disclosures directly to the rate reconciliation
to reduce confusion about where the items discussed flow through the reconciliation. Narrative
disclosures should include a detailed discussion of what drove the change in the effective tax rate and the
overall susceptibility of the rate to changes, which should help users determine whether the past rate is
indicative of the future rate.


The SEC staff may question whether large “provision to return” or “true-up” adjustments included in the
income tax rate reconciliation reflect the correction of prior-year errors rather than changes in estimates.
In addition, the staff may question registrants when information in the income tax rate reconciliation is
inconsistent with disclosures elsewhere in the filing.


_Foreign earnings_ - A registrant may report a relatively low effective tax rate if it derives substantial income
from low-tax-rate jurisdictions and indefinitely reinvests such earnings. In these circumstances, the registrant’s
income tax reconciliation may include a large reconciling item related to these low-tax-rate jurisdictions.


The SEC staff often asks registrants that label a reconciling item as the difference between the foreign tax
rate and the domestic tax rate whether they include more than just the rate differential in that line item
(e.g., permanent differences such as tax amortization of foreign entity goodwill). When applicable, reconciling
items affected by multiple factors should be clarified and disaggregated so that users can understand factors
driving the reconciling item. For example, reconciling items labeled “foreign rate differential” should be
limited to statutory tax rate differences. The SEC staff has suggested that registrants present a multi-column
reconciliation that separately presents the reconciling items and taxable income by material foreign
jurisdictions [98] in addition to the domestic jurisdiction and on a consolidated basis.


98 If a disproportionate amount of a registrant’s profit is attributable to countries with a low tax rate, such as Ireland, the SEC staff has

requested disclosure of such amounts (e.g., $1 billion of our foreign profits were earned in Ireland, which has an effective tax rate of 10%).


**2024 SEC annual reports — Form 10-K** | 84


---

5 Item 7. Management’s discussion and analysis (MD&A)

##### 5.7.3 Investments (including high-yield, highly leveraged transactions)


FRR Section 501.06.b provides disclosure considerations for registrants that participate in high-yield or
highly leveraged transactions [99] or make non-investment grade loans or investments. Discussion of the
potentially greater returns, and potentially greater risks, because of the registrant’s involvement in these
transactions may be included in the business discussion, or other appropriate location of the Form 10-K,
but the effects resulting from participation should be analyzed in MD&A.


The SEC indicated that registrants should consider disclosing:


            - Relevant lending and investing policies


            - The amount of holdings and potential risks inherent in such holdings


            - Information regarding the level of activity


            - Amounts of holdings, if any, giving rise to significantly greater risks


            - An analysis of the actual and reasonably likely material effects of the above matters on income
and operations


These disclosures are discussed in greater detail in our _SEC annual shareholders’ report checklist_
(EY Form A150).

##### 5.7.4 Emerging growth company disclosures


Section 7(a) of the Securities Act, as amended by Section 102(b) of the JOBS Act, exempts an EGC from
adopting new or revised accounting standards following public company effective dates if private
companies have a delayed effective date. Instead, the effective date for private companies will apply to
EGCs that don’t elect to follow public company effective dates.


Generally, if an EGC follows the extended transition provisions for private companies and it loses its EGC
status after it would have had to adopt a standard absent the extended transition, the issuer should adopt
the standard in its next filing after losing status.

##### 5.8 Other disclosures 5.8.1 Accounting estimate and policy changes (including pending adoption of new accounting standards)


FRR-72 states that “appropriate disclosure in MD&A should be considered and may be required” if
a change in an accounting estimate causes a material improvement in earnings. FRR-72 adds that “the
change and the underlying reasons for the change should be disclosed so that readers do not incorrectly
attribute the effect to operational improvements.” MD&A also should discuss the expected effect on
financial information to be reported in the future of changes in accounting estimates that have not been
fully recognized in the statement of operations, if material (e.g., a change in the amortization period for
intangibles, a change in the pension or OPEB discount rate or expected return on plan assets).


99 FRR Section 501.06b does not define those types of transactions. However, the SEC referred to criteria set forth in a 1989

Federal Reserve Board release that issued bank examination guidelines regarding highly leveraged transactions. In those
guidelines, the criteria for a highly leveraged financing include a debt to total assets ratio exceeding 75%. In any event,
registrants should indicate how highly leveraged transactions are defined for MD&A purposes.


**2024 SEC annual reports — Form 10-K** | 85


---

5 Item 7. Management’s discussion and analysis (MD&A)


The SEC staff indicated in SAB Topic 11.M, _Disclosure of the Impact that Recently Issued Accounting Standards_
_Will Have on the Financial Statements of the Registrant When Adopted in a Future Period_, that registrants
should discuss the effect of yet-to-be-adopted accounting standards that, when adopted, are expected to
materially affect financial condition or results of operations. SAB Topic 11.M requirements include:


- A brief description of the new standard, the date by which adoption is required, and the date on
which the registrant plans to adopt, if earlier


- A discussion of the methods of adoption allowed by the standard and the method expected to be
used by the registrant, if determined


- Disclosure of the potential effect of other significant matters that the registrant believes might result
from the adoption of the standard (e.g., technical violations of debt covenant agreements, planned
or intended changes in business practices)


- A discussion of the effect that adoption of the standard is expected to have on the financial statements of
the registrant, unless not known or reasonably estimable


If a pending accounting standard update will affect the preparation of the financial statements, but not have
a material effect, SAB Topic 11.M encourages companies to disclose that a standard has been issued and
that its adoption will not have a material effect on its financial position or results of operations.


The objectives of the disclosure should be to (1) provide notification that a standard has been issued that
the registrant will be required to adopt in the future and (2) assist investors in assessing the significance
of the effect that the standard will have on the financial statements of the registrant when adopted. The
requirements of SAB Topic 11.M do not extend to Exposure Drafts of proposed accounting standards updates.


The SEC staff has reminded registrants that the objectives of SAB Topic 11.M and the purpose of financial
statement disclosures are not necessarily consistent. MD&A should discuss known information about the
expected effect of a new accounting standard on _future_ periods, while the financial statement notes should
disclose the anticipated effect of a new standard on _historical_ financial statements. By distinguishing these
objectives, a preparer can avoid redundancy in its disclosures.


SAB Topic 11.M does not require a company to quantify the effects of a new accounting standard. However,
the SEC staff does expect companies to disclose the expected effects on the financial statements of
adopting a pending standard to the extent those effects are known. If the effects of adopting a new
accounting standard are not known, companies should disclose that fact. It might be appropriate to
disclose a range of possible effects if an approximate amount is not known. The SEC staff has indicated
that qualitative disclosures should be included if quantitative information is not available.


The SEC staff has said that if a registrant does not know or cannot reasonably estimate the effect on the
financial statements of adopting a new standard, it should make a statement to that effect and consider
providing qualitative disclosures to help the reader assess the potential significance of the effect on the
registrant’s financial statements. These qualitative disclosures should include a description of the new
standard’s effect on the registrant’s accounting policies and provide a comparison to the registrant’s
current accounting policies.


The SEC staff has said that a registrant should consider the full scope of the new standard, including
presentation in the financial statements and disclosures in the notes to the financial statements, when
evaluating the effect on its financial statements. The SEC staff also expects registrants to describe the
process they use to assess the effect of the new standard, where they are in the implementation process,
what matters still need to be addressed and what additional steps they plan to take.


**2024 SEC annual reports — Form 10-K** | 86


---

5 Item 7. Management’s discussion and analysis (MD&A)


The SEC staff expects a registrant’s disclosures to evolve as the effective date of a major standard nears
and the registrant makes progress in its implementation plan. That is, the SEC staff expects a registrant’s
disclosures to be more specific each quarter and to be reviewed and discussed with the audit committee.

##### 5.8.2 Discontinued operations


SAB Topic 5.Z, _Accounting and Disclosures Regarding Discontinued Operations_, provides interpretive
guidance on disclosures about discontinued operations required in MD&A. Registrants should discuss
known trends, events and uncertainties involving discontinued operations that might materially affect
the registrant’s liquidity, financial condition and results of operations (including net income) in MD&A for
periods “between the date when a component of an entity is classified as discontinued and the date when
the risks of those operations will be transferred or otherwise terminated.” This discussion should include
changes in the plan of disposal or changes in circumstances related to the plan.


The potential effect on the registrant’s reported results or liquidity of any material contingent liability,
such as product or environmental liabilities or litigation that might remain with the registrant despite
disposal of the underlying business also should be discussed.


If a registrant had decided to discontinue a component of the business and subsequently decides to retain
it, the SEC staff expects MD&A to discuss any material effect on results of operations, liquidity and capital
resources, and the reasonably likely effects of known trends, commitments or contingencies.

##### 5.8.3 Foreign operations


Although FRR Section 501.09 discusses disclosures about foreign operations, it does not mandate any
specific disclosures. The section uses such terms as “encourages” and “should consider” in discussing
information that registrants might disclose to enhance readers’ understanding of the financial
statements. These supplemental disclosures generally would be included in MD&A.


The discussion of disclosures in FRR Section 501.09 is general and, except for the considerations noted
below, contains no guidelines or indication of the SEC’s expectations. Thus, registrants have considerable
latitude in deciding what, if any, supplemental disclosures would help users better understand the effect
of foreign operations and translation on the financial statements. Each registrant should evaluate its own
situation and make disclosures that it considers meaningful.


Discussed below are several types of disclosures registrants should consider:


**Effect of rate changes:** Registrants are encouraged to present an analysis and discussion of the effects
of exchange rate changes on the reported results of operations and the nature and extent of currency
risks to which the registrant is exposed, including the reasonably likely future effects of changes in
exchange rates on operations. The purpose of these disclosures is to assist financial statement users in
understanding the implications of rate changes, comparing recent results with those of prior periods and
anticipating future effects of rate changes. Examples include: quantification of the effect on sales and
operating results of a weakening (strengthening) foreign currency; discussion of foreign operating
results as reflected in the local currency, with the effects of translation noted; and the effects of
exchange rate changes on backlog, interest expense, wages, cost of raw material purchased from the
parent, transactions between subsidiaries, inventory levels, debt-to-equity ratio, working capital,
effective tax rate and cost of sales.


Registrants that make such disclosures should take care that they are not misleading. For example,
reported dollar sales of foreign operations might decline because of a change in exchange rates, but that
change also might affect selling prices, sales volume and cost structures. In that situation, it might not be
sufficient to discuss only the effects of translation on reported sales. Registrants that quantify the effects
of translation at different exchange rates should evaluate the need to clearly explain that disclosure. In


**2024 SEC annual reports — Form 10-K** | 87


---

5 Item 7. Management’s discussion and analysis (MD&A)


addition, when preparing these disclosures, registrants should consider the SEC rules on presenting
non-GAAP financial measures. The SEC staff’s non-GAAP C&DIs note that MD&A can explain how changes in
exchange rates between periods affect the changes in various financial statement line items by presenting
the historical amounts and the current amounts in constant currency. Additionally, a description of the
process of calculating the constant currency amounts and the basis of presentation is required.


Registrants also are encouraged to identify material unhedged monetary assets, liabilities or commitments
denominated in currencies other than the operation’s functional currency, as well as management’s
strategies to manage the currency risks associated with such exposures.


**Cash flow implications of functional currencies:** Under ASC 830, one of the functional currency
indicators is cash flow (ASC 830-10-55-5). That indicator points to a foreign functional currency when
cash flows related to the foreign operation’s individual assets and liabilities are primarily in the foreign
currency and do not directly affect the parent’s cash flows. Conversely, that indicator points to the
parent’s currency (e.g., the US dollar) when cash flows related to the foreign operation’s individual assets
and liabilities directly affect the parent’s cash flows on a current basis and are generally available for
remittance to the parent. The SEC believes that financial statement users might presume cash is
available from foreign operations with a US dollar functional currency, but not from those with a foreign
functional currency. Thus, Section 501.09 suggests that a discussion of the availability of cash flows
from foreign operations may be appropriate in certain circumstances such as:


            - **Foreign functional currency** : If the foreign operations’ cash flows are not available to meet the needs
of other operations, registrants should consider discussing those operations in a disaggregated
manner, because it may be more meaningful than a discussion of liquidity and capital resources for the
registrant as a whole. On the other hand, if cash flows of foreign operations are generally available to
meet the parent’s cash needs, registrants should consider discussing the basis for using the foreign
functional currency (i.e., that the choice was made because of the significance of functional currency
indicators other than the direct effect of the foreign operation’s cash flows on the parent’s cash flows).
The SEC believes that such discussion would facilitate an understanding of the registrant’s operations.


            - **US dollar functional currency** : There may be foreign operations where the US dollar is the functional
currency (e.g., significant foreign operations in highly inflationary economies) even though cash
remittances to the parent are not likely. In such situations, the SEC believes that discussion of only
consolidated liquidity and capital resources might not be sufficient. Discussing those operations in a
disaggregated manner might be more meaningful.


The SEC has suggested it would like to see registrants display net investments by major functional
currency and present an analysis of the translation component of equity either by significant functional
currency or by geographical areas used for segment disclosure purposes.

##### 5.8.4 Loss contingencies (including environmental and product liabilities)


The disclosure requirements for environmental and other loss contingencies address (1) the effects of
compliance with environmental laws on the registrant’s business, (2) pending legal proceedings and
(3) environmental risks and contingencies.


Registrants are required to discuss the following items in disclosures about environmental contingencies:


            - The effect of potential environmental liabilities, quantified to the extent reasonably practicable


            - The aggregate potential cleanup costs in light of joint and several liability, including a discussion of
whether insurance coverage may be contested, and whether and to what extent potential sources of
contribution or indemnification constitute reliable sources of recovery that may be factored into the
determination of whether a material future effect is not reasonably likely to occur


**2024 SEC annual reports — Form 10-K** | 88


---

5 Item 7. Management’s discussion and analysis (MD&A)


            - Historical and anticipated environmental expenditures, and, if material, recurring costs associated
with managing hazardous substances and pollution in ongoing operations, capital expenditures to
limit or monitor hazardous substances or pollutants, mandated remediation expenditures and other
cleanup expenditures that can be anticipated but that are not currently required


The disclosure requirements for product liability contingencies provided in SAB Topic 5.Y include a discussion
of the following: (1) the nature of personal injury or property damages alleged by claimants, (2) the aggregate
settlement costs by type of claim and (3) the related costs of administering and litigating claims.


The SEC staff expects environmental and product liability disclosures to be disaggregated to provide
investors with a full understanding of the contingencies. The SEC staff’s positions regarding disaggregation
of these contingencies are discussed in our _SEC annual shareholders’ report checklist_ (EY Form A150).

##### 5.8.5 Restructuring charges


ASC 420 addresses financial accounting and disclosure related to exit or disposal activities. The SEC staff
expects MD&A to supplement the financial statement disclosures required by ASC 420 for material
restructuring activities by, for example, including the following:


            - A discussion of the events and decisions that gave rise to the restructuring costs and restructuring
plan, and the likely effects of management’s plans on financial position, future operating results and
liquidity, to the extent material (e.g., an inability to realize previously projected economies of scale, a
failure to renew or secure key customer contracts or a failure to keep downtime at acceptable levels
because of aging equipment)


            - Anticipated effects of the restructuring plan on future operating results, and the periods in which
those effects are expected to be realized including whether cost savings from the plan are expected
to be offset by anticipated increases in other expenses or reduced revenues


            - The periods in which material cash outlays are anticipated and the expected source of funding


            - To the extent necessary for the readers’ understanding, separate disclosure and explanation of
discretionary or decision-dependent costs such as exit costs


For restructuring charges recognized in prior periods, the SEC staff believes the following items should
be discussed in MD&A:


            - Material changes in the accrued balances of each significant component of the charge, either as a
result of cash expenditures associated with the plan’s implementation or from revisions to the plan or
changes in estimates, with particular emphasis on the amounts and reasons for reversals of reserves
established in prior periods and their effect on current-period income


            - The progress achieved during the year in implementing the restructuring plan, including qualitative
and quantitative discussion of the extent to which the objectives of the major components of the
restructuring plan have been accomplished


            - If savings anticipated by the restructuring plan are not achieved as expected (either as to amount or
timing), the related reasons for this circumstance and the likely effects on future operating results
and liquidity


In the event a company recognizes liabilities for exit costs and involuntary employee termination benefits
relating to multiple exit plans, it should present separate information for each individual exit plan that has
a material effect on the balance sheet, results of operations or cash flows.


**2024 SEC annual reports — Form 10-K** | 89


---

5 Item 7. Management’s discussion and analysis (MD&A)


If management anticipates that future restructuring actions are likely to occur in a subsequent period and
such actions are likely to result in charges that could have a material effect on the results of operations or
financial position of the company, the SEC staff expects such actions to be discussed in MD&A.


The SEC staff has noted that economic or other events that cause a registrant to consider or adopt an
exit plan, or that impair the carrying amount of assets, generally occur over time. Accordingly, the SEC
staff believes that as those events and the resulting trends and uncertainties evolve, they often will meet
the requirement for disclosure in MD&A prior to the period in which the exit costs and liabilities are
recognized under GAAP.


Our _SEC annual shareholders’ report checklist_ (EY Form A150) provides additional information about the
SEC staff’s expectations concerning the discussion of restructuring charges.

##### 5.8.6 Transactions with related and certain other parties


FRR-61 observes that both US GAAP and the SEC’s rules require disclosure about transactions with
related parties, but certain other parties are not within the definition of “related parties,” such as parties
that are able to negotiate transactions on terms that would not be available from more clearly independent
third parties on an arm’s-length basis. For example, former senior management would not meet the
definition of a related party under US GAAP, but they might be able to negotiate terms that are more
favorable than those available to clearly independent third parties. FRR-61 suggests that further MD&A
discussion might be needed to explain the importance of relationships and transactions with related and
certain other parties, where material. Disclosures suggested by FRR-61 include:


            - A description of the elements of the transactions necessary to understand their business purpose and
economic substance, their effects on the financial statements and any related special risks or contingencies


            - Identification of the related and certain other parties transacting business with the registrant


            - How the parties determined prices


            - Terms or other aspects of transactions and arrangements that differ from those that would likely be
negotiated with clearly independent parties


            - A description of the evaluation made to support any assertion of fairness of the transactions


            - Any ongoing contractual or other commitments

##### 5.8.7 Miscellaneous


**Federal financial assistance:** For financial institutions that receive material federal financial assistance,
the SEC expects registrants to discuss the nature, amount and effect of the assistance on financial
condition or results of operations.


**Treasury stock transactions:** MD&A should contain an explanation of material changes in earnings per
share resulting from a change in the number of shares outstanding, such as that resulting from a large
purchase of treasury stock. The SEC staff has indicated that MD&A should address the effect of such
transactions as they affect balance sheet and income statement captions, including earnings per share.
Although some repurchases of outstanding stock might not have a material effect on other financial
statement captions, discussion might be required to explain the effect on the trend of earnings per share.


**Government inquiries:** The SEC issued FRR-32 _, Disclosure Obligations of Companies Affected by the_
_Government; Defense Contract Procurement Inquiry and Related Issues,_ to remind defense contractors,
as well as other registrants, of their obligation to disclose any reasonably likely material effects on the
financial statements associated with the government’s investigation into illegal or unethical activity in the
procurement of defense contracts.


**2024 SEC annual reports — Form 10-K** | 90


---

5 Item 7. Management’s discussion and analysis (MD&A)


Based on the nature of the government’s inquiry, disclosure also might be required in Form 10-K under
“Description of Business” and “Legal Proceedings,” as well as financial statement disclosure of
loss contingencies.


**Statistical disclosures for banking registrants (Subpart 1400 of Regulation S-K):**


Subpart 1400 of Regulation S-K requires bank holding companies and other lending institutions to
disclose the following items, which are in addition to any relevant US GAAP disclosures:


- Distributions of assets, liabilities and stockholders’ equity, the related interest income and expense,
and interest rates and interest differential (e.g., providing disclosures that help users understand
components of net interest earnings and evaluate the impact of potential changes in interest rates
on future income)


- Weighted average yield of investments in debt securities by maturity


- Maturity analysis of the loan portfolio, including amounts that have predetermined interest rates and
floating or adjustable interest rates


- Certain credit ratios and the factors that explain material changes in the ratios or their components
during the periods presented


- The allowance for credit losses by loan category


- Information about bank deposits, including average amounts and rate paid, and uninsured amounts


See our _GAAP and Regulation S-X checklist supplement for banks, bank holding companies and savings_
_institutions_ (EY Form A69C) for additional disclosures that might be applicable.


**2024 SEC annual reports — Form 10-K** | 91


---

### **6 Financial statements and parent** **company information**

##### 6.1 General

Item 8 of Form 10-K, _Financial Statements and Supplementary Data,_ requires financial statements
meeting the requirements of Regulation S-X, except that Form 10-K is not required to include audited
financial statements of significant acquired businesses or real estate operations (Rules 3-05 and 3-14 of
Regulation S-X) or pro forma financial information (Article 11 of Regulation S-X) or the corresponding
financial statements and pro forma financial information under Article 8 of Regulation S-X for SRCs.


Form 10-K might be required to include audited financial statements beyond those of the registrant.
This section provides guidance for determining whether the following additional financial information
and separate financial statements are required:


            - Disclosure of the restricted net assets of subsidiaries in the notes to the consolidated financial statements


            - A schedule of condensed parent company financial statement information (Schedule I, Rule 5-04(c)
of Regulation S-X)


            - Financial statements of unconsolidated subsidiaries and investees accounted for by the equity
method (Rule 3-09 of Regulation S-X) [100]


            - Disclosures of summarized financial information of unconsolidated subsidiaries and investees in the
notes to the consolidated financial statements (Rule 4-08(g) of Regulation S-X)


            - Financial statements of subsidiaries that guarantee securities of the registrant (Rule 3-10 of
Regulation S-X)


Consolidated financial statements must be included in Item 8 of Form 10-K or incorporated by reference
therein. Other financial statements required by Regulation S-X may be included in Item 8 or Item 15,
_Exhibits, Financial Statement Schedules_, of Form 10-K.


The SEC also may require, by informal written notice, financial statements in addition to, or in substitution
for, those listed above (Rule 3-13 of Regulation S-X). Alternatively, when requested by the registrant, the
SEC may permit the omission of one or more of the required financial statements. Omission, addition or
substitution of financial statements may occur if the SEC believes it is consistent with the protection of
investors. Regulation S-X governs the form and content of and the requirements for financial statements,
including the notes to financial statements and financial schedules. The proxy rules also require that the
consolidated financial statements comply with Regulation S-X.


100 The terms “investees” and “equity investees” in this section mean investments accounted for by the equity method. Also, the SEC

staff has expressed that if an investee is required to be accounted for using the equity method under ASC 323, separate financial
statements of the investee are required if the investee is significant under either the investment or income test in Rule 1-02(w) of
Regulation S-X at a level of 20% or greater. ASC 323-10 requires an investor that has the ability to exercise significant influence over
the operating and financial policies of the investee to apply the equity method of accounting only when it has an investment(s) in
common stock or an investment that is in-substance common stock. In-substance common stock is an investment in an entity that
has risk and reward characteristics substantially similar to that entity’s common stock. In other words, the requirements for financial
statements of equity-method investments apply regardless of whether the investment is in the form of common stock.


**2024 SEC annual reports — Form 10-K** | 92


---

6 Financial statements and parent company information

##### 6.2 Consolidated financial statements


Form 10-K must include audited balance sheets for two years (Rule 3-01 of Regulation S-X) and statements
of comprehensive income and cash flows for three years (Rule 3-02 of Regulation S-X) of the registrant
and its predecessors. Form 10-K also must include disclosure of changes in shareholders’ equity and
noncontrolling interests for each period a statement of comprehensive income is required (Rule 3-04 of
Regulation S-X), which may be included as a financial statement or in the notes.


In addition, ASC 220 requires disclosures about comprehensive income and its components. The guidance
also requires registrants to present items of net income, items of other comprehensive income and total
comprehensive income in one continuous statement or two separate but consecutive statements for each
reporting period. [101]


As noted earlier, a registrant subject to the SEC’s proxy rules must present consolidated financial
statements in accordance with Regulation S-X. The SEC staff expects the registrant’s consolidated
financial statements presented in its annual shareholders’ report and Form 10-K to be identical _._
Generally, the registrant’s financial statements will be incorporated by reference from the ARS.


Financial schedules are required in Form 10-K (but not annual shareholders’ reports) to provide detailed
information in support of certain financial statement captions. See section 7 of this publication for a
discussion and illustrative examples of these schedules.


Article 3A of Regulation S-X (as supplemented by the definitions of “control” and “subsidiary” in Article 1
of Regulation S-X and “controlling financial interest” in ASC 810) governs the presentation of consolidated
financial statements. It states that when consolidating subsidiaries, a registrant should follow principles of
inclusion or exclusion that clearly exhibit the financial position and results of operations of the registrant.


There is a presumption that consolidated financial statements are more meaningful than separate
financial statements and that they are usually necessary for a fair presentation when the reporting entity
directly or indirectly has a controlling financial interest in another entity. The determination of the entities
to be included in the consolidated financial statements generally will be made by reference to generally
accepted accounting principles. If an entity is included or excluded from the consolidated financial
statements for the current year compared with the prior year and such inclusion or exclusion has a
material effect on the consolidated financial statements, the entity’s inclusion or exclusion should be
disclosed to enable investors to assess the comparability of the consolidated financial statements.

##### 6.3 Restrictions on net assets


The SEC requires that the notes to consolidated financial statements disclose restrictions on the transfer
of assets from subsidiaries to the parent. In addition, Schedule I in Form 10-K, if required, calls for
condensed financial statements of the parent company.

##### 6.3.1 Disclosure in the notes to the consolidated financial statements


Rules 4-08(e)(1) and (2) of Regulation S-X require a registrant to disclose the following information
about any restrictions that limit the payment of dividends by the registrant:


            - Restrictions on dividend payments by the parent


            - The amount of consolidated retained earnings or net income restricted, or free of restrictions,
related to dividend payments


            - The amount of consolidated retained earnings that represents the undistributed earnings of equitymethod investees


101 See our _GAAP disclosure checklist_ (EY Form A13) for a summary of these disclosures.


**2024 SEC annual reports — Form 10-K** | 93


---

6 Financial statements and parent company information


Rule 4-08(e)(3) of Regulation S-X requires registrants to disclose, if material, the following information in
the notes to their audited annual financial statements [102] about any restrictions that limit the payment of
dividends by the registrant:


            - The nature of any restrictions on the ability of consolidated subsidiaries to transfer funds to the
registrant in the form of cash dividends, loans or advances (i.e., borrowing arrangements, regulatory
restraints, foreign government restraints)


            - The amount of such restricted net assets as of the end of the most recently completed fiscal year for
consolidated subsidiaries [ 103]


We present the full definition of “restricted net assets” in section 6.3.3 below. It resides in Rule 1-02(dd) of
Regulation S-X and should be applied in all rules in Regulation S-X that use the term.

##### 6.3.2 Condensed parent company financial statements


The condensed parent company financial statements in Schedule I, if required, must be for the same
periods as the consolidated financial statements — generally balance sheets for two years and other
statements for three years. Registrants may condense the parent company financial statements using
the same rules for combining financial statement captions used for preparing condensed interim financial
statements in Article 10 of Regulation S-X. [104] The notes to the condensed financial statements must
disclose material contingencies, guarantees, long-term obligations (including maturities for the next five
years), and mandatory dividend and redemption requirements of redeemable stock. Other notes to the
financial statements may be omitted. Schedule I also must disclose cash dividends paid to the parent by
consolidated subsidiaries, unconsolidated subsidiaries and investees for each of the last three years. An
example of Schedule I is included in section 7 of this publication.


Registrants must include the schedule when the parent’s share of the “restricted” net assets of
consolidated subsidiaries exceeds 25% of consolidated net assets.

##### 6.3.3 Definition of restricted net assets


The SEC defines restricted net assets in Rule 1-02(dd) as follows:


“The term restricted net assets shall mean that amount of the registrant’s proportionate share of net
assets of consolidated subsidiaries (after intercompany eliminations) which as of the end of the most
recent fiscal year may not be transferred to the parent company by subsidiaries in the form of loans,
advances or cash dividends without the consent of a third party (i.e., lender, regulatory agency,
foreign government). Not all limitations on transferability of assets are considered to be restrictions
for purposes of this rule, which considers only specific third-party restrictions on the ability of
subsidiaries to transfer funds outside of the entity. For example, the presence of subsidiary debt


102 When these restrictions are disclosed in the notes to the financial statements, the MD&A discussion of liquidity must describe

the nature of the restrictions and the extent of their effect on the parent’s ability to meet its cash obligations (see section 5 of
this publication).

103 The text of Rule 4-08(e) also requires disclosure of the amount of restricted net assets as of the end of the most recently completed

fiscal year for unconsolidated subsidiaries separate from the amount for consolidated subsidiaries. However, most registrants do not
have “unconsolidated subsidiaries” and we have excluded a separate discussion of unconsolidated subsidiaries from this section to
focus on the guidance that is more commonly applicable. Commission staff has observed that investment companies, particularly
BDCs, may have unconsolidated subsidiaries that are not accounted for using the equity method of accounting. All other registrants
typically do not. Accordingly, BDCs with unconsolidated subsidiaries that are not accounted under the equity method of accounting
should keep in mind that Rule 4-08(e) requires them to disclose the restrictions and amount of restricted net assets of such
subsidiaries separately from the same information for consolidated subsidiaries.

104 Our publication, _**[SEC quarterly reports — Form 10-Q](https://www.ey.com/en_us/technical/accountinglink/2025-sec-quarterly-reports-form-10-q)**_, illustrates the preparation of condensed financial statements in Form 10-Q.


**2024 SEC annual reports — Form 10-K** | 94


---

6 Financial statements and parent company information


which is secured by certain of the subsidiary’s assets does not constitute a restriction under this rule.
However, if there are any loan provisions prohibiting dividend payments, loans or advances to the
parent by a subsidiary, these are considered restrictions for purposes of computing restricted net
assets. When a loan agreement requires that a subsidiary maintain certain working capital, net
tangible asset, or net asset levels, or where formal compensating arrangements exist, there is
considered to be a restriction under the rule because the lender’s intent is normally to preclude the
transfer by dividend or otherwise of funds to the parent company. Similarly, a provision which
requires that a subsidiary reinvest all of its earnings is a restriction, since this precludes loans,
advances or dividends in the amount of such undistributed earnings by the entity. Where restrictions
on the amount of funds which may be loaned or advanced differ from the amount restricted as to
transfer in the form of cash dividends, the amount least restrictive to the subsidiary shall be used.
Redeemable preferred stocks and noncontrolling interests shall be deducted in computing net assets
for purposes of this test.”


The tests should consider only third-party restrictions on the subsidiary’s ability to transfer net assets
through loans, advances or payment of cash dividends. Limitations on the transfer of specific assets or
practical limitations, such as a subsidiary’s illiquidity, are not considered in the test for restricted net
assets. For example, assets pledged as collateral under a subsidiary’s debt agreement should not be
included in the computation. In addition, the illiquid nature of a subsidiary’s noncurrent assets is not
relevant to the tests; thus, it should be assumed that all assets of the subsidiary are available for loan,
advance or dividend to the parent unless third-party agreements would restrict the payment of such
dividends, advances or loans to the parent. However, loan provisions requiring a minimum level of
working capital, net tangible assets or net assets also need to be considered. A loan agreement that
requires the subsidiary to reinvest all earnings also should be considered.


A registrant’s disclosure that it intends to permanently reinvest the undistributed earnings of a subsidiary
(and as a result of meeting the criteria of ASC 740, does not provide income taxes on those earnings)
generally would not indicate restricted net assets because no third-party restriction is involved.


Many loan agreements contain restrictions limiting cash dividends, loans and advances. If only one
provision exists, the restricted amount may be easy to compute. However, some agreements may
contain several provisions that restrict the flow of funds to the parent. In these circumstances, it is
necessary to consider each provision in computing the maximum amount the subsidiary can transfer to
the parent and still comply with all the provisions. Examples are provided later in this section.


Restrictions on foreign subsidiaries’ net assets might exist in several ways. Currency exchange controls
might restrict loans and dividends to the parent. Foreign government incentives, such as “tax holidays”
or grants, might require registrants to reinvest earnings or otherwise limit dividends. However, foreign
withholding taxes on dividend payments generally would not be restrictions on net assets because the
withheld amounts reduce a tax liability. Additionally, the existence of a limited market for foreign
currency, thereby making it not economically feasible to transfer funds, would not be considered a
restriction of net assets.


Bank subsidiaries have restricted net assets because of restrictions of the Federal Reserve Act
(Section 23A) on loans to affiliates. Further, the Office of the Comptroller of the Currency (a bureau of
the US Department of Treasury) restricts dividends of national banks. Some state regulatory agencies
also restrict state banks from paying dividends or making loans and advances to their parent. Such
restrictions should be considered in determining the extent of restricted net assets of subsidiaries.


**2024 SEC annual reports — Form 10-K** | 95


---

6 Financial statements and parent company information


Insurance company subsidiaries have restricted net assets primarily because statutory regulations might
prohibit or restrict the amount of loans or dividends to the parent company. As a result, for most insurance
registrants, restricted net assets will include their insurance subsidiaries’ statutory surplus requirements,
such as the minimum legal capital requirements of the states in which insurance subsidiaries operate. Other
considerations in determining the amount of restricted net assets might include statutory operating ratios
or administrative guidelines or rules that result in statutory capital requirements that exceed minimum legal
requirements or that otherwise limit the amount of loans or dividends to the parent company.


The computation of restricted net assets should be based on the subsidiary’s actual year-end balance
sheet as determined in accordance with generally accepted accounting principles, including “pushdown”
accounting if applied. Management may not include in the calculation of restricted net assets the effects of
transactions or events that have not occurred, even if the transactions could be easily accomplished.


A registrant with a consolidated shareholders' deficit is considered to have a net asset base of zero for
the purpose of computing its proportionate share of the restricted net assets of consolidated subsidiaries.
As a result, any restrictions placed on the net assets of consolidated subsidiaries with positive equity would
be deemed to exceed the 25% threshold in Rule 5-04(c) resulting in a requirement to provide parent
company financial information. This is viewed by the SEC staff as consistent with the guidance in SAB
Topic 6.K.2.b (Question 3), which states that a subsidiary with an excess of liabilities over assets has no
restricted assets. Anomalous results can be discussed with the SEC staff.


For purposes of computing restricted net assets of foreign subsidiaries, the SEC staff expects registrants
to use US GAAP and the currency measurement and translation principles of ASC 830 _._

##### 6.3.4 Computing the restricted net assets of subsidiaries


The following steps summarize how to determine the restricted net assets of a subsidiary:


Step 1: Determine net assets of the subsidiary — The subsidiary’s shareholders’ equity, excluding its

redeemable stock and noncontrolling interest reflected in its balance sheet. [105]


Step 2: Adjust subsidiaries for intercompany eliminations — Add amounts due to (or subtract amounts

due from) the parent and other consolidated subsidiaries. Intercompany profits that are
eliminated in consolidation also are adjustments. (This step identifies the subsidiary’s net assets
reflected in the consolidated financial statements).


Step 3: Determine the parent’s proportionate share of the subsidiary’s net assets — Multiply the results in 2

above by the parent’s proportionate share (generally its ownership percentage).


Step 4: Determine the amount of restricted net assets — Note that (1) there are no restricted net assets

for a subsidiary if its net assets after intercompany eliminations are negative; (2) a subsidiary
has no restricted net assets if it can transfer by loan, advance or dividend, or any combination
thereof, without the consent of a third-party, an amount equal to or greater than the parent’s
proportionate share of net assets and (3) computed restricted net assets for a subsidiary cannot
be greater than the parent’s proportionate share of the subsidiary’s net assets.


Where restrictions on the amount of funds which may be loaned or advanced differ from the amount
restricted as to transfer in the form of cash dividends, the amount least restrictive to the subsidiary can
be used.


105 While noncontrolling interests that are not redeemable are classified as equity, amounts attributable to noncontrolling interests

are not available to the consolidated parent’s shareholders and therefore are excluded from the calculation of net assets.


**2024 SEC annual reports — Form 10-K** | 96


---

6 Financial statements and parent company information

##### 6.3.5 Examples of computing restricted net assets


_**Example 1**_ _—_ Restrictive covenants of a 100%-owned subsidiary’s debt agreement are as follows:


            - Net tangible assets, excluding intercompany accounts, cannot be less than $10


            - Eighty percent of accumulated earnings must be maintained and cannot be paid out as dividends


            - Current ratio of 2:1 is required


The balance sheet of the subsidiary at 31 December 20Y2 is:


Current assets $ 25 Current liabilities $ 11
Noncurrent tangible assets 30 Long-term debt 19
Total liabilities 30
Common stock 10


Retained earnings 15
Total shareholders’ equity 25
$ 55 $ 55


There are no intercompany balances. Net assets are $25. The loan covenants restrict net assets as follows:


**Computed restrictions**

_Net tangible assets_
Currently $25, cannot be less than $10; therefore $10
_Dividends_
80% of retained earnings cannot be paid out; therefore $12 (80% of $15)
_Current ratio_
Current ratio must be at least 2:1. Therefore $22 of current assets is
restricted (current assets required of $22 given current liabilities of $11). $22


_**Conclusion —**_ **Restricted net assets for purposes of the test are $10.** The amount computed from the
dividend restriction ($12) is not used because transfer to the parent could be accomplished by loan or
advance. The amount computed from the current ratio requirement ($22) is not used because
noncurrent assets could be transferred to the parent. In this example, the subsidiary could transfer
$15 ($25 minus $10) to the parent without violating any of the covenants by (1) a dividend or loan of
current assets of $3 and (2) a loan of noncurrent assets [106] of $12.


_**Example 2**_          - Restrictive covenants of a 100%-owned subsidiary’s debt agreement are as follows:


            - Net tangible assets, excluding intercompany accounts, cannot be less than $10


            - Sixty percent of accumulated earnings must be maintained and cannot be paid out as dividends


106 Although the subsidiary’s noncurrent assets are not in a form that is readily transferable to the parent company, the

nonmonetary or illiquid nature of the assets is not relevant for purposes of the parent company tests. The objective of the tests is
to require parent company disclosures when the parent company does not have control of its subsidiaries’ funds because it does
not have unrestricted access to their net assets.


**2024 SEC annual reports — Form 10-K** | 97


---

6 Financial statements and parent company information


At 31 December 20Y2, the balance sheet of the subsidiary is:


Current assets $ 40 Current liabilities $ 10
Noncurrent tangible assets 15 Long-term debt 20
Total liabilities 30
Common stock 10
Retained earnings 15
Total shareholders’ equity 25
$ 55 $ 55


There are no intercompany balances. Net assets are $25. The computation of restricted net assets is
as follows:


**Computed restrictions**

_Net tangible assets_
Currently $25, cannot be less than $10; therefore $10


_Dividends_
60% of retained earnings cannot be paid out; therefore $ 9 (60% of $15)


_**Conclusion**_ _—_ **Restricted net assets for purposes of the test are $10.** The maximum amount that can
be loaned or advanced to the parent without being in violation of the net tangible asset covenant is
$15 ($25-$10). If the registrant were to pay a dividend of $6 ($15-$9), the maximum amount of a
dividend that could be paid without violating the dividend covenant, it also could loan or advance $9
without violating the net tangible asset covenant. In either situation, the amount unrestricted from
transfer to the parent is $15; therefore, restricted net assets are $10 ($25-$15).


_**Example 3**_ - Assume the same balance sheet and covenants as Example 2, except that the debt
agreement also requires the subsidiary to maintain a current ratio (after intercompany accounts) of not
less than 3:1.


_**Conclusion**_ _—_ **Restricted net assets for purposes of the test are $10.** Restricted current assets resulting
from the current ratio covenant are $30. This is the amount that must be maintained in current assets to
meet the required 3-to-1 ratio requirement given current liabilities of $10. However, $15 can be paid in
dividends, loaned or advanced (in combination) to the parent, without violating any covenant if no more
than $6 represented a dividend and at least $5 of the transferred amount consisted of noncurrent assets.
(A transfer of current assets greater than $10 would reduce current assets and result in a violation of the
3:1 minimum current ratio.) Thus $10 is restricted. Restricted net assets for use in the test are the amount
least restrictive to the subsidiary, which in this case is $10.


_**Example 4**_ - The rules require that the parent’s proportionate share of net assets of subsidiary
companies be computed after intercompany eliminations. To illustrate, assume the same facts as
Example 2, except that $10 of the $40 of current assets represents an intercompany receivable.


Net assets $ 25
Intercompany receivable (10)
Adjusted net assets $ 15


_**Conclusion —**_ **Restricted net assets for purposes of the test are $10.** Because $5 still could be loaned or
advanced or paid in dividends to the parent without violating a covenant, restricted net assets are $10 in
these circumstances, as they were in Example 2.


**2024 SEC annual reports — Form 10-K** | 98


---

6 Financial statements and parent company information


_**Example 5**_          - Assume the same facts as Example 2, except that the subsidiary is 80%-owned.


Net assets $ 25
Ownership percent 80%
Parent’s share of net assets $ 20


_**Conclusion**_ _—_ **Restricted net assets for purposes of the test are $5.** Since $15 could be loaned or
advanced to the parent without violating any of the covenants in Example 2, restricted net assets for
purposes of the test would be $5 ($20-$15).


_**Example 6**_ _—_ Company A owns 70% of Subsidiary B, which owns 90% of Subsidiary C. Subsidiary B may
not pay any dividends or make any affiliate loans or advances. Therefore, all of B’s net assets are restricted.
C has net assets of $100 and unrestricted net assets of $45. How should Company A compute its share
of restricted net assets of Subsidiary C for purposes of the test?


_**Conclusion —**_ **Restricted net assets for purposes of the test are $18.** Since all of B’s net assets are
restricted, any dividend, loan or advance from C to B would cause those assets also to be restricted.
However, C can make loans directly to A of up to $45, even though it is a subsidiary of B. Therefore,
A’s share of C’s net assets for purposes of the test would be computed as follows:


C’s net assets $ 100
A’s ownership percent (70% x 90%) 63%
A’s share of net assets $ 63


Because C’s unrestricted net assets of $45 could be loaned to A, restricted net assets for purposes of the
test would be $18 ($63-$45).

##### 6.3.6 Disclosure in the notes to the financial statements


Restricted net assets of subsidiaries computed under these SEC rules do not necessarily result in dividend
restrictions on the consolidated entity. In some instances, the limitation that results in subsidiaries’
restricted net assets is a dividend restriction (e.g., restrictions by regulators on banks and insurance
subsidiaries), and in others (e.g., some subsidiary debt covenants), it does not restrict the ability of the
parent to pay dividends. In many cases, the point will be moot because the subsidiary’s restricted net
assets will be less than other restrictions on the parent paying dividends.


Depending on the nature and possible interrelationship of restrictions on the transfer of funds to the parent
and restrictions on payment of dividends by the parent, the disclosures relating to these matters might be
included in the following notes to the financial statements:


            - Long-term debt (e.g., when the more important information relates to restrictions arising from
debt covenants)


            - Shareholders’ equity (e.g., when dividends are significantly restricted)


            - Investment in affiliates (e.g., when the disclosure of restrictions on the transfer of funds to the
parent arises primarily because of restrictions existing at affiliated companies, such as investees)


**2024 SEC annual reports — Form 10-K** | 99


---

6 Financial statements and parent company information


The following is an example of the disclosures in the notes to the financial statements required by these
rules (Regulation S-X Rule 4-08(e)(3)):


##### 6.4 Equity method investees

Separate financial statements are required in Form 10-K, but not the annual shareholders’ report, for
equity method investees that individually exceed 20% significance for any of the three years presented
(significance is based on the investment or income tests as described later in this section). The significance
of any lower-tier equity investees and unconsolidated subsidiaries should be measured against their
contribution to the consolidated financial statements. For example, separate financial statements of an equity
method investee of a consolidated subsidiary or unconsolidated investment would be required if it met
the significant subsidiary test at the 20% threshold compared with the consolidated financial statements.


In addition, US GAAP requires summarized financial information, or separate financial statements, for
material unconsolidated subsidiaries and investees. The SEC requires this information when equity
method investees exceed 10% significance individually or in the aggregate (Rule 4-08(g) of Regulation S-X).
In addition, ASC 323-10-50 requires certain other disclosures for material investments, including the
percentage of the investee owned, the accounting method for the investment, any difference between
the carrying amount and the underlying equity in net assets and the market value, if available.


Entities whose financial statements or summarized information are included in a registrant’s SEC filing
because they are significant equity method investees under Rule 3-09 or 4-08(g) of Regulation S-X are
considered public business entities under the FASB’s definition in ASU 2013-12. Therefore, such financial
statements or information, in general, would need to be prepared following the accounting and disclosure
requirements applicable to public business entities for standards issued by the FASB that use the public
business entity (PBE) definition.

##### 6.4.1 Separate financial statements


Rule 3-09 of Regulation S-X requires that Form 10-K, but not the annual shareholders’ report, contain
separate financial statements, prepared in accordance with Regulation S-X (including financial schedules),
for equity method investees accounted for by the equity method when such entities are individually
significant. [107] The Regulation S-X significant subsidiary tests are described later in this section under the
heading Significant subsidiary definition. The separate financial statements are only required to be
audited [108] for those fiscal years in which the entity is individually significant at the 20% level applying the


107 Rule 3-09 of Regulation S-X also applies to significant unconsolidated subsidiaries. ASC 810 requires consolidation of all majority
owned subsidiaries except if control does not rest with the majority owner. Consequently, unconsolidated majority-owned
subsidiaries will exist in limited circumstances (e.g., when a subsidiary is in legal reorganization, bankruptcy, under severe
restrictions imposed by a foreign government, when minority owners have substantive participating rights (see ASC 810-10-25-2
through 25-14), or when a subsidiary is a VIE and the majority owner is not the primary beneficiary).

108 The SEC staff has indicated that the audit of a non-issuer’s financial statements that are filed with the SEC to comply with Rule 3-09 of

Regulation S-X and are not referred to in the auditors’ report need not be performed by an auditor registered with the PCAOB, and the
auditor’s report need not indicate the audit was performed in accordance with PCAOB standards (in which case the audit may be
performed in accordance with, and refer to, the auditing standards of the AICPA).


**2024 SEC annual reports — Form 10-K** | 100


---

6 Financial statements and parent company information


income test and investment test. However, if the prior year(s) are audited, for audits conducted in accordance
with either AICPA or PCAOB standards, AICPA AU-C 700.48, Comparative Financial Statements and
Comparative Information, and PCAOB AS 3105, Reports on Comparative Financial Statements, require
that the auditors also report on the prior year(s), respectively. Rule 3-09 applies to all equity method
investees, regardless of whether the investment is held by the registrant, a subsidiary or another
investee. Accordingly, separate financial statements are required for any lower-tier investee in which the
registrant’s proportionate share of such investee meets the 20% test relative to consolidated financial
statements of the registrant.


Financial statements of two or more equity method investees may be combined if they are under
common management or common control as permitted by ASC 810-10-55-1B.


Insofar as practicable, these separate financial statements should be as of the same dates, and for the
same periods, as the audited consolidated financial statements. If it is not practicable to provide separate
financial statements at the same dates and for the same periods as the audited consolidated financial
statements, the financial statements required by Rule 3-09 of Regulation S-X can be presented at a
different date (e.g., the investee’s fiscal year-end). The filing in Form 10-K of the financial statements
required by Rule 3-09 of Regulation S-X can become complicated if the fiscal years of the registrant and
the investee differ, or if either the registrant or the investee is a large accelerated filer or an accelerated
filer (see the When the report is due discussion in section 2).

##### 6.4.2 Summarized financial information


Rule 4-08(g) of Regulation S-X requires consolidated financial statements in annual shareholders’ reports
and Form 10-K to include disclosure in the notes to the financial statements of summarized financial
information about equity method investees if, individually or in the aggregate, they exceed 10% significance
under any one of the three significant subsidiary tests. Registrants must present summarized financial
information for the same periods as consolidated financial statements. Thus, registrants must present
the summarized balance sheet information for the most recent two fiscal years and the summarized
income statement information for the most recent three years.


In addition, the SEC staff generally believes that Rule 4-08(g) permits the aggregation of all equity
investees, whether individually significant (i.e., greater than 10%) or not. However, in situations in
which aggregation can be misleading or suppress important information, the SEC staff may request
separate information. For example, the SEC staff might request that investees in different businesses
be aggregated separately. The SEC staff also might request separate information for individual
investees that are very significant quantitatively or qualitatively.


The SEC requires at least the following detail in the summarized financial information:


            - Current assets


            - Noncurrent assets


            - Current liabilities


            - Noncurrent liabilities


            - Redeemable preferred stock


            - Noncontrolling interests


**2024 SEC annual reports — Form 10-K** | 101


---

6 Financial statements and parent company information


- Net sales or gross revenue


- Gross profit (or costs and expenses applicable to net sales or gross revenue)


- Income or loss from continuing operations


- Net income or loss


- Net income or loss attributable to the entity


No explanatory notes need accompany the summarized information.


In industries that usually do not present classified balance sheets, Rule 1-02(bb) of Regulation S-X states
that “information shall be provided as to the nature and amount of the major components of assets and
liabilities.” However, long-term liabilities and redeemable stock must be disclosed whether or not a
classified balance sheet is presented.


Registrants in specialized industries may substitute other information if that will make their presentation
more meaningful. For example, a finance company would disclose net loans receivable when that item is
one of its largest assets. A bank could present total interest income, total interest expense, provision for
loan losses, and security gains or losses. An insurance company could present net premiums earned, net
investment income, underwriting costs and expenses and realized gains or losses on investments.


Separate audited financial statements for equity method investees may be included in the annual
shareholders’ report and SEC filings in lieu of the summarized financial information required in the notes
to the financial statements by Rule 4-08(g) of Regulation S-X, if the financial statements are prepared in
accordance with US GAAP, IFRS as issued by the IASB, or are reconciled to US GAAP. This is consistent with
ASC 323-10-50-3, which allows either the presentation of separate financial statements or summarized
information in the reporting entity’s notes to the financial statements. When separate financial statements
are presented for the most significant equity method investee, summarized information for the remaining
entities is still required. [109]


For example, if the annual shareholders’ report includes the separate audited financial statements of an
equity investee otherwise required in Form 10-K by Rule 3-09 of Regulation S-X, the registrant’s financial
statement notes need not include summarized financial information for the investee. However, if the
investee is a foreign business, and its financial statements are presented on the basis of a GAAP other
than US GAAP or IFRS as issued by the IASB and are not reconciled to US GAAP [because the investee is
less than 30% significant (Item 17(c)(2)(vi)) of Form 20-F], the disclosures required by Rule 4-08(g)
still must be provided and presented in accordance with US GAAP.


The SEC has emphasized that the information should be complete and that “requests for permission to
omit some entities from the summarized financial information will not be granted in a routine manner”
(FRR 213.03b). However, it is not necessary to include information that is not practicable to furnish for
entities that, individually and in the aggregate, are immaterial.


109 However, if the aggregate significance of all remaining equity method investees does not exceed 10% (e.g., remaining

significance is 6%) and the registrant considers summarized financial information for remaining investees to be immaterial, the
SEC staff said it would not object to the omission of the Rule 4-08(g) disclosure in its entirety.


**2024 SEC annual reports — Form 10-K** | 102


---

6 Financial statements and parent company information

##### 6.4.3 Example of the summarized financial information


The following example is an excerpt from a note to the consolidated financial statements in an annual
shareholders’ report. It illustrates the presentation of summarized financial information and assumes
there are no noncontrolling interests in consolidated subsidiaries of any of the affiliates.


When there are several affiliated companies, it is often helpful to readers to disclose the registrant’s
share of the net assets and net income of each entity.

##### 6.4.4 Significant subsidiary definition


The significance of a subsidiary or investee is based on the “significant subsidiary” tests specified in
Rule 1-02(w) of Regulation S-X. If any of the three significance tests are met at the 10% level for equity
method investees, individually or in the aggregate, summarized financial information is required in a note
to the consolidated financial statements in annual shareholders’ reports and Form 10-K. [110] If either the
investment test or the income test is individually met by an equity method investee at the 20% level,
separate financial statements of the investee are required in Form 10-K. The term significant subsidiary
means a subsidiary that meets any of the conditions above based on the following tests:


            - **Asset test:** The registrant’s and its other subsidiaries’ proportionate share of the total assets
(after intercompany eliminations) of the subsidiary or investee compared to consolidated total assets
as of the end of the most recently completed fiscal year


            - **Investment test:** The registrant’s and its other subsidiaries’ investments in and advances to the subsidiary
or investee as of the end of the most recently completed fiscal year compared to consolidated total assets


            - **Income test:** The lower of the following two components:


              - The absolute value of the registrant’s and its other subsidiaries’ equity in the tested investee’s
income (loss) from continuing operations before income taxes (after intercompany eliminations)
attributable to the controlling interest compared with such income on a consolidated basis [111]


110 These tests are based on the financial statements that the subsidiary or investee would file if it were a registrant

(i.e., consolidated financial statements prepared in conformity with GAAP, including “pushdown” accounting, if appropriate).

111 For an investment accounted for under the fair value option, the SEC staff has expressed that the income test should be done by

using as the numerator the change in the fair value reflected in the registrant's statement of comprehensive income.


**2024 SEC annual reports — Form 10-K** | 103


---

6 Financial statements and parent company information


   - The registrant’s proportionate share of the investee’s revenue from continuing operations
(after intercompany eliminations) compared with revenue from continuing operations of the
registrant, [112] provided both the subsidiary and the registrant had material revenue in each of the
last two years


If the revenue component of the income test does not apply (e.g., because the tested investee or the
registrant does not have material revenue for each of the last two years) and the absolute value of the
registrant’s consolidated income (loss) from continuing operations before income taxes attributable to
the controlling interest for the most recent fiscal year is at least 10% lower than the average of the
absolute value of such amounts for each of its last five fiscal years, the registrant should apply the
income test using its five-year average pretax income from continuing operations in the denominator.
Amended Rule 1-02(w)(1)(iii) calls for using the absolute value of a registrant’s consolidated income
(loss) for each of the five years for purposes of the five-year average. Income averaging over any period
for the investee is not permitted.


For purposes of the significance of foreign companies (either as the investor, unconsolidated subsidiary
or investee), the significance tests must be computed using the investor’s basis of accounting in both the
numerator and denominator (e.g., US GAAP).


Rule 1-02(w) of Regulation S-X further provides that when a loss has been incurred in the current-year
on a consolidated basis, or by the subsidiary or investee being tested (but not both), the equity in the
income or loss of the tested subsidiary or investee should be excluded from consolidated income or loss
in the test. For example:


**Situation 1** **Situation 2**


Income (loss) of tested subsidiary $ (1,000) $ 1,000


Income (loss) of parent and its subsidiaries $ 10,000 $ (10,000)


_Computation (for Situation 1):_ Income of parent and its subsidiaries excluding loss of tested subsidiary:
($10,000 - ($1,000) = $11,000); 1,000 [113] /11,000 = 9% (subsidiary would not be significant)


_Computation (for Situation 2):_ Loss of parent and its subsidiaries excluding income of tested subsidiary:
(($10,000) - $1,000 = ($11,000)); 1,000/11,000 [114] = 9% (subsidiary would not be significant)


In addition, Rule 1-02(w) of Regulation S-X provides that when evaluating the aggregate significance of
individually insignificant entities, the income test should be performed separately for profitable and loss
entities (i.e., losses should not be offset against earnings). Aggregate losses of entities with losses and
aggregate earnings of entities with earnings should be separately compared to the registrant’s consolidated
earnings or loss subject to the adjustment illustrated above.


As a general policy, the SEC staff does not allow alternative measures to determine significance; however,
strict application of the above guidance could produce anomalous results in some circumstances. For
example, if a registrant that has historically incurred significant losses reports a marginal profit for the
most recent year, the rules would require that the marginal profit be used in applying the significant
subsidiary income test. The SEC staff has said it will consider waiver requests when the application of the
required tests provides anomalous results.


112 For an investment accounted for under the fair value option, the SEC staff has expressed a view that the numerator for the

revenue component should be calculated using the registrant’s proportionate share of the investee’s revenues as if the equity
method of accounting had been applied.

113 Use the absolute value of the ($1,000) loss for the subsidiary tested.

114 Use the absolute value of the ($11,000) loss of parent and subsidiaries, excluding the income of subsidiary tested.


**2024 SEC annual reports — Form 10-K** | 104


---

6 Financial statements and parent company information


**2024 SEC annual reports — Form 10-K** | 105


---

6 Financial statements and parent company information


**6.4.4.1** **Rule 3-09 considerations**


**Applying the income test to Rule 3-09:** The numerator of the income component is calculated based on
the registrant’s proportionate share of the pretax income from continuing operations reflected in the
separate financial statements of the investee for the period in which the registrant recognizes income or
loss from the investee under the equity method, adjusted for any basis differences. In determining the basis
differences, the registrant should consider ASC 323-10-35-34 and 35-32A. While not an exclusive list,
items affecting net income of the registrant that should be excluded from the test are impairment charges
at the investor level, gains/losses from stock sales by the registrant; dilution gains/losses from stock sales
by the investee and preferred dividends. The financial information used in the significance tests must be
based on GAAP for public business entities.


Furthermore, the SEC staff expressed its view that the denominator of the income test should reflect
the amounts included in the registrant’s income statement as income from continuing operations, after
adjustment to place the denominator on a basis that is consistent with the numerator. Accordingly,
adjustments should be made as necessary to reported pretax income to (1) adjust for noncontrolling
interests in income of consolidated subsidiaries and (2) adjust equity in earnings of all equity method
investees to exclude the effects of income tax accounting by those investees and the investor, as well as
any discontinued operations reported by those investees. That is, adjustments should be made to the
denominator for all items similar to those in the numerator to achieve an “apples to apples” calculation.


**Rule 3-09 financial statements in the year in which an investee is acquired, disposed of, or changes**
**status:** In the year a registrant acquires a significant investee, the Form 10-K should include separate
financial statements of the investee for the period of ownership. If the registrant determines that audited
investee financial statements from the date of acquisition (or application of the equity method) cannot be
obtained without undue difficulty or cost, the SEC staff indicated that it may favorably consider pre-filing
requests to include investee financial statements for the entire year in lieu of financial statements from
the date of acquisition (or application of the equity method). In addition, Rule 3-05 of Regulation S-X may
require audited financial statements in registration statements or proxy statements for additional periods.


When a company disposes of an equity-method investment during the year (i.e., the registrant sells its
entire interest or the interest is now eligible for cost-method accounting), the SEC staff expects the
Form 10-K to include an income statement of the investee through the date of disposal if the investee
otherwise met the income test at the 20% significance level, not including any gain or loss on disposal.
However, if the registrant determines that audited investee financial statements through the date of
disposal cannot be obtained without undue difficulty or cost, the SEC staff indicated that it may favorably
consider a pre-filing request for (1) the presentation of summarized financial information pursuant to
Rule 4-08(g) of Regulation S-X in lieu of full audited financial statements of the investee in the year of
disposition or (2) the inclusion of investee financial statements for the entire year in lieu of financial
statements through the date of disposition.


However, if the investee is sold near the end of the most recent fiscal year, the SEC staff may be more
reluctant to waive the requirement if the investee is very significant, quantitatively or qualitatively, during
that year. In this circumstance, the SEC staff will consider, among other things, the significance of the
registrant’s participation in the investee’s business, whether similar investments comprise a significant
part of the registrant’s business, and whether significant intercompany transactions have occurred.
However, the SEC staff also has indicated that it will not grant relief from Rule 3-09 of Regulation S-X if
the investment is disposed after year-end and is otherwise significant to the most recent fiscal year.


When a formerly consolidated wholly owned or majority-owned subsidiary becomes an equity-method
investee, the SEC staff has expressed its view that the income test under Rule 1-02(w) of Regulation S-X
in the year of change should include the registrant’s equity in the investee’s pretax earnings for the
period of the fiscal year for which the equity method of accounting was applied to such investee.


**2024 SEC annual reports — Form 10-K** | 106


---

6 Financial statements and parent company information


**Calculating significance of equity investees following a retrospective accounting change or the**
**registrant’s discontinued operation:** The SEC staff believes that, following a change in accounting
principle that requires retrospective application or a discontinued operation in the current fiscal year,
the registrant need not remeasure significance using the restated financial statements in any registration
statement or proxy statement filed during the current fiscal year (even if the restated financial statements
of prior fiscal periods are required to be included in such filings). Registrants also do not need to
recompute significance to determine whether the Rule 3-09 financial statements should be included in
the Form 10-K for a fiscal year to which an accounting change was applied retrospectively.


However, for purposes of determining whether the Rule 3-09 financial statements should be included in
the current fiscal year Form 10-K, the registrant should use the restated financial statements (for all
periods presented), which reflect a discontinued operation, to determine whether the equity investee
was significant for any period presented. Registrants should make the calculation at the end of each
fiscal year based on the primary financial statements of the registrant presented in the annual report.
As a result, previously insignificant equity-method investees (i.e., below 20% significance level) might
now become significant and the current fiscal year Form 10-K might require separate financial
statements of such equity-method investees for all periods presented, audited in the periods in which
significant. Registrants are encouraged to contact the SEC staff if this application results in an
impracticable answer based on the registrant’s particular facts and circumstances.


In addition, the SEC staff indicated that in a scenario in which an equity investee was disposed of before
the event that required retrospective presentation for an accounting change or discontinued operation,
and the equity investee was not previously significant under Rule 3-09 of Regulation S-X, but became
significant in the current period solely as a result of restatement because of the retrospective
presentation, financial statements of that equity investee would not be required.


Similarly, if a registrant’s financial statements are retroactively restated in accordance with ASC 323 to
reflect equity-method accounting for an investment previously accounted for under the cost method,
Rule 3-09 financial statements and summarized financial information may be required for periods in
which the cost method was previously used if the significance tests are met.


**Applying Rule 3-09 when a registrant and its equity investee have different year-ends:** When a
registrant and its equity investee have different year-ends, the registrant may or may not record its
equity in earnings on a lag basis. Therefore, depending on the registrant’s particular accounting
treatment, questions arise as to how and when the significance tests should be performed. Generally,
significance tests should be determined using the investee’s financial results used by the registrant to
calculate the registrant’s equity in the income or loss of the investee presented in the registrant’s
financial statements, not amounts derived from the investee’s financial statements required to be filed
under S-X Rule 3-09. Illustration 6-5 illustrates the application of Rule 3-09 of Regulation S-X when the
registrant records equity in earnings on a lag basis, and Illustration 6-6 illustrates the application of
Rule 3-09 of Regulation S-X when the registrant does not record equity in earnings on a lag basis.


**2024 SEC annual reports — Form 10-K** | 107


---

6 Financial statements and parent company information


The SEC staff believes that the significance tests should be performed using the 30 September 20Y2
financial statements of the equity investee and the 31 December 20Y2 financial statements of the registrant.


The SEC staff believes that the significance tests should be based on a period consistent with the amounts
recognized in the registrant’s financial statements. That is, the significance calculations should be based
on the equity investee’s adjusted 31 December 20Y2 results compared with the registrant’s 31 December
20Y2 results.


In addition, registrants should file financial statements for the investee’s fiscal year-end that is closest to
the registrant’s fiscal year-end to meet the requirements of Rule 3-09 of Regulation S-X. However, if the
equity investee’s fiscal year-end differs from the registrant’s fiscal year-end by six months, the SEC staff
said that the registrant should consider its specific facts and circumstances and follow a consistent
approach on an investee by investee basis. For example, if the registrant’s year-end is 31 December 20Y2
and the equity investee has a 30 June year-end, the registrant can determine whether to file the investee’s
financial statements for the fiscal year prior to the registrant’s year-end (e.g., 30 June 20Y2) or after
the registrant’s year-end (e.g., 30 June 20Y3).

##### 6.4.5 Example


The following example illustrates how to apply these tests to establish whether a registrant must file
separate financial statements or summarized financial information of equity method investees.


_**Example 1**_ _—_ Illustrates some of the disclosure combinations that can result under the rules. To limit the
length of the example, only the income component of the test is illustrated (for illustration purposes,
assume the revenue component is not applicable).


**Registrant’s and its consolidated**
**subsidiaries’ share of pretax income**

**(After intercompany eliminations)**

**Company** **Situation 1** **Situation 2** **Situation 3**

_Investees_
Company A $ 41,000 $ 4,000 $ 102,000
Company B 18,000 3,000 1,000
Company C 11,000 2,000 1,000

$ 70,000 $ 9,000 $ 104,000


_Assume_ : Consolidated pretax income of $500,000. Therefore, 10% equals $50,000 and 20% equals $100,000.


The minimum requirements for financial data are:


**Form 10-K** **Annual Shareholders’ Reports and Form 10-K**


**Complete financial**

**statements**


**Summarized financial information in notes to**

**consolidated financial statements**


Situation 1 None Presented for Companies A, B and C in the aggregate
Situation 2 None None
Situation 3 Company A None


**2024 SEC annual reports — Form 10-K** | 108


---

6 Financial statements and parent company information


The rule requires summarized financial information “for all such subsidiaries and persons.” FRR
Section 213.03b (ASR No. 302, _Separate Financial Statements Required By Regulation S-X_ ) emphasizes
that the information should be complete and that “requests for permission to omit some entities from the
summarized financial information will not be granted in a routine manner.” However, summarized
financial information for entities that are clearly immaterial may be omitted.


For example, in Situation 2 above, the investees represent less than 2% of consolidated income. If the
investment test and other measures of materiality also resulted in immaterial amounts, the summarized
information for the investees could be omitted.


Similarly, in Situation 3 above, investees B and C are clearly immaterial individually and in the aggregate.
If other tests also resulted in immaterial amounts, summarized information for only Company A need
be presented.

##### 6.5 Preparing separate financial information of subsidiaries


The SEC staff views on the allocation of expenses in the financial statements of a registrant’s subsidiaries
in SAB Topic 1.B and the FASB’s guidance about the application of “pushdown” accounting primarily apply
to the subsidiaries’ financial statements that a registrant includes in its filings with the SEC. However, the
provisions also pertain to subsidiary financial information included in the parent’s Form 10-K.

##### 6.5.1 Pushdown accounting


When the FASB issued ASU 2014-17, which gives all acquired entities that are businesses or nonprofit
activities the option to apply pushdown accounting in their separate financial statements when an
acquirer obtains control of them, the SEC staff rescinded the guidance in SAB Topic 5.J, _New Basis of_
_Accounting Required in Certain Circumstances_, that required registrants to apply pushdown accounting in
certain circumstances.


Pushdown accounting reflects the new basis of accounting recorded by the parent at acquisition. In other
words, the parent’s basis is reflected as the historical cost basis of assets and liabilities reflected in the
subsidiary’s financial statements and summarized financial information.

##### 6.5.2 Allocation of expenses


SAB Topic 1.B discusses the SEC staff’s approach to the allocation of expenses and related disclosure in
the separate financial statements of subsidiaries, divisions or other components of a business when
these financial statements are included in filings with the SEC. Because many of the costs of operating
the components of a business are incurred by the parent company (e.g., income taxes, interest,
advertising, accounting, legal), the SEC staff believes it is essential that the separate entity’s financial
statements include its allocable share of these costs. SAB Topic 1.B provides specific guidance on
allocating expenses, as well as the related disclosure requirements, and should be referred to when these
separate financial statements are being prepared.


For annual reporting purposes, the primary thrust of SAB Topic 1.B is directed at the financial statements
included in the Form 10-K of a registrant that has public securities and that also is a subsidiary of another
entity (which incurs common costs on behalf of the subsidiary registrant).


The provisions of SAB Topic 1.B also are applicable to the separate financial statements (pursuant to S-X
Rule 3-09) or summarized financial information (pursuant to S-X Rule 4-08(g)) included in the parent’s
Form 10-K for unconsolidated subsidiaries. Generally, the financial statements of a significant unconsolidated
subsidiary that is itself a registrant would be incorporated by reference from the unconsolidated subsidiaries’
Form 10-K, and therefore, already would reflect the provisions of SAB Topic 1.B.


**2024 SEC annual reports — Form 10-K** | 109


---

6 Financial statements and parent company information

##### 6.6 Subsidiary guarantors or subsidiary issuers of guaranteed securities


Rule 3-10 allows companies to provide alternative disclosures in lieu of separate audited financial
statements of subsidiary issuers and guarantors in certain cases. If separate financial statements are
required, the subsidiary issuer or guarantor financial statements should be as of the dates and for the
periods required by Regulation S-X.


The rules allow companies to provide alternative disclosures in lieu of separate audited financial statements
of subsidiary issuers and guarantors if the parent company is (1) an issuer or co-issuer with one or more
consolidated subsidiaries (jointly and severally) or (2) the full and unconditional guarantor of the registered
debt securities of a consolidated subsidiary issuer.


To be a “full and unconditional” guarantor, the parent company must be obligated by the guarantee to
make a scheduled payment immediately upon the subsidiary issuer’s failure to do so. Further, the holders of
the guaranteed debt securities must have immediate legal recourse against the parent guarantor for its
failure to pay.


In addition to the above criteria, the following conditions must be met to omit the separate subsidiary issuer
and guarantor audited financial statements:


            - The consolidated audited financial statements of the parent company have been filed.


            - The subsidiary issuer/guarantor is consolidated in the parent company’s financial statements. (The
subsidiary is no longer required to be 100% owned by the parent.)


            - The guaranteed security is debt or debt-like.


**Summarized financial information:** Registrants are allowed to disclose summarized financial information
(SFI), as defined under Rule 1-02(bb) of Regulation S-X, of the issuers and guarantors combined as a
group (the obligor group). The disclosure of additional line items is required if it is material for investors
to evaluate the sufficiency of the guarantee. At a minimum, SFI must include the following balance sheet
and income statement line items, if applicable:


            - Current assets, noncurrent assets, current liabilities, noncurrent liabilities and, when applicable,
redeemable preferred stock and noncontrolling interests


            - Net sales or gross revenues, gross profit, income/loss from continuing operations, net income/loss
and net income/loss attributable to the group


**Defining the obligor group and combined presentation:** All eligible subsidiary issuers and guarantors
may be combined with the parent company into a single column of SFI titled “Obligor Group,” unless
further disaggregation is required. The SFI must be presented on a combined basis with intercompany
transactions and resulting balances among the entities included in the obligor group eliminated.


Intercompany amounts between the obligor group and non-obligors must remain (that is, not eliminated
for purposes of the disclosure) and be separately identified in the SFI in addition to other related-party
transactions and balances. However, the SFI of the obligor group, including any SFI of disaggregated issuers
and guarantors, must exclude non-obligor subsidiaries even if those entities are consolidated by entities
in the obligor group. That is, an issuer’s or guarantor’s investment in a subsidiary that is not an obligor
must be excluded from the SFI of the issuer or guarantor.


**Periods presented:** SFI must be presented for the most recent fiscal year presented in the parent
company’s financial statements in the annual report on Form 10-K.


**2024 SEC annual reports — Form 10-K** | 110


---

6 Financial statements and parent company information


**Materiality:** Disclosure of additional SFI line items is required if it is material for investors to evaluate the
sufficiency of the guarantee.


Disclosure required by the rules can be omitted using a different standard of materiality that is consistent
with the US Supreme Court’s definition. That is, disclosure otherwise required by the rules can be omitted
if there is not a substantial likelihood that it would have been viewed by a reasonable investor as having
significantly altered the total mix of information made available.


To help registrants evaluate whether they can omit disclosure on the basis it is not material, the SEC
identified four examples of situations in which the SFI may be omitted, as specified in Rule 13-01 of
Regulation S-X:


            - The assets, liabilities and results of operations of the obligor group are not materially different from
those reported in the registrant’s consolidated financial statements.


            - The obligor group has no material assets, liabilities or results of operations.


            - The issuer is a finance subsidiary, the parent company has provided a full and unconditional
guarantee, and none of the parent company’s other subsidiaries provides a guarantee.


            - A finance subsidiary and the parent company are joint and several co-issuers, and none of the parent
company’s other subsidiaries provides a guarantee.


**Disclosure location:** Rule 13-01 permits the disclosure of alternative guarantor information to be provided
outside of the parent’s financial statements in management’s discussion and analysis. If the registrant elects
to present the alternative disclosures information in the annual financial statements, it must be audited.


**Duration of disclosure:** The rules permit parent companies to cease reporting the alternative disclosures when
the SEC reporting obligations of its subsidiary issuers and guarantors have been suspended or terminated.


See our Technical Line publication, _**[How to apply the SEC’s new requirements for registered debt issued or](https://www.ey.com/en_us/technical/accountinglink/-technical-line---how-to-apply-the-sec-s-new-requirements-for-re)**_
_**[guaranteed by subsidiaries](https://www.ey.com/en_us/technical/accountinglink/-technical-line---how-to-apply-the-sec-s-new-requirements-for-re)**_, for additional information on how to apply Rule 3-10 and Rule 13-01.

##### 6.7 Affiliates whose securities collateralize the registrant’s securities


Rule 13-02 requires disclosures about affiliates whose securities are pledged as collateral that are similar
to those required about subsidiary issuers and guarantors. The disclosures in Rule 13-02 are not required
for any secured debt offering registered before 4 January 2021 for which the registrant was not required
to file separate S-X Rule 3-16 financial statements. Key considerations are discussed below.


**Materiality:** The disclosures are required if they are material.


**Narrative disclosures:** Rule 13-02 requires certain narrative disclosures, including descriptions of the
securities pledged as collateral, each affiliate whose securities are pledged, the terms and conditions of
the collateral arrangement, the events or circumstances that would require delivery of the collateral, and
whether a trading market exists for the pledged securities.


**Financial disclosures:** SFI of the affiliates is also required under Rule 13-02, if material. Unlike the SFI for
the obligor group for guaranteed securities, the financial information of all subsidiaries consolidated by
an affiliate would be included in the SFI even if those subsidiaries’ securities are not pledged as collateral.
When there are multiple affiliates whose securities have been pledged as collateral, disaggregation of the
SFI may be required, if disclosures about the items addressed in the narrative disclosures apply to one or
more, but not all, of the affiliates.


**2024 SEC annual reports — Form 10-K** | 111


---

6 Financial statements and parent company information


**Non-consolidated affiliates:** In the rare cases when an affiliate whose securities have been pledged as
collateral is not a consolidated subsidiary, the registrant must provide any additional financial and
narrative information material for investors to evaluate the pledge; the information must be sufficient so
that it is not misleading and might include separate financial statements of the unconsolidated affiliate.


See our _Form 10-K and registration statement checklist — supplement to GAAP disclosure checklist_
(EY Form A69) for additional disclosures that might be applicable.


Unless the requirements of Rule 13-02 apply, each registered security issued and outstanding before
4 January 2021 is subject to the requirements of S-X Rule 3-16. While S-X Rule 3-16 requires registrants
that pledge the securities of an affiliate as collateral to provide the separate audited financial statements
of that affiliate, registrants have rarely been required to do so in practice. That’s because the securities
typically include a provision that removes the collateral when the SEC requirement to provide separate
financial statements is triggered.


See our Technical Line publication, _**[How to apply the SEC’s new requirements for registered debt issued or](https://www.ey.com/en_us/technical/accountinglink/-technical-line---how-to-apply-the-sec-s-new-requirements-for-re)**_
_**[guaranteed by subsidiaries](https://www.ey.com/en_us/technical/accountinglink/-technical-line---how-to-apply-the-sec-s-new-requirements-for-re)**_, for a summary of Rule 13-02 of Regulation S-X and how to apply the
requirements.

##### 6.8 Regulation S-X waiver requests


Companies may request waivers or modifications to their financial reporting requirements under Rule 3-13
of Regulation S-X. Under certain circumstances, SEC rules may require companies to provide financial
statements that are burdensome to generate but not material to the total mix of information available to
investors. These companies may request permission from the SEC staff under Rule 3-13 to omit those
statements or provide alternative information that may be of comparable benefit to investors.


We have observed indications that the SEC staff is receptive to working with companies making waiver
requests under Rule 3-13 such as those required by Rule 3-09 of Regulation S-X.


The staff’s authority to provide relief under Rule 3-13 is limited to financial statements only. Companies
cannot use Rule 3-13 to request waivers from the SEC staff for US GAAP requirements or information
other than financial statements (e.g., Regulation S-K disclosures).


As a reminder, a company’s failure to obtain a waiver or comply with the reporting rules could prevent a
registration statement from being declared effective or result in the filer being non-timely.


**2024 SEC annual reports — Form 10-K** | 112


---

### **7 Financial schedules**

This section includes the Regulation S-X rules for financial schedules, along with an example of each
schedule. While the financial schedules will be required only in certain limited circumstances, it is important
to recognize when each schedule is required and how to prepare it properly. For commercial and industrial
companies, Rule 5-04 of Regulation S-X specifies which schedules are to be filed. The form and content
of schedules is specified by Article 12 of Regulation S-X.


Schedules should be filed in support of each set of financial statements required by Article 3 of
Regulation S-X. For example, if financial statements are filed for equity method investees under Rule 3-09
of Regulation S-X, schedules supporting those financial statements are required. However, the required
schedule information may be presented in a single schedule with the information shown separately for
each set of financial statements filed.


Schedules may be omitted when they are not applicable or the amounts are immaterial (as defined by
specific materiality standards for each schedule and the general materiality standard of Rule 4-02 of
Regulation S-X). Further, if the information required by any schedule is shown in the related financial
statements or the notes thereto, the schedule may be omitted. When a schedule has been omitted,
the reason for omission should be stated in Form 10-K. Usually this is set forth under Exhibits and
Financial Statement Schedules required by Item 15(a) and (c) of Form 10-K.


Schedules are required to be audited if the related financial statements are required to be audited.


Some schedules are filed for the most recent balance sheet (e.g., 31 December 20Y2); whereas, other
schedules are filed for each period for which an income statement is required (e.g., for each of the
three years in the period ended 31 December 20Y2). The following table indicates the requirements
for each schedule.

##### 7.1 Filing requirements


**Filed for each**
**income statement**


**Title**


**Filed for last**
**balance sheet**


I Condensed financial information of registrant    -    II Valuation and qualifying accounts X
III Real estate and accumulated depreciation X
IV Mortgage loans on real estate X
V Supplemental information concerning property
                                            -                                             casualty insurance operations


- The information required by this schedule must be provided as of the same dates and for the same periods as the audited
consolidated financial statements.


_**Note**_ **:** The schedules on the following pages represent different situations and are not interrelated.


**2024 SEC annual reports — Form 10-K** | 113


---

7 Financial schedules

##### 7.2 Schedule I — Condensed financial information of registrant


The schedule prescribed by Rule 12-04 of Regulation S-X should be filed when the restricted net assets
(as defined in Rule 1-02(dd) of Regulation S-X) of consolidated subsidiaries exceed 25% of consolidated
net assets as of the end of the most recently completed fiscal year. [115] The schedule prescribed by
Rule 12-04 is titled “Condensed financial information of registrant” but it also is commonly and
informally referred to as “parent-company-only condensed financial information” because it reflects the
standalone financial statements of the parent/registrant legal entity excluding consolidated subsidiaries,
and hence, shows the full amount of related intercompany receivables, payables and investments to
such subsidiaries.


Rule 12-04. Condensed financial information of registrant


(a) Provide condensed financial information about financial position, cash flows and results of operations

of the registrant as of the same dates and for the same periods for which audited consolidated
financial statements are required. The financial information required need not be presented in greater
detail than is required for condensed statements by Rule 10-01(a)(2), (3) and (4) of Regulation S-X.
Detailed footnote disclosure which would normally be included with complete financial statements
may be omitted with the exception of disclosures regarding material contingencies, long-term
obligations and guarantees. Descriptions of significant provisions of the registrant’s long-term
obligations, mandatory dividend or redemption requirements of redeemable stocks and guarantees
of the registrant shall be provided along with a five-year schedule of maturities of debt. If the
material contingencies, long-term obligations, redeemable stock requirements and guarantees of
the registrant have been separately disclosed in the consolidated statements, they need not be
repeated in this schedule.


(b) Disclose separately the amounts of cash dividends paid to the registrant for each of the last three

fiscal years by consolidated subsidiaries, unconsolidated subsidiaries and 50%-or-less owned persons
accounted for by the equity method, respectively.


The following example shows how condensed financial statements might be presented. This example is
not intended to illustrate rigid presentation guidelines. Rule 10-01 of Regulation S-X allows flexibility in
the level of detail presented in condensed financial statements.


115 Section 6 of this publication provides guidance for determining restricted net assets.


**2024 SEC annual reports — Form 10-K** | 114


---

7 Financial schedules


**2024 SEC annual reports — Form 10-K** | 115


---

7 Financial schedules


**2024 SEC annual reports — Form 10-K** | 116


---

7 Financial schedules


116 If in the consolidated financial statements these items were identified as relating to the parent, Notes B and C could be omitted

from the schedule.


**2024 SEC annual reports — Form 10-K** | 117


---

7 Financial schedules

##### 7.3 Schedule II — Valuation and qualifying accounts


The schedule prescribed by Rule 12-09 of Regulation S-X is required to be filed in support of valuation
and qualifying accounts included in each balance sheet. Many registrants comply with this requirement
by including the required information in the notes to the financial statements. (Also see Rule 4-02 of
Regulation S-X regarding omission of immaterial items and combination of insignificant amounts).


Rule 12-09 Valuation and qualifying accounts


|COL. A|COL. B|COL. C|Col4|COL. D|COL. E|
|---|---|---|---|---|---|
|||**Additions**|**Additions**|||
|Description1|Balance at beginning<br>of period|(1)<br>Charged to<br>costs and expenses|(2)<br>Charged to other<br>accounts — describe|Deductions —<br>describe|Balance at end<br>of period|


1 List, by major classes, all valuation and qualifying accounts and reserves not included in specific

schedules. Identify each class of valuation and qualifying accounts and reserves by descriptive title.
Group (a) those valuation and qualifying accounts which are deducted in the balance sheet from the
assets to which they apply and (b) those reserves which support the balance sheet caption, Reserves.
Valuation and qualifying accounts and reserves as to which the additions, deductions and balances
were not individually significant may be grouped in one total and in such case the information called
for under columns C & D need not be given.


Commentary


This schedule is required for each period for which an income statement is required and the valuation or
qualifying account was material. Note that the instructions to the schedule require disclosures to be
grouped in (a) those valuation and qualifying accounts which are deducted in the balance sheet from the
assets to which they apply and (b) those reserves which support the balance sheet caption, “Reserves.”


**2024 SEC annual reports — Form 10-K** | 118


---

7 Financial schedules


**2024 SEC annual reports — Form 10-K** | 119


---

7 Financial schedules

##### 7.4 Schedule III — Real estate and accumulated depreciation


The schedule prescribed by Rule 12-28 of Regulation S-X should be filed for real estate (and the related
accumulated depreciation) held by persons a substantial portion of whose business is that of acquiring
and holding for investment real estate or interests in real estate, or interests in other persons a
substantial portion of whose business is that of acquiring and holding real estate or interests in real
estate for investment. Real estate used in the business should be excluded from the schedule.


Rule 12-28. Real estate and accumulated depreciation [1]


**(For certain real estate companies)**


|COL. A|COL. B|COL. C|Col4|COL. D|Col6|COL. E|Col8|Col9|COL. F|COL. G|COL. H|COL. I|
|---|---|---|---|---|---|---|---|---|---|---|---|---|
|Descrip-<br>tion2|Encum-<br>brances|Initial Cost to<br>Company|Initial Cost to<br>Company|Cost Capitalized<br>Subsequent to<br>Acquisition|Cost Capitalized<br>Subsequent to<br>Acquisition|Gross Amount at Which<br>Carried at Close of<br>Period3, 4, 5, 6, 7|Gross Amount at Which<br>Carried at Close of<br>Period3, 4, 5, 6, 7|Gross Amount at Which<br>Carried at Close of<br>Period3, 4, 5, 6, 7|Accu-<br>mulated<br>Depre-<br>ciation|Date of<br>Construction|<br>Date<br>Acquired|<br>Life on Which<br>Depreciation<br>in Latest<br>Income<br>Statements is<br>Computed|
|Descrip-<br>tion2|Encum-<br>brances|Land|Buildings<br>and<br>Improve-<br>ments|Improve-<br>ments|Carrying<br>Costs|Land|Buildings<br>and<br>Improve-<br>ments|Total|Total|Total|Total|Total|


1 All money columns shall be totaled.

2 The description for each property should include type of property (e.g., unimproved land, shopping center, garden apartments,
etc.) and the geographical location.

3 The required information is to be given as to each individual investment included in column E except that an amount not

exceeding five percent of the total of column E may be listed in one amount as “miscellaneous investments.”

4 In a note to this schedule, furnish a reconciliation in the following form, of the total amount at which real estate was carried at the

beginning of each period for which income statements are required, with the total amount shown in column E.


Balance at beginning of period ............................................................... $...........
Additions during period:

Acquisitions through foreclosure ............................... $ ...........
Other acquisitions .................................................... ...........
Improvements, etc. .................................................. ...........
Other (describe) ....................................................... ........... ............
............................................................................... ...........
Deductions during period:

Cost of real estate sold ............................................. $ ...........
Other (describe) ....................................................... ........... ............
Balance at close of period ..................................................................... $...........


If additions, except acquisitions through foreclosure, represent other than cash expenditures, explain. If any of the changes during
the period result from transactions, directly or indirectly with affiliates, explain the bases of such transactions and state the amounts
involved. A similar reconciliation shall be furnished for the accumulated depreciation.


5 If any item of real estate in investments has been written down or reserved against, describe the item and explain the basis for

the write-down or reserve.

6 State in a note to column E the aggregate cost for Federal income tax purposes.

7 The amount of all intercompany profits included in the total of column E shall be stated, if material.


Commentary


Schedule III is required only for certain real estate companies as described by Rule 5-04 of Regulation S-X.
Real estate used in the business should be excluded from the schedule.


This schedule is required only to support the most recent balance sheet required. However, reconciliations
of the changes in real estate and accumulated depreciation (Note 4 of Rule 12-28 of Regulation S-X) are
required in support of each income statement required, as shown in the example. As with the other
schedules, this schedule is not required to be separately presented if all of the required information is
included in the financial statements or notes thereto. The staff has also accepted summarized presentation
by type (e.g., self-storage, single family homes, geography) for entities with a significant number of real
estate investments.


**2024 SEC annual reports — Form 10-K** | 120


---

7 Financial schedules


**2024 SEC annual reports — Form 10-K** | 121


---

7 Financial schedules

##### 7.5 Schedule IV — Mortgage loans on real estate


The schedule prescribed by Rule 12-29 of Regulation S-X should be filed by persons specified under
Schedule III for investments in mortgage loans on real estate.


Rule 12-29. Mortgage loans on real estate [1]


**(For certain real estate companies)**


|COL. A|COL. B|COL. C|COL. D|COL. E|COL. F|COL. G|COL. H|
|---|---|---|---|---|---|---|---|
|Description<br>2, 3, 4|Interest<br>Rate|Final Maturity<br>Date|Periodic<br>Payment<br>Terms5|Prior Liens|Face<br>Amount of<br>Mortgages|Carrying<br>Amount of<br>Mortgages<br>3, 6, 7, 8, 9|Principal<br>Amount of<br>Loans Subject<br>to Delinquent<br>Principal or<br>Interest10|


1 All money columns shall be totaled.

2 The required information is to be given for each individual mortgage loan which exceeds three percent of the total of column G.

3 If the portfolio includes large numbers of mortgages most of which are less than three percent of column G, the mortgages not

required to be reported separately should be grouped by classifications that will indicate the dispersion of the portfolio, i.e., for a
portfolio of mortgages on single family residential housing. The description should also include number of loans by original loan
amounts (e.g., over $100,000, $50,000-$99,999, $20,000-$49,999, under $20,000) and type loan (e.g., VA, FHA,
Conventional). Interest rates and maturity dates may be stated in terms of ranges. Data required by columns D, E and F may be
omitted for mortgages not required to be reported individually.

4 Loans should be grouped by categories, e.g., first mortgage, second mortgage, construction loans, etc., and for each loan the

type of property, e.g., shopping center, high-rise apartments, etc., and its geographic location should be stated.

5 State whether principal and interest is payable at level amount over life to maturity or at varying amounts over life to maturity.

State amount of balloon payment at maturity, if any. Also state prepayment penalty terms, if any.

6 In a note to this schedule, furnish a reconciliation in the following form, of the carrying amount of mortgage loans at the

beginning of each period for which income statements are required, with the total amount shown in column G.


Balance at beginning of period ................................................................... $...........
Additions during period:

New mortgage loans ........................................................ $ ...........
Other (describe) .............................................................. ...........
........................................................................ ........... ............
........................................................................ ........... $...........
Deductions during period:

Collection of principal ....................................................... $ ...........
Foreclosures ...................................................................
Cost of mortgages sold .....................................................
Amortization of premium..................................................
Other (describe) .............................................................. ........... ............
Balance at close of period .......................................................................... $ ..........


If additions represent other than cash expenditures, explain. If any of the changes during the period result from transactions, directly
or indirectly, with affiliates, explain the bases of such transactions, and state the amounts involved. State the aggregate mortgages
(a) renewed and (b) extended. If the carrying amount of new mortgages is in excess of the unpaid amount of the extended
mortgages, explain.


7 If any item of mortgage loans on real estate investments has been written down or reserved against, describe the item and

explain the basis for the write-down or reserve.

8 State in a note to column G the aggregate cost for Federal income tax purposes.

9 The amount of all intercompany profits included in the total of column G shall be stated, if material.

10 (a) Interest in arrears for less than three months may be disregarded in computing the total amount of principal subject to

delinquent interest. (b) Of the total principal amount, state the amount acquired from controlled and other affiliates.


Commentary


Schedule IV is required only for certain real estate companies as described by Rule 5-04 of Regulation S-X.
This schedule is required only in support of the most recent balance sheet required. However,
reconciliations of the changes in mortgage loans (see Note 6 of Rule 12-29 of Regulation S-X) are
required to support each income statement required, as shown in the example.


**2024 SEC annual reports — Form 10-K** | 122


---

7 Financial schedules


**2024 SEC annual reports — Form 10-K** | 123


---

7 Financial schedules

##### 7.6 Schedule V — Supplemental information concerning property-casualty insurance operations


The schedule prescribed by Rule 12-18 of Regulation S-X should be filed when a registrant, its subsidiaries
or 50%-or-less-owned equity basis investees have liabilities for property-casualty (P/C) insurance claims.
The required information should be presented as of the same dates and for the same periods for which the
information is reflected in the audited consolidated financial statements required by Rules 3-01 and 3-02
of Regulation S-X. The schedule may be omitted if reserves for unpaid P/C claims and claims adjustment
expenses of the registrant and its consolidated subsidiaries, its unconsolidated subsidiaries and its 50%-orless-owned equity basis investees did not, in the aggregate, exceed one half of common stockholders’
equity of the registrant and its consolidated subsidiaries as of the beginning of the fiscal year. For
purposes of this test, only the proportionate share of the registrant and its other subsidiaries in the
reserves for unpaid claims and claim adjustment expenses of 50%-or-less-owned equity basis investees
taken in the aggregate after intercompany eliminations should be taken into account.


**2024 SEC annual reports — Form 10-K** | 124


---

7 Financial schedules


Rule 12-18. Supplemental information (for property-casualty insurance underwriters) [1]


|COL. A|COL. B|COL. C|COL. D|COL. E|COL. F|COL. G|COL. H|Col9|COL. I|COL. J|COL. K|
|---|---|---|---|---|---|---|---|---|---|---|---|
|Affiliation with<br>registrant|Deferred<br>policy<br>acquisition<br>costs|<br>Reserves<br>for unpaid<br>claims and<br>claim<br>adjustment<br>expenses|<br>Discount,<br>if any,<br>deducted <br>in<br>Column<br>C4|<br> <br>Unearned<br>premiums|<br> <br>Earned<br>premiums|<br>Net<br>invest-<br>ment<br>income|Claims and claim<br>adjustment<br>expenses<br>incurred related<br>to|Claims and claim<br>adjustment<br>expenses<br>incurred related<br>to|<br>Amortization<br>of deferred<br>policy<br>acquisition<br>costs|<br>Paid claims <br>and claim<br>adjustment<br>expenses|<br> <br>Premiums<br>written|
|Affiliation with<br>registrant|Deferred<br>policy<br>acquisition<br>costs|<br>Reserves<br>for unpaid<br>claims and<br>claim<br>adjustment<br>expenses|<br>Discount,<br>if any,<br>deducted <br>in<br>Column<br>C4|<br> <br>Unearned<br>premiums|<br> <br>Earned<br>premiums|<br>Net<br>invest-<br>ment<br>income|<br>(1)<br>Current<br>year|<br>(2)<br>Prior<br>year|<br>(2)<br>Prior<br>year|<br>(2)<br>Prior<br>year|<br>(2)<br>Prior<br>year|


(a) Consolidated

propertycasualty
entities [2]


(b) Unconsolidated

propertycasualty
subsidiaries [2, 3]

(c) Proportionate

share of
registrant and
its subsidiaries’
50% -or-less
owned property
casualty equity
investees [2, 3]


1 Information included in audited financial statements, including other schedules, need not be repeated

in this schedule. Columns B, C, D and E are as of the balance sheet dates, columns F, G, H, I, J and K
are for the same periods for which income statements are presented in the registrant’s audited
consolidated financial statements.


2 Present combined or consolidated amounts, as appropriate for each category, after intercompany

eliminations.


3 Information is not required here for 50%-or-less owned equity investees that file similar information

with the Commission as registrants in their own right, if that fact and the name of the affiliated
registrant are stated. If ending reserves in any category (a), (b) or (c) above is less than 5% of total
reserves otherwise required to be reported in this schedule, that category may be omitted and that
fact so noted. If the amount of the reserves attributable to 50%-or-less owned equity investees that file
this information as registrants in their own right exceeds 95% of the total category (c) reserves,
information for the other 50%-or-less owned equity investees need not be provided.


4 Disclose in a footnote to this schedule the rate, or range of rates, estimated if necessary, at which the

discount was computed for each category.


**2024 SEC annual reports — Form 10-K** | 125


---

7 Financial schedules


**2024 SEC annual reports — Form 10-K** | 126


---

8 Notification of late filing

### **8 Notification of late filing**


A registrant must notify the SEC when it is not able to file all or any portion of Form 10-K when due. The
SEC will not grant extensions beyond the prescribed due date. However, if a registrant meets certain
conditions under a specific relief provision, the SEC may deem its Form 10-K to have been filed timely
even if it actually was filed up to 15 days late. All companies, including large accelerated filers and
accelerated filers are eligible for this relief.


This section explains the requirements of Rule 12b-25 of Regulation 12B, _Registration and Reporting_, and
related Form 12b-25, for notifying the SEC of late filings of Form 10-K and transition reports on Form
10-K (see When the report is due discussion in section 2).


This section does not discuss the requirements of electronic filers unable to file a report solely due to
electronic difficulties, including submission or posting of an Interactive Data File. Registrants should see
Rule 201 or Rule 202 of Regulation S-T regarding late electronic postings.

##### 8.1 Importance of timely filing


Late filing of Form 10-K is a serious matter. In announcing the current rules, a 1980 SEC Release
(No. 33-6203) stated:


“It should be emphasized that the new notification and relief procedures should not be taken as an
excuse for non-timely reporting. Failure by public companies to observe the periodic reporting
requirements presents an obstacle to the maintenance of fair and informed trading markets in the
securities of publicly-held companies. The pricing mechanism of the market is dependent on timely
information and, thus, late reporting may adversely affect the quality of this process. In this regard,
the Commission will, of course, continue to consider enforcement actions in connection with
delinquent reporting.”


In subsequent releases, the SEC has commented on the need for greater diligence by registrants to achieve
timely and complete filing of reports. If a registrant does not file Form 10-K by its due date, or does not
comply with conditions for the 15-day relief period, the registrant has violated the applicable provisions of
the Exchange Act. In such a case, the registrant would be subject to a potential enforcement proceeding by
the SEC and a possible suspension in trading in addition to other consequences discussed below.


If a live submission is commenced and transmitted to EDGAR on or before 5:30 p.m. Eastern time on a
day when EDGAR is operational, and it is accepted by EDGAR, it will receive the filing date of that day.
However, if the submission is initiated between 5:30 p.m. and 10:00 p.m. Eastern time, and the submission
is accepted by EDGAR, it will be assigned a filing date of the next business day. Therefore, if a registrant
files its Form 10-K after 5:30 p.m. but before 10:00 p.m. ET on its due date, it will also be required to file
a Form 12b-25 with the SEC notifying of the delayed filing.


**2024 SEC annual reports — Form 10-K** | 127


---

8 Notification of late filing

##### 8.2 Other possible consequences of late filing


There are a number of other possible consequences of late filing. For example, when a registrant fails to
file any report required under the Exchange Act, the SEC will not permit any of its Securities Act registration
statements to become effective. [117] In addition, to use Form S-3, an issuer must have complied in all
respects, including timeliness, with the reporting requirements of the Exchange Act for the last 12 months.
Companies that otherwise meet the definition of a well-known seasoned issuer (see section 3 of this
publication) would not be eligible to file an automatic shelf registration statement because timely filing
for the last 12 months is a Form S-3 eligibility requirement.


For certain shareholders to sell restricted securities (and for affiliates to sell any securities) under
Securities Act Rule 144, the registrant must have filed the reports required by the Exchange Act during
the 12 months preceding the sale. Therefore, as long as a required report remains unfiled, the issuer’s
stock may not be sold by these individuals under Rule 144.

##### 8.3 Rule 12b-25 and Form 12b-25


If it cannot file all or any required portion of Form 10-K within the prescribed time period, the registrant
must notify the SEC on Form 12b-25. [118] This form serves as a disclosure mechanism and is available via
EDGAR. Thus, information is available to the public about a registrant’s reasons for not filing a periodic
report or a portion of a report on time.


In certain circumstances, a registrant may file Form 10-K up to 15 days late and still not suffer the
consequences of a late filing. A specific relief provision of Rule 12b-25 provides that the SEC will deem a
late Form 10-K to have been filed timely if _all_ of the following conditions are met:


            - A properly filed notification on Form 12b-25 discloses that filing timely would have caused
unreasonable effort or expense, and the registrant agrees that the Form 10-K, or the delinquent
portion thereof, will be filed no later than the fifteenth calendar day following the original due date
(fifth calendar day for Form 10-Q).


            - The registrant attaches, where applicable, a statement from any person other than the registrant
(e.g., actuary, engineer, independent auditor) whose inability to furnish a required opinion, report or
certification, was the reason that the Form 10-K could not be filed on time.


            - The Form 10-K, or the delinquent portion thereof, is filed within the represented time period (see above).


The SEC staff has expressed concern that some companies may be using Form 12b-25 to delay disclosing
financial difficulties. To deter such actions, the SEC staff examines Forms 12b-25 as they are filed and
reviews the registrant’s related reports. The staff expects transparent disclosure explaining the reasons
for the delay.


117 SEC Release No. 33-5196 dated 27 September 1971.

118 In EDGAR, Form 12b-25 related to a Form 10-K filing is designated as the form type “NT 10-K.”


**2024 SEC annual reports — Form 10-K** | 128


---

8 Notification of late filing


In addition to the requirements for the relief provision described above, the instructions for the form are
summarized as follows:


            - The form must be filed by registrants who are unable to file in a timely fashion: (1) all or any
portion of an annual report, a quarterly report, transition report or distribution report required by
Sections 13 or 15(d) of the Exchange Act or (2) all or any portion of an annual report, semi-annual
report or transition report on Form N-CEN or N-CSR required by Sections 13 or 15(d) of the
Exchange Act or Section 30 of the Investment Company Act of 1940.


            - The form must be filed no later than one business day after the due date of the periodic report in question.


            - The registrant must explain why it cannot file the report within the time required. [119]


            - If the form is being filed for a portion of a report and the balance of the report was filed by the due
date, the registrant must disclose the portion(s) omitted. When the registrant amends the report to
include the omitted information, the registrant must state in the upper right corner of the
amendment: “The following items were the subject of a Form 12b-25 and are included herein.” Then
it must list the item numbers.


Like other Exchange Act filings, Form 12b-25 is subject to Exchange Act Rule 12b-20. That is, in addition
to the required information, the report must contain any additional information necessary to make the
required information not misleading. For example, at the 3 April 2009 CAQ SEC Regulations Committee
meeting, the SEC staff stated that Form 12b-25 also might need to disclose any internal control issues
that led to the registrant’s inability to file the Form 10-K on time.

##### 8.4 Portions of Form 10-K due following the filing date


Rule 12b-25 specifically excludes: (1) schedules required by Article 12 of Regulation S-X that may be
filed by amendment up to 30 days after the due date of the registrant’s annual report on Form 10-K and
(2) financial statements of significant unconsolidated subsidiaries and equity investees. [120] In addition,
information called for in Part III of Form 10-K (Item 10, _Directors, Executive Officers and Corporate_
_Governance_ ; Item 11, _Executive Compensation_ ; Item 12, _Security Ownership of Certain Beneficial_
_Owners and Management and Related Stockholder Matters_ ; Item 13, _Certain Relationships and Related_
_Transactions, and Director Independence;_ and Item 14, _Principal Accountant Fees and Services_ ) may be
incorporated by reference from the registrant’s definitive proxy statement filed within 120 days after
year-end. If the proxy statement is not filed within the 120-day period, the information must be filed as
part of Form 10-K, or as an amendment to Form 10-K not later than the end of the 120-day period.


The SEC staff expects registrants to comply with Rule 12b-25 when they are not able to file financial
schedules, Part III information or financial statements of unconsolidated subsidiaries and equity investees
within the applicable prescribed time period. In these cases, the 15-day relief provision of Rule 12b-25 is
available when its conditions are met.


119 The SEC staff has expressed concerns with the quality of explanations provided. It often finds the explanations provided by

registrants to be boilerplate.

120 See section 2 of this publication for a discussion of the filing deadlines for financial statements required under Rule 3-09 of

Regulation S-X.


**2024 SEC annual reports — Form 10-K** | 129


---

8 Notification of late filing

##### 8.5 Involvement of independent auditors


Rule 12b-25(c) discusses the possible involvement of independent auditors with Form 12b-25:


“If paragraph (b) of this [rule] is applicable and the reason the subject report/portion thereof cannot
be filed timely without unreasonable effort or expense relates to the inability of any person, other
than the registrant, to furnish any required opinion, report or certification, the Form 12b-25 shall
have attached as an exhibit a statement signed by such person stating the specific reasons why such
person is unable to furnish the required opinion, report or certification on or before the date such
report must be filed.”


It is important to distinguish between the responsibilities of the registrant and its independent auditors.
The registrant must explain why the report cannot be filed; the independent auditors must explain why
the audit cannot be completed _only_ if that is the reason for the registrant’s inability to make a timely filing.
The following are examples of situations that a registrant would be required to explain in Form 12b-25,
but that should _not_ require a letter from the registrant’s independent auditors:


            - The preliminary results of the year-end physical inventory indicate a substantial shortage that is
under investigation by the registrant.


            - Year-end financial information for material foreign subsidiaries or branches has not been received.


            - Certain accounting records were accidentally destroyed and are in the process of being
reconstructed.


If a registrant is not able to complete its financial statements for any reason, the independent auditors
obviously will not be able to complete their audit. In a Form 12b-25 filed under such circumstances, the
registrant should explain the reasons for its inability to complete the financial statements. In most cases,
it should not be necessary for the independent auditors to submit a statement because it is the registrant’s
inability to complete its financial statements, rather than the independent auditors’ inability to complete
the audit, that results in the late filing and requires Form 12b-25 to be filed. However, if the independent
auditors’ statement is given, it should explain that the audit could not be completed because of the
registrant’s inability to complete its financial statements including, if known, the registrant’s reasons.

##### 8.6 Complete and accurate statements


It is important that any notifications filed by the registrant and supporting statements by any other
persons, including the registrant’s independent auditors, be complete and accurate. Filing false or
misleading information, including the reason(s) cited for the filing delay, would constitute a violation of
Section 18 of the Exchange Act and could subject the registrant or such other person to civil liabilities,
as well as criminal or administrative sanctions.


**2024 SEC annual reports — Form 10-K** | 130


---

### **9 Smaller reporting companies (SRCs)**

##### 9.1 SRC rules

SEC rules allow an SRC to use the scaled (generally reduced) disclosure and reporting requirements.


An SRC may choose, on an item-by-item basis within any filing, whether to apply Regulation S-K’s scaled
disclosure requirements or its more rigorous disclosure requirements for larger public companies.
Nevertheless, the SEC has stressed the importance of consistent disclosures that allow investors to make
period-to-period comparisons, whether quarterly or annually.

##### 9.2 Definition of a ‘smaller reporting company’


Regulation S-K Item 10(f)(1) defines an SRC as an issuer that is not an investment company, an assetbacked issuer or a majority-owned subsidiary whose parent is not an SRC and meets either of the
following conditions after performing its initial qualification test (e.g., upon filing an initial registration
statement for common equity): [121]


            - Its public float [122] is below $250 million.


            - Its annual revenue for the most recently completed fiscal year is less than $100 million and public
float is less than $700 million (including no public float).


Once an issuer determines that it does not qualify for SRC status because it exceeded one or more of the
conditions above at the initial qualification test, it will remain unqualified unless it meets certain
thresholds when making its annual determination as discussed further below.

##### 9.2.1 Annual redeterminations


The annual determination (or redetermination) for SRC status is performed as of the last business day of
the company’s second fiscal quarter. For a calendar-year company, the annual test for the year ending
31 December 20Y2 would be performed on 30 June 20Y2, the last business day of the second quarter.


The SEC set different entry and exit thresholds for SRC status to minimize moves from one category to
the other due to relatively small changes in public float. The subsequent qualification thresholds are set
at 80% of the initial qualification thresholds described above.


121 A company filing an initial registration statement for shares of its common equity (Securities Act or Exchange Act) should

determine its estimated public float as of a date within 30 days of the date the registration statement is filed and then finalize its
public float calculation at the time the IPO is completed and the common share price at IPO is known.

122 Public float is determined by multiplying the aggregate number of voting and non-voting common shares held by non-affiliates by

the price at which the common shares were last sold, or the average of the bid and asked prices, in the principal market for the
registrant’s common shares. Thus, the determination of public float is premised on the existence of a public trading market for
the issuer’s common equity securities. This is different than the definition of market capitalization, which is an amount equal to
the total number of issued and outstanding shares of the issuer’s common equity securities. Calculating a registrant’s public float
may involve judgment and legal interpretations and analysis, including determining affiliate status based on the facts and
circumstances. Registrants should consult with their legal counsel.


**2024 SEC annual reports — Form 10-K** | 131


---

9 Smaller reporting companies (SRCs)


_**Entry thresholds**_


A registrant that did not initially qualify as an SRC may subsequently qualify only if it meets one of the
following thresholds:


- Its public float is below $200 million at the determination date.


- Its annual revenue for the fiscal year completed before the determination date is less than $80 million,
and its public float at the determination date is less than $560 million (including no public float).


For purposes of performing the two-part revenue and public float qualification test, a registrant should
ordinarily look to its audited financial statements for the most recent fiscal year required to be included
in its initial registration statement or its last annual report on Form 10-K.


Additionally, application of the two-part revenue and public float test depends on the annual revenue and
public float tests performed in the prior year. Generally, if a registrant loses its SRC status because it
exceeds either the $100 million annual revenue or $700 million public float threshold, the registrant is only
required to apply the 80% threshold to the criteria it previously exceeded when performing the current
qualification test. Refer to FRM Section 5120.1b for further details.


An issuer must check a box on the cover page of its SEC filings indicating whether it meets the definition
of an SRC.


**2024 SEC annual reports — Form 10-K** | 132


---

9 Smaller reporting companies (SRCs)


_**Exit provisions**_


A registrant that qualifies as an SRC must redetermine annually whether it continues to qualify as such
on its redetermination date (the last business day of its second fiscal quarter for which a public trading
price of its common stock is available) by measuring its public float and revenue for the most recently
completed year. A registrant that previously qualified as an SRC maintains that status until one of three
exit criteria is met at its next redetermination date:


            - Its public float exceeds $250 million and its annual revenue exceeds $100 million.


            - Its annual revenue exceeds $100 million and it has no public float.


            - Its public float exceeds $700 million, regardless of annual revenue.


If a registrant has no public float (e.g., it has only public debt or preferred stock), it would continue to qualify
if its annual revenues are less than $100 million during its most recently completed fiscal year for which
audited financial statements are available.


_**Eligibility for FPIs**_


Any FPI is eligible to qualify as an SRC in accordance with the threshold requirements. However, to take
advantage of the disclosure relief as an SRC, an FPI must use domestic forms (e.g., Form 10-K, not Form 20-F)
and file financial statements prepared using US GAAP.

##### 9.2.2 Implications of changes in SRC status


A reporting issuer newly qualifying as an SRC on its annual determination date (i.e., the last business day
of its second fiscal quarter) may choose to reflect its change to SRC status in its quarterly report for that
second fiscal quarter or defer to a quarterly or annual report filed thereafter. However, the registrant
must reflect its SRC status by checking the box on the cover page of its SEC filings no later than in its
first Form 10-Q for the next fiscal year regardless of whether it chooses to apply the scaled (i.e., reduced)
disclosure standards permitted for such issuers.


Once a reporting issuer fails to qualify for SRC status at its annual determination, it may choose to continue
using the scaled disclosures permitted for SRCs in its annual report on Form 10-K for the current fiscal year
but must begin providing non-scaled larger company disclosures in its first Form 10-Q for the next fiscal year.


In addition, the issuer can continue taking advantage of other SRC accommodations (e.g., provide financial
statements of an acquired business in accordance with Article 8 of Regulation S-X if it made its initial filing
on Form 8-K and its acquisition before the new fiscal year starts, defer adoption of a new or amended
accounting standards) during this period.

##### 9.2.3 Interaction between SRC status and accelerated filer status


The SEC’s definitions of accelerated filers and large accelerated filers exclude SRCs that have not yet
begun to generate significant revenues and allow issuers with less than $100 million in annual revenues
and less than $700 million in public float to qualify as non-accelerated filers. Consequently, these issuers
are not subject to the requirements for auditor attestation for ICFR.


The definitions provide relief to companies that no longer qualify as EGCs but do not provide relief for all
SRCs that qualify as accelerated filers. That is, issuers that qualify for SRC status under the public float
test only (i.e., they have a public float of less than $250 million but more than $75 million) will continue to
be accelerated filers if their annual revenue is above $100 million.


See our Technical Line publication, _**[Navigating the requirements for merging with a special purpose](https://www.ey.com/en_us/technical/accountinglink/technical-line---navigating-the-requirements-for-merging-with-a-)**_
_**[acquisition company](https://www.ey.com/en_us/technical/accountinglink/technical-line---navigating-the-requirements-for-merging-with-a-)**_, for considerations related to the redetermination of SRC, EGC and filer status for a
company created by the merger of a special purpose acquisition company and an operating company.


**2024 SEC annual reports — Form 10-K** | 133


---

9 Smaller reporting companies (SRCs)

##### 9.3 Form 10-K filing by an SRC 9.3.1 Content


The following table shows the item number, caption and location of the disclosure instructions for the
various items of a Form 10-K filed by an SRC. Items that are not applicable in their entirety are noted
parenthetically as “Not required.”


|Form<br>Item|Form 10-K<br>instructions|Disclosure requirement|Scaling for SRCs|
|---|---|---|---|
|**Part I**|**Part I**|**Part I**|**Part I**|
|Item 1|Business|S-K Item 101|Scaled|
|Item 1A|Risk factors|S-K Item 105|Not required|
|Item 1B|Unresolved staff<br>comments|Material unresolved SEC staff comment<br>letters received more than 180 days<br>before the fiscal year-end|Required if SRC is accelerated filer|
|Item 1C|Cybersecurity|S-K Item 106|Same as non-SRC|
|Item 2|Properties|S-K Item 102|Same as non-SRC|
|Item 3|Legal<br>proceedings|S-K Item 103|Same as non-SRC|
|Item 4|Mine safety<br>disclosures|S-K Item 104|Same as non-SRC|
|**Part II**|**Part II**|**Part II**|**Part II**|
|Item 5|Market for<br>registrant’s<br>common equity<br>and related<br>stockholder<br>matters|S-K Item 201<br> <br>S-K Item 701<br>S-K Item 703|Same as non-SRC except stock<br>performance graph in Item 201(e)<br>Same as non-SRC<br>Same as non-SRC|
|Item 7|Management’s<br>discussion and<br>analysis|S-K Item 303|Same as non-SRC|
|Item 7A|Quantitative and<br>qualitative<br>disclosures about<br>market risk|S-K Item 305|Not required|
|Item 8|Financial<br>statements<br> <br> <br> <br>Supplementary<br>financial<br>information|S-X Rules 3-01 through 3-04<br>S-X Articles 4 and 5<br>S-X Article 7 if the registrant is an<br>insurance company or Article 9 if it’s a<br>bank holding company<br>S-K Item 302|Scaled in Article 8 of Regulation S-X<br> <br> <br> <br> <br>Not required|
|Item 9|Changes in and<br>disagreements<br>with accountants<br>on accounting<br>and financial<br>disclosure|S-K Item 304(b)|Same as non-SRC|
|Item 9A|Controls and<br>procedures|S-K Items 307 and 308|Same as non-SRC<br>An SRC is required to include an audit<br>report on its ICFR only if it is also an<br>accelerated filer|


**2024 SEC annual reports — Form 10-K** | 134


---

9 Smaller reporting companies (SRCs)


|Form<br>Item|Form 10-K<br>instructions|Disclosure requirement|Scaling for SRCs|
|---|---|---|---|
|Item 9B|Other<br>information|Any information required to be<br>disclosed on Form 8-K during the<br>quarter but not reported<br>S-K Item 408(a), (d)|Same as non-SRC|
|Item 9C|Disclosure<br>Regarding<br>Foreign<br>Jurisdictions that<br>Prevent<br>Inspections|HFCA Act disclosure|Same as non-SRC|
|**Part III**|**Part III**|**Part III**|**Part III**|
|Item 10|Directors,<br>executive officers<br>and corporate<br>governance|S-K Items 401, 405, 406 and<br>407(c)(3), (d)(4) and (d)(5)|Scaled corporate governance disclosures<br>under Item 407|
|Item 11|Executive<br>compensation|S-K Items 402 and 407(e)(4) and (e)(5)|Scaled executive compensation disclosures<br>under Item 402|
|Item 12|Security<br>ownership|S-K Items 201(d) and 403|Same as non-SRC|
|Item 13|Certain<br>relationships and<br>related<br>transactions, and<br>director<br>independence|S-K Items 407(a) and 404(c)<br>S-K Items 404(a) and (d)<br>S-K Item 404(b)|Same as non-SRC<br>Expanded for SRCs<br>Not required|
|Item 14|Principal<br>accountant fees<br>and services|Item 9(e) of Schedule 14A|Same as non-SRC|
|**Part IV**|**Part IV**|**Part IV**|**Part IV**|
|Item 15|Exhibits<br>Financial<br>statement<br>schedules|S-K Item 601 Exhibits<br>S-X Article 12 Financial Statement<br>Schedules|Same as non-SRCs<br>Not required|
|Item 16|Form 10-K<br>summary|Optional|Optional|


The following is a list of the item requirements in Regulation S-K and Regulation S-X for which there are
different Form 10-K disclosure requirements for SRCs. For more details about the proxy statement
disclosure requirements of SRCs, refer to our publication _**[Proxy statements — An overview of the](https://www.ey.com/en_us/technical/accountinglink/2025-proxy-statements-an-overview-of-the-requirements)**_
_**[requirements and observations about current practice](https://www.ey.com/en_us/technical/accountinglink/2025-proxy-statements-an-overview-of-the-requirements)**_ .

##### 9.3.2 Item 101. Description of business


Item 101(h) of Regulation S-K describes the disclosure requirements for an SRC. In Form 10-K, an SRC is
required to describe only business developments for the period of time that is material to an understanding
of the general development of the business. An SRC is permitted to provide only material updates along
with a hyperlink to the most recently filed full discussion of its business developments that, together with
the update, would present a complete discussion.


**2024 SEC annual reports — Form 10-K** | 135


---

9 Smaller reporting companies (SRCs)


This business development description must include a discussion of the following topics specified in
Item 101(h):


            - Form and year of organization


            - Any bankruptcy, receivership or similar proceeding


            - Any material reclassification, merger, consolidation or purchase or sale of a significant amount of
assets not in the ordinary course of business


An SRC also must briefly describe its business, including the following if it is material to an understanding
of its business:


            - Principal products or services and their markets


            - Distribution methods of the products or services


            - Status of any publicly announced new product or service


            - Competitive business conditions, its competitive position in the industry and methods of competition


            - Sources and availability of raw materials, and the names of principal suppliers


            - Dependence on one or a few major customers


            - Patents, trademarks, licenses, franchises, concessions, royalty agreements or labor contracts
(including their duration)


            - Need for any government approval of principal products or services, and if pending, the status of the
government approval process


            - Effect of existing or probable governmental regulations


            - Costs and effects of compliance with environmental laws (federal, state and local)


            - Number of total employees and number of full-time employees


SRCs are not required to provide the disclosures in Item 101(c)(2)(ii) about their human capital resources,
including the number of persons employed and any human capital measures or objectives that management
focuses on when managing the business. Instead, SRCs are only required to disclose material information
about their labor contracts, including duration. SRCs may voluntarily choose to apply any disclosure
requirements for non-SRCs that are more extensive than those required for SRCs.


An FPI complying with the SRC disclosures must provide disclosure about enforceability of civil liability
against foreign persons (as set forth in Item 101(g) of Regulation S-K).

##### 9.3.3 Item 201. Common equity and related stockholder matters


An SRC is not required to furnish a stock performance graph (Item 201(e) of Regulation S-K, which is
discussed further in section 4 of this publication).

##### 9.3.4 Item 303. MD&A


The MD&A requirements discussed further in section 5 of this publication also apply to an SRC.


**2024 SEC annual reports — Form 10-K** | 136


---

9 Smaller reporting companies (SRCs)

##### 9.3.5 Item 305. Market risk disclosures


An SRC is not required to file the quantitative and qualitative disclosures about market risk (as discussed
in section 4 of this publication).

##### 9.3.6 Financial information of SRCs


**9.3.6.1** **Financial Information of the SRC registrant**


Article 8 of Regulation S-X - Annual financial information


SRCs may choose to comply with either the requirements for SRC financial statements in Article 8 or those for
non-SRCs elsewhere in Regulation S-X. Article 8 of Regulation S-X requires SRCs to file an audited balance
sheet as of the end of the two most recent fiscal years and audited statements of comprehensive income,
cash flows and changes in stockholders’ equity and noncontrolling interests for the two most recent fiscal
years. Larger registrants are required to file audited financial statements for three fiscal years.


SRCs always have to comply with the following:


            - Article 2 of Regulation S-X, which outlines the requirements for the report and qualifications of the auditor


            - Rule 4-10 regarding the accounting and reporting for oil- and gas-producing activities


SRCs should also provide all information required by any applicable SEC industry guide.


SRCs that choose to prepare their financial statements in accordance with Article 8 are not required to follow
the presentation requirements of Rules 5-02 and 5-03 of Regulation S-X or provide the related note
disclosures. SRCs can also omit the financial schedules required by Rule 5-04 and any note disclosures
required by Rule 4-08 (with the exception of the derivative accounting policy disclosures in Rule 4-08(n)).


Although S-K Item 302 exempts an SRC from its requirements for additional disclosures about oil and gas
producing activities, an SRC engaged in oil and gas producing activities still must provide the disclosures
required by Regulation S-K Subpart 1200, _Disclosure by Registrants Engaged in Oil and Gas Producing_
_Activities,_ under instruction of S-K Item 102, and under S-X 8-01, it must follow the accounting and
reporting standards specified in S-X 4-10. Thus, an SRC still must provide the disclosures otherwise
required by ASC 932.


**9.3.6.2** **Financial statements of other entities**


Financial information for equity method investees


SRCs are not required to provide separate financial statements of significant equity method investees.
However, under Rule 8-03(b)(3), they are required to provide summarized financial data, including sales,
gross profit, net income from continuing operations and net income for significant equity investees that
individually or in the aggregate represent 20% or more of their consolidated assets, equity or income
from continuing operations attributable to the registrant in both annual and interim financial statements.
While this requirement is similar to the interim reporting requirement for larger companies, the threshold
for SRCs is higher (20%) than the threshold for summarized information in annual financial statements
for larger companies (10%), and SRCs aren’t required to provide any balance sheet data.


Other financial statement requirements


SRCs must comply with the requirements of the following rules:


            - Rule 3-10 for separate financial statements of subsidiary issuers and guarantors


            - Rule 13-01 for summarized financial information of subsidiary issuers and guarantors


**2024 SEC annual reports — Form 10-K** | 137


---

9 Smaller reporting companies (SRCs)


- Rule 3-16 for separate financial statements of affiliates whose securities collateralize the registrant’s
securities [123]


- Rule 13-02 for summarized financial information of affiliates whose securities collateralize the
registrant’s securities


If omission of separate financial statements required by Rule 13-01 and Rule 13-02 is permitted, SRCs
must present summarized financial information for the most recent fiscal year in the registrant’s financial
statements in the annual report on Form 10-K (i.e., the same period required for non-SRCs, discussed in
section 6 of this publication). Otherwise, separate financial statements required by Rule 3-10 and Rule 316 may be presented for two years rather than three years (i.e., the periods required for Article 8 of
Regulation S-X). Like other registrants, SRCs can also avail themselves of the provisions of Rule 3-13 of
Regulation S-X to request relief from providing required financial statements when the relief is consistent
with the protection of investors.


In addition, SRCs are not required to provide financial statement schedules. As outlined above, SRCs are
not subject to the reporting requirements of Rule 5-04 of Regulation S-X (regarding the requirement to
provide Schedule I) or the related disclosure requirements in Rule 4-08(e) of Regulation S-X. However,
when the restricted net assets of an SRC’s consolidated subsidiaries represent a significant portion of
consolidated net assets as of its year-end the SRC should consider including disclosures within the liquidity
section of its MD&A of the amount and a description of the nature of the restrictions on the net assets of the
consolidated subsidiaries.


123 For securities issued and outstanding before 4 January 2021, unless the requirements of Rule 13-02 apply.


**2024 SEC annual reports — Form 10-K** | 138


---

### **10 Annual shareholders’ report, Part III of** **Form 10-K and proxy statement**

##### 10.1 Annual shareholders’ report

The SEC encourages, but does not require, the incorporation by reference of portions of the annual
shareholders’ report into Form 10-K. Regulation S-K contains the uniform requirements for most of the
information other than financial statements required in various SEC forms and annual shareholders’ reports.
Some Regulation S-K items, or portions of them, are required in both the annual shareholders’ report and
Form 10-K. In addition, financial statements for both documents must comply with Regulation S-X.


Annual shareholders’ reports of companies registered under Sections 12(b) or 12(g) of the Exchange Act are
required to comply with the SEC proxy rules (Rule 14a-3 of the Exchange Act) and must include the following: [124]


            - Consolidated financial statements — Audited balance sheets for each of the two most recent fiscal
years and statements of income, comprehensive income and cash flows for each of the three most
recent fiscal years prepared in accordance with Regulation S-X, but financial schedules, exhibits and
separate financial statements (e.g., significant investees) may be omitted


            - Supplementary financial information — Item 302 of Regulation S-K — Disclosure of material quarterly
changes [125] and information about oil and gas producing activities


            - Changes in and disagreements with accountants on accounting and financial disclosure — Item 304(b)
of Regulation S-K (if applicable, the required disclosures are the same as for Form 10-K — see section 4
of this publication)


            - MD&A of financial condition and results of operations — Item 303 of Regulation S-K


            - Quantitative and qualitative disclosures about market risk — Item 305 of Regulation S-K


            - A brief description of the general nature and scope of the business done by the registrant and its
subsidiaries for the latest fiscal year


            - Segment information — Item 101 of Regulation S-K, paragraph (c)(1) and instructions 1 and 2


            - Director and executive officer information — Name, principal occupation or employment and name of
employer and its principal business


            - Market disclosures for the issuer’s common equity and related stockholder matters — Item 201(a), (b)
and (c) of Regulation S-K (Note: The annual shareholders’ report is not required to include the
disclosures under Item 201(d) of securities authorized for issuance under equity compensation
plans, which is required in Form 10-K.)


            - Stock performance graph — Item 201(e) of Regulation S-K


The requirements in annual shareholders’ reports for financial statements (except financial schedules,
exhibits and separate financial statements), supplementary information, MD&A, market risk, market
disclosures for the issuer’s common equity and related stockholder matters, and disagreements with
prior independent auditors are identical to the related Form 10-K requirements. In addition, Form 10-K
requirements for the description of business, including segment data, and the director and officer
information include the related annual shareholders’ report requirements.


124 Companies reporting under Section 15(d) of the 1934 Act are required to file on Form 10-K but are not required to file an annual

shareholders’ report that complies with the SEC’s proxy rules. See section 2 of this publication for further discussion.

125 Registrants may omit the summarized financial information from their annual report, unless there has been a material retrospective change

(or changes that are material in the aggregate) affecting comprehensive income. See section 4.4.1 of this publication for further discussion.


**2024 SEC annual reports — Form 10-K** | 139


---

10 Annual shareholders’ report, Part III of Form 10-K and proxy statement


A registrant is not required to incorporate portions of its annual shareholders’ report into its Form 10-K.
If the financial statements in the annual shareholders’ report are not incorporated by reference into Form 10-K,
the SEC expects the financial statements in Form 10-K and the annual shareholders’ report to be _identical_ .
Further, if there is no incorporation by reference, the other disclosures provided in those documents
(market disclosures on common equity and related stockholder matters, supplementary financial information,
MD&A, market risk disclosures, and disagreements with prior independent auditors) must be similar.


Section 404 reports are not required in annual shareholders’ reports. However, if internal control over
financial reporting is ineffective or the auditor has issued an adverse opinion on internal control over
financial reporting (i.e., there are material weaknesses in internal control), the SEC staff has strongly
suggested that the issuer consider including the Section 404 reports in the annual shareholders’ report
to avoid a misleading presentation.


Effective January 2023, a registrant must submit annual reports to security holders in electronic format
in accordance with the EDGAR Filer Manual. A company can no longer furnish its annual report to the
Commission by posting an electronic version on its website or mailing paper copies to shareholders.

##### 10.1.1 Stock performance graph


Item 201(e) of Regulation S-K requires registrants to provide a performance graph that compares the
registrant’s cumulative total shareholder return during the previous five years with a performance
indicator of the overall stock market (i.e., a broad-based index), and the registrant’s peer group. The
disclosure is required only in a registrant’s annual shareholders’ report that precedes or accompanies a
proxy or information statement relating to an annual meeting of security holders for the election of
directors and will not be deemed to be incorporated by reference into any filing under the Securities Act
or the Exchange Act, except when the registrant decides to specifically incorporate it by reference. The
performance graph has the same legal status as the annual report to shareholders and is not deemed to
constitute soliciting material or a “filed” document. SRCs (see section 9, _Smaller reporting companies_ )
are not required to disclose a performance graph.


The peer group index should be either of the following:


            - A published industry or line of business index


            - Peer issuer(s) selected in good faith


If the registrant does not use a published industry or line of business index and does not believe that it
can reasonably identify industry peer issuers, it may use issuer(s) with similar market capitalization(s). If
a registrant elects to construct its own peer group, the identity of the issuer(s) and the basis for its (their)
selection must be disclosed. In addition, the returns of the component issuers making up the index must
be weighted according to their market capitalization. Cumulative total shareholder return is measured by
dividing the change in the market value of the registrant’s share price plus the cumulative amount of
dividends, assuming dividend reinvestment, by the share price at the beginning of the measurement
period. An index prepared by a trade group is considered an index prepared by an affiliate of the registrant.
Under the rule, an index prepared by an affiliate of the registrant may be treated as a published index
only if it is “widely recognized and used.” Even if the index is made “accessible to the registrant’s security
holders,” it may not meet this requirement. In most cases reviewed by the SEC staff, trade group indices
did not satisfy this requirement, so constituent registrants had to be identified.


A registrant that is part of the Standard and Poor’s 500 (S&P 500) must use that index as its broad-based
equity market index. Registrants not part of the S&P 500 may use a different broad-based equity market
index that includes companies that trade on the same stock exchanges or are of comparable market
capitalization. Examples of other indices include the NYSE AMEX Composite, Russell 2000 and the Dow
Jones Wilshire 5000 Total Stock Market Index. Certain published indices may be based solely on price, not
total shareholder return (i.e., the index may not reflect the assumed reinvestment of dividends); therefore,
such indices would require adjustments, which may be difficult, to comply with the SEC’s requirement.


**2024 SEC annual reports — Form 10-K** | 140


---

10 Annual shareholders’ report, Part III of Form 10-K and proxy statement


The total shareholder returns must be shown for a five-year period measured from a fixed point
(measurement point) assuming a fixed investment. The measurement point is defined at the close of
trading on the last trading date preceding the first day of the fifth preceding fiscal year. The registrant
may present a graph that exceeds five years; however, the measurement point remains the same.


The SEC staff has responded to a number of implementation questions concerning the performance graph.
The interpretive guidance follows:


- A registrant may plot monthly or quarterly returns provided that each return is plotted at the same
interval, and the annual changes in cumulative total return must be reflected clearly.


- In calculating the measurement point, a registrant should weight the stock prices of the issuers in a
self-constructed peer or market capitalization index in accordance with the market capitalization for
such issuers as of that date. The returns of the component issuers should be weighted according to
their market capitalization as of the beginning of each period for which a return is indicated.


- A change to a self-constructed peer or market capitalization index generally is equivalent to a change
in the index used, which requires disclosure of the reason for the change along with presentation (in
the year of the change) of both the old and new indices. Presentation on the old basis is not required
if the information omitted is the result of application of pre-established objective criteria to the
composition of the index or, in the case of a self-constructed peer index, the registrant is no longer in
the same industry or line of business. In these cases, a specific description of, and the bases for, the
change must be disclosed, including the name of the entity or entities removed from the index.


- A self-constructed peer or market capitalization index may, but is not required to, exclude the registrant.


- In place of data for the last trading day of a given fiscal year, a registrant may use data for the last
day in that year made available by a third-party index provider.


- A registrant created by a spin off may begin its performance graph presentation on the effective
date of the registration of its common stock under Section 12 of the Exchange Act. Similarly,
following an initial public offering, a registrant may begin its performance graph as of that date.


- A registrant that spins off a portion of its business should treat that transaction as a special dividend,
make the appropriate adjustments to its shareholder return data and disclose the occurrence of the
transaction and resultant adjustments. However, the SEC staff has not provided any additional
guidance regarding what would be considered “appropriate adjustments.”


- The presentation of the registrant’s performance graph does not change as a result of a merger or
other acquisition involving the registrant, if the registrant remains in existence and its common stock
remains outstanding.


- A registrant with several distinct lines of business may construct a composite peer group index composed
of registrants from different industry groups, representing each of the registrant’s lines of business (with
the component registrants weighted by revenues or assets of the reporting company’s lines of business).
Alternatively, the registrant may plot a separate peer index line for each of its lines of business. In both
instances, the basis and the relative importance given to each line of business should be disclosed.


Registrants that are considering constructing a peer group index should consider the complexities
involved. In addition to the difficulties of selecting an appropriate group of peer issuers, registrants might
be subject to greater SEC scrutiny than if a published industry index were used. Further, it might be
difficult to evaluate whether the selected group of peer issuers will continue to provide an appropriate
comparison in future years, which might result in the need to make adjustments to the issuers included in
the peer group. Such adjustments would require disclosure in addition to presentation on the basis of
both the old and new indices.


**2024 SEC annual reports — Form 10-K** | 141


---

10 Annual shareholders’ report, Part III of Form 10-K and proxy statement


##### 10.2 Part III of Form 10-K

Regulation S-K contains the rules for disclosure of information required in Part III of Form 10-K,
including:


Item 201(d) Securities Authorized for Issuance under Equity Compensation Plans
Item 401 Directors, Executive Officers, Promoters and Control Persons
Item 402 Executive Compensation
Item 403 Security Ownership of Certain Beneficial Owners and Management
Item 404 Transactions with Related Persons, Promoters and Certain Control Persons
Item 405 Compliance With Section 16(a) of the Exchange Act
Item 406 Code of Ethics
Item 407 Corporate Governance
Item 408(b) Insider Trading Arrangements and Policies


In addition, Item 14, _Principal Accountant Fees and Services_, in Part III of Form 10-K requires disclosure
identical to that required by Item 9(e) of Schedule 14A (the proxy statement).

##### 10.3 Part IV of Form 10-K


Part IV of Form 10-K requires a registrant to provide a list of documents filed in the report and include
any other required financial statements (e.g., subsidiaries not consolidated, 50% or less owned persons),
exhibits required by Item 601 of Regulation S-K (e.g., articles of incorporation) and financial statement
schedules (e.g., Schedule I, Condensed financial information of registrant).


**2024 SEC annual reports — Form 10-K** | 142


---

10 Annual shareholders’ report, Part III of Form 10-K and proxy statement


Item 16 in Part IV of the Form 10-K allows, but does not require, registrants to include an optional
summary of the Form 10-K. The summary should provide more information than a table of contents and
allow users to easily locate where the disclosure is fully presented in the Form 10-K. The summary does
not need to cover all areas of the Form 10-K but must be presented fairly and include a hyperlink to where
the material discussed can be found in the 10-K (or exhibits).


The exhibit index of nearly all filings subject to Item 601 of Regulation S-K, including those on Forms 10-K
and 20-F, must include a hyperlink to each exhibit listed therein. To enable the inclusion of such hyperlinks,
registrants must submit such filings in HTML.


Registrants must provide a description of their securities, as described in Item 202 of Regulation S-K, as
a filed exhibit. [126]

##### 10.3.1 Confidential information in exhibits


The SEC permits registrants to redact confidential information from material contracts filed as exhibits
under Item 601(b)(10) of Regulation S-K without submitting a confidential treatment request if the
redacted information (1) is not material and (2) would likely cause competitive harm if it were publicly
disclosed. The SEC staff may request that the registrant provide its materiality and competitive harm
analysis on a supplemental basis. The registrant may request confidentiality of such supplemental
material submitted pursuant to Rule 83 while it is in the possession of the Commission or its staff.


Registrants are required to:


            - Mark the filing’s exhibit index to indicate that portions of an exhibit have been omitted


            - Include a prominent statement on the first page of the exhibit saying that certain information has been
excluded because it is not material and would likely cause competitive harm if it were publicly disclosed


            - Indicate with brackets where information has been omitted from the exhibit


Also, under Item 601(a)(5) of Regulation S-K, registrants are not required to file schedules or similar
attachments to a filed exhibit if they do not contain material information or were not otherwise disclosed
in the exhibit or the filing. The filing must contain a list briefly identifying the contents of all omitted schedules.

##### 10.4 Incorporation by reference of proxy material


General Instruction G provides that information called for by Part III of Form 10-K (Items 10, 11, 12, 13
and 14) may be incorporated by reference from the registrant’s definitive proxy or information statement
_if_ the proxy or information statement is filed with the SEC no later than 120 days after the fiscal year-end.
However, if the information called for by these items cannot be incorporated by reference, it must be
included within Form 10-K when filed or included by amendment on Form 10-K/A no later than 120 days
after the fiscal year-end.


Our _**[Proxy statements — An overview of the requirements and observations about current practice](https://www.ey.com/en_us/technical/accountinglink/2025-proxy-statements-an-overview-of-the-requirements)**_
publication summarizes the requirements of Regulation 14A and Schedule 14A under the Exchange Act
for soliciting annual meeting proxies. This publication includes an overview of many of the disclosures
required in Part III of Form 10-K.


There are four exceptions to the general rule that Part III Item 10 information will be identical to, and
generally incorporated by reference from, the annual meeting proxy statement. These exceptions are
discussed further below.


126 Registrants can incorporate a previously filed exhibit by reference (via hyperlink) if the information previously filed remains unchanged.


**2024 SEC annual reports — Form 10-K** | 143


---

10 Annual shareholders’ report, Part III of Form 10-K and proxy statement

##### 10.4.1 Item 10. Executive officers


General Instruction G(3) provides that information required by Item 10 of Form 10-K (Item 401 of
Regulation S-K) for executive officers may be included in Part I of Form 10-K under an appropriate
caption. If this is done, this information need not be included in the proxy or information statement.

##### 10.4.2 Item 10. Audit committee financial experts


The disclosures about audit committee financial experts (Item 407(d)(5) of Regulation S-K) must be
provided in response to Item 10 of Form 10-K, but an instruction to Item 407(d)(5) specifically states
that the disclosures may be omitted from the proxy or information statement. Nevertheless, if the
company elects to provide the disclosures about audit committee financial experts in its proxy statement,
it also may incorporate them by reference into the Form 10-K if the proxy statement is filed no later than
120 days after the company’s fiscal year-end. Otherwise, the disclosures about audit committee financial
experts must be included in the Form 10-K.


Item 407(d)(5) requires a public company to disclose whether its board of directors has determined that
the company has at least one financial expert (as defined) on its audit committee. If so, the company also
must disclose the name of its audit committee financial expert and whether that person is independent. If
the audit committee does not have such an expert, the company is required to explain why not. If the
company has more than one audit committee financial expert, it may, but is not required to, disclose the
names of any additional audit committee financial experts and whether the person(s) is (are) independent.


If the board of directors determines that a person qualifies as an audit committee expert because of
“other relevant experience,” the company must briefly describe that person’s relevant experience. The
SEC staff believes “other relevant experience” cannot be satisfied merely by education.

##### 10.4.3 Item 10. Code of ethics


The disclosures about the issuer’s code of ethics (Item 406 of Regulation S-K) must be provided in
response to Item 10 of Form 10-K, but the proxy or information statement is not required to provide
those disclosures. Nevertheless, if the company elects to provide the disclosures about its code of ethics
in its proxy statement, it also may incorporate them by reference into the Form 10-K if the proxy
statement is filed no later than 120 days after the company’s fiscal year-end. Otherwise, the disclosures
about the code of ethics must be included in the Form 10-K.


Item 406 of Regulation S-K requires an issuer to disclose whether it has adopted a code of ethics (as
defined) that covers its principal executive officer, principal financial officer, principal accounting officer or
controller or persons performing similar functions. If so, the issuer must make its code of ethics publicly
available by one of the following means: filing the code of ethics as an exhibit to its Form 10-K, posting the
code of ethics on its website, provided the Form 10-K disclosed that intention and the website address or by
providing disclosure in its Form 10-K that a copy of the code is available without charge on written request.
If the issuer has not adopted a code of ethics, it is required to disclose why it has not done so.


Once a company files its first annual report with the required disclosures, it is required to file Form 8-K to
report significant amendments to its code of ethics, or any waivers, affecting the specified officers.


**2024 SEC annual reports — Form 10-K** | 144


---

10 Annual shareholders’ report, Part III of Form 10-K and proxy statement

##### 10.4.4 Item 10. Shareholder nominating procedures


The disclosures about material changes, during the fourth fiscal quarter, to the procedures disclosed in
the most recent proxy statement for security holders to recommend a director candidate (Item 407(c)(3)
of Regulation S-K, as discussed below) must be provided in response to Item 10 of Form 10-K, but
Item 407(c)(3) specifically states that the disclosures may be omitted from the proxy or information
statement. Nevertheless, if the company elects to provide the disclosures about such changes in its
proxy statement, it also may incorporate them by reference into the Form 10-K if the proxy statement is
filed no later than 120 days after the company’s fiscal year-end. Otherwise, the disclosures about such
changes must be included in the Form 10-K.


Item 407(c)(3) requires a public company to disclose any material changes to the procedures disclosed in
the most recent proxy statement for security holders to recommend a director candidate. A company is
required to report any material change in its periodic Exchange Act report for the period that the
material change occurs (i.e., the company’s quarterly report on Form 10-Q or, for changes that occur
during the fourth fiscal quarter, the company’s annual report on Form 10-K). A material change requiring
disclosure would include the adoption of procedures by which security holders may recommend a
nominee if the company disclosed in its last proxy statement that it did not have any such procedures.

##### 10.4.5 Item 12. Authorized equity compensation


In addition to the four exceptions to Item 10 discussed above, the information required by Item 201(d) of
Regulation S-K in response to Item 12 of Form 10-K is not required to be included in a proxy or information
statement in all cases. The proxy or information statement is not required to provide this disclosure unless
the registrant is submitting a compensation plan for shareholder action. Nevertheless, even if the registrant
does not submit a compensation plan for shareholder action, a registrant that provides the information
required under Item 201(d) in its proxy statement may incorporate the disclosure by reference into
Item 12 of Form 10-K if the proxy statement is filed no later than 120 days after the company’s fiscal
year-end. Otherwise, the Form 10-K must include the disclosure upon filing or by amendment within
120 days of the fiscal year-end.


The Form 10-K instructions indicate that the disclosures required under Item 201(d) of Regulation S-K
must be provided in response to both Item 5 and Item 12. However, the SEC staff has indicated that the
disclosures required under Item 201(d) only should be included in response to Item 12 of Part III of
Form 10-K. See our publication, _**[Proxy statements — An overview of the requirements and observations](https://www.ey.com/en_us/technical/accountinglink/2025-proxy-statements-an-overview-of-the-requirements)**_
_**[about current practice](https://www.ey.com/en_us/technical/accountinglink/2025-proxy-statements-an-overview-of-the-requirements)**_, for a further discussion of the requirements of Item 201(d) of Regulation S-K.


**2024 SEC annual reports — Form 10-K** | 145


---

### **A Common questions domestic 10-K** **filers ask**


|Question|Large<br>accelerated|Accelerated|Non-accelerated|SRCs|EGCs|Voluntary filers|
|---|---|---|---|---|---|---|
|When is<br>management<br>required to report<br>on internal controls<br>under SOX 404(a)?|<br>Required beginning<br>with the second<br>10-K filing|Required beginning<br>with the second<br>10-K filing|Required beginning<br>with the second<br>10-K filing|Required beginning<br>with the second<br>10-K filing|Required beginning<br>with the second<br>10-K filing|Required beginning<br>with the second<br>10-K filing127|
|When is an<br>independent<br>auditor’s report on<br>internal controls<br>(SOX 404(b))<br>needed?|Required beginning<br>with the second<br>10-K filing|Required beginning<br>with the second<br>10-K filing unless<br>an EGC|Exempt|Required<br>beginning with the<br>second 10-K filing<br>if the SRC is also<br>an accelerated filer<br>(unless an EGC)|Exempt|Exempt|
|Does Regulation S-X<br>apply?|<br>Yes|Yes|Yes|Yes, but may elect<br>certain scaled<br>disclosures<br>(Article 8)|Yes, but could<br>qualify as an SRC|Yes|
|Is the entity an<br>issuer under the<br>Sarbanes-Oxley<br>Act?128|Yes|Yes|Yes|Yes|Yes|No|
|Which auditing<br>standards apply<br>(PCAOB or AICPA)?|<br>PCAOB|PCAOB|PCAOB|PCAOB|PCAOB|PCAOB and<br>AICPA129|
|When is the filing<br>due?<br>|60 days after the<br>fiscal year-end|75 days after the<br>fiscal year-end|90 days after the<br>fiscal year-end|75 days after the<br>fiscal year-end if<br>the SRC is an<br>accelerated filer<br>or 90 days after<br>the fiscal year-end<br>if the SRC is a<br>non-accelerated<br>filer|Accelerated filer<br>EGC: Refer to the<br>due dates for<br>accelerated filer<br>Non-accelerated<br>filer EGC: Refer to<br>the due dates for<br>non-accelerated<br>filer|90 days after the<br>fiscal year-end|


127 Assumes a company does not have prior history of filing a Form 10-K. Otherwise, the company, upon becoming a voluntary filer, must continue to provide

management’s assessment on internal controls under SOX 404(a) without any gap.

128 The term ‘‘issuer’’ means any person (includes natural person and other entities) that issues or proposes to issue securities, subject to certain exceptions as

defined in Section 3 of the Securities Exchange Act of 1934 (15 U.S.C. 78c), the securities of which are registered under Section 12 of that Act (15 U.S.C.
78l), or that is required to file reports under Section 15(d) (15 U.S.C. 78o(d)), or that files or has filed a registration statement that has not yet become
effective under the Securities Act of 1933 (15 U.S.C. 77a et seq.), and that it has not withdrawn.

129 Regulation S-X Rule 1-02(d) notes that, when used in regard to financial statements of entities that are not issuers, the term “audit” means an examination

of the financial statements by an independent accountant in accordance with either PCAOB or AICPA standards (US GAAS). However, we understand that
the SEC staff interprets that definition to apply to the financial statements of entities (other than the filer) whose financial statements are included in a filing
(e.g., financial statements of significant acquired businesses under S-X Rule 3-05, financial statements of significant equity investees under S-X Rule 3-09,
target financial statements in a Form S-4) and therefore voluntary filers must comply with the requirements for “issuers.”


**2024 SEC annual reports — Form 10-K** | A-1


---

### **B Abbreviations**

**Abbreviation** **FASB Accounting Standards Codification**

ASC 220 FASB ASC Topic 220, _Income Statement — Reporting Comprehensive Income_

ASC 270 FASB ASC Topic 270, _Interim Reporting_

ASC 275 FASB ASC Topic 275, _Risks and Uncertainties_

ASC 280 FASB ASC Topic 280, _Segment Reporting_

ASC 323 FASB ASC Topic 323, _Investments_          - _Equity Method and Joint Ventures_

ASC 326 FASB ASC Topic 326, _Financial Instruments — Credit Losses_

ASC 360 FASB ASC Topic 360, _Property, Plant and Equipment_

ASC 420 FASB ASC Topic 420, _Exit or Disposal Cost Obligations_

ASC 460 FASB ASC Topic 460, _Guarantees_

ASC 606 FASB ASC Topic 606, _Revenue from Contracts with Customers_

ASC 740 FASB ASC Topic 740, _Income Taxes_

ASC 805 FASB ASC Topic 805, _Business Combinations_

ASC 810 FASB ASC Topic 810, _Consolidation_

ASC 815 FASB ASC Topic 815, _Derivatives and Hedging_

ASC 825 FASB ASC Topic 825, _Financial Instruments_

ASC 830 FASB ASC Topic 830, _Foreign Currency Matters_

ASC 842 FASB ASC Topic 842, _Leases_

ASC 860 FASB ASC Topic 860, _Transfers and Servicing_

ASC 932 FASB ASC Topic 932, _Extractive Activities_          - _Oil and Gas_

ASC 942 FASB ASC Topic 942, _Financial Services_          - _Depository and Lending_

ASC 944 FASB ASC Topic 944, _Financial Services_          - _Insurance_

ASC 948 FASB ASC Topic 948, _Financial Services_          - _Mortgage Banking_

ASC 954 FASB ASC Topic 954, _Health Care Entities_

**Abbreviation** **Other authoritative standards**

ASU 2014-17 Accounting Standards Update No. 2014-17, _Business Combinations (Topic 805)_

ASU 2013-12 Accounting Standards Update No. 2013-12, _Definition of a Public Business Entity_

ASU 2019-10 Accounting Standards Update No. 2019-10, _Financial Instruments — Credit Losses_
_(Topic 326), Derivatives and Hedging (Topic 815), and Leases (Topic 842):_
_Effective Dates_


**2024 SEC annual reports — Form 10-K** | B-1


---

EY | Building a better working world


EY is building a better working world by creating
new value for clients, people, society and the planet,
while building trust in capital markets.


Enabled by data, AI and advanced technology,
EY teams help clients shape the future with confidence
and develop answers for the most pressing issues of
today and tomorrow.


EY teams work across a full spectrum of services in
assurance, consulting, tax, strategy and transactions.
Fueled by sector insights, a globally connected,
multi-disciplinary network and diverse ecosystem
partners, EY teams can provide services in more than
150 countries and territories.


All in to shape the future with confidence.


EY refers to the global organization, and may refer to one or more,
of the member firms of Ernst & Young Global Limited, each of which
is a separate legal entity. Ernst & Young Global Limited, a UK
company limited by guarantee, does not provide services to clients.
Information about how EY collects and uses personal data and a
description of the rights individuals have under data protection
legislation are available via **[ey.com/privacy](https://www.ey.com/en_us/legal-and-privacy)** . EY member firms do not
practice law where prohibited by local laws. For more information
about our organization, please visit **[ey.com](https://www.ey.com/en_us)** .


Ernst & Young LLP is a client-serving member firm of Ernst & Young
Global Limited operating in the US.


© 2025 Ernst & Young LLP.
All Rights Reserved.


SCORE no. 25291-241US
(Updated 28 May 2025)


This and many of the publications produced by our US Professional
Practice Group, are available free on AccountingLink at
**[ey.com/en_us/technical/accountinglink](https://www.ey.com/en_us/technical/accountinglink)** .


This material has been prepared for general informational purposes only and is not
intended to be relied upon as accounting, tax or other professional advice. Please refer to
your advisors for specific advice.


2024 SEC annual reports — Form 10-K 2

---
*Conversion confidence: 100% (154 pages)*